@@ -2,7 +2,7 @@
  * Routines for ACP133 specific syntaxes in X.500 packet dissection
  * Graeme Lunt 2005
  *
- * $Id: packet-acp133-template.c 27390 2009-02-07 14:33:47Z wmeier $
+ * $Id: packet-acp133-template.c 30516 2009-10-11 16:24:29Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -49,7 +49,7 @@
 #define PFNAME "acp133"
 
 /* Initialize the protocol and registered fields */
-int proto_acp133 = -1;
+static int proto_acp133 = -1;
 
 
 #include "packet-acp133-hf.c"
