@@ -8,7 +8,7 @@
  * Updated to 3GPP TS 29.078 version 7.3.0 Release 7 (2006-06)
  * Built from the gsm-map dissector Copyright 2004, Anders Broman <anders.broman@ericsson.com>
  *
- * $Id: packet-camel-template.c 29727 2009-09-06 05:29:51Z krj $
+ * $Id: packet-camel-template.c 30516 2009-10-11 16:24:29Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -64,7 +64,7 @@
 #define PFNAME "camel"
 
 /* Initialize the protocol and registered fields */
-int proto_camel = -1;
+static int proto_camel = -1;
 int date_format = 1; /*assume european date format */
 int camel_tap = -1;
 /* Global variables */
