@@ -2,7 +2,7 @@
  * Routines for X.711 CMIP packet dissection
  *   Ronnie Sahlberg 2004
  *
- * $Id: packet-cmip-template.c 29344 2009-08-09 07:36:13Z krj $
+ * $Id: packet-cmip-template.c 30516 2009-10-11 16:24:29Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -49,7 +49,7 @@
 #include "packet-pres.h"
 
 /* Initialize the protocol and registered fields */
-int proto_cmip = -1;
+static int proto_cmip = -1;
 static int hf_cmip_actionType_OID = -1;
 static int hf_cmip_eventType_OID = -1;
 static int hf_cmip_attributeId_OID = -1;
@@ -108,18 +108,14 @@ dissect_cmip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 
 	/* do we have spdu type from the session dissector?  */
 	if( !session ){
-		if(tree){
-			proto_tree_add_text(tree, tvb, 0, -1,
-				"Internal error:can't get spdu type from session dissector.");
-			return;
-		}
+		proto_tree_add_text(tree, tvb, 0, -1,
+			"Internal error:can't get spdu type from session dissector.");
+		return;
 	} else {
 		if(session->spdu_type == 0 ) {
-			if(tree){
-				proto_tree_add_text(tree, tvb, 0, -1,
-					"Internal error:wrong spdu type %x from session dissector.",session->spdu_type);
-				return;
-			}
+			proto_tree_add_text(tree, tvb, 0, -1,
+				"Internal error:wrong spdu type %x from session dissector.",session->spdu_type);
+			return;
 		}
 	}
 
