@@ -2,7 +2,7 @@
  * Routines for X.525 (X.500 Directory Shadow Asbtract Service) and X.519 DISP packet dissection
  * Graeme Lunt 2005
  *
- * $Id: packet-disp-template.c 26750 2008-11-11 15:05:00Z wmeier $
+ * $Id: packet-disp-template.c 30516 2009-10-11 16:24:29Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,7 +30,6 @@
 #include <glib.h>
 #include <epan/packet.h>
 #include <epan/prefs.h>
-#include <epan/conversation.h>
 #include <epan/oids.h>
 #include <epan/asn1.h>
 
@@ -65,7 +64,7 @@ void prefs_register_disp(void); /* forward declaration for use in preferences re
 
 
 /* Initialize the protocol and registered fields */
-int proto_disp = -1;
+static int proto_disp = -1;
 
 static struct SESSION_DATA_STRUCTURE* session = NULL;
 
@@ -108,10 +107,8 @@ dissect_disp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 		item = proto_tree_add_item(parent_tree, proto_disp, tvb, 0, -1, FALSE);
 		tree = proto_item_add_subtree(item, ett_disp);
 	}
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "DISP");
-  	if (check_col(pinfo->cinfo, COL_INFO))
-  		col_clear(pinfo->cinfo, COL_INFO);
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "DISP");
+  	col_clear(pinfo->cinfo, COL_INFO);
 
 	switch(session->ros_op & ROS_OP_MASK) {
 	case (ROS_OP_BIND | ROS_OP_ARGUMENT):	/*  BindInvoke */
