@@ -2,7 +2,7 @@
  * Routines for X.518 (X.500 Distributed Operations)  packet dissection
  * Graeme Lunt 2005
  *
- * $Id: packet-dsp-template.c 29344 2009-08-09 07:36:13Z krj $
+ * $Id: packet-dsp-template.c 30516 2009-10-11 16:24:29Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -58,7 +58,7 @@ void prefs_register_dsp(void); /* forward declaration for use in preferences reg
 
 
 /* Initialize the protocol and registered fields */
-int proto_dsp = -1;
+static int proto_dsp = -1;
 
 static struct SESSION_DATA_STRUCTURE* session = NULL;
 
