@@ -2,7 +2,7 @@
  * Routines for h245 packet dissection
  * Copyright 2004, Anders Broman <anders.broman@ericsson.com>
  *
- * $Id: packet-h245-template.c 29747 2009-09-06 14:25:47Z krj $
+ * $Id: packet-h245-template.c 30516 2009-10-11 16:24:29Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -369,7 +369,7 @@ static void h245_setup_channels(packet_info *pinfo, channel_info_t *upcoming_cha
 }
 
 /* Initialize the protocol and registered fields */
-int proto_h245 = -1;
+static int proto_h245 = -1;
 #include "packet-h245-hf.c"
 
 /* Initialize the subtree pointers */
