@@ -3,7 +3,7 @@
  *
  * See RFC 1777 (LDAP v2), RFC 2251 (LDAP v3), and RFC 2222 (SASL).
  *
- * $Id: packet-ldap-template.c 36103 2011-03-01 01:09:32Z gerald $
+ * $Id: packet-ldap-template.c 30506 2009-10-11 14:21:50Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -92,13 +92,12 @@
 #include <epan/emem.h>
 #include <epan/oids.h>
 #include <epan/strutil.h>
+#include <epan/dissectors/packet-frame.h>
 #include <epan/dissectors/packet-tcp.h>
 #include <epan/dissectors/packet-windows-common.h>
 #include <epan/dissectors/packet-dcerpc.h>
 #include <epan/asn1.h>
-#include <epan/expert.h>
 
-#include "packet-frame.h"
 #include "packet-ldap.h"
 #include "packet-ntlmssp.h"
 #include "packet-ssl.h"
@@ -107,9 +106,7 @@
 #include "packet-ber.h"
 #include "packet-per.h"
 
-#include "packet-dns.h"
-
-#define PNAME  "Lightweight-Directory-Access-Protocol"
+#define PNAME  "Lightweight Directory Access Protocol"
 #define PSNAME "LDAP"
 #define PFNAME "ldap"
 
@@ -140,7 +137,6 @@ static int hf_mscldap_netlogon_ipaddress_port = -1;
 static int hf_mscldap_netlogon_ipaddress = -1;
 static int hf_mscldap_netlogon_ipaddress_ipv4 = -1;
 static int hf_mscldap_netlogon_type = -1;
-static int hf_mscldap_netlogon_length = -1;
 static int hf_mscldap_netlogon_flags = -1;
 static int hf_mscldap_netlogon_flags_pdc = -1;
 static int hf_mscldap_netlogon_flags_gc = -1;
@@ -199,7 +195,7 @@ static const char *object_identifier_id = NULL; /* LDAP OID */
 static gboolean do_protocolop = FALSE;
 static gchar    *attr_type = NULL;
 static gboolean is_binary_attr_type = FALSE;
-static guint32 last_frame_seen = 0;
+static gboolean ldap_found_in_frame = FALSE;
 
 #define TCP_PORT_LDAP			389
 #define TCP_PORT_LDAPS			636
@@ -365,7 +361,7 @@ static int dissect_mscldap_ntver_flags(proto_tree *parent_tree, tvbuff_t *tvb, i
   guint32 flags;
   proto_item *item;
   proto_tree *tree=NULL;
-  guint fields[] = { 
+  guint fields[] = {
 		     hf_mscldap_ntver_flags_v1,
 		     hf_mscldap_ntver_flags_v5,
 		     hf_mscldap_ntver_flags_v5ex,
@@ -377,12 +373,12 @@ static int dissect_mscldap_ntver_flags(proto_tree *parent_tree, tvbuff_t *tvb, i
 		     hf_mscldap_ntver_flags_local,
 		     hf_mscldap_ntver_flags_gc,
 		     0 };
-  
+
   guint  *field;
   header_field_info *hfi;
   gboolean one_bit_set = FALSE;
 
-  flags=tvb_get_letohl(tvb, offset); 
+  flags=tvb_get_letohl(tvb, offset);
   item=proto_tree_add_item(parent_tree, hf_mscldap_ntver_flags, tvb, offset, 4, TRUE);
   if(parent_tree){
     tree = proto_item_add_subtree(item, ett_mscldap_ntver_flags);
@@ -405,8 +401,8 @@ static int dissect_mscldap_ntver_flags(proto_tree *parent_tree, tvbuff_t *tvb, i
 
     }
   }
- 
-  proto_item_append_text(item, ")"); 
+
+  proto_item_append_text(item, ")");
 
   offset += 4;
 
@@ -484,7 +480,7 @@ dissect_ldap_AssertionValue(gboolean implicit_tag, tvbuff_t *tvb, int offset, as
 		len = 0;
 		/* get flag value to populate ldapvalue_string */
 		flags=tvb_get_letohl(tvb, offset);
-		
+
 		ldapvalue_string=ep_alloc(1024);
 		g_snprintf(ldapvalue_string, 1023, "0x%08x",flags);
 
@@ -550,12 +546,6 @@ static char *substring_item_final=NULL;
 static char *matching_rule_string=NULL;
 static gboolean matching_rule_dnattr=FALSE;
 
-#define MAX_FILTER_LEN 4096
-static gint Filter_length;
-
-#define MAX_FILTER_ELEMENTS 200
-static gint Filter_elements;
-
 /* Global variables */
 char *mechanism = NULL;
 static gint MessageID =-1;
@@ -571,8 +561,7 @@ static void ldap_do_protocolop(packet_info *pinfo)
 
     valstr = val_to_str(ProtocolOp, ldap_ProtocolOp_choice_vals, "Unknown (%%u)");
 
-    if(check_col(pinfo->cinfo, COL_INFO))
-      col_append_fstr(pinfo->cinfo, COL_INFO, "%s(%u) ", valstr, MessageID);
+    col_append_fstr(pinfo->cinfo, COL_INFO, "%s(%u) ", valstr, MessageID);
 
     if(ldm_tree)
       proto_item_append_text(ldm_tree, " %s(%d)", valstr, MessageID);
@@ -814,6 +803,12 @@ one_more_pdu:
 
 }
 
+static void
+ldap_frame_end(void)
+{
+   ldap_found_in_frame = FALSE;
+}
+
 static void
 dissect_ldap_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean is_mscldap)
 {
@@ -865,7 +860,7 @@ dissect_ldap_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean i
     ldap_info_items = ldap_info;
 
   }
-  
+
   switch (ldap_info->auth_type) {
     case LDAP_AUTH_SASL:
     /*
@@ -897,18 +892,17 @@ dissect_ldap_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean i
      * This is the first PDU, set the Protocol column and clear the
      * Info column.
      */
-    if (check_col(pinfo->cinfo, COL_PROTOCOL)) col_set_str(pinfo->cinfo, COL_PROTOCOL, pinfo->current_proto);
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, pinfo->current_proto);
 
-    if(last_frame_seen == pinfo->fd->num) {
+    if(ldap_found_in_frame) {
       /* we have already dissected an ldap PDU in this frame - add a separator and set a fence */
-      if (check_col(pinfo->cinfo, COL_INFO)) {
-	col_append_str(pinfo->cinfo, COL_INFO, "| ");
-	col_set_fence(pinfo->cinfo, COL_INFO);
-      }
-    } else
-      if (check_col(pinfo->cinfo, COL_INFO)) col_clear(pinfo->cinfo, COL_INFO);
-
-    last_frame_seen = pinfo->fd->num;
+      col_append_str(pinfo->cinfo, COL_INFO, " | ");
+      col_set_fence(pinfo->cinfo, COL_INFO);
+    } else {
+      col_clear(pinfo->cinfo, COL_INFO);
+      register_frame_end_routine (ldap_frame_end);
+      ldap_found_in_frame = TRUE;
+    }
 
     ldap_item = proto_tree_add_item(tree, is_mscldap?proto_cldap:proto_ldap, tvb, 0, -1, FALSE);
     ldap_tree = proto_item_add_subtree(ldap_item, ett_ldap);
@@ -1038,7 +1032,7 @@ dissect_ldap_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean i
 	   */
 	  if (!decr_tvb) {
 	    if(!pinfo->gssapi_data_encrypted){
-	      plain_tvb = tvb_new_subset(gssapi_tvb,  ver_len, -1, -1);
+	      plain_tvb = tvb_new_subset_remaining(gssapi_tvb,  ver_len);
 	    }
 	  }
 
@@ -1050,9 +1044,7 @@ dissect_ldap_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean i
              * The LDAP message was encrypted in the packet, and has
              * been decrypted; dissect the decrypted LDAP message.
              */
-            if (check_col(pinfo->cinfo, COL_INFO)) {
-				col_set_str(pinfo->cinfo, COL_INFO, "SASL GSS-API Privacy (decrypted): ");
-            }
+	    col_set_str(pinfo->cinfo, COL_INFO, "SASL GSS-API Privacy (decrypted): ");
 
             if (sasl_tree) {
 	      enc_item = proto_tree_add_text(sasl_tree, gssapi_tvb, ver_len, -1,
@@ -1070,9 +1062,7 @@ dissect_ldap_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean i
 	     * The LDAP message wasn't encrypted in the packet;
 	     * dissect the plain LDAP message.
              */
-            if (check_col(pinfo->cinfo, COL_INFO)) {
-				col_set_str(pinfo->cinfo, COL_INFO, "SASL GSS-API Integrity: ");
-            }
+	    col_set_str(pinfo->cinfo, COL_INFO, "SASL GSS-API Integrity: ");
 
 	    if (sasl_tree) {
               plain_item = proto_tree_add_text(sasl_tree, gssapi_tvb, ver_len, -1,
@@ -1088,11 +1078,10 @@ dissect_ldap_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean i
              * The LDAP message was encrypted in the packet, and was
              * not decrypted; just show it as encrypted data.
              */
-            if (check_col(pinfo->cinfo, COL_INFO)) {
-        	    col_add_fstr(pinfo->cinfo, COL_INFO, "SASL GSS-API Privacy: payload (%d byte%s)",
-                                 sasl_len - ver_len,
-                                 plurality(sasl_len - ver_len, "", "s"));
-            }
+	    col_add_fstr(pinfo->cinfo, COL_INFO, "SASL GSS-API Privacy: payload (%d byte%s)",
+			 sasl_len - ver_len,
+			 plurality(sasl_len - ver_len, "", "s"));
+
 	    if (sasl_tree) {
               proto_tree_add_text(sasl_tree, gssapi_tvb, ver_len, -1,
                                 "GSS-API Encrypted payload (%d byte%s)",
@@ -1108,23 +1097,67 @@ dissect_ldap_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean i
     }
 }
 
-/*
- * prepend_dot is no longer used, but is being left in place in order to
- * maintain ABI compatibility.
- */
-int dissect_mscldap_string(tvbuff_t *tvb, int offset, char *str, int max_len, gboolean prepend_dot _U_)
+static int dissect_mscldap_string(tvbuff_t *tvb, int offset, char *str, int maxlen, gboolean prepend_dot)
 {
-  int compr_len;
-  const guchar *name;
+  guint8 len;
 
-  /* The name data MUST start at offset 0 of the tvb */
-  compr_len = expand_dns_name(tvb, offset, max_len, 0, &name);
-  g_strlcpy(str, name, max_len);
-  return offset + compr_len;
+  len=tvb_get_guint8(tvb, offset);
+  offset+=1;
+  *str=0;
+
+  while(len){
+    /* add potential field separation dot */
+    if(prepend_dot){
+      if(!maxlen){
+        *str=0;
+        return offset;
+      }
+      maxlen--;
+      *str++='.';
+      *str=0;
+    }
+
+    if(len==0xc0){
+      int new_offset;
+      /* ops its a mscldap compressed string */
+
+      new_offset=tvb_get_guint8(tvb, offset);
+      if (new_offset == offset - 1)
+        THROW(ReportedBoundsError);
+      offset+=1;
+
+      dissect_mscldap_string(tvb, new_offset, str, maxlen, FALSE);
+
+      return offset;
+    }
+
+    prepend_dot=TRUE;
+
+    if(maxlen<=len){
+      if(maxlen>3){
+        *str++='.';
+        *str++='.';
+        *str++='.';
+      }
+      *str=0;
+      return offset; /* will mess up offset in caller, is unlikely */
+    }
+    tvb_memcpy(tvb, str, offset, len);
+    str+=len;
+    *str=0;
+    maxlen-=len;
+    offset+=len;
+
+
+    len=tvb_get_guint8(tvb, offset);
+    offset+=1;
+  }
+  *str=0;
+  return offset;
 }
 
 
-/* These are the cldap DC flags 
+/* These are the cldap DC flags
    http://msdn.microsoft.com/en-us/library/cc201036.aspx
  */
 static const true_false_string tfs_ads_pdc = {
@@ -1192,7 +1225,7 @@ static int dissect_mscldap_netlogon_flags(proto_tree *parent_tree, tvbuff_t *tvb
   guint32 flags;
   proto_item *item;
   proto_tree *tree=NULL;
-  guint fields[] = { 
+  guint fields[] = {
 			 hf_mscldap_netlogon_flags_fnc,
 		     hf_mscldap_netlogon_flags_dnc,
 		     hf_mscldap_netlogon_flags_dns,
@@ -1264,19 +1297,19 @@ static void dissect_NetLogon_PDU(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tr
 
   /* check the len if it is to small return */
   if (len < 10) return;
-  
+
   /* Type */
   itype = tvb_get_letohs(tvb, offset);
 
-  /* get the version number from the end of the buffer, as the 
+  /* get the version number from the end of the buffer, as the
      length is variable and the version determines what fields
 	 need to be decoded */
-  
+
   version = tvb_get_letohl(tvb,len-8);
-  
+
   switch(itype){
-		
-		case LOGON_SAM_LOGON_RESPONSE: 
+
+		case LOGON_SAM_LOGON_RESPONSE:
 			/* Type */
 			proto_tree_add_uint_format(tree, hf_mscldap_netlogon_type, tvb,offset, 2, itype,"Type: LOGON_SAM_LOGON_RESPONSE (19)" );
 			offset = 2;
@@ -1302,7 +1335,7 @@ static void dissect_NetLogon_PDU(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tr
 				/* domain guid */
 				proto_tree_add_item(tree, hf_mscldap_domain_guid, tvb, offset, 16, TRUE);
 				offset += 16;
-				
+
 				/* domain guid part 2
 				   there is another 16 byte guid but this is alway zero, so we will skip it */
 				offset += 16;
@@ -1328,7 +1361,7 @@ static void dissect_NetLogon_PDU(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tr
 
 				/* Flags */
 				offset = dissect_mscldap_netlogon_flags(tree, tvb, offset);
-	
+
 			}
 
 			break;
@@ -1386,26 +1419,26 @@ static void dissect_NetLogon_PDU(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tr
 			old_offset=offset;
 			offset=dissect_mscldap_string(tvb, offset, str, 255, FALSE);
 			proto_tree_add_string(tree, hf_mscldap_clientsitename, tvb, old_offset, offset-old_offset, str);
-			
+
 			/* include the extra fields for version 5 with IP s */
 			if ((version & NETLOGON_NT_VERSION_5EX_WITH_IP) == NETLOGON_NT_VERSION_5EX_WITH_IP){
-				
+
 
 				/* The ip address is returned as a sockaddr_in structure
-				 *  
+				 *
 				 *  This section may need to be updated if the base Windows APIs
 				 *  are changed to support ipv6, which currently is not the case.
 				 *
 				 *  The desector assumes the length is based on ipv4 and
 				 *  ignores the length
 				 */
-				
-				/* skip the length of the sockaddr_in */ 
-				
+
+				/* skip the length of the sockaddr_in */
+
 				offset +=1;
 
 				/* add IP address and desect the sockaddr_in structure */
-				
+
 				old_offset = offset + 4;
 				item = proto_tree_add_ipv4(tree, hf_mscldap_netlogon_ipaddress, tvb, old_offset, 4, tvb_get_ipv4(tvb,old_offset));
 
@@ -1413,15 +1446,15 @@ static void dissect_NetLogon_PDU(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tr
 					proto_tree *subtree;
 
 					subtree = proto_item_add_subtree(item, ett_mscldap_ipdetails);
-					
+
 					/* get sockaddr family */
 					proto_tree_add_item(subtree, hf_mscldap_netlogon_ipaddress_family, tvb, offset, 2, TRUE);
-					offset +=2;		
+					offset +=2;
 
 					/* get sockaddr port */
 					proto_tree_add_item(subtree, hf_mscldap_netlogon_ipaddress_port, tvb, offset, 2, TRUE);
-					offset +=2;	
-					
+					offset +=2;
+
 					/* get IP address */
 					proto_tree_add_ipv4(subtree, hf_mscldap_netlogon_ipaddress_ipv4, tvb, offset, 4, tvb_get_ipv4(tvb,offset));
 					offset +=4;
@@ -1436,14 +1469,14 @@ static void dissect_NetLogon_PDU(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tr
 
 		default:
 			proto_tree_add_uint_format(tree, hf_mscldap_netlogon_type, tvb, offset, 2, itype,"Type: Unknown type (%d)", itype );
-			
-  }				
+
+  }
 
 
  /* complete the decode with the version and token details */
 
   offset = len-8;
- 
+
   /* Version */
   proto_tree_add_item(tree, hf_mscldap_netlogon_version, tvb, offset, 4, TRUE);
   offset += 4;
@@ -1638,11 +1671,11 @@ dissect_ldap_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	gboolean ind;
         conversation_t *conversation;
 	ldap_conv_info_t *ldap_info = NULL;
- 
+
 	/*
 	 * Do we have a conversation for this connection?
 	 */
-	conversation = find_conversation(pinfo->fd->num, 
+	conversation = find_conversation(pinfo->fd->num,
 				&pinfo->src, &pinfo->dst,
 				pinfo->ptype, pinfo->srcport,
 				pinfo->destport, 0);
@@ -1659,19 +1692,19 @@ dissect_ldap_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	 * and performs a few unauthenticated searches of LDAP before
 	 * it performs the bind on the same tcp connection.
 	 */
-	/* check for a SASL header, i.e. assume it is SASL if 
-	 * 1, first four bytes (SASL length) is an integer 
+	/* check for a SASL header, i.e. assume it is SASL if
+	 * 1, first four bytes (SASL length) is an integer
 	 *    with a value that must be <LDAP_SASL_MAX_BUF and >2
 	 *    (>2 to fight false positives, 0x00000000 is a common
 	 *        "random" tcp payload)
-	 * (SASL ldap PDUs might be >64k in size, which is why 
+	 * (SASL ldap PDUs might be >64k in size, which is why
 	 * LDAP_SASL_MAX_BUF is used - defined in packet-ldap.h)
 	 *
 	 * 2, we must have a conversation and the auth type must
 	 *    be LDAP_AUTH_SASL
 	 */
 	sasl_len=tvb_get_ntohl(tvb, 0);
- 
+
 	if( sasl_len<2 ){
 		goto this_was_not_sasl;
 	}
@@ -1679,7 +1712,7 @@ dissect_ldap_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	if( sasl_len>LDAP_SASL_MAX_BUF ){
 		goto this_was_not_sasl;
 	}
-		
+
 	if((!ldap_info) || (ldap_info->auth_type!=LDAP_AUTH_SASL) ){
 		goto this_was_not_sasl;
 	}
@@ -1712,17 +1745,17 @@ this_was_not_sasl:
 this_was_not_normal_ldap:
 
 	/* perhaps it was SSL? */
-	if(ldap_info && 
-	   ldap_info->start_tls_frame && 
+	if(ldap_info &&
+	   ldap_info->start_tls_frame &&
 	   ( pinfo->fd->num >= ldap_info->start_tls_frame)) {
 
 	  /* we have started TLS and so this may be an SSL layer */
 	  guint32 old_start_tls_frame;
 
 	  /* temporarily dissect this port as SSL */
-	  dissector_delete("tcp.port", tcp_port, ldap_handle); 
+	  dissector_delete("tcp.port", tcp_port, ldap_handle);
 	  ssl_dissector_add(tcp_port, "ldap", TRUE);
-    
+
 	  old_start_tls_frame = ldap_info->start_tls_frame;
 	  ldap_info->start_tls_frame = 0; /* make sure we don't call SSL again */
 	  pinfo->can_desegment++; /* ignore this LDAP layer so SSL can use the TCP resegment */
@@ -1769,8 +1802,6 @@ ldap_reinit(void)
   }
 
   ldap_info_items = NULL;
-  last_frame_seen = 0;
-
 }
 
 void
@@ -1796,22 +1827,22 @@ void proto_register_ldap(void) {
 
   static hf_register_info hf[] = {
 
-	  	{ &hf_ldap_sasl_buffer_length,
-		  { "SASL Buffer Length",	"ldap.sasl_buffer_length",
-			FT_UINT32, BASE_DEC, NULL, 0x0,
-			"SASL Buffer Length", HFILL }},
-	    { &hf_ldap_response_in,
-	      { "Response In", "ldap.response_in",
-	        FT_FRAMENUM, BASE_DEC, NULL, 0x0,
-	        "The response to this LDAP request is in this frame", HFILL }},
-	    { &hf_ldap_response_to,
-	      { "Response To", "ldap.response_to",
-	        FT_FRAMENUM, BASE_DEC, NULL, 0x0,
-	        "This is a response to the LDAP request in this frame", HFILL }},
-	    { &hf_ldap_time,
-	      { "Time", "ldap.time",
-	        FT_RELATIVE_TIME, BASE_NONE, NULL, 0x0,
-	        "The time between the Call and the Reply", HFILL }},
+    { &hf_ldap_sasl_buffer_length,
+      { "SASL Buffer Length",   "ldap.sasl_buffer_length",
+        FT_UINT32, BASE_DEC, NULL, 0x0,
+        NULL, HFILL }},
+    { &hf_ldap_response_in,
+      { "Response In", "ldap.response_in",
+        FT_FRAMENUM, BASE_NONE, NULL, 0x0,
+        "The response to this LDAP request is in this frame", HFILL }},
+    { &hf_ldap_response_to,
+      { "Response To", "ldap.response_to",
+        FT_FRAMENUM, BASE_NONE, NULL, 0x0,
+        "This is a response to the LDAP request in this frame", HFILL }},
+    { &hf_ldap_time,
+      { "Time", "ldap.time",
+        FT_RELATIVE_TIME, BASE_NONE, NULL, 0x0,
+        "The time between the Call and the Reply", HFILL }},
 
     { &hf_mscldap_netlogon_type,
       { "Type", "mscldap.netlogon.type",
@@ -1821,57 +1852,57 @@ void proto_register_ldap(void) {
     { &hf_mscldap_netlogon_version,
       { "Version", "mscldap.netlogon.version",
         FT_UINT32, BASE_DEC, NULL, 0x0,
-        "Version", HFILL }},
+        NULL, HFILL }},
 
     { &hf_mscldap_netlogon_ipaddress_family,
       { "Family", "mscldap.netlogon.ipaddress.family",
         FT_UINT16, BASE_DEC, NULL, 0x0,
-        "Family", HFILL }},
+        NULL, HFILL }},
 
     { &hf_mscldap_netlogon_ipaddress_ipv4,
       { "IPv4", "mscldap.netlogon.ipaddress.ipv4",
-        FT_IPv4, BASE_DEC, NULL, 0x0,
+        FT_IPv4, BASE_NONE, NULL, 0x0,
         "IP Address", HFILL }},
 
-	{ &hf_mscldap_netlogon_ipaddress_port,
+    { &hf_mscldap_netlogon_ipaddress_port,
       { "Port", "mscldap.netlogon.ipaddress.port",
         FT_UINT16, BASE_DEC, NULL, 0x0,
-        "Port", HFILL }},
+        NULL, HFILL }},
 
-	{ &hf_mscldap_netlogon_ipaddress,
+    { &hf_mscldap_netlogon_ipaddress,
       { "IP Address","mscldap.netlogon.ipaddress",
-		FT_IPv4, BASE_NONE, NULL, 0x0,
-			"Domain Controller IP Address ", HFILL }},
+        FT_IPv4, BASE_NONE, NULL, 0x0,
+        "Domain Controller IP Address", HFILL }},
 
     { &hf_mscldap_netlogon_lm_token,
       { "LM Token", "mscldap.netlogon.lm_token",
         FT_UINT16, BASE_HEX, NULL, 0x0,
-        "LM Token", HFILL }},
+        NULL, HFILL }},
 
     { &hf_mscldap_netlogon_nt_token,
       { "NT Token", "mscldap.netlogon.nt_token",
         FT_UINT16, BASE_HEX, NULL, 0x0,
-        "NT Token", HFILL }},
+        NULL, HFILL }},
 
     { &hf_mscldap_netlogon_flags,
       { "Flags", "mscldap.netlogon.flags",
         FT_UINT32, BASE_HEX, NULL, 0x0,
         "Netlogon flags describing the DC properties", HFILL }},
-    
-	{ &hf_mscldap_ntver_flags,
+
+    { &hf_mscldap_ntver_flags,
       { "Search Flags", "mscldap.ntver.searchflags",
         FT_UINT32, BASE_HEX, NULL, 0x0,
         "cldap Netlogon request flags", HFILL }},
-	
-	{ &hf_mscldap_domain_guid,
+
+    { &hf_mscldap_domain_guid,
       { "Domain GUID", "mscldap.domain.guid",
-        FT_BYTES, BASE_HEX, NULL, 0x0,
-        "Domain GUID", HFILL }},
+        FT_BYTES, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     { &hf_mscldap_forest,
       { "Forest", "mscldap.forest",
         FT_STRING, BASE_NONE, NULL, 0x0,
-        "Forest", HFILL }},
+        NULL, HFILL }},
 
     { &hf_mscldap_domain,
       { "Domain", "mscldap.domain",
@@ -1881,7 +1912,7 @@ void proto_register_ldap(void) {
     { &hf_mscldap_hostname,
       { "Hostname", "mscldap.hostname",
         FT_STRING, BASE_NONE, NULL, 0x0,
-        "Hostname", HFILL }},
+        NULL, HFILL }},
 
     { &hf_mscldap_nb_domain,
       { "NetBios Domain", "mscldap.nb_domain",
@@ -1891,7 +1922,7 @@ void proto_register_ldap(void) {
     { &hf_mscldap_nb_hostname,
       { "NetBios Hostname", "mscldap.nb_hostname",
         FT_STRING, BASE_NONE, NULL, 0x0,
-        "NetBios Hostname", HFILL }},
+        NULL, HFILL }},
 
     { &hf_mscldap_username,
       { "Username", "mscldap.username",
@@ -1911,49 +1942,49 @@ void proto_register_ldap(void) {
     { &hf_ldap_sid,
       { "Sid", "ldap.sid",
         FT_STRING, BASE_NONE, NULL, 0x0,
-        "Sid", HFILL }},
+        NULL, HFILL }},
 
-	{ &hf_mscldap_ntver_flags_v5cs,
+    { &hf_mscldap_ntver_flags_v5cs,
       { "V5CS", "mscldap.ntver.searchflags.v5cs", FT_BOOLEAN, 32,
-        TFS(&tfs_ntver_v5cs), 0x00000010, "", HFILL }},
+        TFS(&tfs_ntver_v5cs), 0x00000010, NULL, HFILL }},
 
-	{ &hf_mscldap_ntver_flags_v5ip,
+    { &hf_mscldap_ntver_flags_v5ip,
       { "V5IP", "mscldap.ntver.searchflags.v5ip", FT_BOOLEAN, 32,
-        TFS(&tfs_ntver_v5ip), 0x00000008, "", HFILL }},
+        TFS(&tfs_ntver_v5ip), 0x00000008, NULL, HFILL }},
 
-	{ &hf_mscldap_ntver_flags_v5ex,
+    { &hf_mscldap_ntver_flags_v5ex,
       { "V5EX", "mscldap.ntver.searchflags.v5ex", FT_BOOLEAN, 32,
-        TFS(&tfs_ntver_v5ex), 0x00000004, "", HFILL }},
+        TFS(&tfs_ntver_v5ex), 0x00000004, NULL, HFILL }},
 
-	{ &hf_mscldap_ntver_flags_v5,
+    { &hf_mscldap_ntver_flags_v5,
       { "V5", "mscldap.ntver.searchflags.v5", FT_BOOLEAN, 32,
-        TFS(&tfs_ntver_v5), 0x00000002, "", HFILL }},
+        TFS(&tfs_ntver_v5), 0x00000002, NULL, HFILL }},
 
-	{ &hf_mscldap_ntver_flags_v1,
+    { &hf_mscldap_ntver_flags_v1,
       { "V1", "mscldap.ntver.searchflags.v1", FT_BOOLEAN, 32,
-        TFS(&tfs_ntver_v1), 0x00000001, "", HFILL }},
+        TFS(&tfs_ntver_v1), 0x00000001, NULL, HFILL }},
 
-	{ &hf_mscldap_ntver_flags_gc,
+    { &hf_mscldap_ntver_flags_gc,
       { "GC", "mscldap.ntver.searchflags.gc", FT_BOOLEAN, 32,
-        TFS(&tfs_ntver_gc), 0x80000000, "", HFILL }},
+        TFS(&tfs_ntver_gc), 0x80000000, NULL, HFILL }},
 
-	{ &hf_mscldap_ntver_flags_local,
+    { &hf_mscldap_ntver_flags_local,
       { "Local", "mscldap.ntver.searchflags.local", FT_BOOLEAN, 32,
-        TFS(&tfs_ntver_local), 0x40000000, "", HFILL }},
+        TFS(&tfs_ntver_local), 0x40000000, NULL, HFILL }},
 
-	{ &hf_mscldap_ntver_flags_ip,
+    { &hf_mscldap_ntver_flags_ip,
       { "IP", "mscldap.ntver.searchflags.ip", FT_BOOLEAN, 32,
-        TFS(&tfs_ntver_ip), 0x20000000, "", HFILL }},
-	
-	{ &hf_mscldap_ntver_flags_pdc,
+        TFS(&tfs_ntver_ip), 0x20000000, NULL, HFILL }},
+
+    { &hf_mscldap_ntver_flags_pdc,
       { "PDC", "mscldap.ntver.searchflags.pdc", FT_BOOLEAN, 32,
-        TFS(&tfs_ntver_pdc), 0x10000000, "", HFILL }},
+        TFS(&tfs_ntver_pdc), 0x10000000, NULL, HFILL }},
 
-	{ &hf_mscldap_ntver_flags_nt4,
+    { &hf_mscldap_ntver_flags_nt4,
       { "NT4", "mscldap.ntver.searchflags.nt4", FT_BOOLEAN, 32,
-        TFS(&tfs_ntver_nt4), 0x01000000, "", HFILL }},
+        TFS(&tfs_ntver_nt4), 0x01000000, NULL, HFILL }},
 
-	{ &hf_mscldap_netlogon_flags_pdc,
+    { &hf_mscldap_netlogon_flags_pdc,
       { "PDC", "mscldap.netlogon.flags.pdc", FT_BOOLEAN, 32,
         TFS(&tfs_ads_pdc), 0x00000001, "Is this DC a PDC or not?", HFILL }},
 
@@ -1993,15 +2024,15 @@ void proto_register_ldap(void) {
       { "NDNC", "mscldap.netlogon.flags.ndnc", FT_BOOLEAN, 32,
         TFS(&tfs_ads_ndnc), 0x00000400, "Is this an NDNC dc?", HFILL }},
 
-	{ &hf_mscldap_netlogon_flags_rodc,
+    { &hf_mscldap_netlogon_flags_rodc,
       { "RODC", "mscldap.netlogon.flags.rodc", FT_BOOLEAN, 32,
         TFS(&tfs_ads_rodc), 0x00000800, "Is this an read only dc?", HFILL }},
 
-	{ &hf_mscldap_netlogon_flags_wdc,
+    { &hf_mscldap_netlogon_flags_wdc,
       { "WDC", "mscldap.netlogon.flags.writabledc.", FT_BOOLEAN, 32,
         TFS(&tfs_ads_wdc), 0x00001000, "Is this an writable dc (Windows 2008)?", HFILL }},
 
-	{ &hf_mscldap_netlogon_flags_dns,
+    { &hf_mscldap_netlogon_flags_dns,
       { "DNS", "mscldap.netlogon.flags.dnsname", FT_BOOLEAN, 32,
         TFS(&tfs_ads_dns), 0x20000000, "Does the server have a dns name (Windows 2008)?", HFILL }},
 
@@ -2015,34 +2046,34 @@ void proto_register_ldap(void) {
 
     { &hf_ldap_guid,
       { "GUID", "ldap.guid", FT_GUID, BASE_NONE,
-        NULL, 0, "GUID", HFILL }},
+        NULL, 0, NULL, HFILL }},
 
-    { &hf_ldap_AccessMask_ADS_CREATE_CHILD, 
-	  { "Create Child", "ldap.AccessMask.ADS_CREATE_CHILD", FT_BOOLEAN, 32, TFS(&ldap_AccessMask_ADS_CREATE_CHILD_tfs), LDAP_ACCESSMASK_ADS_CREATE_CHILD, "", HFILL }},
+    { &hf_ldap_AccessMask_ADS_CREATE_CHILD,
+      { "Create Child", "ldap.AccessMask.ADS_CREATE_CHILD", FT_BOOLEAN, 32, TFS(&ldap_AccessMask_ADS_CREATE_CHILD_tfs), LDAP_ACCESSMASK_ADS_CREATE_CHILD, NULL, HFILL }},
 
-    { &hf_ldap_AccessMask_ADS_DELETE_CHILD, 
-	  { "Delete Child", "ldap.AccessMask.ADS_DELETE_CHILD", FT_BOOLEAN, 32, TFS(&ldap_AccessMask_ADS_DELETE_CHILD_tfs), LDAP_ACCESSMASK_ADS_DELETE_CHILD, "", HFILL }},
+    { &hf_ldap_AccessMask_ADS_DELETE_CHILD,
+      { "Delete Child", "ldap.AccessMask.ADS_DELETE_CHILD", FT_BOOLEAN, 32, TFS(&ldap_AccessMask_ADS_DELETE_CHILD_tfs), LDAP_ACCESSMASK_ADS_DELETE_CHILD, NULL, HFILL }},
 
-    { &hf_ldap_AccessMask_ADS_LIST, 
-	  { "List", "ldap.AccessMask.ADS_LIST", FT_BOOLEAN, 32, TFS(&ldap_AccessMask_ADS_LIST_tfs), LDAP_ACCESSMASK_ADS_LIST, "", HFILL }},
+    { &hf_ldap_AccessMask_ADS_LIST,
+      { "List", "ldap.AccessMask.ADS_LIST", FT_BOOLEAN, 32, TFS(&ldap_AccessMask_ADS_LIST_tfs), LDAP_ACCESSMASK_ADS_LIST, NULL, HFILL }},
 
-    { &hf_ldap_AccessMask_ADS_SELF_WRITE, 
-	  { "Self Write", "ldap.AccessMask.ADS_SELF_WRITE", FT_BOOLEAN, 32, TFS(&ldap_AccessMask_ADS_SELF_WRITE_tfs), LDAP_ACCESSMASK_ADS_SELF_WRITE, "", HFILL }},
+    { &hf_ldap_AccessMask_ADS_SELF_WRITE,
+      { "Self Write", "ldap.AccessMask.ADS_SELF_WRITE", FT_BOOLEAN, 32, TFS(&ldap_AccessMask_ADS_SELF_WRITE_tfs), LDAP_ACCESSMASK_ADS_SELF_WRITE, NULL, HFILL }},
 
-    { &hf_ldap_AccessMask_ADS_READ_PROP, 
-	  { "Read Prop", "ldap.AccessMask.ADS_READ_PROP", FT_BOOLEAN, 32, TFS(&ldap_AccessMask_ADS_READ_PROP_tfs), LDAP_ACCESSMASK_ADS_READ_PROP, "", HFILL }},
+    { &hf_ldap_AccessMask_ADS_READ_PROP,
+      { "Read Prop", "ldap.AccessMask.ADS_READ_PROP", FT_BOOLEAN, 32, TFS(&ldap_AccessMask_ADS_READ_PROP_tfs), LDAP_ACCESSMASK_ADS_READ_PROP, NULL, HFILL }},
 
-    { &hf_ldap_AccessMask_ADS_WRITE_PROP, 
-	  { "Write Prop", "ldap.AccessMask.ADS_WRITE_PROP", FT_BOOLEAN, 32, TFS(&ldap_AccessMask_ADS_WRITE_PROP_tfs), LDAP_ACCESSMASK_ADS_WRITE_PROP, "", HFILL }},
+    { &hf_ldap_AccessMask_ADS_WRITE_PROP,
+      { "Write Prop", "ldap.AccessMask.ADS_WRITE_PROP", FT_BOOLEAN, 32, TFS(&ldap_AccessMask_ADS_WRITE_PROP_tfs), LDAP_ACCESSMASK_ADS_WRITE_PROP, NULL, HFILL }},
 
-    { &hf_ldap_AccessMask_ADS_DELETE_TREE, 
-	  { "Delete Tree", "ldap.AccessMask.ADS_DELETE_TREE", FT_BOOLEAN, 32, TFS(&ldap_AccessMask_ADS_DELETE_TREE_tfs), LDAP_ACCESSMASK_ADS_DELETE_TREE, "", HFILL }},
+    { &hf_ldap_AccessMask_ADS_DELETE_TREE,
+      { "Delete Tree", "ldap.AccessMask.ADS_DELETE_TREE", FT_BOOLEAN, 32, TFS(&ldap_AccessMask_ADS_DELETE_TREE_tfs), LDAP_ACCESSMASK_ADS_DELETE_TREE, NULL, HFILL }},
 
-    { &hf_ldap_AccessMask_ADS_LIST_OBJECT, 
-	  { "List Object", "ldap.AccessMask.ADS_LIST_OBJECT", FT_BOOLEAN, 32, TFS(&ldap_AccessMask_ADS_LIST_OBJECT_tfs), LDAP_ACCESSMASK_ADS_LIST_OBJECT, "", HFILL }},
+    { &hf_ldap_AccessMask_ADS_LIST_OBJECT,
+      { "List Object", "ldap.AccessMask.ADS_LIST_OBJECT", FT_BOOLEAN, 32, TFS(&ldap_AccessMask_ADS_LIST_OBJECT_tfs), LDAP_ACCESSMASK_ADS_LIST_OBJECT, NULL, HFILL }},
 
-    { &hf_ldap_AccessMask_ADS_CONTROL_ACCESS, 
-	  { "Control Access", "ldap.AccessMask.ADS_CONTROL_ACCESS", FT_BOOLEAN, 32, TFS(&ldap_AccessMask_ADS_CONTROL_ACCESS_tfs), LDAP_ACCESSMASK_ADS_CONTROL_ACCESS, "", HFILL }},
+    { &hf_ldap_AccessMask_ADS_CONTROL_ACCESS,
+      { "Control Access", "ldap.AccessMask.ADS_CONTROL_ACCESS", FT_BOOLEAN, 32, TFS(&ldap_AccessMask_ADS_CONTROL_ACCESS_tfs), LDAP_ACCESSMASK_ADS_CONTROL_ACCESS, NULL, HFILL }},
 
 #include "packet-ldap-hfarr.c"
   };
@@ -2159,6 +2190,10 @@ proto_reg_handoff_ldap(void)
 	oid_add_from_string("LDAP_START_TLS_OID","1.3.6.1.4.1.1466.20037");
 	oid_add_from_string("LDAP_CONTROL_VLVREQUEST VLV","2.16.840.1.113730.3.4.9");
 	oid_add_from_string("LDAP_CONTROL_VLVRESPONSE VLV","2.16.840.1.113730.3.4.10");
+	oid_add_from_string("LDAP_SERVER_QUOTA_CONTROL_OID","1.2.840.113556.1.4.1852");
+	oid_add_from_string("LDAP_SERVER_RANGE_OPTION_OID","1.2.840.113556.1.4.802");
+	oid_add_from_string("LDAP_SERVER_SHUTDOWN_NOTIFY_OID","1.2.840.113556.1.4.1907");
+	oid_add_from_string("LDAP_SERVER_RANGE_RETRIEVAL_NOERR_OID","1.2.840.113556.1.4.1948");
 
 	register_ldap_name_dissector("netlogon", dissect_NetLogon_PDU, proto_cldap);
 	register_ldap_name_dissector("objectGUID", dissect_ldap_guid, proto_ldap);
@@ -2168,7 +2203,7 @@ proto_reg_handoff_ldap(void)
 	register_ldap_name_dissector("nTSecurityDescriptor", dissect_ldap_nt_sec_desc, proto_ldap);
 
 #include "packet-ldap-dis-tab.c"
-	
+
 
 }
 
@@ -2181,7 +2216,7 @@ void prefs_register_ldap(void) {
     /* Set our port number for future use */
     tcp_port = global_ldap_tcp_port;
 
-    if(tcp_port) 
+    if(tcp_port)
       dissector_add("tcp.port", tcp_port, ldap_handle);
 
   }
@@ -2193,7 +2228,7 @@ void prefs_register_ldap(void) {
     /* Set our port number for future use */
     ssl_port = global_ldaps_tcp_port;
 
-    if(ssl_port) 
+    if(ssl_port)
       ssl_dissector_add(ssl_port, "ldap", TRUE);
   }
 
