@@ -2,7 +2,7 @@
  * Routines for RFC2634 Extended Security Services packet dissection
  *   Ronnie Sahlberg 2004
  *
- * $Id: packet-pkixtsp-template.c 23252 2007-10-23 05:50:00Z etxrab $
+ * $Id: packet-pkixtsp-template.c 30124 2009-09-24 19:50:43Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -64,14 +64,9 @@ dissect_timestamp_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tr
 	asn1_ctx_t asn1_ctx;
 	asn1_ctx_init(&asn1_ctx, ASN1_ENC_BER, TRUE, pinfo);
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL)) 
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "PKIXTSP");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "PKIXTSP");
 
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_clear(pinfo->cinfo, COL_INFO);
-		
-		col_set_str(pinfo->cinfo, COL_INFO, "Reply");
-	}
+	col_set_str(pinfo->cinfo, COL_INFO, "Reply");
 
 
 	if(parent_tree){
@@ -90,14 +85,9 @@ dissect_timestamp_query(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tr
 	asn1_ctx_t asn1_ctx;
 	asn1_ctx_init(&asn1_ctx, ASN1_ENC_BER, TRUE, pinfo);
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL)) 
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "PKIXTSP");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "PKIXTSP");
 
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_clear(pinfo->cinfo, COL_INFO);
-		
-		col_set_str(pinfo->cinfo, COL_INFO, "Query");
-	}
+	col_set_str(pinfo->cinfo, COL_INFO, "Query");
 
 
 	if(parent_tree){
@@ -144,6 +134,6 @@ void proto_reg_handoff_pkixtsp(void) {
 	timestamp_query_handle = new_create_dissector_handle(dissect_timestamp_query, proto_pkixtsp);
 	dissector_add_string("media_type", "application/timestamp-query", timestamp_query_handle);
 
-/*#include "packet-pkixtsp-dis-tab.c"*/
+#include "packet-pkixtsp-dis-tab.c"
 }
 
