@@ -2,7 +2,7 @@
  * Routines for QSIG packet dissection
  * 2007  Tomas Kukosa
  *
- * $Id: packet-qsig-template.c 28826 2009-06-24 01:40:54Z stig $
+ * $Id: packet-qsig-template.c 30516 2009-10-11 16:24:29Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -278,7 +278,7 @@ static const value_string qsig_str_error[] = {
 };
                      
 /* Initialize the protocol and registered fields */
-int proto_qsig = -1;
+static int proto_qsig = -1;
 static int hf_qsig_operation = -1;
 static int hf_qsig_service = -1;
 static int hf_qsig_error = -1;
