@@ -3,7 +3,7 @@
  * Copyright 2004 - 2005, Tim Endean <endeant@hotmail.com>
  * Built from the gsm-map dissector Copyright 2004 - 2005, Anders Broman <anders.broman@ericsson.com>
  *
- * $Id: packet-tcap-template.c 29500 2009-08-21 20:32:50Z krj $
+ * $Id: packet-tcap-template.c 30516 2009-10-11 16:24:29Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -47,7 +47,7 @@
 #define PFNAME "tcap"
 
 /* Initialize the protocol and registered fields */
-int proto_tcap = -1;
+static int proto_tcap = -1;
 static int hf_tcap_tag = -1;
 static int hf_tcap_length = -1;
 static int hf_tcap_data = -1;
