@@ -2,7 +2,7 @@
  * Routines for X.420 (X.400 Message Transfer)  packet dissection
  * Graeme Lunt 2005
  *
- * $Id: packet-x420-template.c 27390 2009-02-07 14:33:47Z wmeier $
+ * $Id: packet-x420-template.c 30516 2009-10-11 16:24:29Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -52,7 +52,7 @@
 #define PFNAME "x420"
 
 /* Initialize the protocol and registered fields */
-int proto_x420 = -1;
+static int proto_x420 = -1;
 
 static const char *object_identifier_id; /* content type identifier */
 
@@ -110,10 +110,8 @@ dissect_x420(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 		tree = proto_item_add_subtree(item, ett_x420);
 	}
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "P22");
-	if (check_col(pinfo->cinfo, COL_INFO))
-	  col_set_str(pinfo->cinfo, COL_INFO, "InterPersonal");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "P22");
+	col_set_str(pinfo->cinfo, COL_INFO, "InterPersonal");
 
 	dissect_x420_InformationObject(TRUE, tvb, offset, &asn1_ctx , tree, -1);
 }
