@@ -1,7 +1,7 @@
 /* capture_sync.h
  * Synchronisation between Wireshark capture parent and child instances
  *
- * $Id: capture_sync.h 24407 2008-02-21 12:30:26Z guy $
+ * $Id: capture_sync.h 25556 2008-06-23 21:27:37Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -81,7 +81,7 @@ sync_interface_stats_close(int *read_fd, int *fork_child, gchar **msg);
 
 /** Read a line from a pipe, similar to fgets.  Non-blocking. */
 extern int
-sync_pipe_gets_nonblock(int pipe, char *bytes, int max);
+sync_pipe_gets_nonblock(int pipe_fd, char *bytes, int max);
 
 
 #endif /* capture_sync.h */
