@@ -1,7 +1,7 @@
 /* cfile.h
  * capture_file definition & GUI-independent manipulation
  *
- * $Id: cfile.h 29187 2009-07-24 13:50:57Z etxrab $
+ * $Id: cfile.h 30073 2009-09-22 16:53:11Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -49,7 +49,6 @@ typedef struct _capture_file {
   gint64       f_datalen;       /* Size of capture file data (uncompressed) */
   guint16      cd_t;            /* File type of capture file */
   int          lnk_t;           /* Link-layer type with which to save capture */
-  guint32      vers;            /* Version.  For tcpdump minor is appended to major */
   int          count;           /* Total number of frames */
   int          displayed_count; /* Number of displayed frames */
   int          marked_count;    /* Number of marked frames */
@@ -75,7 +74,7 @@ typedef struct _capture_file {
   /* packet data */
   union wtap_pseudo_header pseudo_header; /* Packet pseudo_header */
   guint8       pd[WTAP_MAX_PACKET_SIZE];  /* Packet data */
-  /* memory chunks have been deprecated in favor of the slice allocator, 
+  /* memory chunks have been deprecated in favor of the slice allocator,
    * which has been added in 2.10
    */
 #if GLIB_CHECK_VERSION(2,10,0)
@@ -83,7 +82,7 @@ typedef struct _capture_file {
 #else
   GMemChunk   *plist_chunk;     /* Memory chunk for frame_data structures */
 #endif
-  frame_data  *plist;           /* Packet list */
+  frame_data  *plist_start;     /* Packet list */
   frame_data  *plist_end;       /* Last packet in list */
   frame_data  *first_displayed; /* First frame displayed */
   frame_data  *last_displayed;  /* Last frame displayed */
@@ -92,9 +91,10 @@ typedef struct _capture_file {
   gint         current_row;     /* Row number for current frame */
   epan_dissect_t *edt;          /* Protocol dissection for currently selected packet */
   field_info  *finfo_selected;	/* Field info for currently selected field */
-  struct ph_stats_s* pstats;    /* accumulated stats (reset on redisplay in GUI)*/
 } capture_file;
 
-void init_cap_file(capture_file *);
+void cap_file_init(capture_file *cf);
+
+void cap_file_add_fdata(capture_file *cf, frame_data *fdata);
 
 #endif /* cfile.h */
