@@ -1,7 +1,7 @@
 /* Edit capture files.  We can delete packets, adjust timestamps, or
  * simply convert from one format to another format.
  *
- * $Id: editcap.c 33544 2010-07-15 21:30:11Z gerald $
+ * $Id: editcap.c 30698 2009-10-25 20:18:24Z gerald $
  *
  * Originally written by Richard Sharpe.
  * Improved by Guy Harris.
@@ -42,8 +42,10 @@
 
 #include "wtap.h"
 
-#ifdef NEED_GETOPT_H
-#include "getopt.h"
+#ifdef HAVE_GETOPT_H
+#include <getopt.h>
+#else
+#include "wsgetopt.h"
 #endif
 
 #ifdef _WIN32
@@ -573,7 +575,7 @@ usage(void)
 {
   fprintf(stderr, "Editcap %s"
 #ifdef SVNVERSION
-	  " (" SVNVERSION ")"
+	  " (" SVNVERSION " from " SVNPATH ")"
 #endif
 	  "\n", VERSION);
   fprintf(stderr, "Edit and/or translate the format of capture files.\n");
@@ -641,7 +643,7 @@ static void
 list_capture_types(void) {
     int i;
 
-    fprintf(stderr, "editcap: The available capture file types for \"F\":\n");
+    fprintf(stderr, "editcap: The available capture file types for the \"-F\" flag are:\n");
     for (i = 0; i < WTAP_NUM_FILE_TYPES; i++) {
       if (wtap_dump_can_open(i))
         fprintf(stderr, "    %s - %s\n",
@@ -654,7 +656,7 @@ list_encap_types(void) {
     int i;
     const char *string;
 
-    fprintf(stderr, "editcap: The available encapsulation types for \"T\":\n");
+    fprintf(stderr, "editcap: The available encapsulation types for the \"-T\" flag are:\n");
     for (i = 0; i < WTAP_NUM_ENCAP_TYPES; i++) {
         string = wtap_encap_short_string(i);
         if (string != NULL)
@@ -682,8 +684,6 @@ main(int argc, char *argv[])
   wtap *wth;
   int i, j, err;
   gchar *err_info;
-  extern char *optarg;
-  extern int optind;
   int opt;
   char *p;
   unsigned int snaplen = 0;             /* No limit               */
@@ -996,7 +996,6 @@ main(int argc, char *argv[])
         pdh = wtap_dump_open(filename, out_file_type,
             out_frame_type, wtap_snapshot_length(wth),
             FALSE /* compressed */, &err);
-fprintf(stderr, "pdh1: %p\n", pdh);
         if (pdh == NULL) {  
           fprintf(stderr, "editcap: Can't open or create %s: %s\n", filename,
                   wtap_strerror(err));
@@ -1028,7 +1027,6 @@ fprintf(stderr, "pdh1: %p\n", pdh);
           pdh = wtap_dump_open(filename, out_file_type,
              out_frame_type, wtap_snapshot_length(wth), FALSE /* compressed */, &err);
 
-fprintf(stderr, "pdh2: %p\n", pdh);
           if (pdh == NULL) {
             fprintf(stderr, "editcap: Can't open or create %s: %s\n", filename,
               wtap_strerror(err));
