@@ -1,7 +1,7 @@
 /* packet-3com-njack.c
  * Routines for the disassembly of the 3com NetworkJack management protocol
  *
- * $Id: packet-3com-njack.c 27057 2008-12-19 04:21:08Z wmeier $
+ * $Id: packet-3com-njack.c 30133 2009-09-25 00:29:06Z wmeier $
  *
  * Copyright 2005 Joerg Mayer (see AUTHORS file)
  *
@@ -500,7 +500,7 @@ dissect_tlvs(tvbuff_t *tvb, proto_tree *njack_tree, guint32 offset)
 			offset += tlv_length;
 			break;
 		default:
-			if (tlv_length > 0) {
+			if (tlv_length != 0) {
 				proto_tree_add_item(tlv_tree, hf_njack_tlv_data,
 					tvb, offset, tlv_length, FALSE);
 				offset += tlv_length;
@@ -576,11 +576,9 @@ dissect_njack(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	gint remaining;
 
 	packet_type = tvb_get_guint8(tvb, 5);
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, PROTO_SHORT_NAME);
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_add_str(pinfo->cinfo, COL_INFO, val_to_str(packet_type,
-			njack_type_vals, "Type 0x%02x"));
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, PROTO_SHORT_NAME);
+        if (check_col(pinfo->cinfo, COL_INFO))  
+		col_add_str(pinfo->cinfo, COL_INFO, val_to_str(packet_type, njack_type_vals, "Type 0x%02x"));
 
 	if (tree) {
 		ti = proto_tree_add_item(tree, proto_njack, tvb, offset, -1,
@@ -614,8 +612,7 @@ dissect_njack(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			proto_tree_add_item(njack_tree, hf_njack_setresult, tvb, offset,
 				1, FALSE);
 			offset += 1;
-			if (check_col(pinfo->cinfo, COL_INFO))
-				col_append_fstr(pinfo->cinfo, COL_INFO, ": %s",
+			col_append_fstr(pinfo->cinfo, COL_INFO, ": %s",
 					val_to_str(setresult, njack_setresult_vals, "[0x%02x]"));
 			break;
 		case NJACK_TYPE_GET:
@@ -650,9 +647,9 @@ static gboolean
 test_njack(tvbuff_t *tvb)
 {
 	/* We need at least 'NJ200' + 1 Byte packet type */
-	if ( tvb_length(tvb) < 6 ||
-		    g_ascii_strncasecmp((const char *)tvb_get_ptr(tvb, 0, 5), "NJ200", 5) ) {
-        	return FALSE;
+	if ( (tvb_length(tvb) < 6) ||
+	     (tvb_strncaseeql(tvb, 0, "NJ200", 5) != 0) ) {
+		return FALSE;
 	}
 	return TRUE;
 }
@@ -683,100 +680,100 @@ proto_register_njack(void)
 
 	/* NJACK header */
 		{ &hf_njack_magic,
-		{ "Magic",	"njack.magic", FT_STRING, BASE_DEC, NULL,
-			0x0, "", HFILL }},
+		{ "Magic",	"njack.magic", FT_STRING, BASE_NONE, NULL,
+			0x0, NULL, HFILL }},
 
 		{ &hf_njack_type,
 		{ "Type",	"njack.type", FT_UINT8, BASE_HEX, NULL,
-			0x0, "", HFILL }},
+			0x0, NULL, HFILL }},
 
 	/* TLV fields */
 		{ &hf_njack_tlv_type,
 		{ "TlvType",	"njack.tlv.type", FT_UINT8, BASE_HEX, VALS(njack_cmd_vals),
-			0x0, "", HFILL }},
+			0x0, NULL, HFILL }},
 
 		{ &hf_njack_tlv_length,
 		{ "TlvLength",	"njack.tlv.length", FT_UINT8, BASE_HEX, NULL,
-			0x0, "", HFILL }},
+			0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_data,
                 { "TlvData",   "njack.tlv.data", FT_BYTES, BASE_NONE, NULL,
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_version,
                 { "TlvFwVersion",   "njack.tlv.version", FT_IPv4, BASE_NONE, NULL,
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_snmpwrite,
                 { "TlvTypeSnmpwrite",   "njack.tlv.snmpwrite", FT_UINT8, BASE_DEC, VALS(&njack_snmpwrite),
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_dhcpcontrol,
                 { "TlvTypeDhcpControl",   "njack.tlv.dhcpcontrol", FT_UINT8, BASE_DEC, VALS(&njack_dhcpcontrol),
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_devicemac,
                 { "TlvTypeDeviceMAC",   "njack.tlv.devicemac", FT_ETHER, BASE_NONE, NULL,
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
 		/* XXX dummy entries, to be replaced */
                 { &hf_njack_tlv_typeip,
                 { "TlvTypeIP",   "njack.tlv.typeip", FT_IPv4, BASE_NONE, NULL,
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_typestring,
-                { "TlvTypeString",   "njack.tlv.typestring", FT_STRING, BASE_DEC, NULL,
-                        0x0, "", HFILL }},
+                { "TlvTypeString",   "njack.tlv.typestring", FT_STRING, BASE_NONE, NULL,
+                        0x0, NULL, HFILL }},
 
 		/* 1st tab */
                 { &hf_njack_tlv_scheduling,
                 { "TlvTypeScheduling",   "njack.tlv.scheduling", FT_UINT8, BASE_DEC, VALS(&njack_scheduling),
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_addtagscheme,
                 { "TlvAddTagScheme",   "njack.tlv.addtagscheme", FT_UINT8, BASE_DEC, VALS(&njack_addtagscheme),
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_portingressmode,
                 { "TlvTypePortingressmode",   "njack.tlv.portingressmode", FT_UINT8, BASE_DEC, VALS(&njack_portingressmode),
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_maxframesize,
                 { "TlvTypeMaxframesize",   "njack.tlv.maxframesize", FT_UINT8, BASE_DEC, VALS(&njack_maxframesize),
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_countermode,
                 { "TlvTypeCountermode",   "njack.tlv.countermode", FT_UINT8, BASE_DEC, VALS(&njack_countermode),
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
                 { &hf_njack_tlv_powerforwarding,
                 { "TlvTypePowerforwarding",   "njack.tlv.powerforwarding", FT_UINT8, BASE_DEC, VALS(&njack_powerforwarding),
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
 	/* Type 0x07: set */
 		{ &hf_njack_set_length,
 		{ "SetLength",	"njack.set.length", FT_UINT16, BASE_HEX, NULL,
-			0x0, "", HFILL }},
+			0x0, NULL, HFILL }},
 
 		{ &hf_njack_set_salt,
 		{ "Salt",	"njack.set.salt", FT_UINT32, BASE_HEX, NULL,
-			0x0, "", HFILL }},
+			0x0, NULL, HFILL }},
 
                 { &hf_njack_set_authdata,
                 { "Authdata",   "njack.tlv.authdata", FT_BYTES, BASE_NONE, NULL,
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
 	/* Type 0x08: set result */
                 { &hf_njack_setresult,
                 { "SetResult",   "njack.setresult", FT_UINT8, BASE_HEX, VALS(njack_setresult_vals),
-                        0x0, "", HFILL }},
+                        0x0, NULL, HFILL }},
 
 	/* Type 0x0b get */
 
 	/* Type 0x0c get response */
 		{ &hf_njack_getresp_unknown1,
 		{ "Unknown1",	"njack.getresp.unknown1", FT_UINT8, BASE_HEX, NULL,
-			0x0, "", HFILL }},
+			0x0, NULL, HFILL }},
 
         };
 	static gint *ett[] = {
