@@ -2,7 +2,7 @@
  * Routines for Agent Extensibility (AgentX) Protocol disassembly
  * RFC 2257
  *
- * $Id: packet-agentx.c 27506 2009-02-22 12:01:19Z jake $
+ * $Id: packet-agentx.c 29340 2009-08-09 06:26:46Z krj $
  *
  * Copyright (c) 2005 by Oleg Terletsky <oleg.terletsky@comverse.com>
  *
@@ -805,8 +805,7 @@ static void dissect_agentx_pdu(tvbuff_t *tvb, packet_info *pinfo,
 	NORLEL(flags, packet_id, tvb, 12); offset+=4;
 	NORLEL(flags, payload_len, tvb, 16); offset+=4;
 
-        if (check_col(pinfo->cinfo, COL_PROTOCOL))
-                col_set_str(pinfo->cinfo, COL_PROTOCOL, "AgentX");
+        col_set_str(pinfo->cinfo, COL_PROTOCOL, "AgentX");
 
         if (check_col(pinfo->cinfo, COL_INFO))
                 col_add_fstr(pinfo->cinfo, COL_INFO, "%s: sid=%d, tid=%d, packid=%d, plen=%d",
@@ -918,60 +917,60 @@ proto_register_agentx(void)
   static hf_register_info hf[] = {
 
     { &hf_version,
-      { "Version        ", "agentx.version", FT_UINT8, BASE_DEC, NULL, 0x0,
+      { "Version", "agentx.version", FT_UINT8, BASE_DEC, NULL, 0x0,
         "header version", HFILL }},
 
     { &hf_type,
-      { "Type           ", "agentx.type", FT_UINT8, BASE_DEC, VALS(type_values), 0x0,
+      { "Type", "agentx.type", FT_UINT8, BASE_DEC, VALS(type_values), 0x0,
         "header type", HFILL }},
 
     { &hf_flags,
-      { "Flags          ", "agentx.flags", FT_UINT8, BASE_DEC, NULL, 0x0,
+      { "Flags", "agentx.flags", FT_UINT8, BASE_DEC, NULL, 0x0,
         "header type", HFILL }},
 
     { &hf_session_id,
-      { "sessionID      ", "agentx.session_id", FT_UINT32, BASE_DEC, NULL, 0x0,
+      { "sessionID", "agentx.session_id", FT_UINT32, BASE_DEC, NULL, 0x0,
         "Session ID", HFILL }},
 
     { &hf_trans_id,
-      { "TransactionID  ", "agentx.transaction_id", FT_UINT32, BASE_DEC, NULL, 0x0,
+      { "TransactionID", "agentx.transaction_id", FT_UINT32, BASE_DEC, NULL, 0x0,
         "Transaction ID", HFILL }},
 
     { &hf_packet_id,
-      { "PacketID       ", "agentx.packet_id", FT_UINT32, BASE_DEC, NULL, 0x0,
+      { "PacketID", "agentx.packet_id", FT_UINT32, BASE_DEC, NULL, 0x0,
         "Packet ID", HFILL }},
 
     { &hf_payload_len,
-      { "Payload length ", "agentx.payload_len", FT_UINT32, BASE_DEC, NULL, 0x0,
-        "Payload length", HFILL }},
+      { "Payload length", "agentx.payload_len", FT_UINT32, BASE_DEC, NULL, 0x0,
+        NULL, HFILL }},
 
     { &hf_ostring,
       { "Octet String", "agentx.ostring", FT_STRING, BASE_NONE, NULL, 0x0,
-        "Octet String", HFILL }},
+        NULL, HFILL }},
 
     { &hf_ostring_len,
       { "OString len", "agentx.ostring_len", FT_UINT32, BASE_DEC, NULL, 0x0,
         "Octet String Length", HFILL }},
 
     { &hf_oid_sub,
-      { "Number subids ", "agentx.n_subid", FT_UINT8, BASE_DEC, NULL, 0x0,
-        "Number subids", HFILL }},
+      { "Number subids", "agentx.n_subid", FT_UINT8, BASE_DEC, NULL, 0x0,
+        NULL, HFILL }},
 
     { &hf_oid_prefix,
-      { "OID prefix    ", "agentx.oid_prefix", FT_UINT8, BASE_DEC, NULL, 0x0,
-        "OID prefix", HFILL }},
+      { "OID prefix", "agentx.oid_prefix", FT_UINT8, BASE_DEC, NULL, 0x0,
+        NULL, HFILL }},
 
     { &hf_oid_include,
-      { "OID include   ", "agentx.oid_include", FT_UINT8, BASE_DEC, NULL, 0x0,
-        "OID include", HFILL }},
+      { "OID include", "agentx.oid_include", FT_UINT8, BASE_DEC, NULL, 0x0,
+        NULL, HFILL }},
 
     { &hf_oid_str,
-      { "OID", "agentx.oid", FT_STRING, BASE_DEC, NULL, 0x0,
-        "OID", HFILL }},
+      { "OID", "agentx.oid", FT_STRING, BASE_NONE, NULL, 0x0,
+        NULL, HFILL }},
 
     { &hf_resp_uptime,
       { "sysUpTime", "agentx.r.uptime", FT_UINT32, BASE_DEC, NULL, 0x0,
-        "sysUpTime", HFILL }},
+        NULL, HFILL }},
 
     { &hf_resp_error,
       { "Resp. error", "agentx.r.error", FT_UINT16, BASE_DEC, VALS(resp_errors), 0x0,
@@ -1023,11 +1022,11 @@ proto_register_agentx(void)
 
     { &hf_unreg_prio,
       { "Priority", "agentx.u.priority", FT_UINT8, BASE_DEC, NULL, 0x0,
-        "Unegister Priority", HFILL }},
+        "Unregister Priority", HFILL }},
 
     { &hf_unreg_rsid,
       { "Range_subid", "agentx.u.range_subid", FT_UINT8, BASE_DEC, NULL, 0x0,
-        "Unegister range_subid", HFILL }},
+        "Unregister range_subid", HFILL }},
 
     { &hf_unreg_ubound,
       { "Upper bound", "agentx.u.upper_bound", FT_UINT32, BASE_DEC, NULL, 0x0,
