@@ -2,7 +2,7 @@
  * Routines for AMR dissection
  * Copyright 2005-2008, Anders Broman <anders.broman[at]ericsson.com>
  *
- * $Id: packet-amr.c 26246 2008-09-22 16:26:41Z wmeier $
+ * $Id: packet-amr.c 29499 2009-08-21 20:25:24Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -40,9 +40,10 @@
 #include <epan/packet.h>
 #include <epan/proto.h>
 #include <epan/expert.h>
+#include <epan/oids.h>
 #include <epan/asn1.h>
 
-#include "prefs.h"
+#include <epan/prefs.h>
 
 #define AMR_NB_SID 8
 #define AMR_WB_SID 9
@@ -113,32 +114,32 @@ static const value_string amr_nb_codec_mode_vals[] = {
 	{6,		"AMR 10,2 kbit/s"},
 	{7,		"AMR 12,2 kbit/s (GSM-EFR)"},
 	{AMR_NB_SID,	"AMR SID (Comfort Noise Frame)"},
-	{9,		"GSM-EFR SID"},
-	{10,		"TDMA-EFR SID "},
-	{11,		"PDC-EFR SID"},
-	{12,		"Illegal Frametype - for future use"},
-	{13,		"Illegal Frametype - for future use"},
-	{14,		"Illegal Frametype - for future use"},
+	{9,				"GSM-EFR SID"},
+	{10,			"TDMA-EFR SID "},
+	{11,			"PDC-EFR SID"},
+	{12,			"Illegal Frametype - for future use"},
+	{13,			"Illegal Frametype - for future use"},
+	{14,			"Illegal Frametype - for future use"},
 	{AMR_NO_TRANS,	"No Data (No transmission/No reception)"},
 	{ 0,	NULL }
 };
 
 static const value_string amr_wb_codec_mode_vals[] = {
-	{0, 		"AMR-WB 6.60 kbit/s"},
-	{1, 		"AMR-WB 8.85 kbit/s"},
-	{2, 		"AMR-WB 12.65 kbit/s"},
-	{3, 		"AMR-WB 14.25 kbit/s"},
-	{4, 		"AMR-WB 15.85 kbit/s"},
-	{5, 		"AMR-WB 18.25 kbit/s"},
-	{6, 		"AMR-WB 19.85 kbit/s"},
-	{7, 		"AMR-WB 23.05 kbit/s"},
-	{8, 		"AMR-WB 23.85 kbit/s"},
+	{0, 			"AMR-WB 6.60 kbit/s"},
+	{1, 			"AMR-WB 8.85 kbit/s"},
+	{2, 			"AMR-WB 12.65 kbit/s"},
+	{3, 			"AMR-WB 14.25 kbit/s"},
+	{4, 			"AMR-WB 15.85 kbit/s"},
+	{5, 			"AMR-WB 18.25 kbit/s"},
+	{6, 			"AMR-WB 19.85 kbit/s"},
+	{7, 			"AMR-WB 23.05 kbit/s"},
+	{8, 			"AMR-WB 23.85 kbit/s"},
 	{AMR_WB_SID,	"AMR-WB SID (Comfort Noise Frame)"},
-	{10,		"Illegal Frametype"},
-	{11,		"Illegal Frametype"},
-	{12,		"Illegal Frametype"},
-	{13,		"Illegal Frametype"},
-	{14,		"Speech lost"},
+	{10,			"Illegal Frametype"},
+	{11,			"Illegal Frametype"},
+	{12,			"Illegal Frametype"},
+	{13,			"Illegal Frametype"},
+	{14,			"Speech lost"},
 	{AMR_NO_TRANS,	"No Data (No transmission/No reception)"},
 	{ 0,	NULL }
 };
@@ -163,14 +164,14 @@ static const value_string amr_nb_codec_mode_request_vals[] = {
 	{5,		"AMR 7,95 kbit/s"},
 	{6,		"AMR 10,2 kbit/s"},
 	{7,		"AMR 12,2 kbit/s (GSM-EFR)"},
-	{8,		"Illegal Frametype - For future us"},
-	{8,		"Illegal Frametype - For future us"},
-	{10,		"Illegal Frametype - For future us"},
-	{11,		"Illegal Frametype - For future us"},
-	{12,		"Illegal Frametype - For future use"},
-	{13,		"Illegal Frametype - For future use"},
-	{14,		"Illegal Frametype - For future use"},
-	{15,		"No mode request"}, 
+	{8,		"Illegal Frametype - For future use"},
+	{8,		"Illegal Frametype - For future use"},
+	{10,	"Illegal Frametype - For future use"},
+	{11,	"Illegal Frametype - For future use"},
+	{12,	"Illegal Frametype - For future use"},
+	{13,	"Illegal Frametype - For future use"},
+	{14,	"Illegal Frametype - For future use"},
+	{15,	"No mode request"}, 
 	{ 0,	NULL }
 };
 
@@ -190,7 +191,7 @@ static const value_string amr_wb_codec_mode_request_vals[] = {
 	{11,		"Illegal Frametype - For future use"},
 	{12,		"Illegal Frametype - For future use"},
 	{13,		"Illegal Frametype - For future use"},
-	{14,		"Illegal Frametype - For future us"},
+	{14,		"Illegal Frametype - For future use"},
 	{15,		"No mode request"}, 
 	{ 0,	NULL }
 };
@@ -316,11 +317,11 @@ static void
 dissect_amr_be(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree){
 	proto_item *item;
 	int ft;
+	int bit_offset = 0;
 	int bitcount; /*bitcounter, MSB = bit 0, over bytes*/
 	int bits_used_for_frames = 0;
 	int bytes_needed_for_frames;
-	gboolean frame_following;
-	guint16 unit16val;
+	guint8 f_bit, q_bit;
 	
 	/* Number of bits per frame for AMR-NB, see Table 1 RFC3267*/
 	/* Values taken for GSM-EFR SID, TDMA-EFR SID and PDC-EFR SID from 3GPP 26.101 Table A.1b */
@@ -334,37 +335,57 @@ dissect_amr_be(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree){
 
 	
 	/* Chapter 4.3 */
+
 	bitcount = 3;
 	if (amr_mode==AMR_NB)
-		item = proto_tree_add_item(tree, hf_amr_nb_cmr, tvb, bitcount/8, 1, FALSE);
+		item = proto_tree_add_bits_item(tree, hf_amr_nb_cmr, tvb, bit_offset, 4, FALSE);
 	else    
-		item = proto_tree_add_item(tree, hf_amr_wb_cmr, tvb, bitcount/8, 1, FALSE);	
+		item = proto_tree_add_bits_item(tree, hf_amr_wb_cmr, tvb, bit_offset, 4, FALSE);	
 	    
+	bit_offset+=4;
+	/* In bandwidth-efficient mode, a ToC entry takes the following format:
+	 *
+	 *    0 1 2 3 4 5
+	 *   +-+-+-+-+-+-+
+	 *   |F|  FT   |Q|
+	 *   +-+-+-+-+-+-+
+	 *
+	 *   F (1 bit): If set to 1, indicates that this frame is followed by
+	 *      another speech frame in this payload; if set to 0, indicates that
+	 *      this frame is the last frame in this payload.
+	 *
+	 *   FT (4 bits): Frame type index, indicating either the AMR or AMR-WB
+	 *      speech coding mode or comfort noise (SID) mode of the
+	 *      corresponding frame carried in this payload.
+	 */
 	do {
 		/* Check F bit */
 		bitcount += 1;
-		frame_following = tvb_get_guint8(tvb,bitcount/8) & 0x80 >> (bitcount % 8);
-		unit16val = tvb_get_ntohs(tvb,bitcount/8);
-		ft = (unit16val >> (11 - (bitcount % 8)))  &0x000F;
+		f_bit = tvb_get_bits8(tvb, bit_offset, 1);
+		proto_tree_add_bits_item(tree, hf_amr_toc_f, tvb, bit_offset, 1, FALSE);
+		bit_offset++;
+		ft = tvb_get_bits8(tvb, bit_offset, 4);
 		if (amr_mode==AMR_NB)
-			item = proto_tree_add_text(tree, tvb, bitcount/8, 1+(bitcount % 8)/5, 
-						   amr_nb_codec_mode_request_vals[ft].strptr);
+			item = proto_tree_add_bits_item(tree, hf_amr_nb_toc_ft, tvb, bit_offset, 4, FALSE);
 		else
-			item = proto_tree_add_text(tree, tvb, bitcount/8, 1+(bitcount % 8)/5, 
-						   amr_wb_codec_mode_request_vals[ft].strptr);
+			item = proto_tree_add_bits_item(tree, hf_amr_wb_toc_ft, tvb, bit_offset, 4, FALSE);
 		    	    
+		bit_offset+=4;
 		bitcount += 4;
 		if (amr_mode==AMR_NB)
 			bits_used_for_frames +=Framebits_NB[ft];
 		else    
 			bits_used_for_frames +=Framebits_WB[ft];
 		/* Check Q bit */
+		q_bit = tvb_get_bits8(tvb, bit_offset, 1);
+		proto_tree_add_bits_item(tree, hf_amr_toc_q, tvb, bit_offset, 1, FALSE);
+		bit_offset++;
 		bitcount += 1;
-		if (tvb_get_guint8(tvb,bitcount/8) & 0x80 >> (bitcount %8))
+		if (q_bit==1)
 			proto_item_append_text(item, " / Frame OK");
 		else    
 			proto_item_append_text(item, " / Frame damaged");
-	} while ((frame_following) && (tvb_reported_length_remaining(tvb, bitcount/8)>2));
+	} while ((f_bit==1) && (tvb_reported_length_remaining(tvb, bitcount/8)>2));
 	
 	if (bits_used_for_frames>0)
 		bytes_needed_for_frames = 1 + (bitcount+bits_used_for_frames)/8-bitcount/8;
@@ -389,7 +410,7 @@ dissect_amr_be(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree){
 	if (tvb_reported_length_remaining(tvb, (bitcount+8)/8)>0)	{
 		item = proto_tree_add_text(tree, tvb, bitcount/8, tvb_reported_length_remaining(tvb, bitcount/8), "Error:");
 		proto_item_append_text(item, " %d Bytes remaining - should be 0!",tvb_reported_length_remaining(tvb, (bitcount+8)/8));
-		expert_add_info_format(pinfo, item, PI_MALFORMED, PI_ERROR, "Superflous data remaining");
+		expert_add_info_format(pinfo, item, PI_MALFORMED, PI_ERROR, "Superfluous data remaining");
 
 		/* Now check the paddings */
 		if (bitcount%8 != 0)	{
@@ -409,6 +430,7 @@ static void
 dissect_amr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	int offset = 0;
+	int bit_offset = 0;
 	int toc_offset = 0;
 	guint8 octet;
 	proto_item *item;
@@ -419,8 +441,7 @@ dissect_amr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	proto_tree *amr_tree, *toc_tree;
 
 /* Make entries in Protocol column and Info column on summary display */
-	if (check_col(pinfo->cinfo, COL_PROTOCOL)) 
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "AMR");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "AMR");
 	if (tree) {
 
 		ti = proto_tree_add_item(tree, proto_amr, tvb, 0, -1, FALSE);
@@ -452,10 +473,11 @@ dissect_amr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		}
 		
 		if (amr_mode==AMR_NB)
-			proto_tree_add_item(amr_tree, hf_amr_nb_cmr, tvb, offset, 1, FALSE);
+			proto_tree_add_bits_item(amr_tree, hf_amr_nb_cmr, tvb, bit_offset, 4, FALSE);
 		else
-			proto_tree_add_item(amr_tree, hf_amr_wb_cmr, tvb, offset, 1, FALSE);    
+			proto_tree_add_bits_item(amr_tree, hf_amr_wb_cmr, tvb, bit_offset, 4, FALSE);
 		    
+		bit_offset+=4;
 		octet = tvb_get_guint8(tvb,offset) & 0x0f;
 		if ( octet != 0  ){
 			item = proto_tree_add_text(amr_tree, tvb, offset, -1, "Reserved != 0, wrongly encoded or not octet aligned. Decoding as bandwidth-efficient mode");
@@ -466,6 +488,7 @@ dissect_amr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 		proto_tree_add_item(amr_tree, hf_amr_reserved, tvb, offset, 1, FALSE);
 		offset++;
+		bit_offset+=4;
 		toc_offset = offset;
 		/*
 		 *  A ToC entry takes the following format in octet-aligned mode:
@@ -491,12 +514,18 @@ dissect_amr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		while ((( octet& 0x80 ) == 0x80)||(first_time == TRUE)){
 			first_time = FALSE;
 			octet = tvb_get_guint8(tvb,offset);	
-			proto_tree_add_item(amr_tree, hf_amr_toc_f, tvb, offset, 1, FALSE);
+			
+			proto_tree_add_bits_item(amr_tree, hf_amr_toc_f, tvb, bit_offset, 1, FALSE);
+			bit_offset++;
 			if (amr_mode==AMR_NB)
-				proto_tree_add_item(amr_tree, hf_amr_nb_toc_ft, tvb, offset, 1, FALSE);
+				proto_tree_add_bits_item(amr_tree, hf_amr_nb_toc_ft, tvb, bit_offset, 4, FALSE);
 			else
-				proto_tree_add_item(amr_tree, hf_amr_wb_toc_ft, tvb, offset, 1, FALSE);    
-			proto_tree_add_item(amr_tree, hf_amr_toc_q, tvb, offset, 1, FALSE);
+				proto_tree_add_bits_item(amr_tree, hf_amr_wb_toc_ft, tvb, bit_offset, 4, FALSE);
+			bit_offset+=4;
+			proto_tree_add_bits_item(amr_tree, hf_amr_toc_q, tvb, bit_offset, 1, FALSE);
+			bit_offset++;
+			/* 2 pading bits */
+			bit_offset+=2;
 			offset++;
 		}
 
@@ -519,6 +548,16 @@ static amr_capability_t amr_capability_tab[] = {
   { "GenericCapability/0.0.8.245.1.1.1/collapsing/3", "gsmEfrComfortNoise", NULL },
   { "GenericCapability/0.0.8.245.1.1.1/collapsing/4", "is-641ComfortNoise", NULL },
   { "GenericCapability/0.0.8.245.1.1.1/collapsing/5", "pdcEFRComfortNoise", NULL },
+  /* ITU-T Rec. G.722.2/Annex F (11/2002) */
+  { "GenericCapability/0.0.7.7222.1.0/collapsing/0", "maxAl-sduFrames", NULL },
+  { "GenericCapability/0.0.7.7222.1.0/collapsing/1", "bitRate", NULL },
+  { "GenericCapability/0.0.7.7222.1.0/collapsing/2", "octetAlign", NULL },
+  { "GenericCapability/0.0.7.7222.1.0/collapsing/3", "modeSet", NULL },
+  { "GenericCapability/0.0.7.7222.1.0/collapsing/4", "modeChangePeriod", NULL },
+  { "GenericCapability/0.0.7.7222.1.0/collapsing/5", "modeChangeNeighbour", NULL },
+  { "GenericCapability/0.0.7.7222.1.0/collapsing/6", "crc", NULL },
+  { "GenericCapability/0.0.7.7222.1.0/collapsing/7", "robustSorting", NULL },
+  { "GenericCapability/0.0.7.7222.1.0/collapsing/8", "interleaving", NULL },
   { NULL, NULL, NULL },
 };      
 
@@ -611,12 +650,12 @@ proto_register_amr(void)
 	static hf_register_info hf[] = {
 		{ &hf_amr_nb_cmr,
 			{ "CMR",           "amr.nb.cmr",
-			FT_UINT8, BASE_DEC, VALS(amr_nb_codec_mode_request_vals), 0xf0,          
+			FT_UINT8, BASE_DEC, VALS(amr_nb_codec_mode_request_vals), 0x0,          
 			"codec mode request", HFILL }
 		},
 		{ &hf_amr_wb_cmr,
 			{ "CMR",           "amr.wb.cmr",
-			FT_UINT8, BASE_DEC, VALS(amr_wb_codec_mode_request_vals), 0xf0,          
+			FT_UINT8, BASE_DEC, VALS(amr_wb_codec_mode_request_vals), 0x0,          
 			"codec mode request", HFILL }
 		},
 		{ &hf_amr_reserved,
@@ -626,93 +665,93 @@ proto_register_amr(void)
 		},
 		{ &hf_amr_toc_f,
 			{ "F bit",           "amr.toc.f",
-			FT_BOOLEAN, 8, TFS(&toc_f_bit_vals), 0x80,          
-			"F bit", HFILL }
+			FT_BOOLEAN, BASE_NONE, TFS(&toc_f_bit_vals), 0x0,          
+			NULL, HFILL }
 		},
 		{ &hf_amr_nb_toc_ft,
 			{ "FT bits",           "amr.nb.toc.ft",
-			FT_UINT8, BASE_DEC, VALS(amr_nb_codec_mode_request_vals), 0x78,          
+			FT_UINT8, BASE_DEC, VALS(amr_nb_codec_mode_request_vals), 0x0,          
 			"Frame type index", HFILL }
 		},
 		{ &hf_amr_wb_toc_ft,
 			{ "FT bits",           "amr.wb.toc.ft",
-			FT_UINT8, BASE_DEC, VALS(amr_wb_codec_mode_request_vals), 0x78,          
+			FT_UINT8, BASE_DEC, VALS(amr_wb_codec_mode_request_vals), 0x0,          
 			"Frame type index", HFILL }
 		},
 		{ &hf_amr_toc_q,
 			{ "Q bit",           "amr.toc.q",
-			FT_BOOLEAN, 8, TFS(&toc_q_bit_vals), 0x04,          
+			FT_BOOLEAN, BASE_NONE, TFS(&toc_q_bit_vals), 0x0,          
 			"Frame quality indicator bit", HFILL }
 		},
 		{ &hf_amr_nb_if1_ft,
 			{ "Frame Type",           "amr.nb.if1.ft",
 			FT_UINT8, BASE_DEC, VALS(amr_nb_codec_mode_vals), 0xf0,          
-			"Frame Type", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_amr_wb_if1_ft,
 			{ "Frame Type",           "amr.wb.if1.ft",
 			FT_UINT8, BASE_DEC, VALS(amr_wb_codec_mode_vals), 0xf0,          
-			"Frame Type", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_amr_nb_if1_mode_req,
 			{ "Mode Type request",           "amr.nb.if1.modereq",
 			FT_UINT8, BASE_DEC, VALS(amr_nb_codec_mode_request_vals), 0xe0,
-			"Mode Type request", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_amr_wb_if1_mode_req,
 			{ "Mode Type request",           "amr.wb.if1.modereq",
 			FT_UINT8, BASE_DEC, VALS(amr_wb_codec_mode_request_vals), 0x0f,
-			"Mode Type request", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_amr_if1_sti,
 			{ "SID Type Indicator",           "amr.if1.sti",
 			FT_BOOLEAN, 8, TFS(&amr_sti_vals), 0x10,          
-			"SID Type Indicator", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_amr_nb_if1_sti_mode_ind,
 			{ "Mode Type indication",           "amr.nb.if1.stimodeind",
 			FT_UINT8, BASE_DEC, VALS(amr_nb_codec_mode_vals), 0x0e,
-			"Mode Type indication", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_amr_wb_if1_sti_mode_ind,
 			{ "Mode Type indication",           "amr.wb.if1.stimodeind",
 			FT_UINT8, BASE_DEC, VALS(amr_wb_codec_mode_vals), 0x0f,
-			"Mode Type indication", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_amr_nb_if1_mode_ind,
 			{ "Mode Type indication",           "amr.nb.if1.modeind",
 			FT_UINT8, BASE_DEC, VALS(amr_nb_codec_mode_vals), 0x07,
-			"Mode Type indication", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_amr_wb_if1_mode_ind,
 			{ "Mode Type indication",           "amr.wb.if1.modeind",
 			FT_UINT8, BASE_DEC, VALS(amr_wb_codec_mode_vals), 0xf0,
-			"Mode Type indication", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_amr_nb_if2_ft,
 			{ "Frame Type",           "amr.nb.if2.ft",
 			FT_UINT8, BASE_DEC, VALS(amr_nb_codec_mode_vals), 0x0f,
-			"Frame Type", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_amr_wb_if2_ft,
 			{ "Frame Type",           "amr.wb.if2.ft",
 			FT_UINT8, BASE_DEC, VALS(amr_wb_codec_mode_vals), 0xf0,
-			"Frame Type", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_amr_if2_sti,
 			{ "SID Type Indicator",           "amr.if2.sti",
 			FT_BOOLEAN, 8, TFS(&amr_sti_vals), 0x80,          
-			"SID Type Indicator", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_amr_nb_if2_sti_mode_ind,
 			{ "Mode Type indication",           "amr.nb.if2.stimodeind",
 			FT_UINT8, BASE_DEC, VALS(amr_nb_codec_mode_vals), 0x07,
-			"Mode Type indication", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_amr_wb_if2_sti_mode_ind,
 			{ "Mode Type indication",           "amr.wb.if2.stimodeind",
 			FT_UINT8, BASE_DEC, VALS(amr_wb_codec_mode_vals), 0x78,
-			"Mode Type indication", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_amr_if1_fqi,
 			{ "FQI",           "amr.fqi",
@@ -772,6 +811,8 @@ proto_register_amr(void)
 	register_dissector("amr_if1_wb", dissect_amr_wb_if1, proto_amr);
 	register_dissector("amr_if2_nb", dissect_amr_nb_if2, proto_amr);
 	register_dissector("amr_if2_wb", dissect_amr_wb_if2, proto_amr);
+
+	oid_add_from_string("G.722.2 (AMR-WB) audio capability","0.0.7.7222.1.0");
 	
 
 }
