@@ -2,7 +2,7 @@
  * Routines for B.A.T.M.A.N. Layer 3 dissection
  * Copyright 2008-2009 Sven Eckelmann <sven.eckelmann@gmx.de>
  *
- * $Id: packet-bat.c 27588 2009-03-03 19:26:45Z etxrab $
+ * $Id: packet-bat.c 30133 2009-09-25 00:29:06Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -132,9 +132,8 @@ static void dissect_bat_batman(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tr
 	guint8 version;
 
 	/* set protocol name */
-	if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "BAT_BATMAN");
-	}
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "BAT_BATMAN");
+	col_clear(pinfo->cinfo, COL_INFO);
 
 	version = tvb_get_guint8(tvb, 0);
 	switch (version) {
@@ -142,10 +141,8 @@ static void dissect_bat_batman(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tr
 		dissect_bat_batman_v5(tvb, pinfo, tree);
 		break;
 	default:
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_clear(pinfo->cinfo, COL_INFO);
-			col_append_fstr(pinfo->cinfo, COL_INFO, "Unsupported Version %d", version);
-		}
+		if (check_col(pinfo->cinfo, COL_INFO))  
+			col_add_fstr(pinfo->cinfo, COL_INFO, "Unsupported Version %d", version);
 		call_dissector(data_handle, tvb, pinfo, tree);
 		break;
 	}
@@ -197,11 +194,8 @@ static void dissect_bat_batman_v5(tvbuff_t *tvb, packet_info *pinfo, proto_tree
 	batman_packeth->hna_len = tvb_get_guint8(tvb, 17);
 
 	/* Set info column */
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_clear(pinfo->cinfo, COL_INFO);
-		col_append_fstr(pinfo->cinfo, COL_INFO, "Seq=%u",
-		                batman_packeth->seqno);
-	}
+        if (check_col(pinfo->cinfo, COL_INFO))  
+		col_add_fstr(pinfo->cinfo, COL_INFO, "Seq=%u", batman_packeth->seqno);
 
 	/* Set tree info */
 	if (tree) {
@@ -210,8 +204,8 @@ static void dissect_bat_batman_v5(tvbuff_t *tvb, packet_info *pinfo, proto_tree
 
 		if (PTREE_DATA(tree)->visible) {
 			ti = proto_tree_add_protocol_format(tree, proto_bat_plugin, tvb, 0, BATMAN_PACKET_V5_SIZE,
-			                                    "B.A.T.M.A.N., Orig: %s (%s)",
-			                                    get_hostname(orig), ip_to_str(batman_packeth->orig.data));
+							    "B.A.T.M.A.N., Orig: %s (%s)",
+							    get_hostname(orig), ip_to_str(batman_packeth->orig.data));
 		} else {
 			ti = proto_tree_add_item(tree, proto_bat_plugin, tvb, 0, BATMAN_PACKET_V5_SIZE, FALSE);
 		}
@@ -270,7 +264,7 @@ static void dissect_bat_batman_v5(tvbuff_t *tvb, packet_info *pinfo, proto_tree
 
 	length_remaining = tvb_reported_length_remaining(tvb, offset);
 	if (length_remaining != 0) {
-		next_tvb = tvb_new_subset(tvb, offset, -1, -1);
+		next_tvb = tvb_new_subset_remaining(tvb, offset);
 
 		if (have_tap_listener(bat_follow_tap)) {
 			tap_queue_packet(bat_follow_tap, pinfo, next_tvb);
@@ -298,8 +292,8 @@ static void dissect_bat_hna(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *t
 
 		if (PTREE_DATA(tree)->visible) {
 			ti = proto_tree_add_protocol_format(tree, proto_bat_plugin, tvb, 0, 5,
-			                                    "B.A.T.M.A.N. HNA: %s/%d",
-			                                    ip_to_str(hna_addr), hna_netmask);
+							    "B.A.T.M.A.N. HNA: %s/%d",
+							    ip_to_str(hna_addr), hna_netmask);
 		} else {
 			ti = proto_tree_add_item(tree, proto_bat_plugin, tvb, 0, 5, FALSE);
 		}
@@ -336,19 +330,16 @@ static void dissect_bat_gw(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	ip_addr = tvb_get_ptr(tvb, ip_pos, 4);
 
 	/* set protocol name */
-	if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "BAT_GW");
-	}
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "BAT_GW");
 
 	/* Set info column */
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_clear(pinfo->cinfo, COL_INFO);
-		col_append_fstr(pinfo->cinfo, COL_INFO, "Type=%s",
-		                val_to_str(gw_packeth->type, gw_packettypenames, "Unknown (0x%02x)"));
-		if (ip != 0) {
+        if (check_col(pinfo->cinfo, COL_INFO))  
+		col_add_fstr(pinfo->cinfo, COL_INFO, "Type=%s",
+			     val_to_str(gw_packeth->type, gw_packettypenames, "Unknown (0x%02x)"));
+	if (ip != 0) {
+		if (check_col(pinfo->cinfo, COL_INFO))  
 			col_append_fstr(pinfo->cinfo, COL_INFO, " IP: %s (%s)",
-			                get_hostname(ip), ip_to_str(ip_addr));
-		}
+					get_hostname(ip), ip_to_str(ip_addr));
 	}
 
 
@@ -359,8 +350,8 @@ static void dissect_bat_gw(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 		if (PTREE_DATA(tree)->visible) {
 			ti = proto_tree_add_protocol_format(tree, proto_bat_plugin, tvb, 0, 1,
-			                                    "B.A.T.M.A.N. GW [%s]",
-			                                    val_to_str(gw_packeth->type, gw_packettypenames, "Unknown (0x%02x)"));
+							    "B.A.T.M.A.N. GW [%s]",
+							    val_to_str(gw_packeth->type, gw_packettypenames, "Unknown (0x%02x)"));
 		} else {
 			ti = proto_tree_add_item(tree, proto_bat_plugin, tvb, 0, 1, FALSE);
 		}
@@ -377,7 +368,7 @@ static void dissect_bat_gw(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	length_remaining = tvb_reported_length_remaining(tvb, offset);
 	if (length_remaining != 0) {
-		next_tvb = tvb_new_subset(tvb, offset, -1, -1);
+		next_tvb = tvb_new_subset_remaining(tvb, offset);
 
 		if (have_tap_listener(bat_follow_tap)) {
 			tap_queue_packet(bat_follow_tap, pinfo, next_tvb);
@@ -396,9 +387,7 @@ static void dissect_bat_vis(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	guint8 version;
 
 	/* set protocol name */
-	if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "BAT_VIS");
-	}
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "BAT_VIS");
 
 	version = tvb_get_guint8(tvb, 4);
 	switch (version) {
@@ -409,10 +398,8 @@ static void dissect_bat_vis(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		dissect_bat_vis_v23(tvb, pinfo, tree);
 		break;
 	default:
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_clear(pinfo->cinfo, COL_INFO);
-			col_append_fstr(pinfo->cinfo, COL_INFO, "Unsupported Version %d", version);
-		}
+		if (check_col(pinfo->cinfo, COL_INFO))  
+			col_add_fstr(pinfo->cinfo, COL_INFO, "Unsupported Version %d", version);
 		call_dissector(data_handle, tvb, pinfo, tree);
 		break;
 	}
@@ -439,16 +426,12 @@ static void dissect_bat_vis_v22(tvbuff_t *tvb, packet_info *pinfo, proto_tree *t
 	vis_packeth->tq_max = tvb_get_ntohs(tvb, 6);
 
 	/* set protocol name */
-	if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "BAT_VIS");
-	}
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "BAT_VIS");
 
 	/* Set info column */
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_clear(pinfo->cinfo, COL_INFO);
-		col_append_fstr(pinfo->cinfo, COL_INFO, "Src: %s (%s)",
-		                get_hostname(sender_ip), ip_to_str(vis_packeth->sender_ip.data));
-	}
+        if (check_col(pinfo->cinfo, COL_INFO))  
+		col_add_fstr(pinfo->cinfo, COL_INFO, "Src: %s (%s)",
+			     get_hostname(sender_ip), ip_to_str(vis_packeth->sender_ip.data));
 
 	/* Set tree info */
 	if (tree) {
@@ -456,8 +439,8 @@ static void dissect_bat_vis_v22(tvbuff_t *tvb, packet_info *pinfo, proto_tree *t
 
 		if (PTREE_DATA(tree)->visible) {
 			ti = proto_tree_add_protocol_format(tree, proto_bat_plugin, tvb, 0, VIS_PACKET_V22_SIZE,
-			                                    "B.A.T.M.A.N. Vis, Src: %s (%s)",
-			                                    get_hostname(sender_ip), ip_to_str(vis_packeth->sender_ip.data));
+							    "B.A.T.M.A.N. Vis, Src: %s (%s)",
+							    get_hostname(sender_ip), ip_to_str(vis_packeth->sender_ip.data));
 		} else {
 			ti = proto_tree_add_item(tree, proto_bat_plugin, tvb, 0, VIS_PACKET_V22_SIZE, FALSE);
 		}
@@ -497,7 +480,7 @@ static void dissect_bat_vis_v22(tvbuff_t *tvb, packet_info *pinfo, proto_tree *t
 
 	length_remaining = tvb_reported_length_remaining(tvb, offset);
 	if (length_remaining != 0) {
-		next_tvb = tvb_new_subset(tvb, offset, -1, -1);
+		next_tvb = tvb_new_subset_remaining(tvb, offset);
 
 		if (have_tap_listener(bat_follow_tap)) {
 			tap_queue_packet(bat_follow_tap, pinfo, next_tvb);
@@ -528,9 +511,9 @@ static void dissect_vis_entry_v22(tvbuff_t *tvb, packet_info *pinfo _U_, proto_t
 
 		if (PTREE_DATA(tree)->visible) {
 			ti = proto_tree_add_protocol_format(tree, proto_bat_plugin, tvb, 0, 7,
-			                                    "VIS Entry: [%s] %s (%s)",
-			                                    val_to_str(vis_datah->type, vis_packettypenames, "Unknown (0x%02x)"),
-			                                    get_hostname(ip), ip_to_str(vis_datah->ip.data));
+							    "VIS Entry: [%s] %s (%s)",
+							    val_to_str(vis_datah->type, vis_packettypenames, "Unknown (0x%02x)"),
+							    get_hostname(ip), ip_to_str(vis_datah->ip.data));
 		} else {
 			ti = proto_tree_add_item(tree, proto_bat_plugin, tvb, 0, 7, FALSE);
 		}
@@ -574,16 +557,12 @@ static void dissect_bat_vis_v23(tvbuff_t *tvb, packet_info *pinfo, proto_tree *t
 	vis_packeth->tq_max = tvb_get_guint8(tvb, 6);
 
 	/* set protocol name */
-	if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "BAT_VIS");
-	}
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "BAT_VIS");
 
 	/* Set info column */
-	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_clear(pinfo->cinfo, COL_INFO);
-		col_append_fstr(pinfo->cinfo, COL_INFO, "Src: %s (%s)",
-		                get_hostname(sender_ip), ip_to_str(vis_packeth->sender_ip.data));
-	}
+        if (check_col(pinfo->cinfo, COL_INFO))  
+		col_add_fstr(pinfo->cinfo, COL_INFO, "Src: %s (%s)",
+			     get_hostname(sender_ip), ip_to_str(vis_packeth->sender_ip.data));
 
 	/* Set tree info */
 	if (tree) {
@@ -591,8 +570,8 @@ static void dissect_bat_vis_v23(tvbuff_t *tvb, packet_info *pinfo, proto_tree *t
 
 		if (PTREE_DATA(tree)->visible) {
 			ti = proto_tree_add_protocol_format(tree, proto_bat_plugin, tvb, 0, VIS_PACKET_V23_SIZE,
-			                                    "B.A.T.M.A.N. Vis, Src: %s (%s)",
-			                                    get_hostname(sender_ip), ip_to_str(vis_packeth->sender_ip.data));
+							    "B.A.T.M.A.N. Vis, Src: %s (%s)",
+							    get_hostname(sender_ip), ip_to_str(vis_packeth->sender_ip.data));
 		} else {
 			ti = proto_tree_add_item(tree, proto_bat_plugin, tvb, 0, VIS_PACKET_V23_SIZE, FALSE);
 		}
@@ -632,7 +611,7 @@ static void dissect_bat_vis_v23(tvbuff_t *tvb, packet_info *pinfo, proto_tree *t
 
 	length_remaining = tvb_reported_length_remaining(tvb, offset);
 	if (length_remaining != 0) {
-		next_tvb = tvb_new_subset(tvb, offset, -1, -1);
+		next_tvb = tvb_new_subset_remaining(tvb, offset);
 
 		if (have_tap_listener(bat_follow_tap)) {
 			tap_queue_packet(bat_follow_tap, pinfo, next_tvb);
@@ -663,9 +642,9 @@ static void dissect_vis_entry_v23(tvbuff_t *tvb, packet_info *pinfo _U_, proto_t
 
 		if (PTREE_DATA(tree)->visible) {
 			ti = proto_tree_add_protocol_format(tree, proto_bat_plugin, tvb, 0, 7,
-			                                    "VIS Entry: [%s] %s (%s)",
-			                                    val_to_str(vis_datah->type, vis_packettypenames, "Unknown (0x%02x)"),
-			                                    get_hostname(ip), ip_to_str(vis_datah->ip.data));
+							    "VIS Entry: [%s] %s (%s)",
+							    val_to_str(vis_datah->type, vis_packettypenames, "Unknown (0x%02x)"),
+							    get_hostname(ip), ip_to_str(vis_datah->ip.data));
 		} else {
 			ti = proto_tree_add_item(tree, proto_bat_plugin, tvb, 0, 7, FALSE);
 		}
@@ -696,132 +675,132 @@ void proto_register_bat(void)
 		{ &hf_bat_batman_version,
 		  { "Version", "bat.batman.version",
 		    FT_UINT8, BASE_DEC, NULL, 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_batman_flags,
 		  { "Flags", "bat.batman.flags",
 		    FT_UINT8, BASE_HEX, NULL, 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_batman_ttl,
 		  { "Time to Live", "bat.batman.ttl",
 		    FT_UINT8, BASE_DEC, NULL, 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_batman_gwflags,
 		  { "Gateway Flags", "bat.batman.gwflags",
 		    FT_UINT8, BASE_HEX, NULL, 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_batman_seqno,
 		  { "Sequence number", "bat.batman.seq",
 		    FT_UINT16, BASE_DEC, NULL, 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_batman_gwport,
 		  { "Gateway Port", "bat.batman.gwport",
 		    FT_UINT16, BASE_DEC, NULL, 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_batman_orig,
 		  { "Originator", "bat.batman.orig",
 		    FT_IPv4, BASE_NONE, NULL, 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_batman_old_orig,
 		  { "Received from", "bat.batman.old_orig",
 		    FT_IPv4, BASE_NONE, NULL, 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_batman_tq,
 		  { "Transmission Quality", "bat.batman.tq",
 		    FT_UINT8, BASE_DEC, NULL, 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_batman_hna_len,
 		  { "Number of HNAs", "bat.batman.hna_len",
 		    FT_UINT8, BASE_DEC, NULL, 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_batman_flags_unidirectional,
 		  { "Unidirectional", "bat.batman.flags.unidirectional",
-		    FT_BOOLEAN, 8, TFS(&flags_set_truth), 0x80,
-		    "", HFILL }
+		    FT_BOOLEAN, 8, TFS(&tfs_set_notset), 0x80,
+		    NULL, HFILL }
 		},
 		{ &hf_bat_batman_flags_directlink,
 		  { "DirectLink", "bat.batman.flags.directlink",
-		    FT_BOOLEAN, 8, TFS(&flags_set_truth), 0x40,
-		    "", HFILL }
+		    FT_BOOLEAN, 8, TFS(&tfs_set_notset), 0x40,
+		    NULL, HFILL }
 		},
 		{ &hf_bat_batman_hna_network,
 		  { "HNA Network", "bat.batman.hna_network",
 		    FT_IPv4, BASE_NONE, NULL, 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_batman_hna_netmask,
 		  { "HNA Netmask", "bat.batman.hna_netmask",
 		    FT_UINT8, BASE_DEC, NULL, 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_gw_type,
 		  { "Type", "bat.gw.type",
 		    FT_UINT8, BASE_DEC, VALS(gw_packettypenames), 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_gw_ip,
 		  { "IP", "bat.gw.ip",
 		    FT_IPv4, BASE_NONE, NULL, 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_vis_vis_orig,
 		  { "Originator", "bat.vis.sender_ip",
 		    FT_IPv4, BASE_NONE, NULL, 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_vis_version,
 		  { "Version", "bat.vis.version",
 		    FT_UINT8, BASE_DEC, NULL, 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_vis_gwflags,
 		  { "Gateway Flags", "bat.vis.gwflags",
 		    FT_UINT8, BASE_HEX, NULL, 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_max_tq_v22,
 		  { "Maximum Transmission Quality", "bat.vis.tq_max",
 		    FT_UINT16, BASE_DEC, NULL, 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_max_tq_v23,
 		  { "Maximum Transmission Quality", "bat.vis.tq_max",
 		    FT_UINT8, BASE_DEC, NULL, 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_vis_data_type,
 		  { "Type", "bat.vis.data_type",
 		    FT_UINT8, BASE_DEC, VALS(vis_packettypenames), 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		},
 		{ &hf_bat_vis_tq_v22,
 		  { "Transmission Quality", "bat.vis.tq",
 		    FT_UINT16, BASE_DEC, NULL, 0x0,
-		    "", HFILL}
+		    NULL, HFILL}
 		},
 		{ &hf_bat_vis_tq_v23,
 		  { "Transmission Quality", "bat.vis.tq",
 		    FT_UINT8, BASE_DEC, NULL, 0x0,
-		    "", HFILL}
+		    NULL, HFILL}
 		},
 		{ &hf_bat_vis_netmask,
 		  { "Netmask", "bat.vis.netmask",
 		    FT_UINT8, BASE_DEC, NULL, 0x0,
-		    "", HFILL}
+		    NULL, HFILL}
 		},
 		{ &hf_bat_vis_data_ip,
 		  { "IP", "bat.vis.data_ip",
 		    FT_IPv4, BASE_NONE, NULL, 0x0,
-		    "", HFILL }
+		    NULL, HFILL }
 		}
 	};
 
@@ -837,10 +816,10 @@ void proto_register_bat(void)
 	};
 
 	proto_bat_plugin = proto_register_protocol(
-	                           "B.A.T.M.A.N. Layer 3 Protocol",
-	                           "BAT",          /* short name */
-	                           "bat"           /* abbrev */
-	                   );
+		"B.A.T.M.A.N. Layer 3 Protocol",
+		"BAT",          /* short name */
+		"bat"           /* abbrev */
+		);
 
 	/* Register our configuration options for B.A.T.M.A.N. */
 	bat_module = prefs_register_protocol(proto_bat_plugin, proto_reg_handoff_bat);
@@ -849,17 +828,17 @@ void proto_register_bat(void)
 	proto_register_subtree_array(ett, array_length(ett));
 
 	prefs_register_uint_preference(bat_module, "batman.bat.port", "BAT UDP Port",
-	                               "Set the port for B.A.T.M.A.N. BAT "
-	                               "messages (if other than the default of 4305)",
-	                               10, &global_bat_batman_udp_port);
+				       "Set the port for B.A.T.M.A.N. BAT "
+				       "messages (if other than the default of 4305)",
+				       10, &global_bat_batman_udp_port);
 	prefs_register_uint_preference(bat_module, "batman.gw.port", "GW UDP Port",
-	                               "Set the port for B.A.T.M.A.N. Gateway "
-	                               "messages (if other than the default of 4306)",
-	                               10, &global_bat_gw_udp_port);
+				       "Set the port for B.A.T.M.A.N. Gateway "
+				       "messages (if other than the default of 4306)",
+				       10, &global_bat_gw_udp_port);
 	prefs_register_uint_preference(bat_module, "batman.vis.port", "VIS UDP Port",
-	                               "Set the port for B.A.T.M.A.N. VIS "
-	                               "messages (if other than the default of 4307)",
-	                               10, &global_bat_vis_udp_port);
+				       "Set the port for B.A.T.M.A.N. VIS "
+				       "messages (if other than the default of 4307)",
+				       10, &global_bat_vis_udp_port);
 }
 
 void proto_reg_handoff_bat(void)
