@@ -4,7 +4,7 @@
  *
  *  (c) 2007, Luis E. Garcia Ontanon <luis@ontanon.org>
  *
- * $Id: packet-bctp.c 25938 2008-08-05 21:31:17Z guy $
+ * $Id: packet-bctp.c 29446 2009-08-16 12:36:22Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -72,7 +72,7 @@ static const value_string bvei_vals[] = {
 static void dissect_bctp(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree) {
 	proto_item* pi = proto_tree_add_item(tree, proto_bctp, tvb,0,2, FALSE);
 	proto_tree* pt = proto_item_add_subtree(pi,ett_bctp);
-	tvbuff_t* sub_tvb = tvb_new_subset(tvb, 2, -1, -1);
+	tvbuff_t* sub_tvb = tvb_new_subset_remaining(tvb, 2);
 	guint8 tpi = tvb_get_guint8(tvb,1) & 0x3f;
 	
 	proto_tree_add_item(pt, hf_bctp_bvei, tvb,0,2, FALSE);
@@ -96,8 +96,8 @@ proto_register_bctp (void)
 	static hf_register_info hf[] = {
 		{&hf_bctp_bvei, {"BVEI", "bctp.bvei", FT_UINT16, BASE_HEX, VALS(bvei_vals), 0x4000, "BCTP Version Error Indicator", HFILL }},
 		{&hf_bctp_bvi, {"BVI", "bctp.bvi", FT_UINT16, BASE_HEX, NULL, 0x1F00, "BCTP Version Indicator", HFILL }},
-		{&hf_bctp_tpei, {"TPEI", "bctp.tpei", FT_UINT16, BASE_HEX, NULL, 0x0040, "Tunnelled Protocol Error Indicator", HFILL }},
-		{&hf_bctp_tpi, {"TPI", "bctp.tpi", FT_UINT16, BASE_HEX, NULL, 0x003F, "Tunnelled Protocol Indicator", HFILL }},
+		{&hf_bctp_tpei, {"TPEI", "bctp.tpei", FT_UINT16, BASE_HEX, NULL, 0x0040, "Tunneled Protocol Error Indicator", HFILL }},
+		{&hf_bctp_tpi, {"TPI", "bctp.tpi", FT_UINT16, BASE_HEX, NULL, 0x003F, "Tunneled Protocol Indicator", HFILL }},
 	};
 	static gint *ett[] = {
 		&ett_bctp
@@ -109,7 +109,7 @@ proto_register_bctp (void)
 
 	register_dissector("bctp", dissect_bctp, proto_bctp);
 
-	bctp_dissector_table = register_dissector_table("bctp.tpi", "BCTP Tunnelled Protocol Indicator", FT_UINT32, BASE_DEC);
+	bctp_dissector_table = register_dissector_table("bctp.tpi", "BCTP Tunneled Protocol Indicator", FT_UINT32, BASE_DEC);
 }
 
 void
