@@ -10,7 +10,7 @@
  * Added BSSAP+ according to ETSI TS 129 018 V6.3.0 (2005-3GPP TS 29.018 version 6.3.0 Release 6)
  * Copyright 2006, Anders Broman <Anders.Broman [AT] ericsson.com>
  *
- * $Id: packet-bssap.c 27050 2008-12-18 19:08:49Z wmeier $
+ * $Id: packet-bssap.c 29345 2009-08-09 07:59:51Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1652,10 +1652,7 @@ static void dissect_bssap_plus(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tr
 	/*
 	 * Make entry in the Protocol column on summary display
 	 */
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-	{
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "BSSAP+");
-	}
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "BSSAP+");
     
 	if (pinfo->sccp_info && pinfo->sccp_info->data.co.assoc)
 		pinfo->sccp_info->data.co.assoc->payload = SCCP_PLOAD_BSSAP;
@@ -1669,7 +1666,7 @@ static void dissect_bssap_plus(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tr
 	offset++;
 
 	if (check_col(pinfo->cinfo, COL_INFO)){
-		col_set_str(pinfo->cinfo,COL_INFO, val_to_str(message_type,bssap_plus_message_type_values,"Unknown %u"));
+		col_add_str(pinfo->cinfo,COL_INFO, val_to_str(message_type,bssap_plus_message_type_values,"Unknown %u"));
 	}
 
 	switch(message_type){
@@ -2198,160 +2195,160 @@ proto_register_bssap(void)
 	    { &hf_bssap_pdu_type,
 	      { "Message Type", "bssap.pdu_type",
 		FT_UINT8, BASE_HEX, VALS(bssap_pdu_type_values), 0x0,
-		"", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bsap_pdu_type,
 	      { "Message Type", "bsap.pdu_type",
 		FT_UINT8, BASE_HEX, VALS(bsap_pdu_type_values), 0x0,
-		"", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bssap_dlci_cc,
 	      { "Control Channel", "bssap.dlci.cc",
 		FT_UINT8, BASE_HEX, VALS(bssap_cc_values), CC_MASK,
-		"", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bsap_dlci_cc,
 	      { "Control Channel", "bsap.dlci.cc",
 		FT_UINT8, BASE_HEX, VALS(bsap_cc_values), CC_MASK,
-		"", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bssap_dlci_spare,
 	      { "Spare", "bssap.dlci.spare",
 		FT_UINT8, BASE_HEX, NULL, SPARE_MASK,
-		"", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bsap_dlci_rsvd,
 	      { "Reserved", "bsap.dlci.rsvd",
 		FT_UINT8, BASE_HEX, NULL, SPARE_MASK,
-		"", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bssap_dlci_sapi,
 	      { "SAPI", "bssap.dlci.sapi",
 		FT_UINT8, BASE_HEX, VALS(bssap_sapi_values), SAPI_MASK,
-		"", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bsap_dlci_sapi,
 	      { "SAPI", "bsap.dlci.sapi",
 		FT_UINT8, BASE_HEX, VALS(bsap_sapi_values), SAPI_MASK,
-		"", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bssap_length,
 	      { "Length", "bssap.length",
 		FT_UINT8, BASE_DEC, NULL, 0x0,
-		"", HFILL}},
+		NULL, HFILL}},
 
 	    { &hf_bssap_plus_message_type,
 	      { "Message Type", "bssap_plus.msg_type",
 		FT_UINT8, BASE_DEC, VALS(bssap_plus_message_type_values), 0x0,
-		"Message Type", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bssap_plus_ie,
 	      { "IEI", "bssap_plus.iei",
 		FT_UINT8, BASE_DEC, VALS(bssap_plus_ie_id_values), 0x0,
-		"", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bssap_plus_ie_len,
 	      { "Length indicator", "bssap_plus.iei",
 		FT_UINT8, BASE_DEC, NULL, 0x0,
-		"Length indicator", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bssap_extension,
 	      { "Extension", "bssap.extension",
 	        FT_BOOLEAN, 8, TFS(&bssap_extension_value), 0x80,
-	        "Extension", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_type_of_number,
 	      { "Type of number", "bssap.type_of_number",
 	        FT_UINT8, BASE_HEX, VALS(gsm_a_type_of_number_values), 0x70,
-	        "Type of number", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_numbering_plan_id,
 	      { "Numbering plan identification", "bssap.number_plan",
 	        FT_UINT8, BASE_HEX, VALS(gsm_a_numbering_plan_id_values), 0x0f,
-	        "Numbering plan identification", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_sgsn_number,
 	      { "SGSN number", "bssap.sgsn_number",
 	        FT_STRING, BASE_NONE, NULL, 0,
-	        "SGSN number", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_vlr_number,
 	      { "VLR number", "bssap.vlr_number",
 	        FT_STRING, BASE_NONE, NULL, 0,
-	        "VLR number", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_cell_global_id_ie,
 	      { "Cell global identity IE", "bssap.cell_global_id_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "Cell global identity IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_channel_needed_ie,
 	      { "Channel needed IE", "bssap.cell_global_id_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "Channel needed IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_dlink_tnl_pld_cntrl_amd_inf_ie,
 	      { "Downlink Tunnel Payload Control and Info IE", "bssap.dlink_tnl_pld_cntrl_amd_inf_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "Downlink Tunnel Payload Control and Info IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_ulink_tnl_pld_cntrl_amd_inf_ie,
 	      { "Uplink Tunnel Payload Control and Info IE", "bssap.ulink_tnl_pld_cntrl_amd_inf_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "Uplink Tunnel Payload Control and Info IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_emlpp_prio_ie,
 	      { "eMLPP Priority IE", "bssap.emlpp_prio_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "eMLPP Priority IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_gprs_erroneous_msg_ie,
 	      { "Erroneous message IE", "bssap.erroneous_msg_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "Erroneous message IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_gprs_loc_upd_type_ie,
 	      { "GPRS location update type IE", "bssap.loc_upd_type_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "GPRS location update type IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_Gs_cause_ie,
 	      { "Gs Cause IE", "bssap.Gs_cause_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "Gs Cause IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_imei_ie,
 	      { "IMEI IE", "bssap.imei_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "IMEI IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_imesiv_ie,
 	      { "IMEISV IE", "bssap.imesiv",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "IMEISV IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_imsi_ie,
 	      { "IMSI IE", "bssap.imsi_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "IMSI IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_imsi_det_from_gprs_serv_type_ie,
 	      { "IMSI detach from GPRS service type IE", "bssap.msi_det_from_gprs_serv_type_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "IMSI detach from GPRS service type IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_imsi_det_from_non_gprs_serv_type_ie,
 	      { "IMSI detach from non-GPRS service IE", "bssap.msi_det_from_non_gprs_serv_type_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "IMSI detach from non-GPRS service IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_info_req_ie,
 	      { "Information requested IE", "bssap.info_req_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "Information requested IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_loc_area_id_ie,
 	      { "Location area identifier IE", "bssap.loc_area_id_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "Location area identifier IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_loc_inf_age_ie,
 	      { "Location information age IE", "bssap.loc_inf_age",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "Location information age IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_mm_information_ie,
 	      { "MM information IE", "bssap.mm_information",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "MM information IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_mobile_id_ie,
 	      { "Mobile identity IE", "bssap.mobile_id_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "Mobile identity IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_mobile_stn_cls_mrk1_ie,
 	      { "Mobile station classmark 1 IE", "bssap.mobile_stn_cls_mrk1_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "Mobile station classmark 1 IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_mobile_station_state_ie,
 	      { "Mobile station state IE", "bssap.mobile_station_state_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "Mobile station state IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_ptmsi_ie,
 	      { "PTMSI IE", "bssap.ptmsi_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "PTMSI IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_reject_cause_ie,
 	      { "Reject cause IE", "bssap.reject_cause_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "Reject cause IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_service_area_id_ie,
 	      { "Service area identification IE", "bssap.mobile_stn_cls_mrk1_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
@@ -2359,109 +2356,109 @@ proto_register_bssap(void)
 	    { &hf_bssap_sgsn_nr_ie,
 	      { "SGSN number IE", "bssap.imsi_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "SGSN number IE", HFILL }},	
+	        NULL, HFILL }},	
 	    { &hf_bssap_tmsi_ie,
 	      { "TMSI IE", "bssap.tmsi_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "TMSI IE", HFILL }},	
+	        NULL, HFILL }},	
 	    { &hf_bssap_tmsi_status_ie,
 	      { "TMSI status IE", "bssap.tmsi_status_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "TMSI status IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_vlr_number_ie,
 	      { "VLR number IE", "bssap.vlr_number_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "VLR number IE", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_global_cn_id_ie,
 	      { "Global CN-Id IE", "bssap.global_cn_id_ie",
 	        FT_NONE, BASE_NONE, NULL, 0,
-	        "Global CN-Id IE", HFILL }},
+	        NULL, HFILL }},
 
 	    { &hf_bssap_plus_ie_data,
 	      { "IE Data", "bssap.ie_data",
 	        FT_BYTES, BASE_NONE, NULL, 0,
-	        "IE Data", HFILL }},
+	        NULL, HFILL }},
 
 	    { &hf_bssap_call_priority,
 	      { "eMLPP Priority", "bssap.gprs_loc_upd_type",
 		FT_UINT8, BASE_DEC, VALS(bssap_call_priority_values), 0x07,
-		"eMLPP Priority", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bssap_gprs_loc_upd_type,
 	      { "GPRS location update type", "bssap.gprs_loc_upd_type",
 		FT_UINT8, BASE_DEC, VALS(bssap_plus_GPRS_loc_upd_type_values), 0x0,
-		"GPRS location update type", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bssap_Gs_cause,
 	      { "Gs cause", "bssap.gprs_loc_upd_type",
 		FT_UINT8, BASE_DEC, VALS(bssap_Gs_cause_values), 0x0,
-		"Gs cause", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bssap_imei,
 	      { "IMEI", "bssap.imei",
 	        FT_STRING, BASE_NONE, NULL, 0,
-	        "IMEI", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_imeisv,
 	      { "IMEISV", "bssap.imeisv",
 	        FT_STRING, BASE_NONE, NULL, 0,
-	        "IMEISV", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_imsi,
 	      { "IMSI", "bssap.imsi",
 	        FT_STRING, BASE_NONE, NULL, 0,
-	        "IMSI", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_imsi_det_from_gprs_serv_type,
 	      { "IMSI detach from GPRS service type", "bssap.imsi_det_from_gprs_serv_type",
 		FT_UINT8, BASE_DEC, VALS(bssap_Gs_cause_values), 0x0,
-		"IMSI detach from GPRS service type", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bssap_info_req,
 	      { "Information requested", "bssap.info_req",
 		FT_UINT8, BASE_DEC, VALS(bssap_info_req_values), 0x0,
-		"Information requested", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bssap_loc_inf_age,
 	      { "AgeOfLocationInformation in minutes", "bssap.loc_inf_age",
 		FT_UINT16, BASE_DEC, NULL, 0x0,
-		"AgeOfLocationInformation in minutes", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bssap_mobile_station_state,
 	      { "Mobile station state", "bssap.mobile_station_state",
 		FT_UINT8, BASE_DEC, VALS(bssap_mobile_station_state_values), 0x0,
-		"Mobile station state", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bssap_ptmsi,
 	      { "PTMSI", "bssap.ptmsi",
-		FT_BYTES, BASE_HEX, NULL, 0x0,
-		"PTMSI", HFILL}},
+		FT_BYTES, BASE_NONE, NULL, 0x0,
+		NULL, HFILL}},
 	    { &hf_bssap_tmsi,
 	      { "TMSI", "bssap.tmsi",
-		FT_BYTES, BASE_HEX, NULL, 0x0,
-		"TMSI", HFILL}},
+		FT_BYTES, BASE_NONE, NULL, 0x0,
+		NULL, HFILL}},
 	    { &hf_bssap_tmsi_status,
 	      { "TMSI status", "bssap.tmsi_status",
 	        FT_BOOLEAN, 8, TFS(&bssap_tmsi_flag), 0x01,
-	        "TMSI status", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_tom_prot_disc,
 	      { "TOM Protocol Discriminator", "bssap.Tom_prot_disc",
 	        FT_UINT8, BASE_DEC, VALS(bssap_tom_prot_disc_values), 0x78,
-	        "TOM Protocol Discriminator", HFILL}},
+	        NULL, HFILL}},
 	    { &hf_bssap_e_bit,
 	      { "E: Cipher Request", "bssap.tmsi_status",
 	        FT_BOOLEAN, 8, TFS(&bssap_E_flag), 0x04,
-	        "E: Cipher Request", HFILL }},
+	        NULL, HFILL }},
 	    { &hf_bssap_tunnel_prio,
 	      { "Tunnel Priority", "bssap.tunnel_prio",
 		FT_UINT8, BASE_DEC, NULL, 0x0,
-		"Tunnel Priority", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bssap_global_cn_id,
 	      { "Global CN-Id", "bssap.global_cn_id",
-		FT_BYTES, BASE_HEX, NULL, 0x0,
-		"Global CN-Id", HFILL}},
+		FT_BYTES, BASE_NONE, NULL, 0x0,
+		NULL, HFILL}},
 	    { &hf_bssap_plmn_id,
 	      { "PLMN-Id", "bssap.plmn_id",
-		FT_BYTES, BASE_HEX, NULL, 0x0,
-		"PLMN-Id", HFILL}},
+		FT_BYTES, BASE_NONE, NULL, 0x0,
+		NULL, HFILL}},
 	    { &hf_bssap_cn_id,
 	      { "CN-Id", "bssap.cn_id",
 		FT_UINT16, BASE_DEC, NULL, 0x0,
-		"CN-Id", HFILL}},
+		NULL, HFILL}},
 	    { &hf_bssap_cell_global_id,
 	      { "Cell global identity", "bssap.plmn_id",
-		FT_BYTES, BASE_HEX, NULL, 0x0,
-		"Cell global identity", HFILL}},
+		FT_BYTES, BASE_NONE, NULL, 0x0,
+		NULL, HFILL}},
 	};
 
 	/* Setup protocol subtree array */
