@@ -2,7 +2,7 @@
  * Routines for the disassembly of the "Cisco Discovery Protocol"
  * (c) Copyright Hannes R. Boehm <hannes@boehm.org>
  *
- * $Id: packet-cdp.c 27171 2009-01-06 19:58:42Z jake $
+ * $Id: packet-cdp.c 29446 2009-08-16 12:36:22Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -68,6 +68,7 @@ static int hf_cdp_tlvlength = -1;
 
 static gint ett_cdp = -1;
 static gint ett_cdp_tlv = -1;
+static gint ett_cdp_nrgyz_tlv = -1;
 static gint ett_cdp_address = -1;
 static gint ett_cdp_capabilities = -1;
 static gint ett_cdp_checksum = -1;
@@ -79,6 +80,9 @@ dissect_address_tlv(tvbuff_t *tvb, int offset, int length, proto_tree *tree);
 static void
 dissect_capabilities(tvbuff_t *tvb, int offset, int length, proto_tree *tree);
 static void
+dissect_nrgyz_tlv(tvbuff_t *tvb, int offset, guint16 length, guint16 num, 
+  proto_tree *tree);
+static void
 add_multi_line_string_to_tree(proto_tree *tree, tvbuff_t *tvb, gint start,
   gint len, const gchar *prefix);
 
@@ -109,6 +113,7 @@ add_multi_line_string_to_tree(proto_tree *tree, tvbuff_t *tvb, gint start,
 #define TYPE_POWER_REQUESTED    0x0019 /* Power Requested */
 #define TYPE_POWER_AVAILABLE    0x001a /* Power Available */
 #define TYPE_PORT_UNIDIR        0x001b /* Port Unidirectional */
+#define TYPE_NRGYZ              0x001d /* EnergyWise over CDP */
 
 static const value_string type_vals[] = {
 	{ TYPE_DEVICE_ID,    	"Device ID" },
@@ -136,6 +141,7 @@ static const value_string type_vals[] = {
 	{ TYPE_POWER_REQUESTED, "Power Requested" },
 	{ TYPE_POWER_AVAILABLE, "Power Available" },
 	{ TYPE_PORT_UNIDIR,     "Port Unidirectional" },
+	{ TYPE_NRGYZ,           "EnergyWise" },
 	{ 0,                    NULL }
 };
 
@@ -146,6 +152,19 @@ static const value_string type_hello_vals[] = {
 	{ 0,                    NULL }
 };
 
+#define TYPE_NRGYZ_ROLE		   0x00000007
+#define TYPE_NRGYZ_DOMAIN	   0x00000008
+#define TYPE_NRGYZ_NAME		   0x00000009
+#define TYPE_NRGYZ_REPLYTO	   0x00000017
+
+static const value_string type_nrgyz_vals[] = {
+	{ TYPE_NRGYZ_ROLE,	     "Role" },
+	{ TYPE_NRGYZ_DOMAIN,	     "Domain" },
+	{ TYPE_NRGYZ_NAME,	     "Name" },
+	{ TYPE_NRGYZ_REPLYTO,	     "Reply To" },
+	{ 0,			     NULL }
+};
+
 static void
 dissect_cdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
@@ -165,10 +184,8 @@ dissect_cdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     guint32 ip_addr;
     vec_t cksum_vec[1];
 
-    if (check_col(pinfo->cinfo, COL_PROTOCOL))
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "CDP");
-    if (check_col(pinfo->cinfo, COL_INFO))
-	col_clear(pinfo->cinfo, COL_INFO);
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "CDP");
+    col_clear(pinfo->cinfo, COL_INFO);
 
     if (tree) {
         ti = proto_tree_add_item(tree, proto_cdp, tvb, offset, -1, FALSE);
@@ -860,7 +877,7 @@ dissect_cdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	/* Move offset to where the list of Power Available Values Exist */
 	offset += 8;
 	while(power_avail_len) {
-	  if (power_avail_len > 4) {
+	  if (power_avail_len >= 4) {
 	    power_avail = tvb_get_ntohl(tvb, offset);
 	    if (tree) {
 	      proto_tree_add_text(tlv_tree, tvb, offset,
@@ -870,20 +887,64 @@ dissect_cdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	    power_avail_len -= 4;
 	    offset += 4;
 	  } else {
-	    if (power_avail_len == 4) {
-	      power_avail = tvb_get_ntohl(tvb, offset);
-	      if (tree) {
-		proto_tree_add_text(tlv_tree, tvb, offset,
-				    4, "Power Available: %u mW", power_avail);
-		proto_item_append_text(tlvi, "%u mW", power_avail);
-	      }
-	    }
 	    offset += power_avail_len;
 	    break;
 	  }
 	}
 	break;
 
+      case TYPE_NRGYZ:
+	if (tree) {
+	  tlvi = proto_tree_add_text(cdp_tree, tvb,
+				     offset, length, "EnergyWise");
+	  tlv_tree = proto_item_add_subtree(tlvi, ett_cdp_tlv);
+	  proto_tree_add_uint(tlv_tree, hf_cdp_tlvtype, tvb,
+			      offset + TLV_TYPE, 2, type);
+	  proto_tree_add_uint(tlv_tree, hf_cdp_tlvlength, tvb,
+			      offset + TLV_LENGTH, 2, length);
+	  proto_tree_add_text(tlv_tree, tvb, offset + 4,
+			      20, "Encrypted Data");
+	  proto_tree_add_text(tlv_tree, tvb, offset + 24,
+			      4, "Unknown (Seen Sequence?): %u",
+			      tvb_get_ntohl(tvb, offset + 24));
+	  proto_tree_add_text(tlv_tree, tvb, offset + 28,
+			      4, "Sequence Number: %u",
+			      tvb_get_ntohl(tvb, offset + 28));
+	  proto_tree_add_text(tlv_tree, tvb, offset + 32,
+			      16, "Model Number: %s",
+			      tvb_format_stringzpad(tvb, offset + 32, 16));
+	  proto_tree_add_text(tlv_tree, tvb, offset + 48,
+			      2, "Unknown Pad: %x",
+			      tvb_get_ntohs(tvb, offset + 48));
+	  proto_tree_add_text(tlv_tree, tvb, offset + 50,
+			      3, "Hardware Version ID: %s",
+			      tvb_format_stringzpad(tvb, offset + 50, 3));
+	  proto_tree_add_text(tlv_tree, tvb, offset + 53,
+			      11, "System Serial Number: %s",
+			      tvb_format_stringzpad(tvb, offset + 53, 11));
+	  proto_tree_add_text(tlv_tree, tvb, offset + 64,
+			      8, "Unknown Values");
+	  proto_tree_add_text(tlv_tree, tvb, offset + 72,
+			      2, "Length of TLV table: %u",
+			      tvb_get_ntohs(tvb, offset + 72));
+	  proto_tree_add_text(tlv_tree, tvb, offset + 74,
+			      2, "Number of TLVs in table: %u",
+			      tvb_get_ntohs(tvb, offset + 74));
+/*
+	  proto_tree_add_text(tlv_tree, tvb,
+			      offset + 76, length - 76,
+			      "EnergyWise TLV Table");
+*/
+	  dissect_nrgyz_tlv(tvb, offset + 76,
+			    tvb_get_ntohs(tvb, offset + 72),
+			    tvb_get_ntohs(tvb, offset + 74),
+			    tlv_tree);
+
+
+	}
+	offset += length;
+	break;
+
       default:
 	if (tree) {
 	  tlvi = proto_tree_add_text(cdp_tree, tvb, offset,
@@ -905,7 +966,7 @@ dissect_cdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	offset += length;
       }
     }
-    call_dissector(data_handle, tvb_new_subset(tvb, offset, -1, -1), pinfo,
+    call_dissector(data_handle, tvb_new_subset_remaining(tvb, offset), pinfo,
 		   cdp_tree);
 }
 
@@ -1060,6 +1121,101 @@ dissect_capabilities(tvbuff_t *tvb, int offset, int length, proto_tree *tree)
 	    "Not a Repeater"));
 }
 
+static void
+dissect_nrgyz_tlv(tvbuff_t *tvb, int offset, guint16 length, guint16 num,
+		  proto_tree *tree) 
+{
+    guint32 tlvt, tlvl, ip_addr;
+    proto_item *it = NULL;
+    proto_tree *etree = NULL;
+    char const *ttext = NULL;
+
+    while (num-- && length >= 8) {
+	tlvt = tvb_get_ntohl(tvb, offset);
+	tlvl = tvb_get_ntohl(tvb, offset + 4);
+
+	if (length < tlvl) break;
+	length -= tlvl;
+
+	if (tlvl < 8) {
+		proto_tree_add_text(tree, tvb, offset, 8,
+				    "TLV with invalid length %u (< 8)",
+				    tlvl);
+		offset += 8;
+		break;
+	}
+	else {
+	    ttext = val_to_str(tlvt, type_nrgyz_vals, "Unknown (0x%04x)");
+	    switch (tlvt) {
+	    case TYPE_NRGYZ_ROLE:
+	    case TYPE_NRGYZ_DOMAIN:
+	    case TYPE_NRGYZ_NAME:
+		it = proto_tree_add_text(tree, tvb, offset,
+					 tlvl, "EnergyWise %s: %s", ttext,
+					 tvb_format_stringzpad(tvb,
+							 offset + 8, tlvl - 8)
+					 );
+		break;
+	    case TYPE_NRGYZ_REPLYTO:
+		ip_addr = tvb_get_ipv4(tvb, offset + 12);
+		it = proto_tree_add_text(tree, tvb, offset,
+					 tlvl, "EnergyWise %s: %s port %u",
+					 ttext,
+					 ip_to_str((guint8 *)&ip_addr),
+					 tvb_get_ntohs(tvb, offset + 10)
+					 );
+		break;
+	    default:
+		it = proto_tree_add_text(tree, tvb, offset,
+					 tlvl, "EnergyWise %s TLV", ttext);
+	    }
+	    etree = proto_item_add_subtree(it, ett_cdp_nrgyz_tlv);
+	    proto_tree_add_text(etree, tvb, offset, 4,
+				"TLV Type: %x (%s)", tlvt, ttext);
+	    proto_tree_add_text(etree, tvb, offset + 4, 4,
+				"TLV Length: %u", tlvl);
+	    switch (tlvt) {
+	    case TYPE_NRGYZ_ROLE:
+	    case TYPE_NRGYZ_DOMAIN:
+	    case TYPE_NRGYZ_NAME:
+		proto_tree_add_text(etree, tvb, offset + 8,
+				    tlvl - 8, "%s %s", ttext,
+				    tvb_format_stringzpad(tvb,
+							  offset + 8, tlvl - 8)
+				    );
+		break;
+	    case TYPE_NRGYZ_REPLYTO:
+		ip_addr = tvb_get_ipv4(tvb, offset + 12);
+		proto_tree_add_text(etree, tvb, offset + 8, 2,
+				    "Unknown Field");
+		proto_tree_add_text(etree, tvb, offset + 10, 2,
+				    "Port %d",
+				    tvb_get_ntohs(tvb, offset + 10)
+				    );
+		proto_tree_add_text(etree, tvb, offset + 12, 4,
+				    "IP Address %s",
+				    ip_to_str((guint8 *)&ip_addr)
+				    );
+		proto_tree_add_text(etree, tvb, offset + 16, 2,
+				    "Unknown Field (Backup server Port?)");
+		proto_tree_add_text(etree, tvb, offset + 18, 4,
+				    "Unknown Field (Backup Server IP?)");
+		break;
+	    default:
+		if (tlvl > 8) {
+		    proto_tree_add_text(etree, tvb, offset + 8,
+					tlvl - 8, "Data");
+		}
+	    }
+	    offset += tlvl;
+	}
+    }
+    if (length) {
+	proto_tree_add_text(tree, tvb, offset, length,
+			    "Invalid garbage at end");
+    }
+}
+
 static void
 add_multi_line_string_to_tree(proto_tree *tree, tvbuff_t *tvb, gint start,
   gint len, const gchar *prefix)
@@ -1071,7 +1227,7 @@ add_multi_line_string_to_tree(proto_tree *tree, tvbuff_t *tvb, gint start,
     int line_len;
     int data_len;
 
-    prefix_len = strlen(prefix);
+    prefix_len = (int)strlen(prefix);
     if (prefix_len > 64)
 	prefix_len = 64;
     for (i = 0; i < prefix_len; i++)
@@ -1094,35 +1250,36 @@ proto_register_cdp(void)
     static hf_register_info hf[] = {
 	{ &hf_cdp_version,
 	{ "Version",		"cdp.version",  FT_UINT8, BASE_DEC, NULL, 0x0,
-	  "", HFILL }},
+	  NULL, HFILL }},
 
 	{ &hf_cdp_ttl,
 	{ "TTL",		"cdp.ttl", FT_UINT16, BASE_DEC, NULL, 0x0,
-	  "", HFILL }},
+	  NULL, HFILL }},
 
 	{ &hf_cdp_checksum,
 	{ "Checksum",		"cdp.checksum", FT_UINT16, BASE_HEX, NULL, 0x0,
-	  "", HFILL }},
+	  NULL, HFILL }},
 
 	{ &hf_cdp_checksum_good,
 	  { "Good",       "cdp.checksum_good", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
 	    "True: checksum matches packet content; False: doesn't match content or not checked", HFILL }},
 	
 	{ &hf_cdp_checksum_bad,
-	  { "Bad ",       "cdp.checksum_bad", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
+	  { "Bad",       "cdp.checksum_bad", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
 	    "True: checksum doesn't match packet content; False: matches content or not checked", HFILL }},
 	
 	{ &hf_cdp_tlvtype,
 	{ "Type",		"cdp.tlv.type", FT_UINT16, BASE_HEX, VALS(type_vals), 0x0,
-	  "", HFILL }},
+	  NULL, HFILL }},
 
 	{ &hf_cdp_tlvlength,
 	{ "Length",		"cdp.tlv.len", FT_UINT16, BASE_DEC, NULL, 0x0,
-	  "", HFILL }}
+	  NULL, HFILL }}
     };
     static gint *ett[] = {
 	&ett_cdp,
 	&ett_cdp_tlv,
+	&ett_cdp_nrgyz_tlv,
 	&ett_cdp_address,
 	&ett_cdp_capabilities,
 	&ett_cdp_checksum
