@@ -1,7 +1,7 @@
 /* packet-csm-encaps.c
  * Routines for CSM_ENCAPS dissection
  * Copyright 2005, Angelo Bannack <angelo.bannack@siemens.com>
- * $Id: packet-csm-encaps.c 26089 2008-08-25 22:06:20Z wmeier $
+ * $Id: packet-csm-encaps.c 29340 2009-08-09 06:26:46Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -42,8 +42,6 @@
 #include <glib.h>
 
 #include <epan/packet.h>
-#include <epan/reassemble.h>
-#include <epan/conversation.h>
 #include <epan/tap.h>
 
 #include <epan/proto.h>
@@ -171,26 +169,25 @@ static int hf_csm_encaps_param            = -1;
 static gint ett_csm_encaps         = -1;
 static gint ett_csm_encaps_control = -1;
 
-gchar *csm_fc(guint16 fc, guint16 ct);
-gboolean csm_to_host(guint16 fc, guint16 ct);
-
 
 /* returns the command name */
-gchar *csm_fc(guint16 fc, guint16 ct)
+static gchar *
+csm_fc(guint16 fc, guint16 ct)
 {
-    if (fc == 0x0000) {
-        return g_strdup(val_to_str(ct, class_type_vals,
-            "0x%04x"));
-    } else {
-        return g_strdup(val_to_str(fc, function_code_vals,
-            "0x%04x"));
-    }
+	if (fc == 0x0000) {
+		return g_strdup(val_to_str(ct, class_type_vals,
+					   "0x%04x"));
+	} else {
+		return g_strdup(val_to_str(fc, function_code_vals,
+					   "0x%04x"));
+	}
 }
 
 
 
 /* check to see if the message is an exclusive message send to host */
-gboolean csm_to_host(guint16 fc, guint16 ct)
+static gboolean
+csm_to_host(guint16 fc, guint16 ct)
 {
 	if (fc == 0x0000)
 	{
@@ -247,8 +244,7 @@ dissect_csm_encaps(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	}
 
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "CSM_ENCAPS");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "CSM_ENCAPS");
 
 	if (check_col(pinfo->cinfo, COL_INFO)) {
 		col_clear(pinfo->cinfo, COL_INFO);
