@@ -5,7 +5,7 @@
  * Routines for DCERPC over SMB packet disassembly
  * Copyright 2001-2003, Tim Potter <tpot@samba.org>
  *
- * $Id: packet-dcerpc-nt.c 28770 2009-06-18 21:30:42Z stig $
+ * $Id: packet-dcerpc-nt.c 30631 2009-10-20 08:44:26Z sahlberg $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -39,6 +39,25 @@
 #include "packet-dcerpc-nt.h"
 #include "packet-windows-common.h"
 
+
+int hf_nt_cs_len = -1;
+int hf_nt_cs_size = -1;
+static int hf_lsa_String_name_len = -1;
+static int hf_lsa_String_name_size = -1;
+
+
+static gint ett_nt_unicode_string = -1;
+static gint ett_lsa_String = -1;
+
+
+
+/* This is used to safely walk the decode tree up, one item at a time safely.
+   This is used by dcerpc dissectors that want to push the display of a string
+   higher up in the tree for greater visibility.
+*/
+#define GET_ITEM_PARENT(x) \
+	((x->parent!=NULL)?x->parent:x)
+
 /*
  * This file contains helper routines that are used by the DCERPC over SMB
  * dissectors for wireshark.
@@ -58,13 +77,8 @@ const value_string platform_id_vals[] = {
 
 /* Parse some common RPC structures */
 
-gint ett_nt_unicode_string = -1; /* FIXME: make static */
-
 /* Dissect a counted string as a callback to dissect_ndr_pointer_cb() */
 
-static int hf_nt_cs_len = -1;
-static int hf_nt_cs_size = -1;
-
 int
 dissect_ndr_counted_string_cb(tvbuff_t *tvb, int offset,
 			      packet_info *pinfo, proto_tree *tree,
@@ -75,9 +89,9 @@ dissect_ndr_counted_string_cb(tvbuff_t *tvb, int offset,
 	dcerpc_info *di = pinfo->private_data;
 	guint16 len, size;
 
-        /* Structure starts with short, but is aligned for longs */
+        /* Structure starts with short, but is aligned for pointer */
 
-	ALIGN_TO_4_BYTES;
+	ALIGN_TO_5_BYTES;
 
 	if (di->conformant_run)
 		return offset;
@@ -101,6 +115,10 @@ dissect_ndr_counted_string_cb(tvbuff_t *tvb, int offset,
 			dissect_ndr_wchar_cvstring, NDR_POINTER_UNIQUE,
 			"Character Array", hf_index, callback, callback_args);
 
+	if (di->call_data->flags & DCERPC_IS_NDR64) {
+		ALIGN_TO_5_BYTES;
+	}
+
 	return offset;
 }
 
@@ -178,9 +196,9 @@ dissect_ndr_counted_byte_array_cb(tvbuff_t *tvb, int offset,
 	proto_tree *subtree;
 	guint16 len, size;
 
-        /* Structure starts with short, but is aligned for longs */
+        /* Structure starts with short, but is aligned for pointer */
 
-	ALIGN_TO_4_BYTES;
+	ALIGN_TO_5_BYTES;
 
 	if (di->conformant_run)
 		return offset;
@@ -209,6 +227,10 @@ dissect_ndr_counted_byte_array_cb(tvbuff_t *tvb, int offset,
 			dissect_ndr_char_cvstring, NDR_POINTER_UNIQUE,
 			"Byte Array", hf_index, callback, callback_args);
 
+	if (di->call_data->flags & DCERPC_IS_NDR64) {
+		ALIGN_TO_5_BYTES;
+	}
+
 	return offset;
 }
 
@@ -245,15 +267,15 @@ static void cb_byte_array_postprocess(packet_info *pinfo, proto_tree *tree _U_,
 
 	if (levels > 0 && item && s && s[0]) {
 		proto_item_append_text(item, ": %s", s);
-		item = item->parent;
+		item = GET_ITEM_PARENT(item);
 		levels--;
 		if (levels > 0) {
 			proto_item_append_text(item, ": %s", s);
-			item = item->parent;
+			item = GET_ITEM_PARENT(item);
 			levels--;
 			while (levels > 0) {
 				proto_item_append_text(item, " %s", s);
-				item = item->parent;
+				item = GET_ITEM_PARENT(item);
 				levels--;
 			}
 		}
@@ -284,9 +306,9 @@ dissect_ndr_counted_ascii_string_cb(tvbuff_t *tvb, int offset,
 	proto_tree *subtree;
 	guint16 len, size;
 
-        /* Structure starts with short, but is aligned for longs */
+        /* Structure starts with short, but is aligned for pointer */
 
-	ALIGN_TO_4_BYTES;
+	ALIGN_TO_5_BYTES;
 
 	if (di->conformant_run)
 		return offset;
@@ -315,6 +337,10 @@ dissect_ndr_counted_ascii_string_cb(tvbuff_t *tvb, int offset,
 			dissect_ndr_char_cvstring, NDR_POINTER_UNIQUE,
 			"Ascii String", hf_index, callback, callback_args);
 
+	if (di->call_data->flags & DCERPC_IS_NDR64) {
+		ALIGN_TO_5_BYTES;
+	}
+
 	return offset;
 }
 
@@ -339,6 +365,51 @@ dissect_nt_GUID(tvbuff_t *tvb, int offset,
 	return offset;
 }
 
+/* This function is used to dissect a lsa_String
+	typedef [public] struct {
+		[value(strlen_m_term(name)*2)] uint16 name_len;
+		[value(strlen_m_term(name)*2)] uint16 name_size;
+		[string,charset(UTF16)] uint16 *name;
+	} lsa_String;
+ */
+int
+dissect_ndr_lsa_String(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *parent_tree, guint8 *drep, guint32 param, int hfindex)
+{
+	proto_item *item = NULL;
+	proto_tree *tree = NULL;
+	dcerpc_info *di = pinfo->private_data;
+	int old_offset;
+	header_field_info *hf_info;
+
+	ALIGN_TO_5_BYTES;
+
+	old_offset = offset;
+	hf_info=proto_registrar_get_nth(hfindex);
+
+	if (parent_tree) {
+		item = proto_tree_add_text(parent_tree, tvb, offset, 0, "%s: ", hf_info->name);
+		tree = proto_item_add_subtree(item, ett_lsa_String);
+	}
+	
+	offset = PIDL_dissect_uint16(tvb, offset, pinfo, tree, drep, hf_lsa_String_name_len, 0);
+
+	offset = PIDL_dissect_uint16(tvb, offset, pinfo, tree, drep, hf_lsa_String_name_size, 0);
+
+	offset = dissect_ndr_pointer_cb(
+		tvb, offset, pinfo, tree, drep,
+		dissect_ndr_wchar_cvstring, NDR_POINTER_UNIQUE,
+		hf_info->name, hfindex, cb_wstr_postprocess,
+		GINT_TO_POINTER(param));
+
+	proto_item_set_len(item, offset-old_offset);
+
+	if (di->call_data->flags & DCERPC_IS_NDR64) {
+		ALIGN_TO_5_BYTES;
+	}
+
+	return offset;
+}
+
 /* This function is used to dissect a DCERPC encoded 64 bit time value.
    XXX it should be fixed both here and in dissect_nt_64bit_time so
    it can handle both BIG and LITTLE endian encodings
@@ -1132,18 +1203,17 @@ void cb_wstr_postprocess(packet_info *pinfo, proto_tree *tree _U_,
 	}
 
 	/* Append string to upper-level proto_items */
-
 	if (levels > 0 && item && s && s[0]) {
 		proto_item_append_text(item, ": %s", s);
-		item = item->parent;
+		item = GET_ITEM_PARENT(item);
 		levels--;
 		if (levels > 0) {
 			proto_item_append_text(item, ": %s", s);
-			item = item->parent;
+			item = GET_ITEM_PARENT(item);
 			levels--;
 			while (levels > 0) {
 				proto_item_append_text(item, " %s", s);
-				item = item->parent;
+				item = GET_ITEM_PARENT(item);
 				levels--;
 			}
 		}
@@ -1198,15 +1268,15 @@ void cb_str_postprocess(packet_info *pinfo, proto_tree *tree _U_,
 
 	if (levels > 0 && item && s && s[0]) {
 		proto_item_append_text(item, ": %s", s);
-		item = item->parent;
+		item = GET_ITEM_PARENT(item);
 		levels--;
 		if (levels > 0) {
 			proto_item_append_text(item, ": %s", s);
-			item = item->parent;
+			item = GET_ITEM_PARENT(item);
 			levels--;
 			while (levels > 0) {
 				proto_item_append_text(item, " %s", s);
-				item = item->parent;
+				item = GET_ITEM_PARENT(item);
 				levels--;
 			}
 		}
@@ -1263,7 +1333,7 @@ dissect_ndr_nt_SID(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	/* the SID contains a conformant array, first we must eat
 	   the 4-byte max_count before we can hand it off */
 
-	offset = dissect_ndr_uint32 (tvb, offset, pinfo, tree, drep,
+	offset = dissect_ndr_uint3264 (tvb, offset, pinfo, tree, drep,
 			hf_nt_count, NULL);
 
 	offset = dissect_nt_sid(tvb, offset, tree, name, &sid_str,
@@ -1311,15 +1381,15 @@ dissect_ndr_nt_SID_with_options(tvbuff_t *tvb, int offset, packet_info *pinfo, p
 
 		if (levels > 0 && item && s && s[0]) {
 			proto_item_append_text(item, ": %s", s);
-			item = item->parent;
+			item = GET_ITEM_PARENT(item);
 			levels--;
 			if (levels > 0) {
 				proto_item_append_text(item, ": %s", s);
-				item = item->parent;
+				item = GET_ITEM_PARENT(item);
 				levels--;
 				while (levels > 0) {
 					proto_item_append_text(item, " %s", s);
-					item = item->parent;
+					item = GET_ITEM_PARENT(item);
 					levels--;
 				}
 			}
@@ -1565,6 +1635,7 @@ dissect_ndr_nt_PSID_ARRAY(tvbuff_t *tvb, int offset,
 	guint32 count;
 	proto_item *item=NULL;
 	proto_tree *tree=NULL;
+	dcerpc_info *di = pinfo->private_data;
 	int old_offset=offset;
 
 	if(parent_tree){
@@ -1573,6 +1644,8 @@ dissect_ndr_nt_PSID_ARRAY(tvbuff_t *tvb, int offset,
 		tree = proto_item_add_subtree(item, ett_nt_sid_array);
 	}
 
+	ALIGN_TO_5_BYTES;
+
 	offset = dissect_ndr_uint32 (tvb, offset, pinfo, tree, drep,
 			hf_nt_count, &count);
         offset = dissect_ndr_pointer(tvb, offset, pinfo, tree, drep,
@@ -1580,6 +1653,11 @@ dissect_ndr_nt_PSID_ARRAY(tvbuff_t *tvb, int offset,
 			"PSID_ARRAY", -1);
 
 	proto_item_set_len(item, offset-old_offset);
+
+	if (di->call_data->flags & DCERPC_IS_NDR64) {
+		ALIGN_TO_5_BYTES;
+	}
+
 	return offset;
 }
 
@@ -1761,6 +1839,14 @@ void dcerpc_smb_init(int proto_dcerpc)
                 { &hf_nt_attrib,
 		  { "Attributes", "dcerpc.nt.attr",
 		    FT_UINT32, BASE_HEX, NULL, 0x0, NULL, HFILL }},
+
+		{ &hf_lsa_String_name_len, 
+		  { "Name Len", "dcerpc.lsa_String.name_len",
+		    FT_UINT16, BASE_DEC, NULL, 0, NULL, HFILL }},
+
+		{ &hf_lsa_String_name_size, 
+		  { "Name Size", "dcerpc.lsa_String.name_size",
+		    FT_UINT16, BASE_DEC, NULL, 0, NULL, HFILL }},
 	};
 
 	static gint *ett[] = {
@@ -1776,6 +1862,7 @@ void dcerpc_smb_init(int proto_dcerpc)
                 &ett_nt_sid_and_attributes_array,
                 &ett_nt_sid_and_attributes,
 		&ett_nt_counted_ascii_string,
+		&ett_lsa_String,
 	};
 
 	/* Register ett's and hf's */
