@@ -3,7 +3,7 @@
  * Copyright 2003, Tim Potter <tpot@samba.org>
  * Copyright 2003, Ronnie Sahlberg,  added function dissectors
  *
- * $Id: packet-dcerpc-svcctl.c 22703 2007-08-28 11:45:08Z sahlberg $
+ * $Id: packet-dcerpc-svcctl.c 28989 2009-07-07 14:54:15Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -617,7 +617,7 @@ proto_register_dcerpc_svcctl(void)
         static hf_register_info hf[] = {
 	  { &hf_svcctl_opnum,
 	    { "Operation", "svcctl.opnum", FT_UINT16, BASE_DEC,
-	      NULL, 0x0, "Operation", HFILL }},
+	      NULL, 0x0, NULL, HFILL }},
 	  { &hf_svcctl_machinename,
 	    { "MachineName", "svcctl.machinename", FT_STRING, BASE_NONE,
 	      NULL, 0x0, "Name of the host we want to open the database on", HFILL }},
@@ -629,22 +629,22 @@ proto_register_dcerpc_svcctl(void)
 	      NULL, 0x0, "SVCCTL Access Mask", HFILL }},
 	  { &hf_svcctl_scm_rights_connect,
 	    { "Connect", "svcctl.scm_rights_connect", FT_BOOLEAN, 32,
-	      TFS(&flags_set_truth), 0x00000001, "SVCCTL Rights to connect to SCM", HFILL }},
+	      TFS(&tfs_set_notset), 0x00000001, "SVCCTL Rights to connect to SCM", HFILL }},
 	  { &hf_svcctl_scm_rights_create_service,
 	    { "Create Service", "svcctl.scm_rights_create_service", FT_BOOLEAN, 32,
-	      TFS(&flags_set_truth), 0x00000002, "SVCCTL Rights to create services", HFILL }},
+	      TFS(&tfs_set_notset), 0x00000002, "SVCCTL Rights to create services", HFILL }},
 	  { &hf_svcctl_scm_rights_enumerate_service,
 	    { "Enumerate Service", "svcctl.scm_rights_enumerate_service", FT_BOOLEAN, 32,
-	      TFS(&flags_set_truth), 0x00000004, "SVCCTL Rights to enumerate services", HFILL }},
+	      TFS(&tfs_set_notset), 0x00000004, "SVCCTL Rights to enumerate services", HFILL }},
 	  { &hf_svcctl_scm_rights_lock,
 	    { "Lock", "svcctl.scm_rights_lock", FT_BOOLEAN, 32,
-	      TFS(&flags_set_truth), 0x00000008, "SVCCTL Rights to lock database", HFILL }},
+	      TFS(&tfs_set_notset), 0x00000008, "SVCCTL Rights to lock database", HFILL }},
 	  { &hf_svcctl_scm_rights_query_lock_status,
 	    { "Query Lock Status", "svcctl.scm_rights_query_lock_status", FT_BOOLEAN, 32,
-	      TFS(&flags_set_truth), 0x00000010, "SVCCTL Rights to query database lock status", HFILL }},
+	      TFS(&tfs_set_notset), 0x00000010, "SVCCTL Rights to query database lock status", HFILL }},
 	  { &hf_svcctl_scm_rights_modify_boot_config,
 	    { "Modify Boot Config", "svcctl.scm_rights_modify_boot_config", FT_BOOLEAN, 32,
-	      TFS(&flags_set_truth), 0x00000020, "SVCCTL Rights to modify boot config", HFILL }},
+	      TFS(&tfs_set_notset), 0x00000020, "SVCCTL Rights to modify boot config", HFILL }},
 	  { &hf_svcctl_hnd,
 	    { "Context Handle", "svcctl.hnd", FT_BYTES, BASE_NONE,
 	      NULL, 0x0, "SVCCTL Context handle", HFILL }},
