@@ -3,7 +3,7 @@
  * Copyright 2005, Scientific Research Corporation
  * Initial implementation by Jeremy Ouellette <jouellet@scires.com>
  *
- * $Id: packet-dis-fields.c 21990 2007-05-29 18:52:42Z guy $
+ * $Id: packet-dis-fields.c 30604 2009-10-18 21:13:53Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -36,6 +36,7 @@
 guint32 pduType;
 guint32 entityKind;
 guint32 entityDomain;
+guint32 variableDatumLength;
 
 DIS_ParserNode DIS_FIELDS_PDU_HEADER[] =
 {
@@ -134,6 +135,21 @@ DIS_ParserNode DIS_FIELDS_NONE[] =
     { DIS_FIELDTYPE_END, NULL, 0,0,0 }
 };
 
+DIS_ParserNode DIS_FIELDS_FIXED_DATUM[] =
+{
+    { DIS_FIELDTYPE_DATUM_ID,                "Datum ID",0,0,0 },
+    { DIS_FIELDTYPE_FIXED_DATUM_VALUE,       "Datum value",0,0,0 },
+    { DIS_FIELDTYPE_END,                     NULL,0,0,0 }
+};
+
+DIS_ParserNode DIS_FIELDS_VARIABLE_DATUM[] =
+{
+    { DIS_FIELDTYPE_DATUM_ID,                "Datum ID",0,0,0 },
+    { DIS_FIELDTYPE_DATUM_LENGTH,            "Datum length",0,0,&variableDatumLength },
+    { DIS_FIELDTYPE_VARIABLE_DATUM_VALUE,    "Datum value",0,0,0 },
+    { DIS_FIELDTYPE_END,                     NULL,0,0,0 }
+};
+
 DIS_BitMask DIS_APPEARANCE_LANDPLATFORM[] =
 {
     { 0x00000001, 0, "Paint Scheme", {
@@ -496,10 +512,65 @@ gint parseField_Double(tvbuff_t *tvb, proto_tree *tree, gint offset, DIS_ParserN
 
     offset = alignOffset(offset, 8);
     doubleVal = tvb_get_ntohieee_double(tvb, offset);
-    proto_tree_add_text(tree, tvb, offset, 8, "%s = %lf",
+    proto_tree_add_text(tree, tvb, offset, 8, "%s = %f",
         parserNode.fieldLabel, doubleVal);
 
     offset += 8;
 
     return offset;
 }
+
+/* Parse the Timestamp */
+gint parseField_Timestamp(tvbuff_t *tvb, proto_tree *tree, gint offset, DIS_ParserNode parserNode)
+{
+   /* some consts */
+   static double MSEC_PER_SECOND = 1000.0;
+   static double MSEC_PER_MINUTE = 60.0 * 1000.0 ;
+   static double MSEC_PER_HOUR = 60.0 * 60.0 * 1000.0;
+   static double FSV = 0x7fffffff;
+   /* variables */
+   guint isAbsolute = 0;
+   guint32 uintVal;
+   guint minutes;
+   guint seconds;
+   guint milliseconds;
+   double ms;
+
+   offset = alignOffset(offset, 4);
+   
+   /* convert to host value */
+   uintVal = tvb_get_ntohl(tvb, offset);
+   /* determine absolute vis sim time */
+   if( uintVal & 1 )
+      isAbsolute = 1;
+
+   /* convert TS to MS */
+   ms = (uintVal >> 1) * MSEC_PER_HOUR / FSV;
+   ms += 0.5;
+
+   /* calc minutes and reduce ms */
+   minutes = (guint) (ms / MSEC_PER_MINUTE);
+   ms -= (minutes * MSEC_PER_MINUTE);
+
+   /* calc seconds and reduce ms */
+   seconds = (guint) (ms / MSEC_PER_SECOND);
+   ms -= (seconds * MSEC_PER_SECOND);
+
+   /* truncate milliseconds */
+   milliseconds = (guint) ms;
+
+   /* push out the values */
+   if( isAbsolute )
+   {
+      proto_tree_add_text(tree, tvb, offset, 4, "%s = %02d:%02d %03d absolute (UTM)",
+            parserNode.fieldLabel, minutes, seconds, milliseconds);
+   }
+   else
+   {
+      proto_tree_add_text(tree, tvb, offset, 4, "%s = %02d:%02d %03d relative",
+            parserNode.fieldLabel, minutes, seconds, milliseconds);
+   }
+
+   offset += 4;
+   return offset;
+}
