@@ -2,7 +2,7 @@
  * This is a dissector for the DirectPlay protocol.
  * Copyright 2006 - 2008 by Kai Blin
  *
- * $Id: packet-dplay.c 26899 2008-12-02 08:11:23Z jmayer $
+ * $Id: packet-dplay.c 30082 2009-09-22 21:18:11Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1011,7 +1011,7 @@ static gint dissect_type2f_message(proto_tree *tree, tvbuff_t *tvb, gint offset)
 static void dissect_dplay(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
     guint16 message_type;
-    guint16 second_message_type = -1;
+    guint16 second_message_type = G_MAXUINT16;
     guint16 proto_version;
     guint16 packet_size;
     guint32 dplay_id;
@@ -1024,13 +1024,11 @@ static void dissect_dplay(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     if(memcmp(play_id, (guint8 *)&dplay_id, 4) != 0)
     {
-        if(check_col(pinfo->cinfo, COL_PROTOCOL))
-            col_set_str(pinfo->cinfo, COL_PROTOCOL, "DPLAY");
+        col_set_str(pinfo->cinfo, COL_PROTOCOL, "DPLAY");
         /* Clear out stuff in the info column */
+        col_clear(pinfo->cinfo, COL_INFO);
         if(check_col(pinfo->cinfo,COL_INFO))
-            col_clear(pinfo->cinfo,COL_INFO);
-        if(check_col(pinfo->cinfo,COL_INFO))
-            col_add_fstr(pinfo->cinfo,COL_INFO, "DPlay data packet");
+            col_set_str(pinfo->cinfo, COL_INFO, "DPlay data packet");
         return;
     }
 
@@ -1039,13 +1037,9 @@ static void dissect_dplay(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         second_message_type = tvb_get_letohs(tvb, 72);
     }
 
-    if(check_col(pinfo->cinfo, COL_PROTOCOL))
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "DPLAY");
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "DPLAY");
     /* Clear out stuff in the info column */
-    if(check_col(pinfo->cinfo,COL_INFO))
-    {
-        col_clear(pinfo->cinfo,COL_INFO);
-    }
+    col_clear(pinfo->cinfo, COL_INFO);
 
     if(check_col(pinfo->cinfo,COL_INFO))
     {
@@ -1143,13 +1137,11 @@ static void dissect_dplay_player_msg(tvbuff_t *tvb, packet_info *pinfo, proto_tr
 {
     guint32 mixed, size, token;
 
-    if(check_col(pinfo->cinfo, COL_PROTOCOL))
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "DPLAY");
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "DPLAY");
     /* Clear out stuff in the info column */
+    col_clear(pinfo->cinfo, COL_INFO);
     if(check_col(pinfo->cinfo,COL_INFO))
-        col_clear(pinfo->cinfo,COL_INFO);
-    if(check_col(pinfo->cinfo,COL_INFO))
-        col_add_fstr(pinfo->cinfo,COL_INFO, "DPlay player to player message");
+        col_set_str(pinfo->cinfo, COL_INFO, "DPlay player to player message");
 
     if(tree)
     {
@@ -1216,48 +1208,48 @@ void proto_register_dplay(void)
     /* Common data fields */
     { &hf_dplay_size,
         { "DirectPlay package size", "dplay.size", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_token,
         { "DirectPlay token", "dplay.token", FT_UINT32, BASE_HEX,
-        VALS(dplay_token_val), 0x0, "", HFILL}},
+        VALS(dplay_token_val), 0x0, NULL, HFILL}},
     { &hf_dplay_saddr_af,
         { "DirectPlay s_addr_in address family", "dplay.saddr.af", FT_UINT16, BASE_HEX,
-        VALS(dplay_af_val), 0x0, "", HFILL}},
+        VALS(dplay_af_val), 0x0, NULL, HFILL}},
     { &hf_dplay_saddr_port,
         { "DirectPlay s_addr_in port", "dplay.saddr.port", FT_UINT16, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_saddr_ip,
         { "DirectPlay s_addr_in ip address", "dplay.saddr.ip", FT_IPv4, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_saddr_padding,
         { "DirectPlay s_addr_in null padding", "dplay.saddr.padding", FT_BYTES, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_play_str,
         { "DirectPlay action string", "dplay.dplay_str", FT_STRING, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_command,
         { "DirectPlay command", "dplay.command", FT_UINT16, BASE_HEX,
-        VALS(dplay_command_val), 0x0, "", HFILL}},
+        VALS(dplay_command_val), 0x0, NULL, HFILL}},
     { &hf_dplay_proto_dialect,
         { "DirectPlay dialect version", "dplay.dialect.version", FT_UINT16, BASE_HEX,
-        VALS(dplay_proto_dialect_val), 0x0, "", HFILL}},
+        VALS(dplay_proto_dialect_val), 0x0, NULL, HFILL}},
     { &hf_dplay_play_str_2,
         { "DirectPlay second action string", "dplay.dplay_str_2", FT_STRING, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_command_2,
         { "DirectPlay second command", "dplay.command_2", FT_UINT16, BASE_HEX,
-        VALS(dplay_command_val), 0x0, "", HFILL}},
+        VALS(dplay_command_val), 0x0, NULL, HFILL}},
     { &hf_dplay_proto_dialect_2,
         { "DirectPlay second dialect version", "dplay.dialect.version_2", FT_UINT16, BASE_HEX,
-        VALS(dplay_proto_dialect_val), 0x0, "", HFILL}},
+        VALS(dplay_proto_dialect_val), 0x0, NULL, HFILL}},
     { &hf_dplay_player_msg,
-        { "DirectPlay Player to Player message", "dplay.player_msg", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "DirectPlay Player to Player message", "dplay.player_msg", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
 
     /* Session Desc structure fields */
     { &hf_dplay_sess_desc_flags,
         { "DirectPlay session desc flags", "dplay.flags", FT_UINT32, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_flags_no_create_players,
         { "no create players flag", "dplay.flags.no_create_players", FT_BOOLEAN, 32,
         TFS(&tfs_dplay_flag), DPLAY_FLAG_NO_CREATE_PLAYERS, "No Create Players", HFILL}},
@@ -1314,239 +1306,239 @@ void proto_register_dplay(void)
         TFS(&tfs_dplay_flag), DPLAY_FLAG_NO_SESS_DESC_CHANGES, "No Sess Desc Changes", HFILL}},
     { &hf_dplay_instance_guid,
         { "DirectPlay instance guid", "dplay.instance.guid", FT_GUID, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_game_guid,
         { "DirectPlay game GUID", "dplay.game.guid", FT_GUID, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_sess_desc_length,
         { "DirectPlay session desc length", "dplay.sess_desc.length", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_max_players,
-        { "DirectPlay max players ", "dplay.sess_desc.max_players", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        { "DirectPlay max players", "dplay.sess_desc.max_players", FT_UINT32, BASE_DEC,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_curr_players,
         { "DirectPlay current players", "dplay.sess_desc.curr_players", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_sess_name_ptr,
-        { "Session description name pointer placeholder", "dplay.sess_desc.name_ptr", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "Session description name pointer placeholder", "dplay.sess_desc.name_ptr", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_passwd_ptr,
-        { "Session description password pointer placeholder", "dplay.sess_desc.pw_ptr", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "Session description password pointer placeholder", "dplay.sess_desc.pw_ptr", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_sess_desc_reserved_1,
-        { "Session description reserved 1", "dplay.sess_desc.res_1", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "Session description reserved 1", "dplay.sess_desc.res_1", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_sess_desc_reserved_2,
-        { "Session description reserved 2", "dplay.sess_desc.res_2", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "Session description reserved 2", "dplay.sess_desc.res_2", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_sess_desc_user_1,
-        { "Session description user defined 1", "dplay.sess_desc.user_1", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "Session description user defined 1", "dplay.sess_desc.user_1", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_sess_desc_user_2,
-        { "Session description user defined 2", "dplay.sess_desc.user_2", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "Session description user defined 2", "dplay.sess_desc.user_2", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_sess_desc_user_3,
-        { "Session description user defined 3", "dplay.sess_desc.user_3", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "Session description user defined 3", "dplay.sess_desc.user_3", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_sess_desc_user_4,
-        { "Session description user defined 4", "dplay.sess_desc.user_4", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "Session description user defined 4", "dplay.sess_desc.user_4", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
 
     /* PackedPlayer structure fields */
     { &hf_dplay_pp_size,
         { "PackedPlayer size", "dplay.pp.size", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_pp_flags,
         { "PackedPlayer flags", "dplay.pp.flags", FT_UINT32, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_pp_flag_sysplayer,
         { "is system player", "dplay.pp.flags.sysplayer", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_PP_FLAG_SYSPLAYER, "", HFILL}},
+        TFS(&tfs_dplay_flag), DPLAY_PP_FLAG_SYSPLAYER, NULL, HFILL}},
     { &hf_dplay_pp_flag_nameserver,
         { "is name server", "dplay.pp.flags.nameserver", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_PP_FLAG_NAMESERVER, "", HFILL}},
+        TFS(&tfs_dplay_flag), DPLAY_PP_FLAG_NAMESERVER, NULL, HFILL}},
     { &hf_dplay_pp_flag_in_group,
         { "in group", "dplay.pp.flags.in_group", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_PP_FLAG_IN_GROUP, "", HFILL}},
+        TFS(&tfs_dplay_flag), DPLAY_PP_FLAG_IN_GROUP, NULL, HFILL}},
     { &hf_dplay_pp_flag_sending,
         { "sending player on local machine", "dplay.pp.flags.sending", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_SPP_FLAG_SENDING, "", HFILL}},
+        TFS(&tfs_dplay_flag), DPLAY_SPP_FLAG_SENDING, NULL, HFILL}},
     { &hf_dplay_pp_id,
-        { "PackedPlayer ID", "dplay.pp.id", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "PackedPlayer ID", "dplay.pp.id", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_pp_short_name_len,
         { "PackedPlayer short name length", "dplay.pp.short_name_len", FT_UINT32, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_pp_long_name_len,
         { "PackedPlayer long name length", "dplay.pp.long_name_len", FT_UINT32, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_pp_sp_data_size,
         { "PackedPlayer service provider data size", "dplay.pp.sp_data_size", FT_UINT32, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_pp_player_data_size,
         { "PackedPlayer player data size", "dplay.pp.player_data_size", FT_UINT32, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_pp_num_players,
         { "PackedPlayer player count", "dplay.pp.player_count", FT_UINT32, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_pp_system_player,
-        { "PackedPlayer system player ID", "dplay.pp.sysplayer_id", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "PackedPlayer system player ID", "dplay.pp.sysplayer_id", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_pp_fixed_size,
         { "PackedPlayer fixed size", "dplay.pp.fixed_size", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_pp_dialect,
         { "PackedPlayer dialect version", "dplay.pp.dialect", FT_UINT32, BASE_HEX,
-        VALS(&dplay_proto_dialect_val), 0x0, "", HFILL}},
+        VALS(&dplay_proto_dialect_val), 0x0, NULL, HFILL}},
     { &hf_dplay_pp_unknown_1,
-        { "PackedPlayer unknown 1", "dplay.pp.unknown_1", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "PackedPlayer unknown 1", "dplay.pp.unknown_1", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_pp_short_name,
         { "PackedPlayer short name", "dplay.pp.short_name", FT_STRING, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_pp_long_name,
         { "PackedPlayer long name", "dplay.pp.short_name", FT_STRING, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_pp_player_data,
-        { "PackedPlayer player data", "dplay.pp.player_data", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "PackedPlayer player data", "dplay.pp.player_data", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_pp_sp_data,
-        { "PackedPlayer service provider data", "dplay.pp.sp_data", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "PackedPlayer service provider data", "dplay.pp.sp_data", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_pp_player_id,
-        { "PackedPlayer player ID", "dplay.pp.player_id", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "PackedPlayer player ID", "dplay.pp.player_id", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_pp_parent_id,
-        { "PackedPlayer parent ID", "dplay.pp.parent_id", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "PackedPlayer parent ID", "dplay.pp.parent_id", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
 
     /* SuperPackedPlayer structure fields */
     { &hf_dplay_spp_size,
         { "SuperPackedPlayer size", "dplay.spp.size", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_spp_flags,
         { "SuperPackedPlayer flags", "dplay.spp.flags", FT_UINT32, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_spp_flags_sysplayer,
         { "is system player", "dplay.spp.flags.sysplayer", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_SPP_FLAG_SYSPLAYER, "", HFILL}},
+        TFS(&tfs_dplay_flag), DPLAY_SPP_FLAG_SYSPLAYER, NULL, HFILL}},
     { &hf_dplay_spp_flags_nameserver,
         { "is name server", "dplay.spp.flags.nameserver", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_SPP_FLAG_NAMESERVER, "", HFILL}},
+        TFS(&tfs_dplay_flag), DPLAY_SPP_FLAG_NAMESERVER, NULL, HFILL}},
     { &hf_dplay_spp_flags_in_group,
         { "in group", "dplay.spp.flags.in_group", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_SPP_FLAG_IN_GROUP, "", HFILL}},
+        TFS(&tfs_dplay_flag), DPLAY_SPP_FLAG_IN_GROUP, NULL, HFILL}},
     { &hf_dplay_spp_flags_sending,
         { "sending player on local machine", "dplay.spp.flags.sending", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_SPP_FLAG_SENDING, "", HFILL}},
+        TFS(&tfs_dplay_flag), DPLAY_SPP_FLAG_SENDING, NULL, HFILL}},
     { &hf_dplay_spp_id,
-        { "SuperPackedPlayer ID", "dplay.spp.id", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "SuperPackedPlayer ID", "dplay.spp.id", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_spp_player_info_mask,
         { "SuperPackedPlayer player info mask", "dplay.spp.pim", FT_UINT32, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_spp_have_short_name,
         { "SuperPackedPlayer have short name", "dplay.spp.pim.short_name", FT_UINT32, BASE_HEX,
-        VALS(yes_no_val), 0x0, "", HFILL}},
+        VALS(yes_no_val), 0x0, NULL, HFILL}},
     { &hf_dplay_spp_have_long_name,
         { "SuperPackedPlayer have long name", "dplay.spp.pim.long_name", FT_UINT32, BASE_HEX,
-        VALS(yes_no_val), 0x0, "", HFILL}},
+        VALS(yes_no_val), 0x0, NULL, HFILL}},
     { &hf_dplay_spp_sp_length_type,
         { "SuperPackedPlayer service provider length info", "dplay.spp.pim.sp_length", FT_UINT32, BASE_HEX,
-        VALS(dplay_spp_length_val), 0x0, "", HFILL}},
+        VALS(dplay_spp_length_val), 0x0, NULL, HFILL}},
     { &hf_dplay_spp_pd_length_type,
         { "SuperPackedPlayer player data length info", "dplay.spp.pim.pd_length", FT_UINT32, BASE_HEX,
-        VALS(dplay_spp_length_val), 0x0, "", HFILL}},
+        VALS(dplay_spp_length_val), 0x0, NULL, HFILL}},
     { &hf_dplay_spp_player_count_type,
         { "SuperPackedPlayer player count info", "dplay.spp.pim.player_count", FT_UINT32, BASE_HEX,
-        VALS(dplay_spp_length_val), 0x0, "", HFILL}},
+        VALS(dplay_spp_length_val), 0x0, NULL, HFILL}},
     { &hf_dplay_spp_have_parent_id,
         { "SuperPackedPlayer have parent ID", "dplay.spp.pim.parent_id", FT_UINT32, BASE_HEX,
-        VALS(yes_no_val), 0x0, "", HFILL}},
+        VALS(yes_no_val), 0x0, NULL, HFILL}},
     { &hf_dplay_spp_shortcut_count_type,
         { "SuperPackedPlayer shortcut count info", "dplay.spp.pim.shortcut_count", FT_UINT32, BASE_HEX,
-        VALS(dplay_spp_length_val), 0x0, "", HFILL}},
+        VALS(dplay_spp_length_val), 0x0, NULL, HFILL}},
     { &hf_dplay_spp_dialect,
         { "SuperPackedPlayer dialect version", "dplay.spp.dialect", FT_UINT32, BASE_HEX,
-        VALS(&dplay_proto_dialect_val), 0x0, "", HFILL}},
+        VALS(&dplay_proto_dialect_val), 0x0, NULL, HFILL}},
     { &hf_dplay_spp_sys_player_id,
-        { "SuperPackedPlayer system player ID", "dplay.spp.sysplayer_id", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "SuperPackedPlayer system player ID", "dplay.spp.sysplayer_id", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_spp_short_name,
         { "SuperPackedPlayer short name", "dplay.spp.short_name", FT_STRING, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_spp_long_name,
         { "SuperPackedPlayer long name", "dplay.spp.short_name", FT_STRING, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_spp_player_data_length,
         { "SuperPackedPlayer player data length", "dplay.spp.pd_length", FT_UINT32, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_spp_player_data,
-        { "SuperPackedPlayer player data", "dplay.spp.player_data", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "SuperPackedPlayer player data", "dplay.spp.player_data", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_spp_sp_data_length,
         { "SuperPackedPlayer service provider data length", "dplay.spp.sp_data_length", FT_UINT32, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_spp_sp_data,
-        { "SuperPackedPlayer service provider data", "dplay.spp.sp_data", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "SuperPackedPlayer service provider data", "dplay.spp.sp_data", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_spp_player_count,
         { "SuperPackedPlayer player count", "dplay.spp.player_count", FT_UINT32, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_spp_player_id,
-        { "SuperPackedPlayer player ID", "dplay.spp.player_id", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "SuperPackedPlayer player ID", "dplay.spp.player_id", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_spp_parent_id,
-        { "SuperPackedPlayer parent ID", "dplay.spp.parent_id", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "SuperPackedPlayer parent ID", "dplay.spp.parent_id", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_spp_shortcut_count,
         { "SuperPackedPlayer shortcut count", "dplay.spp.shortcut_count", FT_UINT32, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_spp_shortcut_id,
-        { "SuperPackedPlayer shortcut ID", "dplay.spp.shortcut_id", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "SuperPackedPlayer shortcut ID", "dplay.spp.shortcut_id", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
 
     /* Data fields for SecDesc struct */
     { &hf_dplay_sd_size,
         { "SecDesc struct size", "dplay.sd.size", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_sd_flags,
         { "SecDesc flags", "dplay.sd.flags", FT_UINT32, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_sd_sspi,
-        { "SecDesc SSPI provider ptr", "dplay.sd.sspi", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "SecDesc SSPI provider ptr", "dplay.sd.sspi", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_sd_capi,
-        { "SecDesc CAPI provider ptr", "dplay.sd.capi", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "SecDesc CAPI provider ptr", "dplay.sd.capi", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_sd_capi_type,
         { "SecDesc CAPI provider type", "dplay.sd.capi_type", FT_UINT32, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_sd_enc_alg,
         { "SecDesc encryption algorithm" , "dplay.sd.enc_alg", FT_UINT32, BASE_HEX,
-        VALS(dplay_enc_alg_val), 0x0, "", HFILL}},
+        VALS(dplay_enc_alg_val), 0x0, NULL, HFILL}},
 
     /* Data fields for message type 0x0001 */
     { &hf_dplay_type_01_name_offset,
         { "Enum Session Reply name offset", "dplay.type_01.name_offs", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_01_game_name,
         { "Enum Session Reply game name", "dplay.type_01.game_name", FT_STRING, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
 
     /* Data fields for message type 0x0002 */
     { &hf_dplay_type_02_game_guid,
         { "DirectPlay game GUID", "dplay.type02.game.guid", FT_GUID, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_02_password_offset,
         { "Enum Sessions password offset", "dplay.type02.password_offset", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_02_flags,
         { "Enum Session flags", "dplay.type02.flags", FT_UINT32, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_02_password,
         { "Session password", "dplay.type02.password", FT_STRING, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_enum_sess_flag_join,
         { "Enumerate joinable sessions", "dplay.type02.joinable", FT_BOOLEAN, 32,
         TFS(&tfs_dplay_flag), DPLAY_ENUM_SESS_FLAG_JOIN, "Joinable", HFILL}},
@@ -1560,185 +1552,185 @@ void proto_register_dplay(void)
     /* Data fields for message type 0x0005 */
     { &hf_dplay_type_05_flags,
         { "Player ID request flags", "dplay.type_05.flags", FT_UINT32, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_05_system_player,
         { "is system player", "dplay.type_05.flags.sys_player", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_TYPE05_FLAG_SYSPLAYER, "", HFILL}},
+        TFS(&tfs_dplay_flag), DPLAY_TYPE05_FLAG_SYSPLAYER, NULL, HFILL}},
     { &hf_dplay_type_05_name_server,
         { "is name server", "dplay.type_05.flags.name_server", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_TYPE05_FLAG_NAMESERVER, "", HFILL}},
+        TFS(&tfs_dplay_flag), DPLAY_TYPE05_FLAG_NAMESERVER, NULL, HFILL}},
     { &hf_dplay_type_05_local,
         { "is local player", "dplay.type_05.flags.local", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_TYPE05_FLAG_LOCAL, "", HFILL}},
+        TFS(&tfs_dplay_flag), DPLAY_TYPE05_FLAG_LOCAL, NULL, HFILL}},
     { &hf_dplay_type_05_unknown,
         { "unknown", "dplay.type_05.flags.unknown", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_TYPE05_FLAG_UNKNOWN, "", HFILL}},
+        TFS(&tfs_dplay_flag), DPLAY_TYPE05_FLAG_UNKNOWN, NULL, HFILL}},
     { &hf_dplay_type_05_secure,
         { "is secure session", "dplay.type_05.flags.secure", FT_BOOLEAN, 32,
-        TFS(&tfs_dplay_flag), DPLAY_TYPE05_FLAG_SECURE, "", HFILL}},
+        TFS(&tfs_dplay_flag), DPLAY_TYPE05_FLAG_SECURE, NULL, HFILL}},
 
     /* Data fields for message type 0x0007 */
     { &hf_dplay_type_07_dpid,
-        { "DirectPlay ID", "dplay.type_07.dpid", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "DirectPlay ID", "dplay.type_07.dpid", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_07_sspi_offset,
         { "SSPI provider offset", "dplay.type_07.sspi_offset", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_07_capi_offset,
         { "CAPI provider offset", "dplay.type_07.capi_offset", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_07_hresult,
         { "Request player HRESULT", "dplay.type_07.hresult", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_07_sspi,
         { "SSPI provider", "dplay.type_07.sspi", FT_STRING, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_07_capi,
         { "CAPI provider", "dplay.type_07.capi", FT_STRING, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
 
     /* Data fields for message type 0x0008, 0x0009, 0x000b, 0x000c, 0x000d,
      * 0x000e, 0x002e and 0x0038*/
     { &hf_dplay_multi_id_to,
-        { "ID to", "dplay.multi.id_to", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "ID to", "dplay.multi.id_to", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_multi_player_id,
-        { "Player ID", "dplay.multi.player_id", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "Player ID", "dplay.multi.player_id", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_multi_group_id,
-        { "Group ID", "dplay.multi.group_id", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "Group ID", "dplay.multi.group_id", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_multi_create_offset,
         { "Offset to PackedPlayer struct", "dplay.multi.create_offset", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_multi_password_offset,
         { "Offset to password", "dplay.multi.password_offset", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_multi_password,
         { "Password", "dplay.multi.password", FT_STRING, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
 
     /* Data fields for message type 0x000f */
     { &hf_dplay_type_0f_id_to,
-        { "ID to", "dplay.type_0f.id_to", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "ID to", "dplay.type_0f.id_to", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_0f_id,
-        { "Player ID", "dplay.type_0f.player_id", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "Player ID", "dplay.type_0f.player_id", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_0f_data_size,
         { "Data Size", "dplay.multi.group_id", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_0f_data_offset,
         { "Data Offset", "dplay.type_0f.data_offset", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_0f_data,
-        { "Player Data", "dplay.type_0f.player_data", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "Player Data", "dplay.type_0f.player_data", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
 
     /* Data fields for message type 0x0013 */
     { &hf_dplay_type_13_id_to,
-        { "ID to", "dplay.type_13.id_to", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "ID to", "dplay.type_13.id_to", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_13_player_id,
-        { "Player ID", "dplay.type_13.player_id", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "Player ID", "dplay.type_13.player_id", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_13_group_id,
-        { "Group ID", "dplay.type_13.group_id", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "Group ID", "dplay.type_13.group_id", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_13_create_offset,
         { "Create Offset", "dplay.type_13.create_offset", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_13_password_offset,
         { "Password Offset", "dplay.type_13.password_offset", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_13_password,
         { "Password", "dplay.type_13.password", FT_STRING, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_13_tick_count,
-        { "Tick count? Looks like an ID", "dplay.type_13.tick_count", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "Tick count? Looks like an ID", "dplay.type_13.tick_count", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
 
     /* Data fields for message type 0x0015 */
     { &hf_dplay_message_guid,
         { "Message GUID", "dplay.message.guid", FT_GUID, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_15_packet_idx,
         { "Packet Index", "dplay.type_15.packet_idx", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_15_data_size,
         { "Data Size", "dplay.type_15.data_size", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_15_offset,
         { "Offset", "dplay.type_15.offset", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_15_total_packets,
         { "Total Packets", "dplay.type_15.total_packets", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_15_msg_size,
         { "Message size", "dplay.type_15.message.size", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_15_packet_offset,
         { "Packet offset", "dplay.type_15.packet_offset", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
 
     /* Data field for message type 0x0016 and 0x0017 */
     { &hf_dplay_ping_id_from,
-        { "ID From", "dplay.ping.id_from", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "ID From", "dplay.ping.id_from", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_ping_tick_count,
         { "Tick Count", "dplay.ping.tick_count", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
 
     /* Data fields for message type 0x001a */
     { &hf_dplay_type_1a_id_to,
-        { "ID From", "dplay.type_1a.id_to", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "ID From", "dplay.type_1a.id_to", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_1a_sess_name_ofs,
         { "Session Name Offset", "dplay.type_1a.sess_name_ofs", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_1a_password_ofs,
         { "Password Offset", "dplay.type_1a.password_offset", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_1a_session_name,
         { "Session Name", "dplay.type_1a.session_name", FT_STRING, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_1a_password,
         { "Password", "dplay.type_1a.password", FT_STRING, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
 
     /* Data fields for message type 0x0029 */
     { &hf_dplay_type_29_player_count,
         { "SuperEnumPlayers Reply player count", "dplay.type_29.player_count", FT_UINT32,
-        BASE_DEC, NULL, 0x0, "", HFILL}},
+        BASE_DEC, NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_29_group_count,
         { "SuperEnumPlayers Reply group count", "dplay.type_29.group_count", FT_UINT32,
-        BASE_DEC, NULL, 0x0, "", HFILL}},
+        BASE_DEC, NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_29_packed_offset,
         { "SuperEnumPlayers Reply packed offset", "dplay.type_29.packed_offset", FT_UINT32,
-        BASE_DEC, NULL, 0x0, "", HFILL}},
+        BASE_DEC, NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_29_shortcut_count,
         { "SuperEnumPlayers Reply shortcut count", "dplay.type_29.shortcut_count", FT_UINT32,
-        BASE_DEC, NULL, 0x0, "", HFILL}},
+        BASE_DEC, NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_29_description_offset,
         { "SuperEnumPlayers Reply description offset", "dplay.type_29.desc_offset", FT_UINT32,
-        BASE_DEC, NULL, 0x0, "", HFILL}},
+        BASE_DEC, NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_29_name_offset,
         { "SuperEnumPlayers Reply name offset", "dplay.type_29.name_offset", FT_UINT32,
-        BASE_DEC, NULL, 0x0, "", HFILL}},
+        BASE_DEC, NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_29_password_offset,
         { "SuperEnumPlayers Reply password offset", "dplay.type_29.pass_offset", FT_UINT32,
-        BASE_DEC, NULL, 0x0, "", HFILL}},
+        BASE_DEC, NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_29_game_name,
         { "SuperEnumPlayers Reply game name", "dplay.type_29.game_name", FT_STRING, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
     { &hf_dplay_type_29_password,
         { "SuperEnumPlayers Reply Password", "dplay.type_29.password", FT_STRING, BASE_NONE,
-        NULL, 0x0, "", HFILL}},
+        NULL, 0x0, NULL, HFILL}},
 
     /* Data fields for message type 0x002f */
     { &hf_dplay_type_2f_dpid,
-        { "ID of the forwarded player", "dplay.type_29.id", FT_BYTES, BASE_HEX,
-        NULL, 0x0, "", HFILL}},
+        { "ID of the forwarded player", "dplay.type_29.id", FT_BYTES, BASE_NONE,
+        NULL, 0x0, NULL, HFILL}},
     };
 
     static gint *ett[] = {
