@@ -3,7 +3,7 @@
  * This decoder is for FC-SB3 version 1.4
  * Copyright 2003, Dinesh G Dutt <ddutt@cisco.com>
  *
- * $Id: packet-fcsb3.c 28412 2009-05-19 17:16:14Z stig $
+ * $Id: packet-fcsb3.c 30125 2009-09-24 20:00:21Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -627,72 +627,56 @@ dissect_status (packet_info *pinfo, proto_tree *parent_tree, tvbuff_t *tvb, int
 	proto_tree_add_boolean(tree, hf_sbccs_dib_status_attention, tvb, offset, 1, flags);
 	if (flags&0x80){
 		proto_item_append_text(item, "  Attention");
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_append_str(pinfo->cinfo, COL_INFO, "  Attention");
-		}
+		col_append_str(pinfo->cinfo, COL_INFO, "  Attention");
 	}
 	flags&=(~( 0x80 ));
 
 	proto_tree_add_boolean(tree, hf_sbccs_dib_status_modifier, tvb, offset, 1, flags);
 	if (flags&0x40){
 		proto_item_append_text(item, "  Status Modifier");
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_append_str(pinfo->cinfo, COL_INFO, "  Status Modifier");
-		}
+		col_append_str(pinfo->cinfo, COL_INFO, "  Status Modifier");
 	}
 	flags&=(~( 0x40 ));
 
 	proto_tree_add_boolean(tree, hf_sbccs_dib_status_cue, tvb, offset, 1, flags);
 	if (flags&0x20){
 		proto_item_append_text(item, "  Control-Unit End");
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_append_str(pinfo->cinfo, COL_INFO, "  Control-Unit End");
-		}
+		col_append_str(pinfo->cinfo, COL_INFO, "  Control-Unit End");
 	}
 	flags&=(~( 0x20 ));
 
 	proto_tree_add_boolean(tree, hf_sbccs_dib_status_busy, tvb, offset, 1, flags);
 	if (flags&0x10){
 		proto_item_append_text(item, "  Busy");
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_append_str(pinfo->cinfo, COL_INFO, "  Busy");
-		}
+		col_append_str(pinfo->cinfo, COL_INFO, "  Busy");
 	}
 	flags&=(~( 0x10 ));
 
 	proto_tree_add_boolean(tree, hf_sbccs_dib_status_channelend, tvb, offset, 1, flags);
 	if (flags&0x08){
 		proto_item_append_text(item, "  Channel End");
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_append_str(pinfo->cinfo, COL_INFO, "  Channel End");
-		}
+		col_append_str(pinfo->cinfo, COL_INFO, "  Channel End");
 	}
 	flags&=(~( 0x08 ));
 
 	proto_tree_add_boolean(tree, hf_sbccs_dib_status_deviceend, tvb, offset, 1, flags);
 	if (flags&0x04){
 		proto_item_append_text(item, "  Device End");
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_append_str(pinfo->cinfo, COL_INFO, "  Device End");
-		}
+		col_append_str(pinfo->cinfo, COL_INFO, "  Device End");
 	}
 	flags&=(~( 0x04 ));
 
 	proto_tree_add_boolean(tree, hf_sbccs_dib_status_unit_check, tvb, offset, 1, flags);
 	if (flags&0x02){
 		proto_item_append_text(item, "  Unit Check");
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_append_str(pinfo->cinfo, COL_INFO, "  Unit Check");
-		}
+		col_append_str(pinfo->cinfo, COL_INFO, "  Unit Check");
 	}
 	flags&=(~( 0x02 ));
 
 	proto_tree_add_boolean(tree, hf_sbccs_dib_status_unit_exception, tvb, offset, 1, flags);
 	if (flags&0x01){
 		proto_item_append_text(item, "  Unit Exception");
-		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_append_str(pinfo->cinfo, COL_INFO, "  Unit Exception");
-		}
+		col_append_str(pinfo->cinfo, COL_INFO, "  Unit Exception");
 	}
 	flags&=(~( 0x01 ));
 
@@ -882,8 +866,7 @@ static void dissect_fc_sbccs_dib_status_hdr (tvbuff_t *tvb, packet_info *pinfo,
         proto_tree_add_item (tree, hf_sbccs_lrc, tvb, offset+12, 4, 0);
 
         if (supp_status_cnt) {
-            next_tvb = tvb_new_subset (tvb, offset+FC_SBCCS_DIB_LRC_HDR_SIZE,
-                                       -1, -1);
+            next_tvb = tvb_new_subset_remaining (tvb, offset+FC_SBCCS_DIB_LRC_HDR_SIZE);
             call_dissector (data_handle, next_tvb, pinfo, tree);
         }
     }
@@ -1019,8 +1002,7 @@ static void dissect_fc_sbccs (tvbuff_t *tvb, packet_info *pinfo,
     void* pd_save;
         
     /* Make entries in Protocol column and Info column on summary display */
-    if (check_col(pinfo->cinfo, COL_PROTOCOL)) 
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "FC-SB3");
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "FC-SB3");
 
     /* Decode the basic SB3 and IU header and determine type of frame */
     type = get_fc_sbccs_iu_type (tvb, offset);
@@ -1088,15 +1070,14 @@ static void dissect_fc_sbccs (tvbuff_t *tvb, packet_info *pinfo,
         dissect_fc_sbccs_dib_link_hdr (tvb, pinfo, dib_tree, offset);
         break;
     default:
-        next_tvb = tvb_new_subset (tvb, offset, -1, -1);
+        next_tvb = tvb_new_subset_remaining (tvb, offset);
         call_dissector (data_handle, next_tvb, pinfo, dib_tree);
         break;
     }
 
     if ((get_fc_sbccs_iu_type (tvb, 0) != FC_SBCCS_IU_CTL) &&
         (get_fc_sbccs_iu_type (tvb, 0) != FC_SBCCS_IU_CMD_LINK_CTL))  {
-        next_tvb = tvb_new_subset (tvb, offset+FC_SBCCS_DIB_LRC_HDR_SIZE,
-                                   -1, -1);
+        next_tvb = tvb_new_subset_remaining (tvb, offset+FC_SBCCS_DIB_LRC_HDR_SIZE);
         call_dissector (data_handle, next_tvb, pinfo, tree);
     }
     pinfo->private_data = pd_save;
@@ -1115,208 +1096,208 @@ proto_register_fcsbccs (void)
     static hf_register_info hf[] = {
         { &hf_sbccs_chid,
           {"Channel Image ID", "sbccs.chid", FT_UINT8, BASE_DEC, NULL, 0x0,
-           "", HFILL}},
+           NULL, HFILL}},
         { &hf_sbccs_cuid,
           {"Control Unit Image ID", "sbccs.cuid", FT_UINT8, BASE_DEC, NULL,
-           0x0, "", HFILL}},
+           0x0, NULL, HFILL}},
         { &hf_sbccs_devaddr,
           {"Device Address", "sbccs.devaddr", FT_UINT16, BASE_DEC, NULL, 0x0,
-           "", HFILL}},
+           NULL, HFILL}},
         { &hf_sbccs_iui,
           {"Information Unit Identifier", "sbccs.iui", FT_UINT8, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_sbccs_dhflags,
-          {"DH Flags", "sbccs.dhflags", FT_UINT8, BASE_HEX, NULL, 0x0, "",
+          {"DH Flags", "sbccs.dhflags", FT_UINT8, BASE_HEX, NULL, 0x0, NULL,
            HFILL}},
         { &hf_sbccs_ccw,
-          {"CCW Number", "sbccs.ccw", FT_UINT16, BASE_HEX, NULL, 0x0, "",
+          {"CCW Number", "sbccs.ccw", FT_UINT16, BASE_HEX, NULL, 0x0, NULL,
            HFILL}},
         { &hf_sbccs_token,
-          {"Token", "sbccs.token", FT_UINT24, BASE_DEC, NULL, 0x0, "",
+          {"Token", "sbccs.token", FT_UINT24, BASE_DEC, NULL, 0x0, NULL,
            HFILL}},
         { &hf_sbccs_dib_iucnt,
           {"DIB IU Count", "sbccs.iucnt", FT_UINT8, BASE_DEC, NULL, 0x0,
-           "", HFILL}},
+           NULL, HFILL}},
         { &hf_sbccs_dib_datacnt,
           {"DIB Data Byte Count", "sbccs.databytecnt", FT_UINT16, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_sbccs_dib_ccw_cmd,
           {"CCW Command", "sbccs.ccwcmd", FT_UINT8, BASE_HEX,
-           VALS (fc_sbccs_dib_cmd_val), 0x0, "", HFILL}},
+           VALS (fc_sbccs_dib_cmd_val), 0x0, NULL, HFILL}},
         { &hf_sbccs_dib_ccw_cnt,
-          {"CCW Count", "sbccs.ccwcnt", FT_UINT16, BASE_DEC, NULL, 0x0, "",
+          {"CCW Count", "sbccs.ccwcnt", FT_UINT16, BASE_DEC, NULL, 0x0, NULL,
            HFILL}},
         { &hf_sbccs_dib_ioprio,
           {"I/O Priority", "sbccs.ioprio", FT_UINT8, BASE_DEC, NULL, 0x0,
-           "", HFILL}},
+           NULL, HFILL}},
         { &hf_sbccs_dib_status,
-          {"Status", "sbccs.status", FT_UINT8, BASE_HEX, NULL, 0x0, "",
+          {"Status", "sbccs.status", FT_UINT8, BASE_HEX, NULL, 0x0, NULL,
            HFILL}},
         { &hf_sbccs_dib_residualcnt,
           {"Residual Count", "sbccs.residualcnt", FT_UINT8, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_sbccs_dib_iupacing,
           {"IU Pacing", "sbccs.iupacing", FT_UINT8, BASE_DEC, NULL, 0x0,
-           "", HFILL}},
+           NULL, HFILL}},
         { &hf_sbccs_dib_qtuf,
           {"Queue-Time Unit Factor", "sbccs.qtuf", FT_UINT8, BASE_DEC,
-           NULL, 0xF0, "", HFILL}},
+           NULL, 0xF0, NULL, HFILL}},
         { &hf_sbccs_dib_qtu,
           {"Queue-Time Unit", "sbccs.qtu", FT_UINT16, BASE_DEC, NULL, 0xFFF,
-           "", HFILL}},
+           NULL, HFILL}},
         { &hf_sbccs_dib_dtuf,
           {"Defer-Time Unit Function", "sbccs.dtuf", FT_UINT8, BASE_DEC,
-           NULL, 0xF0, "", HFILL}},
+           NULL, 0xF0, NULL, HFILL}},
         { &hf_sbccs_dib_dtu,
           {"Defer-Time Unit", "sbccs.dtu", FT_UINT16, BASE_DEC, NULL, 0xFFF,
-           "", HFILL}},
+           NULL, HFILL}},
         { &hf_sbccs_dib_ctlfn,
           {"Control Function", "sbccs.ctlfn", FT_UINT8, BASE_HEX,
-           VALS (fc_sbccs_dib_ctl_fn_val), 0x0, "", HFILL}},
+           VALS (fc_sbccs_dib_ctl_fn_val), 0x0, NULL, HFILL}},
         { &hf_sbccs_dib_linkctlfn,
           {"Link Control Function", "sbccs.linkctlfn", FT_UINT8, BASE_HEX,
-           VALS (fc_sbccs_dib_link_ctl_fn_val), 0x0, "", HFILL}},
+           VALS (fc_sbccs_dib_link_ctl_fn_val), 0x0, NULL, HFILL}},
         { &hf_sbccs_dib_ctccntr,
           {"CTC Counter", "sbccs.ctccntr", FT_UINT16, BASE_DEC, NULL, 0x0,
-           "", HFILL}},
+           NULL, HFILL}},
         { &hf_sbccs_lrc,
-          {"LRC", "sbccs.lrc", FT_UINT32, BASE_HEX, NULL, 0x0, "", HFILL}},
+          {"LRC", "sbccs.lrc", FT_UINT32, BASE_HEX, NULL, 0x0, NULL, HFILL}},
         { &hf_sbccs_dev_xcp_code,
           {"Device Level Exception Code", "sbccs.dip.xcpcode", FT_UINT8,
-           BASE_DEC, VALS (fc_sbccs_dib_dev_xcpcode_val), 0x0, "", HFILL}},
+           BASE_DEC, VALS (fc_sbccs_dib_dev_xcpcode_val), 0x0, NULL, HFILL}},
         { &hf_sbccs_prg_pth_errcode,
           {"Purge Path Error Code", "sbccs.purgepathcode", FT_UINT8,
-           BASE_DEC, VALS (fc_sbccs_dib_purge_path_err_val), 0x0, "", HFILL}},
+           BASE_DEC, VALS (fc_sbccs_dib_purge_path_err_val), 0x0, NULL, HFILL}},
         { &hf_sbccs_prg_rsp_errcode,
           {"Purge Path Response Error Code", "sbccs.purgepathrspcode",
            FT_UINT8, BASE_DEC, VALS (fc_sbccs_dib_purge_path_rsp_err_val),
-           0x0, "", HFILL}},
+           0x0, NULL, HFILL}},
         { &hf_sbccs_dib_lprcode,
           {"LPR Reason Code", "sbccs.lprcode", FT_UINT8, BASE_DEC,
-           VALS (fc_sbccs_dib_lpr_errcode_val), 0xF, "", HFILL}},
+           VALS (fc_sbccs_dib_lpr_errcode_val), 0xF, NULL, HFILL}},
         { &hf_sbccs_dib_tin_imgid_cnt,
           {"TIN Image ID", "sbccs.tinimageidcnt", FT_UINT8, BASE_DEC, NULL,
-           0x0, "", HFILL}},
+           0x0, NULL, HFILL}},
         { &hf_sbccs_dib_lrjcode,
           {"LRJ Reaspn Code", "sbccs.lrjcode", FT_UINT8, BASE_HEX,
-           VALS (fc_sbccs_dib_lrj_errcode_val), 0x7F, "", HFILL}},
+           VALS (fc_sbccs_dib_lrj_errcode_val), 0x7F, NULL, HFILL}},
         { &hf_sbccs_iui_as,
           {"AS", "sbccs.iui.as", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_iui_as), 0x10, "", HFILL}},
+           TFS(&tfs_sbccs_iui_as), 0x10, NULL, HFILL}},
         { &hf_sbccs_iui_es,
           {"ES", "sbccs.iui.es", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_iui_es), 0x08, "", HFILL}},
+           TFS(&tfs_sbccs_iui_es), 0x08, NULL, HFILL}},
         { &hf_sbccs_iui_val,
           {"Val", "sbccs.iui.val", FT_UINT8, BASE_HEX,
-           VALS(fc_sbccs_iu_val), 0x07, "", HFILL}},
+           VALS(fc_sbccs_iu_val), 0x07, NULL, HFILL}},
         { &hf_sbccs_dhflags_end,
           {"End", "sbccs.dhflags.end", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_dhflags_end), 0x80, "", HFILL}},
+           TFS(&tfs_sbccs_dhflags_end), 0x80, NULL, HFILL}},
         { &hf_sbccs_dhflags_chaining,
           {"Chaining", "sbccs.dhflags.chaining", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_dhflags_chaining), 0x10, "", HFILL}},
+           TFS(&tfs_sbccs_dhflags_chaining), 0x10, NULL, HFILL}},
         { &hf_sbccs_dhflags_earlyend,
           {"Early End", "sbccs.dhflags.earlyend", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_dhflags_earlyend), 0x08, "", HFILL}},
+           TFS(&tfs_sbccs_dhflags_earlyend), 0x08, NULL, HFILL}},
         { &hf_sbccs_dhflags_nocrc,
           {"No CRC", "sbccs.dhflags.nocrc", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_dhflags_nocrc), 0x04, "", HFILL}},
+           TFS(&tfs_sbccs_dhflags_nocrc), 0x04, NULL, HFILL}},
         { &hf_sbccs_dib_ccw_flags,
           {"CCW Control Flags", "sbccs.ccwflags", FT_UINT8, BASE_HEX, NULL,
-           0x0, "", HFILL}},
+           0x0, NULL, HFILL}},
         { &hf_sbccs_dib_ccw_flags_cd,
           {"CD", "sbccs.ccwflags.cd", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_ccwflags_cd), 0x80, "", HFILL}},
+           TFS(&tfs_sbccs_ccwflags_cd), 0x80, NULL, HFILL}},
         { &hf_sbccs_dib_ccw_flags_cc,
           {"CC", "sbccs.ccwflags.cc", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_ccwflags_cc), 0x40, "", HFILL}},
+           TFS(&tfs_sbccs_ccwflags_cc), 0x40, NULL, HFILL}},
         { &hf_sbccs_dib_ccw_flags_sli,
           {"SLI", "sbccs.ccwflags.sli", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_ccwflags_sli), 0x20, "", HFILL}},
+           TFS(&tfs_sbccs_ccwflags_sli), 0x20, NULL, HFILL}},
         { &hf_sbccs_dib_ccw_flags_crr,
           {"CRR", "sbccs.ccwflags.crr", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_ccwflags_crr), 0x08, "", HFILL}},
+           TFS(&tfs_sbccs_ccwflags_crr), 0x08, NULL, HFILL}},
         { &hf_sbccs_dib_cmdflags,
           {"Command Flags", "sbccs.cmdflags", FT_UINT8, BASE_HEX, NULL, 0x0,
-           "", HFILL}},
+           NULL, HFILL}},
         { &hf_sbccs_dib_cmdflags_du,
           {"DU", "sbccs.cmdflags.du", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_cmdflags_du), 0x10, "", HFILL}},
+           TFS(&tfs_sbccs_cmdflags_du), 0x10, NULL, HFILL}},
         { &hf_sbccs_dib_cmdflags_coc,
           {"COC", "sbccs.cmdflags.coc", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_cmdflags_coc), 0x08, "", HFILL}},
+           TFS(&tfs_sbccs_cmdflags_coc), 0x08, NULL, HFILL}},
         { &hf_sbccs_dib_cmdflags_syr,
           {"SYR", "sbccs.cmdflags.syr", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_cmdflags_syr), 0x04, "", HFILL}},
+           TFS(&tfs_sbccs_cmdflags_syr), 0x04, NULL, HFILL}},
         { &hf_sbccs_dib_cmdflags_rex,
           {"REX", "sbccs.cmdflags.rex", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_cmdflags_rex), 0x02, "", HFILL}},
+           TFS(&tfs_sbccs_cmdflags_rex), 0x02, NULL, HFILL}},
         { &hf_sbccs_dib_cmdflags_sss,
           {"SSS", "sbccs.cmdflags.sss", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_cmdflags_sss), 0x01, "", HFILL}},
+           TFS(&tfs_sbccs_cmdflags_sss), 0x01, NULL, HFILL}},
         { &hf_sbccs_dib_statusflags,
           {"Status Flags", "sbccs.statusflags", FT_UINT8, BASE_HEX,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_sbccs_dib_statusflags_ffc,
           {"FFC", "sbccs.statusflags.ffc", FT_UINT8, BASE_HEX,
-           VALS(status_ffc_val), 0xE0, "", HFILL}},
+           VALS(status_ffc_val), 0xE0, NULL, HFILL}},
         { &hf_sbccs_dib_statusflags_ci,
           {"CI", "sbccs.statusflags.ci", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_statusflags_ci), 0x10, "", HFILL}},
+           TFS(&tfs_sbccs_statusflags_ci), 0x10, NULL, HFILL}},
         { &hf_sbccs_dib_statusflags_cr,
           {"CR", "sbccs.statusflags.cr", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_statusflags_cr), 0x04, "", HFILL}},
+           TFS(&tfs_sbccs_statusflags_cr), 0x04, NULL, HFILL}},
         { &hf_sbccs_dib_statusflags_lri,
           {"LRI", "sbccs.statusflags.lri", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_statusflags_lri), 0x02, "", HFILL}},
+           TFS(&tfs_sbccs_statusflags_lri), 0x02, NULL, HFILL}},
         { &hf_sbccs_dib_statusflags_rv,
           {"RV", "sbccs.statusflags.rv", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_statusflags_rv), 0x01, "", HFILL}},
+           TFS(&tfs_sbccs_statusflags_rv), 0x01, NULL, HFILL}},
         { &hf_sbccs_dib_status_attention,
           {"Attention", "sbccs.status.attention", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_status_attention), 0x80, "", HFILL}},
+           TFS(&tfs_sbccs_status_attention), 0x80, NULL, HFILL}},
         { &hf_sbccs_dib_status_modifier,
           {"Status Modifier", "sbccs.status.modifier", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_status_modifier), 0x40, "", HFILL}},
+           TFS(&tfs_sbccs_status_modifier), 0x40, NULL, HFILL}},
         { &hf_sbccs_dib_status_cue,
           {"Control-Unit End", "sbccs.status.cue", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_status_cue), 0x20, "", HFILL}},
+           TFS(&tfs_sbccs_status_cue), 0x20, NULL, HFILL}},
         { &hf_sbccs_dib_status_busy,
           {"Busy", "sbccs.status.busy", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_status_busy), 0x10, "", HFILL}},
+           TFS(&tfs_sbccs_status_busy), 0x10, NULL, HFILL}},
         { &hf_sbccs_dib_status_channelend,
           {"Channel End", "sbccs.status.channel_end", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_status_channelend), 0x08, "", HFILL}},
+           TFS(&tfs_sbccs_status_channelend), 0x08, NULL, HFILL}},
         { &hf_sbccs_dib_status_deviceend,
           {"Device End", "sbccs.status.device_end", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_status_deviceend), 0x04, "", HFILL}},
+           TFS(&tfs_sbccs_status_deviceend), 0x04, NULL, HFILL}},
         { &hf_sbccs_dib_status_unit_check,
           {"Unit Check", "sbccs.status.unit_check", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_status_unitcheck), 0x02, "", HFILL}},
+           TFS(&tfs_sbccs_status_unitcheck), 0x02, NULL, HFILL}},
         { &hf_sbccs_dib_status_unit_exception,
           {"Unit Exception", "sbccs.status.unitexception", FT_BOOLEAN, 8,
-           TFS(&tfs_sbccs_status_unitexception), 0x01, "", HFILL}},
+           TFS(&tfs_sbccs_status_unitexception), 0x01, NULL, HFILL}},
         { &hf_sbccs_dib_ctlparam,
           {"Control Parameters", "sbccs.ctlparam", FT_UINT24, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_sbccs_dib_ctlparam_rc,
           {"RC", "sbccs.ctlparam.rc", FT_BOOLEAN, 24,
-           TFS(&tfs_sbccs_ctlparam_rc), 0x80, "", HFILL}},
+           TFS(&tfs_sbccs_ctlparam_rc), 0x80, NULL, HFILL}},
         { &hf_sbccs_dib_ctlparam_ru,
           {"RU", "sbccs.ctlparam.ru", FT_BOOLEAN, 24,
-           TFS(&tfs_sbccs_ctlparam_ru), 0x10, "", HFILL}},
+           TFS(&tfs_sbccs_ctlparam_ru), 0x10, NULL, HFILL}},
         { &hf_sbccs_dib_ctlparam_ro,
           {"RO", "sbccs.ctlparam.ro", FT_BOOLEAN, 24,
-           TFS(&tfs_sbccs_ctlparam_ro), 0x08, "", HFILL}},
+           TFS(&tfs_sbccs_ctlparam_ro), 0x08, NULL, HFILL}},
         { &hf_sbccs_dib_linkctlinfo,
           {"Link Control Information", "sbccs.linkctlinfo", FT_UINT16,
-           BASE_HEX, NULL, 0x0, "", HFILL}},
+           BASE_HEX, NULL, 0x0, NULL, HFILL}},
         { &hf_sbccs_dib_linkctlinfo_ctcconn,
           {"CTC Conn", "sbccs.linkctlinfo.ctc_conn", FT_BOOLEAN, 16,
-           TFS(&tfs_sbccs_linkctlinfo_ctcconn), 0x80, "", HFILL}},
+           TFS(&tfs_sbccs_linkctlinfo_ctcconn), 0x80, NULL, HFILL}},
         { &hf_sbccs_dib_linkctlinfo_ecrcg,
           {"Enhanced CRC Generation", "sbccs.linkctlinfo.ecrcg", FT_BOOLEAN, 16,
-           TFS(&tfs_sbccs_linkctlinfo_ecrcg), 0x01, "", HFILL}},
+           TFS(&tfs_sbccs_linkctlinfo_ecrcg), 0x01, NULL, HFILL}},
     };
 
 
