@@ -3,7 +3,7 @@
  * This decoder is for FC-SP version 1.1
  * Copyright 2003, Dinesh G Dutt <ddutt@cisco.com>
  *
- * $Id: packet-fcsp.c 26089 2008-08-25 22:06:20Z wmeier $
+ * $Id: packet-fcsp.c 28770 2009-06-18 21:30:42Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -469,94 +469,94 @@ proto_register_fcsp (void)
     static hf_register_info hf[] = {
         { &hf_auth_proto_ver,
           {"Protocol Version", "fcsp.version", FT_UINT8, BASE_HEX, NULL,
-           0x0, "", HFILL}},
+           0x0, NULL, HFILL}},
         { &hf_auth_msg_code,
           {"Message Code", "fcsp.opcode", FT_UINT8, BASE_HEX,
-           VALS (fcauth_msgcode_vals), 0x0, "", HFILL}},
+           VALS (fcauth_msgcode_vals), 0x0, NULL, HFILL}},
         { &hf_auth_flags,
-          {"Flags", "fcsp.flags", FT_UINT8, BASE_HEX, NULL, 0x0, "",
+          {"Flags", "fcsp.flags", FT_UINT8, BASE_HEX, NULL, 0x0, NULL,
            HFILL}},
         { &hf_auth_len,
           {"Packet Length", "fcsp.len", FT_UINT32, BASE_DEC, NULL, 0x0,
-           "", HFILL}},
+           NULL, HFILL}},
         { &hf_auth_tid,
           {"Transaction Identifier", "fcsp.tid", FT_UINT32, BASE_HEX, NULL,
-           0x0, "", HFILL}},
+           0x0, NULL, HFILL}},
         { &hf_auth_initiator_wwn,
-          {"Initiator Name (WWN)", "fcsp.initwwn", FT_STRING, BASE_HEX, NULL,
-           0x0, "", HFILL}},
+          {"Initiator Name (WWN)", "fcsp.initwwn", FT_STRING, BASE_NONE, NULL,
+           0x0, NULL, HFILL}},
         { &hf_auth_initiator_name,
           {"Initiator Name (Unknown Type)", "fcsp.initname", FT_BYTES,
-           BASE_HEX, NULL, 0x0, "", HFILL}},
+           BASE_NONE, NULL, 0x0, NULL, HFILL}},
         { &hf_auth_initiator_name_type,
           {"Initiator Name Type", "fcsp.initnametype", FT_UINT16, BASE_HEX,
-           VALS (fcauth_name_type_vals), 0x0, "", HFILL}},
+           VALS (fcauth_name_type_vals), 0x0, NULL, HFILL}},
         { &hf_auth_initiator_name_len,
           {"Initiator Name Length", "fcsp.initnamelen", FT_UINT16, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_auth_usable_proto,
           {"Number of Usable Protocols", "fcsp.usableproto", FT_UINT32,
-           BASE_DEC, NULL, 0x0, "", HFILL}},
+           BASE_DEC, NULL, 0x0, NULL, HFILL}},
         { &hf_auth_rjt_code,
           {"Reason Code", "fcsp.rjtcode", FT_UINT8, BASE_DEC,
-           VALS (fcauth_rjtcode_vals), 0x0, "", HFILL}},
+           VALS (fcauth_rjtcode_vals), 0x0, NULL, HFILL}},
         { &hf_auth_rjt_codedet,
           {"Reason Code Explanation", "fcsp.rjtcodet", FT_UINT8, BASE_DEC,
-           VALS (fcauth_rjtcode_detail_vals), 0x0, "", HFILL}},
+           VALS (fcauth_rjtcode_detail_vals), 0x0, NULL, HFILL}},
         { &hf_auth_responder_wwn,
-          {"Responder Name (WWN)", "fcsp.rspwwn", FT_STRING, BASE_HEX, NULL,
-           0x0, "", HFILL}},
+          {"Responder Name (WWN)", "fcsp.rspwwn", FT_STRING, BASE_NONE, NULL,
+           0x0, NULL, HFILL}},
         { &hf_auth_responder_name,
-          {"Responder Name (Unknown Type)", "fcsp.rspname", FT_BYTES, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+          {"Responder Name (Unknown Type)", "fcsp.rspname", FT_BYTES, BASE_NONE,
+           NULL, 0x0, NULL, HFILL}},
         { &hf_auth_responder_name_type,
           {"Responder Name Type", "fcsp.rspnametype", FT_UINT16, BASE_HEX,
-           VALS (fcauth_name_type_vals), 0x0, "", HFILL}},
+           VALS (fcauth_name_type_vals), 0x0, NULL, HFILL}},
         { &hf_auth_responder_name_len,
           {"Responder Name Type", "fcsp.rspnamelen", FT_UINT16, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_auth_dhchap_hashid,
           {"Hash Identifier", "fcsp.dhchap.hashid", FT_UINT32, BASE_HEX, NULL, 0x0,
-           "", HFILL}},
+           NULL, HFILL}},
         { &hf_auth_dhchap_groupid,
           {"DH Group Identifier", "fcsp.dhchap.groupid", FT_UINT32, BASE_HEX, NULL,
-           0x0, "", HFILL}},
+           0x0, NULL, HFILL}},
         { &hf_auth_dhchap_chal_len,
           {"Challenge Value Length", "fcsp.dhchap.challen", FT_UINT32, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_auth_dhchap_val_len,
           {"DH Value Length", "fcsp.dhchap.vallen", FT_UINT32, BASE_DEC, NULL,
-           0x0, "", HFILL}},
+           0x0, NULL, HFILL}},
         { &hf_auth_dhchap_rsp_len,
           {"Response Value Length", "fcsp.dhchap.rsplen", FT_UINT32, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_auth_proto_type,
           {"Authentication Protocol Type", "fcsp.proto", FT_UINT32, BASE_DEC,
-           VALS (fcauth_proto_type_vals), 0x0, "", HFILL}},
+           VALS (fcauth_proto_type_vals), 0x0, NULL, HFILL}},
         { &hf_auth_proto_param_len,
           {"Protocol Parameters Length", "fcsp.protoparamlen", FT_UINT32,
-           BASE_DEC, NULL, 0x0, "", HFILL}},
+           BASE_DEC, NULL, 0x0, NULL, HFILL}},
         { &hf_auth_dhchap_param_tag,
           {"Parameter Tag", "fcsp.dhchap.paramtype", FT_UINT16, BASE_HEX,
-           VALS (fcauth_dhchap_param_vals), 0x0, "", HFILL}},
+           VALS (fcauth_dhchap_param_vals), 0x0, NULL, HFILL}},
         { &hf_auth_dhchap_param_len,
           {"Parameter Length", "fcsp.dhchap.paramlen", FT_UINT16, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_auth_dhchap_hash_type,
           {"Hash Algorithm", "fcsp.dhchap.hashtype", FT_UINT32, BASE_DEC,
-           VALS (fcauth_dhchap_hash_algo_vals), 0x0, "", HFILL}},
+           VALS (fcauth_dhchap_hash_algo_vals), 0x0, NULL, HFILL}},
         { &hf_auth_dhchap_group_type,
           {"DH Group", "fcsp.dhchap.dhgid", FT_UINT32, BASE_DEC,
-           VALS (fcauth_dhchap_dhgid_vals), 0x0, "", HFILL}},
+           VALS (fcauth_dhchap_dhgid_vals), 0x0, NULL, HFILL}},
         { &hf_auth_dhchap_chal_value,
-          {"Challenge Value", "fcsp.dhchap.chalval", FT_BYTES, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+          {"Challenge Value", "fcsp.dhchap.chalval", FT_BYTES, BASE_NONE,
+           NULL, 0x0, NULL, HFILL}},
         { &hf_auth_dhchap_dhvalue,
-          {"DH Value", "fcsp.dhchap.dhvalue", FT_BYTES, BASE_HEX, NULL, 0x0,
-           "", HFILL}},
+          {"DH Value", "fcsp.dhchap.dhvalue", FT_BYTES, BASE_NONE, NULL, 0x0,
+           NULL, HFILL}},
         { &hf_auth_dhchap_rsp_value,
-          {"Response Value", "fcsp.dhchap.rspval", FT_BYTES, BASE_HEX, NULL,
-           0x0, "", HFILL}},
+          {"Response Value", "fcsp.dhchap.rspval", FT_BYTES, BASE_NONE, NULL,
+           0x0, NULL, HFILL}},
           
     };
 
@@ -574,8 +574,6 @@ proto_register_fcsp (void)
     /* Required function calls to register the header fields and subtrees used */
     proto_register_field_array(proto_fcsp, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
-
-    data_handle = find_dissector("data");
 }
 
 /* If this dissector uses sub-dissector registration add a registration routine.
@@ -585,10 +583,6 @@ proto_register_fcsp (void)
 void
 proto_reg_handoff_fcsp (void)
 {
-    dissector_handle_t fcsp_handle;
-
-    fcsp_handle = create_dissector_handle (dissect_fcsp, proto_fcsp);
-
     data_handle = find_dissector ("data");
 }
 
