@@ -3,7 +3,7 @@
  * Routines for FIP dissection - FCoE Initialization Protocol
  * Copyright (c) 2008 Cisco Systems, Inc. (jeykholt@cisco.com)
  *
- * $Id: packet-fip.c 30673 2009-10-23 16:27:44Z gerald $
+ * $Id: packet-fip.c 30577 2009-10-16 21:26:51Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -264,12 +264,10 @@ dissect_fip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     const char *info;
     char *text;
 
-    if (check_col(pinfo->cinfo, COL_PROTOCOL))
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "FIP");
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "FIP");
 
     if (!tvb_bytes_exist(tvb, 0, FIP_HEADER_LEN)) {
-        if (check_col(pinfo->cinfo, COL_INFO))
-            col_set_str(pinfo->cinfo, COL_INFO, "[packet too short]");
+        col_set_str(pinfo->cinfo, COL_INFO, "[packet too short]");
         if (tree)
             proto_tree_add_protocol_format(tree, proto_fip, tvb, 0,
                                             -1, "FIP [packet too short]");
@@ -474,57 +472,57 @@ proto_register_fip(void)
          */
         { &hf_fip_ver,
           {"Version", "fip.ver", FT_UINT8, BASE_DEC,
-            NULL, 0xf0, "", HFILL}},
+            NULL, 0xf0, NULL, HFILL}},
         { &hf_fip_op,
           {"Opcode", "fip.opcode", FT_UINT16, BASE_HEX,
-           VALS(&fip_opcodes), 0, "", HFILL}},
+           VALS(&fip_opcodes), 0, NULL, HFILL}},
         { &hf_fip_disc_subcode,
           {"Discovery Subcode", "fip.disc_subcode", FT_UINT8, BASE_HEX,
-           VALS(&fip_disc_subcodes), 0, "", HFILL}},
+           VALS(&fip_disc_subcodes), 0, NULL, HFILL}},
         { &hf_fip_ls_subcode,
           {"Link Service Subcode", "fip.ls.subcode", FT_UINT8, BASE_HEX,
-           VALS(&fip_ls_subcodes), 0, "", HFILL}},
+           VALS(&fip_ls_subcodes), 0, NULL, HFILL}},
         { &hf_fip_ctrl_subcode,
           {"Control Subcode", "fip.ctrl_subcode", FT_UINT8, BASE_HEX,
-           VALS(&fip_ctrl_subcodes), 0, "", HFILL}},
+           VALS(&fip_ctrl_subcodes), 0, NULL, HFILL}},
         { &hf_fip_vlan_subcode,
           {"VLAN Subcode", "fip.vlan_subcode", FT_UINT8, BASE_HEX,
-           VALS(&fip_vlan_subcodes), 0, "", HFILL}},
+           VALS(&fip_vlan_subcodes), 0, NULL, HFILL}},
         { &hf_fip_hex_subcode,
           {"Unknown Subcode", "fip.subcode", FT_UINT8, BASE_HEX,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_fip_dlen,
           {"Length of Descriptors (words)", "fip.dl_len", FT_UINT16, BASE_DEC,
-            NULL, 0, "", HFILL}},
+            NULL, 0, NULL, HFILL}},
         { &hf_fip_flags,
           {"Flags", "fip.flags", FT_UINT16, BASE_HEX,
-            NULL, 0, "", HFILL}},
+            NULL, 0, NULL, HFILL}},
         { &hf_fip_flag_fpma,
           {"Fabric Provided MAC addr", "fip.flags.fpma", FT_BOOLEAN, 16,
-            NULL, FIP_FL_FPMA, "", HFILL}},
+            NULL, FIP_FL_FPMA, NULL, HFILL}},
         { &hf_fip_flag_spma,
           {"Server Provided MAC addr", "fip.flags.spma", FT_BOOLEAN, 16,
-            NULL, FIP_FL_SPMA, "", HFILL}},
+            NULL, FIP_FL_SPMA, NULL, HFILL}},
         { &hf_fip_flag_avail,
           {"Available", "fip.flags.available", FT_BOOLEAN, 16,
-            NULL, FIP_FL_AVAIL, "", HFILL}},
+            NULL, FIP_FL_AVAIL, NULL, HFILL}},
         { &hf_fip_flag_sol,
           {"Solicited", "fip.flags.sol", FT_BOOLEAN, 16,
-            NULL, FIP_FL_SOL, "", HFILL}},
+            NULL, FIP_FL_SOL, NULL, HFILL}},
         { &hf_fip_flag_fport,
           {"F_Port", "fip.flags.fport", FT_BOOLEAN, 16,
-            NULL, FIP_FL_FPORT, "", HFILL}},
+            NULL, FIP_FL_FPORT, NULL, HFILL}},
         { &hf_fip_desc_type,
           {"Descriptor Type", "fip.desc_type", FT_UINT8, BASE_HEX,
-            VALS(&fip_desc_types), 0, "", HFILL}},
+            VALS(&fip_desc_types), 0, NULL, HFILL}},
         { &hf_fip_desc_len,
           {"Descriptor Length (words)", "fip.desc_len", FT_UINT8, BASE_DEC,
-            NULL, 0, "", HFILL}},
+            NULL, 0, NULL, HFILL}},
         /*
          * Various descriptor fields.
          */
         { &hf_fip_desc_pri,
-          {"Priority", "fip.pri", FT_UINT8, BASE_DEC, NULL, 0, "", HFILL}},
+          {"Priority", "fip.pri", FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL}},
         { &hf_fip_desc_mac,
           {"MAC Address", "fip.mac", FT_ETHER, BASE_NONE, NULL,
             0, NULL, HFILL}},
@@ -532,43 +530,43 @@ proto_register_fip(void)
           {"FC-MAP-OUI", "fip.map", FT_STRING, BASE_NONE, NULL,
             0, NULL, HFILL}},
         { &hf_fip_desc_name,
-          {"Switch or Node Name", "fip.name", FT_STRING, BASE_HEX, NULL,
-            0, "", HFILL}},
+          {"Switch or Node Name", "fip.name", FT_STRING, BASE_NONE, NULL,
+            0, NULL, HFILL}},
         { &hf_fip_desc_fab_vfid,
           {"VFID", "fip.fab.vfid", FT_UINT16, BASE_DEC, NULL,
-            0, "", HFILL}},
+            0, NULL, HFILL}},
         { &hf_fip_desc_fab_map,
-          {"FC-MAP", "fip.fab.map", FT_STRING, BASE_HEX, NULL,
-            0, "", HFILL}},
+          {"FC-MAP", "fip.fab.map", FT_STRING, BASE_NONE, NULL,
+            0, NULL, HFILL}},
         { &hf_fip_desc_fab_name,
           {"Fabric Name", "fip.fab.name", FT_STRING, BASE_NONE, NULL,
-            0, "", HFILL}},
+            0, NULL, HFILL}},
         { &hf_fip_desc_fcoe_size,
           {"Max FCoE frame size", "fip.fcoe_size", FT_UINT16, BASE_DEC, NULL,
-            0, "", HFILL}},
+            0, NULL, HFILL}},
         { &hf_fip_desc_vn_mac,
-          {"VN_Port MAC Address", "fip.vn.mac", FT_ETHER, 0, NULL,
-            0, "", HFILL}},
+          {"VN_Port MAC Address", "fip.vn.mac", FT_ETHER, BASE_NONE, NULL,
+            0, NULL, HFILL}},
         { &hf_fip_desc_vn_fid,
           {"VN_Port FC_ID", "fip.vn.fc_id", FT_UINT32, BASE_HEX, NULL,
-            0, "", HFILL}},
+            0, NULL, HFILL}},
         { &hf_fip_desc_vn_wwpn,
-          {"Port Name", "fip.vn.pwwn", FT_STRING, BASE_HEX, NULL,
-            0, "", HFILL}},
+          {"Port Name", "fip.vn.pwwn", FT_STRING, BASE_NONE, NULL,
+            0, NULL, HFILL}},
         { &hf_fip_desc_fka,
           {"FKA_ADV_Period", "fip.fka", FT_UINT32, BASE_DEC, NULL,
-            0, "", HFILL}},
+            0, NULL, HFILL}},
         { &hf_fip_desc_vend,
           {"Vendor-ID", "fip.vendor", FT_BYTES, BASE_NONE, NULL,
             0, NULL, HFILL}},
         { &hf_fip_desc_vend_data,
-          {"Vendor-specific data", "fip.vendor.data", FT_BYTES, BASE_HEX, NULL,
-            0, "", HFILL}},
+          {"Vendor-specific data", "fip.vendor.data", FT_BYTES, BASE_NONE, NULL,
+            0, NULL, HFILL}},
         { &hf_fip_desc_vlan,
-          {"VLAN", "fip.vlan", FT_UINT16, BASE_DEC, NULL, 0, "", HFILL}},
+          {"VLAN", "fip.vlan", FT_UINT16, BASE_DEC, NULL, 0, NULL, HFILL}},
         { &hf_fip_desc_unk,
-          {"Unknown Descriptor", "fip.desc", FT_BYTES, BASE_HEX, NULL,
-            0, "", HFILL}}
+          {"Unknown Descriptor", "fip.desc", FT_BYTES, BASE_NONE, NULL,
+            0, NULL, HFILL}}
     };
     static gint *ett[] = {
         &ett_fip,
