@@ -2,7 +2,7 @@
  *
  * Top-most dissector. Decides dissector based on Wiretap Encapsulation Type.
  *
- * $Id: packet-frame.c 29767 2009-09-07 13:54:46Z krj $
+ * $Id: packet-frame.c 30051 2009-09-21 18:48:53Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -302,7 +302,7 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	  }
 
 	  if(pinfo->fd->color_filter != NULL) {
-	      color_filter_t *color_filter = pinfo->fd->color_filter;
+	      const color_filter_t *color_filter = pinfo->fd->color_filter;
 	      item = proto_tree_add_string(fh_tree, hf_frame_color_filter_name, tvb,
 		    0, 0, color_filter->filter_name);
 	      PROTO_ITEM_SET_GENERATED(item);
