@@ -3,7 +3,7 @@
  * Copyright 1999, Richard Sharpe <rsharpe@ns.aus.com>
  * Copyright 2001, Juan Toledo <toledo@users.sourceforge.net> (Passive FTP)
  *
- * $Id: packet-ftp.c 26285 2008-09-27 14:02:23Z wmeier $
+ * $Id: packet-ftp.c 30691 2009-10-25 11:43:30Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -84,14 +84,21 @@ static const value_string response_table[] = {
 	{ 227, "Entering Passive Mode" },
 	{ 229, "Entering Extended Passive Mode" },
 	{ 230, "User logged in, proceed" },
+	{ 232, "User logged in, authorized by security data exchange" },
+	{ 234, "Security data exchange complete" },
+	{ 235, "Security data exchange completed successfully" },
 	{ 250, "Requested file action okay, completed" },
 	{ 257, "PATHNAME created" },
 	{ 331, "User name okay, need password" },
 	{ 332, "Need account for login" },
+	{ 334, "Requested security mechanism is ok" },
+	{ 335, "Security data is acceptable, more is required" },
+	{ 336, "Username okay, need password. Challenge is ..." },
 	{ 350, "Requested file action pending further information" },
 	{ 421, "Service not available, closing control connection" },
 	{ 425, "Can't open data connection" },
 	{ 426, "Connection closed; transfer aborted" },
+	{ 431, "Need some unavailable resource to process security" },
 	{ 450, "Requested file action not taken" },
 	{ 451, "Requested action aborted: local error in processing" },
 	{ 452, "Requested action not taken. Insufficient storage space in system" },
@@ -102,10 +109,18 @@ static const value_string response_table[] = {
 	{ 504, "Command not implemented for that parameter" },
 	{ 530, "Not logged in" },
 	{ 532, "Need account for storing files" },
+	{ 533, "Command protection level denied for policy reasons" },
+	{ 534, "Request denied for policy reasons" },
+	{ 535, "Failed security check (hash, sequence, etc)" },
+	{ 536, "Requested PROT level not supported by mechanism" },
+	{ 537, "Command protection level not supported by security mechanism" },
 	{ 550, "Requested action not taken: File unavailable" },
 	{ 551, "Requested action aborted: page type unknown" },
 	{ 552, "Requested file action aborted: Exceeded storage allocation" },
 	{ 553, "Requested action not taken: File name not allowed" },
+	{ 631, "Integrity protected reply" },
+	{ 632, "Confidentiality and integrity protected reply" },
+	{ 633, "Confidentiality protected reply" },
 	{ 0,   NULL }
 };
 
@@ -178,9 +193,7 @@ parse_port_pasv(const guchar *line, int linelen, guint32 *ftp_ip,
 	/*
 	 * Copy the rest of the line into a null-terminated buffer.
 	 */
-	args = ep_alloc(linelen + 1);
-	memcpy(args, line, linelen);
-	args[linelen] = '\0';
+	args = ep_strndup(line, linelen);
 	p = args;
 
 	for (;;) {
@@ -238,9 +251,7 @@ parse_extended_pasv_response(const guchar *line, int linelen, guint16 *ftp_port)
 	/*
 	 * Copy the rest of the line into a null-terminated buffer.
 	 */
-	args = ep_alloc(linelen + 1);
-	memcpy(args, line, linelen);
-	args[linelen] = '\0';
+	args = ep_strndup(line, linelen);
 	p = args;
 
 	/*
@@ -324,8 +335,7 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	else
 		is_request = FALSE;
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "FTP");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "FTP");
 
 	/*
 	 * Find the end of the first line.
@@ -451,8 +461,8 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			next_token = line;
 		}
 	}
-	offset += next_token - line;
-	linelen -= next_token - line;
+	offset += (gint) (next_token - line);
+	linelen -= (int) (next_token - line);
 	line = next_token;
 
 	if (tree) {
@@ -633,8 +643,7 @@ dissect_ftpdata(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         proto_tree      *ti, *ftp_data_tree;
         int		data_length;
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "FTP-DATA");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "FTP-DATA");
 
 	if (check_col(pinfo->cinfo, COL_INFO)) {
 		col_add_fstr(pinfo->cinfo, COL_INFO, "FTP Data: %u bytes",
@@ -674,22 +683,22 @@ proto_register_ftp(void)
     { &hf_ftp_request_command,
       { "Request command",    "ftp.request.command",
       	FT_STRING,  BASE_NONE, NULL, 0x0,
-      	"", HFILL }},
+      	NULL, HFILL }},
 
     { &hf_ftp_request_arg,
       { "Request arg",	      "ftp.request.arg",
       	FT_STRING,  BASE_NONE, NULL, 0x0,
-      	"", HFILL }},
+      	NULL, HFILL }},
 
     { &hf_ftp_response_code,
       { "Response code",      "ftp.response.code",
       	FT_UINT32,   BASE_DEC, VALS(response_table), 0x0,
-      	"", HFILL }},
+      	NULL, HFILL }},
 
     { &hf_ftp_response_arg,
       { "Response arg",      "ftp.response.arg",
       	FT_STRING,  BASE_NONE, NULL, 0x0,
-      	"", HFILL }},
+      	NULL, HFILL }},
 
     { &hf_ftp_pasv_ip,
       { "Passive IP address", "ftp.passive.ip",
