@@ -11,7 +11,7 @@
  *   support on mobile radio interface
  *   (3GPP TS 24.011 version 4.1.1 Release 4)
  *
- * $Id: packet-gsm_a_rp.c 26265 2008-09-25 02:21:04Z wmeier $
+ * $Id: packet-gsm_a_rp.c 30125 2009-09-24 20:00:21Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -104,7 +104,7 @@ gint ett_gsm_rp_elem[NUM_GSM_RP_ELEM];
 /*
  * [5] 8.2.3
  */
-static guint8
+static guint16
 de_rp_message_ref(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len _U_, gchar *add_string _U_, int string_len _U_)
 {
 	guint8	oct;
@@ -130,7 +130,7 @@ de_rp_message_ref(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len _U_
 /*
  * [5] 8.2.5.1
  */
-static guint8
+static guint16
 de_rp_orig_addr(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len, gchar *add_string, int string_len)
 {
 	return(de_cld_party_bcd_num(tvb, tree, offset, len, add_string, string_len));
@@ -139,7 +139,7 @@ de_rp_orig_addr(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len, gcha
 /*
  * [5] 8.2.5.2
  */
-static guint8
+static guint16
 de_rp_dest_addr(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len, gchar *add_string, int string_len)
 {
 	return(de_cld_party_bcd_num(tvb, tree, offset, len, add_string, string_len));
@@ -148,7 +148,7 @@ de_rp_dest_addr(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len, gcha
 /*
  * [5] 8.2.5.3
  */
-static guint8
+static guint16
 de_rp_user_data(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len, gchar *add_string _U_, int string_len _U_)
 {
 	guint32	curr_offset;
@@ -176,7 +176,7 @@ de_rp_user_data(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len, gcha
 /*
  * [5] 8.2.5.4
  */
-static guint8
+static guint16
 de_rp_cause(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len, gchar *add_string, int string_len)
 {
 	guint8	oct;
@@ -251,7 +251,7 @@ de_rp_cause(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len, gchar *a
 	return(curr_offset - offset);
 }
 
-guint8 (*rp_elem_fcn[])(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len, gchar *add_string, int string_len) = {
+guint16 (*rp_elem_fcn[])(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len, gchar *add_string, int string_len) = {
 	/* Short Message Service Information Elements [5] 8.2 */
 	de_rp_message_ref,	/* RP-Message Reference */
 	de_rp_orig_addr,	/* RP-Origination Address */
@@ -280,11 +280,11 @@ rp_data_n_ms(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len)
 
 	ELEM_MAND_V(GSM_A_PDU_TYPE_RP, DE_RP_MESSAGE_REF);
 
-	ELEM_MAND_LV(GSM_A_PDU_TYPE_RP, DE_RP_ORIG_ADDR, "");
+	ELEM_MAND_LV(GSM_A_PDU_TYPE_RP, DE_RP_ORIG_ADDR, NULL);
 
-	ELEM_MAND_LV(GSM_A_PDU_TYPE_RP, DE_RP_DEST_ADDR, "");
+	ELEM_MAND_LV(GSM_A_PDU_TYPE_RP, DE_RP_DEST_ADDR, NULL);
 
-	ELEM_MAND_LV(GSM_A_PDU_TYPE_RP, DE_RP_USER_DATA, "");
+	ELEM_MAND_LV(GSM_A_PDU_TYPE_RP, DE_RP_USER_DATA, NULL);
 
 	EXTRANEOUS_DATA_CHECK(curr_len, 0);
 }
@@ -306,11 +306,11 @@ rp_data_ms_n(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len)
 
 	ELEM_MAND_V(GSM_A_PDU_TYPE_RP, DE_RP_MESSAGE_REF);
 
-	ELEM_MAND_LV(GSM_A_PDU_TYPE_RP, DE_RP_ORIG_ADDR, "");
+	ELEM_MAND_LV(GSM_A_PDU_TYPE_RP, DE_RP_ORIG_ADDR, NULL);
 
-	ELEM_MAND_LV(GSM_A_PDU_TYPE_RP, DE_RP_DEST_ADDR, "");
+	ELEM_MAND_LV(GSM_A_PDU_TYPE_RP, DE_RP_DEST_ADDR, NULL);
 
-	ELEM_MAND_LV(GSM_A_PDU_TYPE_RP, DE_RP_USER_DATA, "");
+	ELEM_MAND_LV(GSM_A_PDU_TYPE_RP, DE_RP_USER_DATA, NULL);
 
 	EXTRANEOUS_DATA_CHECK(curr_len, 0);
 }
@@ -350,7 +350,7 @@ rp_ack_n_ms(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len)
 
 	ELEM_MAND_V(GSM_A_PDU_TYPE_RP, DE_RP_MESSAGE_REF);
 
-	ELEM_OPT_TLV(0x41, GSM_A_PDU_TYPE_RP, DE_RP_USER_DATA, "");
+	ELEM_OPT_TLV(0x41, GSM_A_PDU_TYPE_RP, DE_RP_USER_DATA, NULL);
 
 	EXTRANEOUS_DATA_CHECK(curr_len, 0);
 }
@@ -372,7 +372,7 @@ rp_ack_ms_n(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len)
 
 	ELEM_MAND_V(GSM_A_PDU_TYPE_RP, DE_RP_MESSAGE_REF);
 
-	ELEM_OPT_TLV(0x41, GSM_A_PDU_TYPE_RP, DE_RP_USER_DATA, "");
+	ELEM_OPT_TLV(0x41, GSM_A_PDU_TYPE_RP, DE_RP_USER_DATA, NULL);
 
 	EXTRANEOUS_DATA_CHECK(curr_len, 0);
 }
@@ -394,9 +394,9 @@ rp_error_n_ms(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len)
 
 	ELEM_MAND_V(GSM_A_PDU_TYPE_RP, DE_RP_MESSAGE_REF);
 
-	ELEM_MAND_LV(GSM_A_PDU_TYPE_RP, DE_RP_CAUSE, "");
+	ELEM_MAND_LV(GSM_A_PDU_TYPE_RP, DE_RP_CAUSE, NULL);
 
-	ELEM_OPT_TLV(0x41, GSM_A_PDU_TYPE_RP, DE_RP_USER_DATA, "");
+	ELEM_OPT_TLV(0x41, GSM_A_PDU_TYPE_RP, DE_RP_USER_DATA, NULL);
 
 	EXTRANEOUS_DATA_CHECK(curr_len, 0);
 }
@@ -418,9 +418,9 @@ rp_error_ms_n(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint len)
 
 	ELEM_MAND_V(GSM_A_PDU_TYPE_RP, DE_RP_MESSAGE_REF);
 
-	ELEM_MAND_LV(GSM_A_PDU_TYPE_RP, DE_RP_CAUSE, "");
+	ELEM_MAND_LV(GSM_A_PDU_TYPE_RP, DE_RP_CAUSE, NULL);
 
-	ELEM_OPT_TLV(0x41, GSM_A_PDU_TYPE_RP, DE_RP_USER_DATA, "");
+	ELEM_OPT_TLV(0x41, GSM_A_PDU_TYPE_RP, DE_RP_USER_DATA, NULL);
 
 	EXTRANEOUS_DATA_CHECK(curr_len, 0);
 }
@@ -451,10 +451,7 @@ dissect_rp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	proto_tree	*rp_tree = NULL;
 	const gchar	*str;
 
-	if (check_col(pinfo->cinfo, COL_INFO))
-	{
-		col_append_str(pinfo->cinfo, COL_INFO, "(RP) ");
-	}
+	col_append_str(pinfo->cinfo, COL_INFO, "(RP) ");
 
 	/*
 	 * In the interest of speed, if "tree" is NULL, don't do any work
@@ -515,7 +512,7 @@ dissect_rp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	if (str == NULL) return;
 
-	if ((len - offset) <= 0) return;
+	if (offset >=len) return;
 
 	/*
 	 * decode elements
@@ -546,20 +543,21 @@ proto_register_gsm_a_rp(void)
 	{ &hf_gsm_a_rp_msg_type,
 		{ "RP Message Type",	"gsm_a.rp_msg_type",
 		FT_UINT8, BASE_HEX, VALS(gsm_rp_msg_strings), 0x0,
-		"", HFILL }
+		NULL, HFILL }
 	},
 	{ &hf_gsm_a_rp_elem_id,
 		{ "Element ID",	"gsm_a_rp.elem_id",
 		FT_UINT8, BASE_DEC, NULL, 0,
-		"", HFILL }
+		NULL, HFILL }
 	},
 	};
 
 	/* Setup protocol subtree array */
 #define	NUM_INDIVIDUAL_ELEMS	1
-	static gint *ett[NUM_INDIVIDUAL_ELEMS +
-			NUM_GSM_RP_MSG];
-
+	gint *ett[NUM_INDIVIDUAL_ELEMS +
+		  NUM_GSM_RP_MSG +
+		  NUM_GSM_RP_ELEM];
+        
 	ett[0] = &ett_rp_msg;
 
 	last_offset = NUM_INDIVIDUAL_ELEMS;
