@@ -4,7 +4,7 @@
  *
  *  (c) 2006, Luis E. Garcia Ontanon <luis@ontanon.org>
  *
- * $Id: packet-h248_3gpp.c 28770 2009-06-18 21:30:42Z stig $
+ * $Id: packet-h248_3gpp.c 30182 2009-09-28 17:58:47Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -25,6 +25,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include "packet-h248.h"
 #define PNAME  "H.248 3GPP"
 #define PSNAME "H2483GPP"
