@@ -2,13 +2,13 @@
  *
  * Routines for RFC-4629-encapsulated H.263 dissection
  *
- * Copyright 2003 Niklas gren <niklas.ogren@7l.se>
+ * Copyright 2003 Niklas Ogren <niklas.ogren@7l.se>
  * Seven Levels Consultants AB
  *
  * Copyright 2008 Richard van der Hoff, MX Telecom
  * <richardv@mxtelecom.com>
  *
- * $Id: packet-h263p.c 26246 2008-09-22 16:26:41Z wmeier $
+ * $Id: packet-h263p.c 30127 2009-09-24 20:21:23Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -39,7 +39,7 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "prefs.h"
+#include <epan/prefs.h>
 
 #include "packet-h263.h"
 
@@ -88,9 +88,7 @@ dissect_h263P( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 	tvbuff_t *next_tvb;
 	*/
 
-	if ( check_col( pinfo->cinfo, COL_PROTOCOL ) )   {
-		col_set_str( pinfo->cinfo, COL_PROTOCOL, "H.263 RFC4629 " );
-	}
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "H.263 RFC4629 ");
 
 	if ( tree ) {
 	  ti = proto_tree_add_item( tree, proto_h263P, tvb, offset, -1, FALSE );
@@ -180,8 +178,7 @@ dissect_h263P( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 				  /* Picture Start Code (PSC)
 				   * ( 1000 00x.)
 				   */
-				  if(check_col( pinfo->cinfo, COL_INFO))
-					  col_append_str( pinfo->cinfo, COL_INFO, "(PSC) ");
+				  col_append_str( pinfo->cinfo, COL_INFO, "(PSC) ");
 				  offset = dissect_h263_picture_layer( tvb, pinfo, h263P_data_tree, offset, -1, TRUE);
 				  break;
 			  case 0xfc:
@@ -193,8 +190,7 @@ dissect_h263P( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 				  /* Group of Block Start Code (GBSC) or
 				   * Slice Start Code (SSC)
 				   */
-				  if ( check_col( pinfo->cinfo, COL_INFO) )
-					  col_append_str( pinfo->cinfo, COL_INFO, "(GBSC) ");
+				  col_append_str( pinfo->cinfo, COL_INFO, "(GBSC) ");
 				  dissect_h263_group_of_blocks_layer( tvb, h263P_data_tree, offset,TRUE);
 				  break;
 			  }
@@ -322,7 +318,7 @@ proto_register_h263P(void)
 				BASE_DEC,
 				NULL,
 				0xe0,
-				"Thread ID", HFILL
+				NULL, HFILL
 			}
 		},
 		{
@@ -358,7 +354,7 @@ proto_register_h263P(void)
 				BASE_NONE,
 				NULL,
 				0x0,
-				"Extra picture header", HFILL
+				NULL, HFILL
 			}
 		},
 		{
