@@ -1,6 +1,11 @@
 /* packet-ieee802154.c
  *
- * $Id: packet-ieee802154.c 28412 2009-05-19 17:16:14Z stig $
+ * $Id: packet-ieee802154.c 30691 2009-10-25 11:43:30Z etxrab $
+ *
+ * Auxiliary Security Header support and
+ * option to force TI CC24xx FCS format
+ * By Jean-Francois Wauthy <jfw@info.fundp.ac.be>
+ * Copyright 2009 The University of Namur, Belgium
  *
  * IEEE 802.15.4 Dissectors for Wireshark
  * By Owen Kirby <osk@exegin.com>
@@ -89,6 +94,9 @@
 /* ethertype for 802.15.4 tag - encapsulating an Ethernet packet */
 static unsigned int ieee802154_ethertype = 0x809A;
 
+/* boolean value set if the FCS field is using the TI CC24xx format */
+static gboolean ieee802154_cc24xx = FALSE;
+
 /*  Function declarations */
 /* Register Functions. Loads the dissector into Wireshark. */
 void proto_reg_handoff_ieee802154   (void);
@@ -172,11 +180,22 @@ static int hf_ieee802154_bcn_gts_direction = -1;
 static int hf_ieee802154_bcn_pending16 = -1;
 static int hf_ieee802154_bcn_pending64 = -1;
 
+/*  Registered fields for Auxiliary Security Header */
+static int hf_ieee802154_security_level = -1;
+static int hf_ieee802154_key_id_mode = -1;
+static int hf_ieee802154_aux_sec_reserved = -1;
+static int hf_ieee802154_aux_sec_frame_counter = -1;
+static int hf_ieee802154_aux_sec_key_source = -1;
+static int hf_ieee802154_aux_sec_key_index = -1;
+
 /*  Initialize Subtree Pointers */
 static gint ett_ieee802154_nonask_phy = -1;
 static gint ett_ieee802154_nonask_phy_phr = -1;
 static gint ett_ieee802154 = -1;
 static gint ett_ieee802154_fcf = -1;
+static gint ett_ieee802154_auxiliary_security = -1;
+static gint ett_ieee802154_aux_sec_control = -1;
+static gint ett_ieee802154_aux_sec_key_id = -1;
 static gint ett_ieee802154_fcs = -1;
 static gint ett_ieee802154_cmd = -1;
 static gint ett_ieee802154_cmd_cinfo = -1;
@@ -220,6 +239,26 @@ static const value_string ieee802154_cmd_names[] = {
     { 0, NULL }
 };
 
+static const value_string ieee802154_sec_level_names[] = {
+    { SECURITY_LEVEL_NONE,        "No Security" },
+    { SECURITY_LEVEL_MIC_32,      "32-bit Message Integrity Code" },
+    { SECURITY_LEVEL_MIC_64,      "64-bit Message Integrity Code" },
+    { SECURITY_LEVEL_MIC_128,     "128-bit Message Integrity Code" },
+    { SECURITY_LEVEL_ENC,         "Encryption" },
+    { SECURITY_LEVEL_ENC_MIC_32,  "Encryption with 32-bit Message Integrity Code" },
+    { SECURITY_LEVEL_ENC_MIC_64,  "Encryption with 64-bit Message Integrity Code" },
+    { SECURITY_LEVEL_ENC_MIC_128, "Encryption with 128-bit Message Integrity Code" },
+    { 0, NULL }
+};
+
+static const value_string ieee802154_key_id_mode_names[] = {
+    { KEY_ID_MODE_IMPLICIT,       "Implicit Key" },
+    { KEY_ID_MODE_KEY_INDEX,      "Indexed Key using the Default Key Source" },
+    { KEY_ID_MODE_KEY_EXPLICIT_4, "Explicit Key with 4-octet Key Source" },
+    { KEY_ID_MODE_KEY_EXPLICIT_8, "Explicit Key with 8-octet Key Source" },
+    { 0, NULL }
+};
+
 /* CRC definitions. IEEE 802.15.4 CRCs vary from CCITT by using an initial value of
  * 0x0000, and no XOR out. IEEE802154_CRC_XOR is defined as 0xFFFF in order to un-XOR
  * the output from the CCITT CRC routines in Wireshark.
@@ -228,33 +267,6 @@ static const value_string ieee802154_cmd_names[] = {
 #define IEEE802154_CRC_XOROUT   0xFFFF
 #define ieee802154_crc_tvb(tvb, offset)   (crc16_ccitt_tvb_seed(tvb, offset, IEEE802154_CRC_SEED) ^ IEEE802154_CRC_XOROUT)
 
-/*FUNCTION:------------------------------------------------------
- *  NAME
- *      get_by_mask
- *  DESCRIPTION
- *      Extracts an integer sub-field from an int with a given mask
- *      if the mask is 0, this will return 0, if the mask is non-
- *      continuos the output is undefined.
- *  PARAMETERS
- *      guint       input
- *      guint       mask
- *  RETURNS
- *      guint
- *---------------------------------------------------------------
- */
-guint
-get_by_mask(guint input, guint mask)
-{
-    /* Sanity Check, don't want infinite loops. */
-    if (mask == 0) return 0;
-    /* Shift input and mask together. */
-    while (!(mask & 0x1)) {
-        input >>= 1;
-        mask >>=1;
-    } /* while */
-    return (input & mask);
-} /* get_by_mask */
-
 #define EUI64_STRLEN    (3*(sizeof(guint64)+1))
 /*FUNCTION:------------------------------------------------------
  *  NAME
@@ -281,7 +293,7 @@ print_eui64(guint64 addr)
     eui64addr.len = sizeof(guint64);
     eui64addr.data = &addr;
     /* Print the address. */
-    return address_to_str(&eui64addr);
+    return ep_address_to_str(&eui64addr);
 } /* print_eui64 */
 
 /*FUNCTION:------------------------------------------------------
@@ -313,16 +325,14 @@ print_eui64_oui(guint64 addr)
     manuf_name = get_manuf_name_if_known(eui64addr.data);
     if (manuf_name == NULL) {
         /* Could not find an OUI. */
-        return address_to_str(&eui64addr);
+        return ep_address_to_str(&eui64addr);
     }
     else {
         /* Found an address string. */
-        gchar       *output_str = ep_alloc(64);
-        g_snprintf(output_str, 64, "%s_%02x:%02x:%02x:%02x:%02x", manuf_name,
+        return ep_strdup_printf("%s_%02x:%02x:%02x:%02x:%02x", manuf_name,
             ((guint8 *)(eui64addr.data))[3], ((guint8 *)(eui64addr.data))[4],
             ((guint8 *)(eui64addr.data))[5], ((guint8 *)(eui64addr.data))[6],
             ((guint8 *)(eui64addr.data))[7]);
-        return output_str;
     }
 } /* print_eui64_oui */
 
@@ -355,18 +365,18 @@ dissect_ieee802154_fcf(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, ieee
     fcf = tvb_get_letohs(tvb, *offset);
 
      /* Parse FCF Flags. */
-    packet->frame_type      = get_by_mask(fcf, IEEE802154_FCF_TYPE_MASK);
-    packet->security_enable = get_by_mask(fcf, IEEE802154_FCF_SEC_EN);
-    packet->frame_pending   = get_by_mask(fcf, IEEE802154_FCF_FRAME_PND);
-    packet->ack_request     = get_by_mask(fcf, IEEE802154_FCF_ACK_REQ);
-    packet->intra_pan       = get_by_mask(fcf, IEEE802154_FCF_INTRA_PAN);
-    packet->version         = get_by_mask(fcf, IEEE802154_FCF_VERSION);
-    packet->dst_addr_mode   = get_by_mask(fcf, IEEE802154_FCF_DADDR_MASK);
-    packet->src_addr_mode   = get_by_mask(fcf, IEEE802154_FCF_SADDR_MASK);
+    packet->frame_type      = fcf & IEEE802154_FCF_TYPE_MASK;
+    packet->security_enable = fcf & IEEE802154_FCF_SEC_EN;
+    packet->frame_pending   = fcf & IEEE802154_FCF_FRAME_PND;
+    packet->ack_request     = fcf & IEEE802154_FCF_ACK_REQ;
+    packet->intra_pan       = fcf & IEEE802154_FCF_INTRA_PAN;
+    packet->version         = (fcf & IEEE802154_FCF_VERSION) >> 12;
+    packet->dst_addr_mode   = (fcf & IEEE802154_FCF_DADDR_MASK) >> 10;
+    packet->src_addr_mode   = (fcf & IEEE802154_FCF_SADDR_MASK) >> 14;
 
     /* Display the frame type. */
     if (tree) proto_item_append_text(tree, " %s", val_to_str(packet->frame_type, ieee802154_frame_types, "Reserved"));
-    if (check_col(pinfo->cinfo, COL_INFO)) col_set_str(pinfo->cinfo, COL_INFO, val_to_str(packet->frame_type, ieee802154_frame_types, "Reserved"));
+    if (check_col(pinfo->cinfo, COL_INFO)) col_set_str(pinfo->cinfo, COL_INFO, val_to_str_const(packet->frame_type, ieee802154_frame_types, "Reserved"));
 
     /* Add the FCF to the protocol tree. */
     if (tree) {
@@ -423,9 +433,7 @@ dissect_ieee802154_nonask_phy(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tre
     }
 
     /* Add the protocol name. */
-    if(check_col(pinfo->cinfo, COL_PROTOCOL)){
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "IEEE 802.15.4 non-ASK PHY");
-    }
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "IEEE 802.15.4 non-ASK PHY");
     /* Add the packet length. */
     if(check_col(pinfo->cinfo, COL_PACKET_LENGTH)){
         col_clear(pinfo->cinfo, COL_PACKET_LENGTH);
@@ -478,7 +486,7 @@ static void
 dissect_ieee802154(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
     /* Call the common dissector. */
-    dissect_ieee802154_common(tvb, pinfo, tree, 0);
+    dissect_ieee802154_common(tvb, pinfo, tree, (ieee802154_cc24xx ? DISSECT_IEEE802154_OPTION_CC24xx : 0));
 } /* dissect_ieee802154 */
 
 /*FUNCTION:------------------------------------------------------
@@ -585,9 +593,7 @@ dissect_ieee802154_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, g
         ieee802154_tree = proto_item_add_subtree(proto_root, ett_ieee802154);
     }
     /* Add the protocol name. */
-    if(check_col(pinfo->cinfo, COL_PROTOCOL)){
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "IEEE 802.15.4");
-    }
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "IEEE 802.15.4");
     /* Add the packet length. */
     if(check_col(pinfo->cinfo, COL_PACKET_LENGTH)){
         col_clear(pinfo->cinfo, COL_PACKET_LENGTH);
@@ -797,6 +803,90 @@ dissect_ieee802154_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, g
         }
     }
 
+    /*=====================================================
+     * AUXILIARY SECURITY HEADER
+     *=====================================================
+     */
+    /* The Auxiliary Security Header only exists in IEEE 802.15.4-2006 */
+    if (packet->security_enable && (packet->version == 1)) {
+      proto_item *ti;
+      proto_tree *header_tree, *field_tree;
+
+      guint                     key_length = 0;
+      guint8                    security_control;
+      ieee802154_security_level sec_level;
+      ieee802154_key_id_mode    key_id_mode;
+      guint32                   frame_counter;
+
+      guint64 key_source = 0;
+      guint8  key_index;
+
+      security_control = tvb_get_guint8(tvb, offset);
+
+      sec_level = (security_control & IEEE802154_AUX_SEC_LEVEL_MASK);
+      key_id_mode = (security_control & IEEE802154_AUX_KEY_ID_MODE_MASK);
+      switch ((key_id_mode >> 3)) {
+      case KEY_ID_MODE_IMPLICIT:
+        break;
+      case KEY_ID_MODE_KEY_INDEX:
+        key_length++;
+        break;
+      case KEY_ID_MODE_KEY_EXPLICIT_4:
+        key_length += 5;
+        break;
+      case KEY_ID_MODE_KEY_EXPLICIT_8:
+        key_length += 9;
+        break;
+      }
+
+      ti = proto_tree_add_text(ieee802154_tree, tvb, offset, 5 + key_length, "Auxiliary Security Header");
+      header_tree = proto_item_add_subtree(ti, ett_ieee802154_auxiliary_security);
+
+      /* Security Control Field */
+      ti = proto_tree_add_text(header_tree, tvb, offset, sizeof (guint8), "Security Control Field (0x%02x)", security_control);
+      field_tree = proto_item_add_subtree(ti, ett_ieee802154_aux_sec_control);
+
+      proto_tree_add_uint(field_tree, hf_ieee802154_security_level, tvb, offset, sizeof(guint8), sec_level);
+      proto_tree_add_uint(field_tree, hf_ieee802154_key_id_mode, tvb, offset, sizeof(guint8), key_id_mode);
+      proto_tree_add_uint(field_tree, hf_ieee802154_aux_sec_reserved, tvb, offset, sizeof(guint8), 0);
+
+      offset++;
+
+      /* Frame Counter Field */
+      frame_counter = tvb_get_letohl (tvb, offset);
+
+      proto_tree_add_uint(header_tree, hf_ieee802154_aux_sec_frame_counter, tvb, offset, sizeof(guint32), frame_counter);
+
+      offset += sizeof (guint32);
+
+      /* Key Identifier Fields */
+      switch ((key_id_mode >> 3)) {
+      case KEY_ID_MODE_IMPLICIT:
+      case KEY_ID_MODE_KEY_INDEX:
+        break;
+      case KEY_ID_MODE_KEY_EXPLICIT_4:
+        key_source = (guint64) tvb_get_ntohl(tvb, offset);
+        break;
+      case KEY_ID_MODE_KEY_EXPLICIT_8:
+        key_source = tvb_get_ntoh64(tvb, offset);
+        break;
+      }
+
+      ti = proto_tree_add_text(header_tree, tvb, offset, key_length, "Key Identifier Field");
+      field_tree = proto_item_add_subtree(ti, ett_ieee802154_aux_sec_key_id);
+
+      /* Key Source Field */
+      if ((key_id_mode >> 3) > KEY_ID_MODE_KEY_INDEX) {
+        proto_tree_add_uint64(field_tree, hf_ieee802154_aux_sec_key_source, tvb, offset, sizeof (guint64), key_source);
+        offset += key_length - 1;
+      }
+
+      /* Key Index Field */
+      key_index = tvb_get_guint8(tvb, offset);
+      proto_tree_add_uint(field_tree, hf_ieee802154_aux_sec_key_index, tvb, offset, sizeof (guint8), key_index);
+      offset++;
+    }
+
     /*=====================================================
      * PAYLOAD DISSECTION
      *=====================================================
@@ -885,13 +975,13 @@ dissect_ieee802154_fcs:
         /* Display the FCS depending on expected FCS format */
         if ((options & DISSECT_IEEE802154_OPTION_CC24xx)) {
             /* Create a subtree for the FCS. */
-            ti = proto_tree_add_text(ieee802154_tree, tvb, offset, sizeof(guint16), "Frame Check Sequence: FCS %s", (fcs_ok) ? "OK" : "Bad");
+            ti = proto_tree_add_text(ieee802154_tree, tvb, offset, sizeof(guint16), "Frame Check Sequence (TI CC24xx format): FCS %s", (fcs_ok) ? "OK" : "Bad");
             field_tree = proto_item_add_subtree(ti, ett_ieee802154_fcs);
             /* Display FCS contents.  */
-            ti = proto_tree_add_int(field_tree, hf_ieee802154_rssi, tvb, offset, sizeof(guint16), get_by_mask(fcs, IEEE802154_CC24xx_RSSI));
+            ti = proto_tree_add_int(field_tree, hf_ieee802154_rssi, tvb, offset++, sizeof(gint8), (gint8) (fcs & IEEE802154_CC24xx_RSSI));
             proto_item_append_text(ti, " dBm"); /*  Displaying Units */
-            proto_tree_add_boolean(field_tree, hf_ieee802154_fcs_ok, tvb, offset, sizeof(guint16), get_by_mask(fcs, IEEE802154_CC24xx_CRC_OK));
-            proto_tree_add_uint(field_tree, hf_ieee802154_correlation, tvb, offset, sizeof(guint16), get_by_mask(fcs, IEEE802154_CC24xx_CORRELATION));
+            proto_tree_add_boolean(field_tree, hf_ieee802154_fcs_ok, tvb, offset, sizeof(gint8), (gboolean) (fcs & IEEE802154_CC24xx_CRC_OK));
+            proto_tree_add_uint(field_tree, hf_ieee802154_correlation, tvb, offset, sizeof(gint8), (guint8) ((fcs & IEEE802154_CC24xx_CORRELATION) >> 8));
         }
         else {
             ti = proto_tree_add_uint(ieee802154_tree, hf_ieee802154_fcs, tvb, offset, sizeof(guint16), fcs);
@@ -916,7 +1006,7 @@ dissect_ieee802154_fcs:
 
     /* If the CRC is invalid, make a note of it in the info column. */
     if (!fcs_ok) {
-        if (check_col(pinfo->cinfo, COL_INFO)) col_append_fstr(pinfo->cinfo, COL_INFO, ", Bad FCS");
+        col_append_str(pinfo->cinfo, COL_INFO, ", Bad FCS");
         if (tree) proto_item_append_text(proto_root, ", Bad FCS");
 
         /* Flag packet as having a bad crc. */
@@ -1121,7 +1211,7 @@ dissect_ieee802154_cmd(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, ieee
     /* Get and display the command frame identifier. */
     cmd_id = tvb_get_guint8(tvb, offset);
     if(check_col(pinfo->cinfo, COL_INFO)) {
-        col_set_str(pinfo->cinfo, COL_INFO, val_to_str(cmd_id, ieee802154_cmd_names, "Unknown Command"));
+        col_set_str(pinfo->cinfo, COL_INFO, val_to_str_const(cmd_id, ieee802154_cmd_names, "Unknown Command"));
     }
     if (tree) {
         /* Create a subtree for this command frame. */
@@ -1539,22 +1629,22 @@ void proto_register_ieee802154(void)
 
         { &hf_ieee802154_nonask_phy_preamble,
         { "Preamble",                       "wpan-nonask-phy.preamble", FT_UINT32, BASE_HEX, NULL, 0x0,
-            "", HFILL }},
+            NULL, HFILL }},
 
         { &hf_ieee802154_nonask_phy_sfd,
         { "Start of Frame Delimiter",       "wpan-nonask-phy.sfd", FT_UINT8, BASE_HEX, NULL, 0x0,
-            "", HFILL }},
+            NULL, HFILL }},
 
         { &hf_ieee802154_nonask_phy_length,
         { "Frame Length",                   "wpan-nonask-phy.frame_length", FT_UINT8, BASE_HEX, NULL, IEEE802154_PHY_LENGTH_MASK,
-            "", HFILL }},
+            NULL, HFILL }},
     };
 
 
     static hf_register_info hf[] = {
         { &hf_ieee802154_frame_type,
         { "Frame Type",                     "wpan.frame_type", FT_UINT16, BASE_HEX, VALS(ieee802154_frame_types), IEEE802154_FCF_TYPE_MASK,
-            "", HFILL }},
+            NULL, HFILL }},
 
         { &hf_ieee802154_security,
         { "Security Enabled",               "wpan.security", FT_BOOLEAN, 16, NULL, IEEE802154_FCF_SEC_EN,
@@ -1574,66 +1664,66 @@ void proto_register_ieee802154(void)
 
         { &hf_ieee802154_seqno,
         { "Sequence Number",                "wpan.seq_no", FT_UINT8, BASE_DEC, NULL, 0x0,
-            "", HFILL }},
+            NULL, HFILL }},
 
         { &hf_ieee802154_dst_addr_mode,
         { "Destination Addressing Mode",    "wpan.dst_addr_mode", FT_UINT16, BASE_HEX, VALS(ieee802154_addr_modes), IEEE802154_FCF_DADDR_MASK,
-            "", HFILL }},
+            NULL, HFILL }},
 
         { &hf_ieee802154_src_addr_mode,
         { "Source Addressing Mode",         "wpan.src_addr_mode", FT_UINT16, BASE_HEX, VALS(ieee802154_addr_modes), IEEE802154_FCF_SADDR_MASK,
-            "", HFILL }},
+            NULL, HFILL }},
 
         { &hf_ieee802154_version,
         { "Frame Version",                  "wpan.version", FT_UINT16, BASE_DEC, NULL, IEEE802154_FCF_VERSION,
-            "", HFILL }},
+            NULL, HFILL }},
 
         { &hf_ieee802154_dst_pan,
         { "Destination PAN",                "wpan.dst_pan", FT_UINT16, BASE_HEX, NULL, 0x0,
-            "", HFILL }},
+            NULL, HFILL }},
 
         { &hf_ieee802154_dst_addr16,
         { "Destination",                    "wpan.dst_addr16", FT_UINT16, BASE_HEX, NULL, 0x0,
-            "", HFILL }},
+            NULL, HFILL }},
 
         { &hf_ieee802154_dst_addr64,
         { "Destination",                    "wpan.dst_addr64", FT_UINT64, BASE_HEX, NULL, 0x0,
-            "", HFILL }},
+            NULL, HFILL }},
 
         { &hf_ieee802154_src_panID,
         { "Source PAN",                     "wpan.src_pan", FT_UINT16, BASE_HEX, NULL, 0x0,
-            "", HFILL }},
+            NULL, HFILL }},
 
         { &hf_ieee802154_src_addr16,
         { "Source",                         "wpan.src_addr16", FT_UINT16, BASE_HEX, NULL, 0x0,
-            "", HFILL }},
+            NULL, HFILL }},
 
         { &hf_ieee802154_src_addr64,
         { "Source",                         "wpan.src_addr64", FT_UINT64, BASE_HEX, NULL, 0x0,
-            "", HFILL }},
+            NULL, HFILL }},
 
         { &hf_ieee802154_fcs,
         { "FCS",                            "wpan.fcs", FT_UINT16, BASE_HEX, NULL, 0x0,
-            "", HFILL }},
+            NULL, HFILL }},
 
         { &hf_ieee802154_rssi,
         { "RSSI",                           "wpan.rssi", FT_INT8, BASE_DEC, NULL, 0x0,
             "Received Signal Strength", HFILL }},
 
         { &hf_ieee802154_fcs_ok,
-        { "FCS Valid",                      "wpan.fcs_ok", FT_BOOLEAN, 8, NULL, 0x0,
-            "", HFILL }},
+        { "FCS Valid",                      "wpan.fcs_ok", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
+            NULL, HFILL }},
 
         { &hf_ieee802154_correlation,
         { "LQI Correlation Value",          "wpan.correlation", FT_UINT8, BASE_DEC, NULL, 0x0,
-            "", HFILL }},
+            NULL, HFILL }},
 
             /*  Command Frame Specific Fields */
             /*--------------------------------*/
 
         { &hf_ieee802154_cmd_id,
         { "Command Identifier",         "wpan.cmd.id", FT_UINT8, BASE_HEX, VALS(ieee802154_cmd_names), 0x0,
-            "", HFILL }},
+            NULL, HFILL }},
 
             /*  Capability Information Fields */
         { &hf_ieee802154_cmd_cinfo_alt_coord,
@@ -1667,11 +1757,11 @@ void proto_register_ieee802154(void)
 
         { &hf_ieee802154_cmd_asrsp_status,
         { "Association Status",         "wpan.cmd.asrsp.status", FT_UINT8, BASE_HEX, NULL, 0x0,
-            "", HFILL }},
+            NULL, HFILL }},
 
         { &hf_ieee802154_cmd_disas_reason,
         { "Disassociation Reason",      "wpan.cmd.disas.reason", FT_UINT8, BASE_HEX, NULL, 0x0,
-            "", HFILL }},
+            NULL, HFILL }},
 
             /*  Coordinator Realignment fields */
         { &hf_ieee802154_cmd_coord_pan,
@@ -1737,11 +1827,11 @@ void proto_register_ieee802154(void)
             "The number of GTS descriptors present in this beacon frame.", HFILL }},
 
         { &hf_ieee802154_bcn_gts_permit,
-        { "GTS Permit",                 "wpan.bcn.gts.permit", FT_BOOLEAN, 8, NULL, 0x0,
+        { "GTS Permit",                 "wpan.bcn.gts.permit", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
             "Whether the PAN coordinator is accepting GTS requests or not.", HFILL }},
 
         { &hf_ieee802154_bcn_gts_direction,
-        { "Direction",                  "wpan.bcn.gts.direction", FT_BOOLEAN, 8, NULL, 0x0,
+        { "Direction",                  "wpan.bcn.gts.direction", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
             "A flag defining the direction of the GTS Slot.", HFILL }},
 
         { &hf_ieee802154_bcn_pending16,
@@ -1750,7 +1840,32 @@ void proto_register_ieee802154(void)
 
         { &hf_ieee802154_bcn_pending64,
         { "Address",                    "wpan.bcn.pending64", FT_UINT64, BASE_HEX, NULL, 0x0,
-            "Device with pending data to receive.", HFILL }}
+            "Device with pending data to receive.", HFILL }},
+            /* Auxiliary Security Header Fields */
+            /*----------------------------------*/
+        { &hf_ieee802154_security_level,
+        { "Security Level", "wpan.aux_sec.sec_level", FT_UINT8, BASE_HEX, VALS(ieee802154_sec_level_names), IEEE802154_AUX_SEC_LEVEL_MASK,
+            "The Security Level of the frame", HFILL }},
+
+        { &hf_ieee802154_key_id_mode,
+        { "Key Identifier Mode", "wpan.aux_sec.key_id_mode", FT_UINT8, BASE_HEX, VALS(ieee802154_key_id_mode_names), IEEE802154_AUX_KEY_ID_MODE_MASK,
+            "The scheme to use by the recipient to lookup the key in its key table", HFILL }},
+
+        { &hf_ieee802154_aux_sec_reserved,
+        { "Reserved", "wpan.aux_sec.reserved", FT_UINT8, BASE_HEX, NULL, IEEE802154_AUX_KEY_RESERVED_MASK,
+            "Reserved", HFILL }},
+
+        { &hf_ieee802154_aux_sec_frame_counter,
+        { "Frame Counter", "wpan.aux_sec.frame_counter", FT_UINT32, BASE_DEC, NULL, 0x0,
+            "Frame counter of the originator of the protected frame", HFILL }},
+
+        { &hf_ieee802154_aux_sec_key_source,
+        { "Key Source", "wpan.aux_sec.key_source", FT_UINT64, BASE_HEX, NULL, 0x0,
+            "Key Source for processing of the protected frame", HFILL }},
+
+        { &hf_ieee802154_aux_sec_key_index,
+        { "Key Index", "wpan.aux_sec.key_index", FT_UINT8, BASE_HEX, NULL, 0x0,
+            "Key Index for processing of the protected frame", HFILL }}
     };
 
     static gint *ett[] = {
@@ -1758,6 +1873,9 @@ void proto_register_ieee802154(void)
         &ett_ieee802154_nonask_phy_phr,
         &ett_ieee802154,
         &ett_ieee802154_fcf,
+        &ett_ieee802154_auxiliary_security,
+        &ett_ieee802154_aux_sec_control,
+        &ett_ieee802154_aux_sec_key_id,
         &ett_ieee802154_fcs,
         &ett_ieee802154_cmd,
         &ett_ieee802154_cmd_cinfo,
@@ -1782,12 +1900,16 @@ void proto_register_ieee802154(void)
     proto_register_subtree_array(ett, array_length(ett));
 
     /* add a user preference to set the 802.15.4 ethertype */
-    ieee802154_module = prefs_register_protocol(proto_ieee802154, 
-						proto_reg_handoff_ieee802154);
+    ieee802154_module = prefs_register_protocol(proto_ieee802154,
+        proto_reg_handoff_ieee802154);
     prefs_register_uint_preference(ieee802154_module, "802154_ethertype",
-				   "802.15.4 Ethertype (in hex)",
-				   "(Hexadecimal) Ethertype used to indicate IEEE 802.15.4 frame.",
-				   16, &ieee802154_ethertype);
+                                   "802.15.4 Ethertype (in hex)",
+                                   "(Hexadecimal) Ethertype used to indicate IEEE 802.15.4 frame.",
+                                   16, &ieee802154_ethertype);
+    prefs_register_bool_preference(ieee802154_module, "802154_cc24xx",
+                                   "TI CC24xx FCS format",
+                                   "Set if the FCS field is in TI CC24xx format.",
+                                   &ieee802154_cc24xx);
 
     /* Register the subdissector list */
     register_heur_dissector_list("wpan", &ieee802154_heur_subdissector_list);
@@ -1830,11 +1952,11 @@ void proto_reg_handoff_ieee802154(void)
 
         prefs_initialized = TRUE;
     } else {
-        dissector_delete("ethertype", old_ieee802154_ethertype, ieee802154_handle);	
+        dissector_delete("ethertype", old_ieee802154_ethertype, ieee802154_handle);
     }
 
     old_ieee802154_ethertype = ieee802154_ethertype;
-	
+
     /* Register dissector handles. */
     dissector_add("ethertype", ieee802154_ethertype, ieee802154_handle);
 
