@@ -1,7 +1,7 @@
 /* packet-ieee8023.c
  * Routine for dissecting 802.3 (as opposed to D/I/X Ethernet) packets.
  *
- * $Id: packet-ieee8023.c 25731 2008-07-13 18:56:54Z guy $
+ * $Id: packet-ieee8023.c 29446 2009-08-16 12:36:22Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -35,6 +35,7 @@
 
 static dissector_handle_t ipx_handle;
 static dissector_handle_t llc_handle;
+static dissector_handle_t ccsds_handle;
 
 void
 dissect_802_3(volatile int length, gboolean is_802_2, tvbuff_t *tvb,
@@ -75,7 +76,7 @@ dissect_802_3(volatile int length, gboolean is_802_2, tvbuff_t *tvb,
     captured_length = length;
   next_tvb = tvb_new_subset(tvb, offset_after_length, captured_length, length);
   TRY {
-    trailer_tvb = tvb_new_subset(tvb, offset_after_length + length, -1, -1);
+    trailer_tvb = tvb_new_subset_remaining(tvb, offset_after_length + length);
   }
   CATCH2(BoundsError, ReportedBoundsError) {
     /* The packet has exactly "length" bytes worth of captured data
@@ -98,8 +99,15 @@ dissect_802_3(volatile int length, gboolean is_802_2, tvbuff_t *tvb,
   TRY {
     if (is_802_2)
       call_dissector(llc_handle, next_tvb, pinfo, tree);
-    else
-      call_dissector(ipx_handle, next_tvb, pinfo, tree);
+    else {
+      /* Check if first three bits of payload are 0x7.
+         If so, then payload is IPX.  If not, then it's CCSDS.
+         Refer to packet-eth.c for setting of is_802_2 variable. */
+      if (tvb_get_bits8(next_tvb, 0, 3) == 7)
+        call_dissector(ipx_handle, next_tvb, pinfo, tree);
+      else
+        call_dissector(ccsds_handle, next_tvb, pinfo, tree);
+    }
   }
   CATCH(BoundsError) {
    /* Somebody threw BoundsError, which means that dissecting the payload
@@ -126,8 +134,9 @@ void
 proto_reg_handoff_ieee802_3(void)
 {
   /*
-   * Get handles for the IPX and LLC dissectors.
+   * Get handles for the subdissectors.
    */
   ipx_handle = find_dissector("ipx");
   llc_handle = find_dissector("llc");
+  ccsds_handle = find_dissector("ccsds");
 }
