@@ -3,7 +3,7 @@
  * Copyright 2007-2008, Alexey Neyman, Pigeon Point Systems <avn@pigeonpoint.com>
  * Copyright Duncan Laurie <duncan@sun.com>
  *
- * $Id: packet-ipmi-session.c 27324 2009-01-28 21:52:57Z wmeier $
+ * $Id: packet-ipmi-session.c 28770 2009-06-18 21:30:42Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -270,40 +270,40 @@ proto_register_ipmi_session(void)
 	static hf_register_info hf[] = {
 		{ &hf_ipmi_session_authtype, {
 			"Authentication Type", "ipmi.session.authtype",
-			FT_UINT8, BASE_HEX, VALS(ipmi_authtype_vals), 0, "", HFILL }},
+			FT_UINT8, BASE_HEX, VALS(ipmi_authtype_vals), 0, NULL, HFILL }},
 		{ &hf_ipmi_session_payloadtype,{
 			"Payload Type", "ipmi.session.payloadtype",
-			FT_UINT8, BASE_HEX, VALS(ipmi_payload_vals), 0x3f, "", HFILL }},
+			FT_UINT8, BASE_HEX, VALS(ipmi_payload_vals), 0x3f, NULL, HFILL }},
 		{ &hf_ipmi_session_payloadtype_auth,{
 			"Authenticated","ipmi.session.payloadtype.auth",
-			FT_BOOLEAN,8,  TFS(&ipmi_payload_aut_val), 0x40, "", HFILL }},
+			FT_BOOLEAN,8,  TFS(&ipmi_payload_aut_val), 0x40, NULL, HFILL }},
 		{ &hf_ipmi_session_payloadtype_enc,{
 			"Encryption","ipmi.session.payloadtype.enc",
-			FT_BOOLEAN,8,  TFS(&ipmi_payload_enc_val), 0x80, "", HFILL }},
+			FT_BOOLEAN,8,  TFS(&ipmi_payload_enc_val), 0x80, NULL, HFILL }},
 		{ &hf_ipmi_session_oem_iana, {
 			"OEM IANA", "ipmi.session.oem.iana",
-			FT_BYTES, BASE_HEX, NULL, 0, "", HFILL }},
+			FT_BYTES, BASE_NONE, NULL, 0, NULL, HFILL }},
 		{ &hf_ipmi_session_oem_payload_id, {
 			"OEM Payload ID", "ipmi.session.oem.payloadid",
-			FT_BYTES, BASE_HEX, NULL, 0, "", HFILL }},
+			FT_BYTES, BASE_NONE, NULL, 0, NULL, HFILL }},
 		{ &hf_ipmi_session_sequence, {
 			"Session Sequence Number", "ipmi.session.sequence",
-			FT_UINT32, BASE_HEX, NULL, 0, "", HFILL }},
+			FT_UINT32, BASE_HEX, NULL, 0, NULL, HFILL }},
 		{ &hf_ipmi_session_id, {
 			"Session ID", "ipmi.session.id",
-			FT_UINT32, BASE_HEX, NULL, 0, "", HFILL }},
+			FT_UINT32, BASE_HEX, NULL, 0, NULL, HFILL }},
 		{ &hf_ipmi_session_authcode, {
 			"Authentication Code", "ipmi.session.authcode",
-			FT_BYTES, BASE_HEX, NULL, 0, "", HFILL }},
+			FT_BYTES, BASE_NONE, NULL, 0, NULL, HFILL }},
 		{ &hf_ipmi_session_msg_len_1b, {
 			"Message Length", "ipmi.msg.len",
-			FT_UINT8, BASE_DEC, NULL, 0, "", HFILL }},
+			FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
 		{ &hf_ipmi_session_msg_len_2b, {
 			"Message Length", "ipmi.msg.len",
-			FT_UINT16, BASE_DEC, NULL, 0, "", HFILL }},
+			FT_UINT16, BASE_DEC, NULL, 0, NULL, HFILL }},
 		{ &hf_ipmi_session_trailer, {
 			"IPMI Session Wrapper (trailer)", "ipmi.sess.trailer",
-			FT_BYTES, BASE_HEX, NULL, 0, "", HFILL }},
+			FT_BYTES, BASE_NONE, NULL, 0, NULL, HFILL }},
 	};
 
 	static gint *ett[] = { &ett_ipmi_session, &ett_ipmi_session_payloadtype };
