@@ -3,7 +3,7 @@
  *
  * Guy Harris <guy@alum.mit.edu>
  *
- * $Id: packet-ipp.c 26091 2008-08-26 01:28:50Z wmeier $
+ * $Id: packet-ipp.c 29446 2009-08-16 12:36:22Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -189,8 +189,7 @@ dissect_ipp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	guint16 status_code;
 	const gchar *status_fmt;
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "IPP");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "IPP");
 	if (check_col(pinfo->cinfo, COL_INFO)) {
 		if (is_request)
 			col_set_str(pinfo->cinfo, COL_INFO, "IPP request");
@@ -253,7 +252,7 @@ dissect_ipp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 		if (tvb_offset_exists(tvb, offset)) {
 			call_dissector(data_handle,
-			    tvb_new_subset(tvb, offset, -1, -1), pinfo,
+			    tvb_new_subset_remaining(tvb, offset), pinfo,
 			    ipp_tree);
 		}
 	}
@@ -687,7 +686,7 @@ proto_register_ipp(void)
         static hf_register_info hf[] = {
                 { &hf_ipp_timestamp,
                   { "Time", "ipp.timestamp", FT_ABSOLUTE_TIME, BASE_NONE,
-                    NULL, 0, "", HFILL }},
+                    NULL, 0, NULL, HFILL }},
         };
 	static gint *ett[] = {
 		&ett_ipp,
