@@ -3,7 +3,7 @@
  * Enterasys Networks Home: http://www.enterasys.com/
  * Copyright 2003, Joshua Craig Douglas <jdouglas@enterasys.com>
  *
- * $Id: packet-ismp.c 27062 2008-12-19 17:39:52Z gerald $
+ * $Id: packet-ismp.c 28959 2009-07-06 17:45:40Z jmayer $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -48,6 +48,7 @@ static int hf_ismp_code_length = -1;
 static int hf_ismp_auth_data = -1;
 
 /* Enterasys/Cabletron Dicovery Protocol fields*/
+static int hf_ismp_edp = -1;
 static int hf_ismp_edp_version = -1;
 static int hf_ismp_edp_module_ip = -1;
 static int hf_ismp_edp_module_mac = -1;
@@ -234,7 +235,7 @@ dissect_ismp_edp(tvbuff_t *tvb, packet_info *pinfo, int offset, proto_tree *ismp
 
 	/* Set up structures needed to add the protocol subtree and manage it */
 	proto_item *edp_ti;
-	proto_tree *ismp_edp_tree;
+	proto_tree *edp_tree;
 	
 	proto_item *edp_options_ti;
 	proto_tree *edp_options_tree;
@@ -252,40 +253,43 @@ dissect_ismp_edp(tvbuff_t *tvb, packet_info *pinfo, int offset, proto_tree *ismp
 	proto_tree *edp_tuples_leaf_tree;
 
 	/* add column iformation marking this as EDP (Enterasys Discover Protocol */
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "EDP Message");
-	if (check_col(pinfo->cinfo, COL_INFO)) 
-		col_clear(pinfo->cinfo, COL_INFO);
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "ISMP.EDP");
+	col_clear(pinfo->cinfo, COL_INFO);
 
 	/* create display subtree for EDP */
 	if (ismp_tree) {
-		edp_ti  = proto_tree_add_text(ismp_tree, tvb, offset, 0, "Enterasys Discovery Protocol");
-		ismp_edp_tree = proto_item_add_subtree(edp_ti, ett_ismp_edp);
+		edp_ti  = proto_tree_add_item(ismp_tree, hf_ismp_edp, tvb, offset,
+			tvb_length_remaining(tvb, offset), FALSE);
+		edp_tree = proto_item_add_subtree(edp_ti, ett_ismp_edp);
 
-		
-		proto_tree_add_item(ismp_edp_tree, hf_ismp_edp_version, tvb, offset, 2, FALSE);
+		col_add_fstr(pinfo->cinfo, COL_INFO, "MIP %s, MMAC %s, ifIdx %d",
+			ip_to_str(tvb_get_ptr(tvb, offset+2, 4)),
+			ether_to_str(tvb_get_ptr(tvb, offset+6, 6)),
+			tvb_get_ntohl(tvb, offset+12));
+
+		proto_tree_add_item(edp_tree, hf_ismp_edp_version, tvb, offset, 2, FALSE);
 		offset += 2;
-		proto_tree_add_item(ismp_edp_tree, hf_ismp_edp_module_ip, tvb, offset, 4, FALSE);
+		proto_tree_add_item(edp_tree, hf_ismp_edp_module_ip, tvb, offset, 4, FALSE);
 		offset += 4;
-		proto_tree_add_item(ismp_edp_tree, hf_ismp_edp_module_mac, tvb, offset, 6, FALSE);
+		proto_tree_add_item(edp_tree, hf_ismp_edp_module_mac, tvb, offset, 6, FALSE);
 		offset += 6;
-		proto_tree_add_item(ismp_edp_tree, hf_ismp_edp_module_port, tvb, offset, 4, FALSE);
+		proto_tree_add_item(edp_tree, hf_ismp_edp_module_port, tvb, offset, 4, FALSE);
 		offset += 4;
-		proto_tree_add_item(ismp_edp_tree, hf_ismp_edp_chassis_mac, tvb, offset, 6, FALSE);
+		proto_tree_add_item(edp_tree, hf_ismp_edp_chassis_mac, tvb, offset, 6, FALSE);
 		offset += 6;
-		proto_tree_add_item(ismp_edp_tree, hf_ismp_edp_chassis_ip, tvb, offset, 4, FALSE);
+		proto_tree_add_item(edp_tree, hf_ismp_edp_chassis_ip, tvb, offset, 4, FALSE);
 		offset += 4;
 		device_type = tvb_get_ntohs(tvb, offset);
-		proto_tree_add_item(ismp_edp_tree, hf_ismp_edp_device_type, tvb, offset, 2, FALSE);
+		proto_tree_add_item(edp_tree, hf_ismp_edp_device_type, tvb, offset, 2, FALSE);
 		offset += 2;
-		proto_tree_add_uint_format(ismp_edp_tree, hf_ismp_edp_module_rev, tvb, offset, 4, tvb_get_ntohl(tvb, offset),
+		proto_tree_add_uint_format(edp_tree, hf_ismp_edp_module_rev, tvb, offset, 4, tvb_get_ntohl(tvb, offset),
 			"Module Firmware Revision: %02x.%02x.%02x.%02x", tvb_get_guint8(tvb, offset),
 			tvb_get_guint8(tvb, offset+1), tvb_get_guint8(tvb, offset+2), tvb_get_guint8(tvb, offset+3));
 		offset += 4;
 
 		/* create display subtree for EDP options */
 		options = tvb_get_ntohl(tvb, offset);
-		edp_options_ti = proto_tree_add_uint_format(ismp_edp_tree, hf_ismp_edp_options, tvb, offset, 4,
+		edp_options_ti = proto_tree_add_uint_format(edp_tree, hf_ismp_edp_options, tvb, offset, 4,
 			options,"Options: 0x%08x",options);
 		edp_options_tree = proto_item_add_subtree(edp_options_ti, ett_ismp_edp_options);
 
@@ -353,7 +357,7 @@ dissect_ismp_edp(tvbuff_t *tvb, packet_info *pinfo, int offset, proto_tree *ismp
 		
 		/* determine the number of neighbors and create EDP neighbors subtree */
 		num_neighbors = tvb_get_ntohs(tvb, offset);
-		proto_tree_add_item(ismp_edp_tree, hf_ismp_edp_num_neighbors, tvb, offset, 2, FALSE);
+		proto_tree_add_item(edp_tree, hf_ismp_edp_num_neighbors, tvb, offset, 2, FALSE);
 		offset += 2;
 		if (num_neighbors > 0)
 		{
@@ -361,13 +365,13 @@ dissect_ismp_edp(tvbuff_t *tvb, packet_info *pinfo, int offset, proto_tree *ismp
 			if (tvb_reported_length_remaining(tvb, offset) >= (num_neighbors *10))
 			{
 				neighbors_ptr = tvb_get_ptr( tvb, offset, (num_neighbors*10) );
-				edp_neighbors_ti = proto_tree_add_bytes_format(ismp_edp_tree, hf_ismp_edp_neighbors, tvb, 
+				edp_neighbors_ti = proto_tree_add_bytes_format(edp_tree, hf_ismp_edp_neighbors, tvb, 
 					offset, num_neighbors*10, neighbors_ptr, "Neighbors:");
 			}
 			else
 			{
 				neighbors_ptr = tvb_get_ptr( tvb, offset, tvb_reported_length_remaining(tvb, offset) );
-				edp_neighbors_ti = proto_tree_add_bytes_format(ismp_edp_tree, hf_ismp_edp_neighbors, tvb, 
+				edp_neighbors_ti = proto_tree_add_bytes_format(edp_tree, hf_ismp_edp_neighbors, tvb, 
 					offset, num_neighbors *10, neighbors_ptr, "Neighbors:");
 			}
 			edp_neighbors_tree = proto_item_add_subtree(edp_neighbors_ti, ett_ismp_edp_neighbors);
@@ -386,7 +390,7 @@ dissect_ismp_edp(tvbuff_t *tvb, packet_info *pinfo, int offset, proto_tree *ismp
 			}
 			if (neighbors_count != num_neighbors)
 			{
-				proto_tree_add_text(ismp_edp_tree, tvb, offset, tvb_reported_length_remaining(tvb, offset),
+				proto_tree_add_text(edp_tree, tvb, offset, tvb_reported_length_remaining(tvb, offset),
 				"MALFORMED PACKET");
 				return;
 			}
@@ -398,11 +402,11 @@ dissect_ismp_edp(tvbuff_t *tvb, packet_info *pinfo, int offset, proto_tree *ismp
 			tvb_reported_length_remaining(tvb, offset) >= 2) 
 		{
 			num_tuples = tvb_get_ntohs(tvb, offset);
-			proto_tree_add_item(ismp_edp_tree, hf_ismp_edp_num_tuples, tvb, offset, 2, FALSE);
+			proto_tree_add_item(edp_tree, hf_ismp_edp_num_tuples, tvb, offset, 2, FALSE);
 			offset += 2;
 		}
 		else if (tvb_reported_length_remaining(tvb, offset) > 0) {
-			proto_tree_add_text(ismp_edp_tree, tvb, offset, 
+			proto_tree_add_text(edp_tree, tvb, offset, 
 				tvb_reported_length_remaining(tvb, offset), "MALFORMED PACKET");
 			return;
 		}
@@ -415,8 +419,8 @@ dissect_ismp_edp(tvbuff_t *tvb, packet_info *pinfo, int offset, proto_tree *ismp
 		if (num_tuples && tvb_reported_length_remaining(tvb, offset) >= 4)
 		{
 			tuples_ptr = tvb_get_ptr(tvb, offset, tvb_reported_length_remaining(tvb, offset));
-			edp_tuples_ti = proto_tree_add_bytes_format(ismp_edp_tree, hf_ismp_edp_tuples, tvb,
-				offset, tvb_reported_length_remaining(tvb, offset), tuples_ptr, "Tuples:");
+			edp_tuples_ti = proto_tree_add_bytes_format(edp_tree, hf_ismp_edp_tuples, tvb,
+				offset, tvb_reported_length_remaining(tvb, offset), tuples_ptr, "Tuples");
 			edp_tuples_tree = proto_item_add_subtree(edp_tuples_ti, ett_ismp_edp_tuples);
 
 			while ( (tuples_count < num_tuples) && (tvb_reported_length_remaining(tvb, offset) >= 4) )
@@ -449,6 +453,8 @@ dissect_ismp_edp(tvbuff_t *tvb, packet_info *pinfo, int offset, proto_tree *ismp
 						case EDP_TUPLE_INT_NAME:
 							proto_tree_add_text(edp_tuples_leaf_tree, tvb, offset, tuple_length,
 								"Interface Name = %s", tvb_format_text(tvb, offset, tuple_length));
+							col_append_fstr(pinfo->cinfo, COL_INFO, ", ifName %s",
+								tvb_format_text(tvb, offset, tuple_length));
 							break;
 						case EDP_TUPLE_SYS_DESCRIPT:
 							proto_tree_add_text(edp_tuples_leaf_tree, tvb, offset, tuple_length,
@@ -475,7 +481,7 @@ dissect_ismp_edp(tvbuff_t *tvb, packet_info *pinfo, int offset, proto_tree *ismp
 			} 
 			if (tuples_count != num_tuples)
 			{
-				proto_tree_add_text(ismp_edp_tree, tvb, offset, 
+				proto_tree_add_text(edp_tree, tvb, offset, 
 					tvb_reported_length_remaining(tvb, offset), "MALFORMED PACKET");
 				return;
 			}
@@ -505,10 +511,8 @@ dissect_ismp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	proto_tree *ismp_tree;
 
 /* Make entries in Protocol column and Info column on summary display */
-	if (check_col(pinfo->cinfo, COL_PROTOCOL)) 
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "ISMP");
-	if (check_col(pinfo->cinfo, COL_INFO)) 
-		col_clear(pinfo->cinfo, COL_INFO);
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "ISMP");
+	col_clear(pinfo->cinfo, COL_INFO);
 
 	/*
 	 * XXX - I've seen captures with packets that have the ISMP
@@ -541,7 +545,7 @@ dissect_ismp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		
 		/* if Enterasys Discover Protocol, dissect it */
 		if(message_type == ISMPTYPE_EDP)
-			dissect_ismp_edp(tvb, pinfo, offset, ismp_tree);
+			dissect_ismp_edp(tvb, pinfo, offset, tree);
 	}
 
 }
@@ -554,285 +558,297 @@ proto_register_ismp(void)
 
 /* Setup list of header fields  See Section 1.6.1 for details*/
 	static hf_register_info hf[] = {
+#if 0
+		{ &hf_ismp,
+			{ "ISMP", "ismp",
+			FT_PROTOCOL, BASE_NONE, NULL, 0x0,
+			"Inter Switch Message Protocol", HFILL }
+		},
+#endif
 		{ &hf_ismp_version,
 			{ "Version",           "ismp.version",
 			FT_UINT16, BASE_DEC, NULL, 0x0,          
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_message_type,
 			{ "Message Type", "ismp.msgtype",
 			FT_UINT16, BASE_DEC, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_seq_num,
 			{ "Sequence Number", "ismp.seqnum",
 			FT_UINT16, BASE_DEC, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_code_length,
 			{ "Auth Code Length", "ismp.codelen",
 			FT_UINT8, BASE_DEC, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		}, 
 		{ &hf_ismp_auth_data,
 			{ "Auth Data", "ismp.authdata",
-			FT_BYTES, BASE_HEX, NULL, 0x0,
-			"", HFILL }
+			FT_BYTES, BASE_NONE, NULL, 0x0,
+			NULL, HFILL }
+		},
+		{ &hf_ismp_edp,
+			{ "EDP", "ismp.edp",
+			FT_PROTOCOL, BASE_NONE, NULL, 0x0,
+			"Enterasys Discovery Protocol", HFILL }
 		},
 		{ &hf_ismp_edp_version,
 			{ "Version", "ismp.edp.version",
 			FT_UINT16, BASE_DEC, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_module_ip,
 			{ "Module IP Address", "ismp.edp.modip",
 			FT_IPv4, BASE_NONE, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_module_mac,
 			{ "Module MAC Address", "ismp.edp.modmac",
 			FT_ETHER, BASE_NONE, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_module_port,
 			{ "Module Port (ifIndex num)", "ismp.edp.modport",
 			FT_UINT32, BASE_DEC, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_chassis_mac,
 			{ "Chassis MAC Address", "ismp.edp.chassismac",
 			FT_ETHER, BASE_NONE, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_chassis_ip,
 			{ "Chassis IP Address", "ismp.edp.chassisip",
 			FT_IPv4, BASE_NONE, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_device_type,
 			{ "Device Type", "ismp.edp.devtype",
 			FT_UINT16, BASE_DEC, edp_device_types, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_module_rev,
 			{ "Module Firmware Revision", "ismp.edp.rev",
 			FT_UINT32, BASE_DEC, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_options,
 			{ "Device Options", "ismp.edp.opts",
 			FT_UINT32, BASE_DEC, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_sfs_option_unused1,
 			{ "Unused", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SFS_OPTION_UNUSED1,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_sfs_option_sfssup,
 			{ "SFS Support", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SFS_OPTION_SFSSUP,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_sfs_option_lsp,
 			{ "LSP Support", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SFS_OPTION_LSP,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_sfs_option_flood,
 			{ "Flood Path Support", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SFS_OPTION_FLOOD,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_sfs_option_resolve,
 			{ "Resolve Support", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SFS_OPTION_RESOLVE,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_sfs_option_unused2,
 			{ "Unused", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SFS_OPTION_UNUSED2,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_sfs_option_tagflood,
 			{ "Tagged Flood Support", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SFS_OPTION_TAGFLOOD,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_sfs_option_calltap,
 			{ "Call Tap Support", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SFS_OPTION_CALLTAP,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_sfs_option_conmsg,
 			{ "Connection Message Support", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SFS_OPTION_CONMSG,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_sfs_option_redun,
 			{ "Redundant Access Support", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SFS_OPTION_REDUN,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_sfs_option_isolated,
 			{ "Isolated Switch", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SFS_OPTION_ISOLATED,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_sfs_option_uplink_switch,
 			{ "Uplink Switch", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SFS_OPTION_UPLINK_SWITCH,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_sfs_option_uplink_core,
 			{ "Uplink Core", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SFS_OPTION_UPLINK_CORE,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_sfs_option_uplink_port,
 			{ "Uplink Port", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SFS_OPTION_UPLINK_PORT,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_sfs_option_uplink_flood,
 			{ "Uplink Flood Support", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SFS_OPTION_UPLINK_FLOOD,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_rtr_option_ssr,
 			{ "SSR Type Device", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_RTR_OPTION_SSR,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_rtr_option_igmp,
 			{ "IGMP Active", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_RTR_OPTION_IGMP,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_rtr_option_rip,
 			{ "RIP Active", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_RTR_OPTION_RIP,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_rtr_option_bgp,
 			{ "BGP Active", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_RTR_OPTION_BGP,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_rtr_option_ospf,
 			{ "OSPF Active", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_RTR_OPTION_OSPF,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_rtr_option_dvmrp,
 			{ "DVMRP Active", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_RTR_OPTION_DVMRP,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_rtr_option_8021q,
 			{ "802.1Q Support", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_RTR_OPTION_8021Q,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_rtr_option_gvrp,
 			{ "GVRP Support", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_RTR_OPTION_GVRP,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_rtr_option_gmrp,
 			{ "GMRP Support", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_RTR_OPTION_GMRP,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_rtr_option_igmp_snoop,
 			{ "IGMP Snooping Support", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_RTR_OPTION_IGMP_SNOOP,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_rtr_option_route,
 			{ "Route Bridging", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_RTR_OPTION_ROUTE,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_rtr_option_trans,
 			{ "Transparent Bridging", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_RTR_OPTION_TRANS,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_rtr_option_level1,
 			{ "Level 1 Functionality", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_RTR_OPTION_LEVEL1,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_switch_option_8021q,
 			{ "802.1Q Support", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SWITCH_OPTION_8021Q,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_switch_option_gvrp,
 			{ "GVRP Support", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SWITCH_OPTION_GVRP,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_switch_option_gmrp,
 			{ "GMRP Support", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SWITCH_OPTION_GMRP,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_switch_option_igmp,
 			{ "IGMP Snooping Support", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SWITCH_OPTION_IGMP,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_switch_option_route,
 			{ "Route Bridging", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SWITCH_OPTION_ROUTE,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_switch_option_trans,
 			{ "Transparent Bridging", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SWITCH_OPTION_TRANS,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_switch_option_level1,
 			{ "Level 1 Functionality", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_SWITCH_OPTION_LEVEL1,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_end_station_option_dhcp,
 			{ "DHCP Enabled", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_END_STATION_OPTION_DHCP,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_end_station_option_dns,
 			{ "DNS Enabled", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_END_STATION_OPTION_DNS,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_end_station_option_ad,
 			{ "Active Directory Enabled", "ismp.edp.opts",
 			FT_BOOLEAN, 32, TFS(&is_set), EDP_END_STATION_OPTION_AD,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_num_neighbors,
 			{ "Number of Known Neighbors", "ismp.edp.maccount",
 			FT_UINT16, BASE_DEC, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_neighbors,
 			{ "Neighbors", "ismp.edp.nbrs",
 			FT_BYTES, BASE_NONE, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_num_tuples,
 			{ "Number of Tuples", "ismp.edp.numtups",
 			FT_UINT16, BASE_DEC, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_ismp_edp_tuples,
 			{ "Number of Tuples", "ismp.edp.tups",
 			FT_BYTES, BASE_NONE, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 	};
 
