@@ -2,7 +2,7 @@
  * Routines for LAPDm frame disassembly
  * Duncan Salerno <duncan.salerno@googlemail.com>
  *
- * $Id: packet-lapdm.c 27736 2009-03-16 10:14:44Z stig $
+ * $Id: packet-lapdm.c 30125 2009-09-24 20:00:21Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -223,8 +223,7 @@ dissect_lapdm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     if (tvb_length(tvb) < LAPDM_HEADER_LEN)
         return;
 
-    if (check_col(pinfo->cinfo, COL_PROTOCOL))
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "LAPDm");
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "LAPDm");
 
     address = tvb_get_guint8(tvb, 0);
     length = tvb_get_guint8(tvb, 2);
@@ -314,9 +313,7 @@ dissect_lapdm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                         call_dissector(data_handle, reassembled, pinfo, tree);
             }
             else {
-                if (check_col(pinfo->cinfo, COL_INFO)) {
-                    col_append_str(pinfo->cinfo, COL_INFO, " (Fragment)");
-                }
+                col_append_str(pinfo->cinfo, COL_INFO, " (Fragment)");
                 if (tree) {
                     proto_tree_add_text(lapdm_tree, payload, 0, -1, "Fragment Data");
                 }
@@ -430,19 +427,19 @@ proto_register_lapdm(void)
 
         { &hf_lapdm_fragment_overlap,
         { "Message fragment overlap", "lapdm.fragment.overlap", FT_BOOLEAN, BASE_NONE,
-        NULL, 0x00, "LAPDm Message fragment overlaps with other fragment(s)", HFILL }},
+        NULL, 0x0, "LAPDm Message fragment overlaps with other fragment(s)", HFILL }},
 
         { &hf_lapdm_fragment_overlap_conflicts,
         { "Message fragment overlapping with conflicting data", "lapdm.fragment.overlap.conflicts", FT_BOOLEAN, BASE_NONE,
-        NULL, 0x00, "LAPDm Message fragment overlaps with conflicting data", HFILL }},
+        NULL, 0x0, "LAPDm Message fragment overlaps with conflicting data", HFILL }},
 
         { &hf_lapdm_fragment_multiple_tails,
         { "Message has multiple tail fragments", "lapdm.fragment.multiple_tails", FT_BOOLEAN, BASE_NONE,
-        NULL, 0x00, "LAPDm Message fragment has multiple tail fragments", HFILL }},
+        NULL, 0x0, "LAPDm Message fragment has multiple tail fragments", HFILL }},
 
         { &hf_lapdm_fragment_too_long_fragment,
         { "Message fragment too long", "lapdm.fragment.too_long_fragment", FT_BOOLEAN, BASE_NONE,
-        NULL, 0x00, "LAPDm Message fragment data goes beyond the packet end", HFILL }},
+        NULL, 0x0, "LAPDm Message fragment data goes beyond the packet end", HFILL }},
 
         { &hf_lapdm_fragment_error,
         { "Message defragmentation error", "lapdm.fragment.error", FT_FRAMENUM, BASE_NONE,
