@@ -1,7 +1,7 @@
 /* packet-lwres.c
  * Routines for light weight reslover (lwres, part of BIND9) packet disassembly
  *
- * $Id: packet-lwres.c 27888 2009-03-29 21:20:15Z etxrab $
+ * $Id: packet-lwres.c 29340 2009-08-09 06:26:46Z krj $
  *
  * Copyright (c) 2003 by Oleg Terletsky <oleg.terletsky@comverse.com>
  *
@@ -1166,8 +1166,7 @@ dissect_lwres(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	proto_item* lwres_item;
 	proto_tree* lwres_tree;
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "lw_res");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "lw_res");
 	length = tvb_get_ntohl(tvb, LW_LENGTH_OFFSET);
 	version = tvb_get_ntohs(tvb, LW_VERSION_OFFSET);
 	flags = tvb_get_ntohs(tvb, LW_PKTFLASG_OFFSET);
@@ -1358,7 +1357,7 @@ proto_register_lwres(void)
   	"lwres namelen", HFILL }},
 
     { &hf_req_name,
-      { "Domain name" , "lwres.reqdname" , FT_STRING, BASE_DEC, NULL, 0x0,
+      { "Domain name" , "lwres.reqdname" , FT_STRING, BASE_NONE, NULL, 0x0,
 	"lwres reqdname", HFILL }},
 
     { &hf_ttl,
@@ -1378,7 +1377,7 @@ proto_register_lwres(void)
    	"lwres realnamelen", HFILL }},
 
     { &hf_realname,
-      { "Real doname name", "lwres.realname", FT_STRING, BASE_DEC, NULL, 0x0,
+      { "Real doname name", "lwres.realname", FT_STRING, BASE_NONE, NULL, 0x0,
 	"lwres realname", HFILL }},
 
 	{ &hf_a_record,
@@ -1414,7 +1413,7 @@ proto_register_lwres(void)
 	  "lwres adn namelen", HFILL }},
 
 	{ &hf_adn_name,
-        { "Name", "lwres.adn.name", FT_STRING, BASE_DEC, NULL, 0x0,
+        { "Name", "lwres.adn.name", FT_STRING, BASE_NONE, NULL, 0x0,
 	  "lwres adn name", HFILL }}, 
 
 	 { &hf_adn_naliases,
@@ -1426,11 +1425,11 @@ proto_register_lwres(void)
 	  "lwres adn naddrs", HFILL }}, 
 
 	  	{ &hf_adn_realname,
-        { "Real name", "lwres.adn.realname", FT_STRING, BASE_DEC, NULL, 0x0,
+        { "Real name", "lwres.adn.realname", FT_STRING, BASE_NONE, NULL, 0x0,
 	  "lwres adn realname", HFILL }}, 
 
 	  	{ &hf_adn_aliasname,
-        { "Alias name", "lwres.adn.aliasname", FT_STRING, BASE_DEC, NULL, 0x0,
+        { "Alias name", "lwres.adn.aliasname", FT_STRING, BASE_NONE, NULL, 0x0,
 	  "lwres adn aliasname", HFILL }}, 
 
 	{ &hf_adn_family,
@@ -1442,7 +1441,7 @@ proto_register_lwres(void)
 	"lwres adn addr length", HFILL }},
 
 	{ &hf_adn_addr_addr,
-    { "IP Address", "lwres.adn.addr.addr", FT_STRING, BASE_DEC, NULL, 0x0,
+    { "IP Address", "lwres.adn.addr.addr", FT_STRING, BASE_NONE, NULL, 0x0,
 	  "lwres adn addr addr", HFILL }},
 
     /* Add more fields here */
