@@ -2,7 +2,7 @@
  * Routines for dissection of Cisco MDS Switch Internal Header
  * Copyright 2001, Dinesh G Dutt <ddutt@andiamo.com>
  *
- * $Id: packet-mdshdr.c 23405 2007-11-08 22:40:20Z etxrab $
+ * $Id: packet-mdshdr.c 29446 2009-08-16 12:36:22Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -158,6 +158,7 @@ dissect_mdshdr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 /* Set up structures needed to add the protocol subtree and manage it */
     proto_item *ti_main, *ti_hdr, *ti_trlr;
+    proto_item *hidden_item; 
     proto_tree *mdshdr_tree_main, *mdshdr_tree_hdr, *mdshdr_tree_trlr;
     int offset = 0;
     guint    pktlen;
@@ -168,11 +169,9 @@ dissect_mdshdr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     int trailer_start = 0;
 
     /* Make entries in Protocol column and Info column on summary display */
-    if (check_col(pinfo->cinfo, COL_PROTOCOL)) 
-        col_set_str(pinfo->cinfo, COL_PROTOCOL, "MDS Header");
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "MDS Header");
     
-    if (check_col (pinfo->cinfo, COL_INFO))
-        col_clear (pinfo->cinfo, COL_INFO);
+    col_clear(pinfo->cinfo, COL_INFO);
 
     sof = tvb_get_guint8 (tvb, offset+MDSHDR_SOF_OFFSET) & 0x0F;
     pktlen = tvb_get_ntohs (tvb, offset+MDSHDR_PKTLEN_OFFSET) & 0x1FFF;
@@ -228,8 +227,9 @@ dissect_mdshdr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                                       MDSHDR_HEADER_SIZE, "MDS Header");
 
         mdshdr_tree_hdr = proto_item_add_subtree (ti_hdr, ett_mdshdr_hdr);
-        proto_tree_add_item_hidden (mdshdr_tree_hdr, hf_mdshdr_sof, tvb, MDSHDR_SOF_OFFSET,
+        hidden_item = proto_tree_add_item (mdshdr_tree_hdr, hf_mdshdr_sof, tvb, MDSHDR_SOF_OFFSET,
                                     MDSHDR_SIZE_BYTE, 0);
+        PROTO_ITEM_SET_HIDDEN(hidden_item);
         proto_tree_add_item (mdshdr_tree_hdr, hf_mdshdr_pkt_len, tvb, MDSHDR_PKTLEN_OFFSET, 
                              MDSHDR_SIZE_INT16, 0);
         proto_tree_add_item (mdshdr_tree_hdr, hf_mdshdr_dstidx, tvb, MDSHDR_DIDX_OFFSET,
@@ -238,9 +238,10 @@ dissect_mdshdr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                              MDSHDR_SIZE_INT16, 0);
         proto_tree_add_item (mdshdr_tree_hdr, hf_mdshdr_vsan, tvb, MDSHDR_VSAN_OFFSET,
                              MDSHDR_SIZE_INT16, 0);
-        proto_tree_add_uint_hidden(mdshdr_tree_hdr, hf_mdshdr_span,
+        hidden_item = proto_tree_add_uint(mdshdr_tree_hdr, hf_mdshdr_span,
                                    tvb, MDSHDR_VSAN_OFFSET,
                                    MDSHDR_SIZE_BYTE, span_id);
+        PROTO_ITEM_SET_HIDDEN(hidden_item);
         
         /* Add Mdshdr Trailer part */
         if (tvb_length (tvb) >= MDSHDR_HEADER_SIZE + pktlen) {
@@ -261,7 +262,7 @@ dissect_mdshdr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         next_tvb = tvb_new_subset (tvb, MDSHDR_HEADER_SIZE, pktlen, pktlen);
     }
     else {
-        next_tvb = tvb_new_subset (tvb, MDSHDR_HEADER_SIZE, -1, -1);
+        next_tvb = tvb_new_subset_remaining (tvb, MDSHDR_HEADER_SIZE);
     }
 
     /* Call the Fibre Channel dissector */
@@ -285,22 +286,22 @@ proto_register_mdshdr(void)
 /* Setup list of header fields  See Section 1.6.1 for details*/
     static hf_register_info hf[] = {
         { &hf_mdshdr_sof,
-          {"SOF", "mdshdr.sof", FT_UINT8, BASE_DEC, VALS(sof_vals), 0x0, "", HFILL}},
+          {"SOF", "mdshdr.sof", FT_UINT8, BASE_DEC, VALS(sof_vals), 0x0, NULL, HFILL}},
         { &hf_mdshdr_pkt_len,
-          {"Packet Len", "mdshdr.plen", FT_UINT16, BASE_DEC, NULL, 0x1FFF, "", HFILL}},
+          {"Packet Len", "mdshdr.plen", FT_UINT16, BASE_DEC, NULL, 0x1FFF, NULL, HFILL}},
         { &hf_mdshdr_dstidx,
-          {"Dst Index", "mdshdr.dstidx", FT_UINT16, BASE_HEX, NULL, 0xFFC, "", HFILL}},
+          {"Dst Index", "mdshdr.dstidx", FT_UINT16, BASE_HEX, NULL, 0xFFC, NULL, HFILL}},
         { &hf_mdshdr_srcidx,
-          {"Src Index", "mdshdr.srcidx", FT_UINT16, BASE_HEX, NULL, 0x3FF, "", HFILL}},
+          {"Src Index", "mdshdr.srcidx", FT_UINT16, BASE_HEX, NULL, 0x3FF, NULL, HFILL}},
         { &hf_mdshdr_vsan,
-          {"VSAN", "mdshdr.vsan", FT_UINT16, BASE_DEC, NULL, 0x0FFF, "", HFILL}},
+          {"VSAN", "mdshdr.vsan", FT_UINT16, BASE_DEC, NULL, 0x0FFF, NULL, HFILL}},
         { &hf_mdshdr_eof,
-          {"EOF", "mdshdr.eof", FT_UINT8, BASE_DEC, VALS(eof_vals), 0x0, "", HFILL}},
+          {"EOF", "mdshdr.eof", FT_UINT8, BASE_DEC, VALS(eof_vals), 0x0, NULL, HFILL}},
         { &hf_mdshdr_span,
           {"SPAN Frame", "mdshdr.span", FT_UINT8, BASE_DEC, NULL, 0x0,
-           "", HFILL}},
+           NULL, HFILL}},
         { &hf_mdshdr_fccrc,
-          {"CRC", "mdshdr.crc", FT_UINT32, BASE_HEX, NULL, 0x0, "", HFILL}},
+          {"CRC", "mdshdr.crc", FT_UINT32, BASE_HEX, NULL, 0x0, NULL, HFILL}},
     };
 
 /* Setup protocol subtree array */
