@@ -2,7 +2,7 @@
  * Routines for Network Service Over IP dissection
  * Copyright 2000, Susanne Edlund <susanne.edlund@ericsson.com>
  *
- * $Id: packet-nsip.c 26246 2008-09-22 16:26:41Z wmeier $
+ * $Id: packet-nsip.c 29446 2009-08-16 12:36:22Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -253,11 +253,6 @@ typedef struct {
 static nsip_ip_element_info_t ipv4_element = { NSIP_IP_VERSION_4, 4, 8 };
 static nsip_ip_element_info_t ipv6_element = { NSIP_IP_VERSION_6, 16, 20 };
 
-static true_false_string set_unset = {
-  "Set",
-  "Not set"
-};
-
 static void 
 get_value_length(nsip_ie_t *ie, build_info_t *bi) {
   /* length indicator in bit 8, 0 => two bytes, 1 => one byte */
@@ -707,7 +702,7 @@ decode_pdu_ns_unitdata(build_info_t *bi) {
   decode_iei_control_bits(ies, bi, bi->offset);
   decode_pdu_general(&ies[1], 1, bi);
 
-  next_tvb = tvb_new_subset(bi->tvb, bi->offset, -1, -1);
+  next_tvb = tvb_new_subset_remaining(bi->tvb, bi->offset);
   if (bssgp_handle) {
     call_dissector(bssgp_handle, next_tvb, bi->pinfo, bi->parent_tree);
   } 
@@ -944,11 +939,9 @@ dissect_nsip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
 
   pinfo->current_proto = "NSIP";
 
-  if (check_col(pinfo->cinfo, COL_PROTOCOL)) 
-    col_set_str(pinfo->cinfo, COL_PROTOCOL, "NSIP");
+  col_set_str(pinfo->cinfo, COL_PROTOCOL, "NSIP");
     
-  if (check_col(pinfo->cinfo, COL_INFO)) 
-    col_clear(pinfo->cinfo, COL_INFO);
+  col_clear(pinfo->cinfo, COL_INFO);
 
   pdu_type = tvb_get_guint8(tvb, 0);
   bi.offset++;
@@ -979,7 +972,7 @@ proto_register_nsip(void)
     { &hf_nsip_cause,
       { "Cause", "nsip.cause",
 	FT_UINT8, BASE_OCT, VALS(tab_nsip_cause_values), 0x0,          
-	"", HFILL }
+	NULL, HFILL }
     },
     { &hf_nsip_ns_vci,
       { "NS-VCI", "nsip.ns_vci",
@@ -1014,82 +1007,82 @@ proto_register_nsip(void)
     { &hf_nsip_max_num_ns_vc,
       { "Maximum number of NS-VCs", "nsip.max_num_ns_vc",
 	FT_UINT16, BASE_DEC, NULL, 0x0,          
-	"", HFILL }
+	NULL, HFILL }
     },
     { &hf_nsip_num_ip4_endpoints,
       { "Number of IP4 endpoints", "nsip.num_ip4_endpoints",
 	FT_UINT16, BASE_DEC, NULL, 0x0,          
-	"", HFILL }
+	NULL, HFILL }
     },
     { &hf_nsip_num_ip6_endpoints,
       { "Number of IP6 endpoints", "nsip.num_ip6_endpoints",
 	FT_UINT16, BASE_DEC, NULL, 0x0,          
-	"", HFILL }
+	NULL, HFILL }
     },
     { &hf_nsip_reset_flag,
       { "Reset flag", "nsip.reset_flag",
-	FT_BOOLEAN, 8, TFS(&set_unset), NSIP_MASK_RESET_FLAG,          
-	"", HFILL }
+	FT_BOOLEAN, 8, TFS(&tfs_set_notset), NSIP_MASK_RESET_FLAG,          
+	NULL, HFILL }
     },
     { &hf_nsip_ip_address_type,
       { "IP Address Type", "nsip.ip_address_type",
 	FT_UINT8, BASE_DEC, VALS(ip_address_type_vals), 0x0,
-	"", HFILL }
+	NULL, HFILL }
     },
     { &hf_nsip_ip_address_ipv4,
       { "IP Address", "nsip.ip_address",
 	FT_IPv4, BASE_NONE, NULL, 0x0,          
-	"", HFILL }
+	NULL, HFILL }
     },
     { &hf_nsip_ip_address_ipv6,
       { "IP Address", "nsip.ip_address",
 	FT_IPv6, BASE_NONE, NULL, 0x0,          
-	"", HFILL }
+	NULL, HFILL }
     },
     { &hf_nsip_end_flag,
       { "End flag", "nsip.end_flag",
-	FT_BOOLEAN, 8, TFS(&set_unset), NSIP_MASK_END_FLAG,          
-	"", HFILL }
+	FT_BOOLEAN, 8, TFS(&tfs_set_notset), NSIP_MASK_END_FLAG,          
+	NULL, HFILL }
     },
     { &hf_nsip_control_bits_r,
       { "Request change flow", "nsip.control_bits.r",
-	FT_BOOLEAN, 8, TFS(&set_unset), NSIP_MASK_CONTROL_BITS_R,          
-	"", HFILL }
+	FT_BOOLEAN, 8, TFS(&tfs_set_notset), NSIP_MASK_CONTROL_BITS_R,          
+	NULL, HFILL }
     },
     { &hf_nsip_control_bits_c,
       { "Confirm change flow", "nsip.control_bits.c",
-	FT_BOOLEAN, 8, TFS(&set_unset), NSIP_MASK_CONTROL_BITS_C,          
-	"", HFILL }
+	FT_BOOLEAN, 8, TFS(&tfs_set_notset), NSIP_MASK_CONTROL_BITS_C,          
+	NULL, HFILL }
     },
     { &hf_nsip_transaction_id,
       { "Transaction ID", "nsip.transaction_id",
       FT_UINT8, BASE_DEC, NULL, 0x0,
-      "", HFILL }
+      NULL, HFILL }
     },
     { &hf_nsip_ip_element_ip_address_ipv4,
       { "IP Address", "nsip.ip_element.ip_address",
 	FT_IPv4, BASE_NONE, NULL, 0x0,          
-	"", HFILL }
+	NULL, HFILL }
     },
     { &hf_nsip_ip_element_ip_address_ipv6,
       { "IP Address", "nsip.ip_element.ip_address",
 	FT_IPv6, BASE_NONE, NULL, 0x0,          
-	"", HFILL }
+	NULL, HFILL }
     },
     { &hf_nsip_ip_element_udp_port,
       { "UDP Port", "nsip.ip_element.udp_port",
 	FT_UINT16, BASE_DEC, NULL, 0x0,          
-	"", HFILL }
+	NULL, HFILL }
     },
     { &hf_nsip_ip_element_signalling_weight,
       { "Signalling Weight", "nsip.ip_element.signalling_weight",
 	FT_UINT8, BASE_DEC, NULL, 0x0,          
-	"", HFILL }
+	NULL, HFILL }
     },
     { &hf_nsip_ip_element_data_weight,
       { "Data Weight", "nsip.ip_element.data_weight",
 	FT_UINT8, BASE_DEC, NULL, 0x0,          
-	"", HFILL }
+	NULL, HFILL }
     },
   };
 
