@@ -2,7 +2,7 @@
 * Routines for the disassembly of the "Nortel Networks / SynOptics Network Management Protocol"
 * (c) Copyright Giles Scott <giles.scott1 [AT] arubanetworks.com>
 *
-* $Id: packet-nt-sonmp.c 26028 2008-08-14 23:51:52Z wmeier $
+* $Id: packet-nt-sonmp.c 29499 2009-08-21 20:25:24Z krj $
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
@@ -34,7 +34,6 @@
 
 #include <glib.h>
 #include <epan/packet.h>
-/* #include "strutil.h" */
 #include <epan/nlpid.h>
 
 /* Although this protocol is propietary it is documented in the SynOptics MIB's
@@ -215,8 +214,7 @@ dissect_sonmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	proto_tree *sonmp_tree = NULL;
 	proto_item *ti;
 	
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "SONMP");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "SONMP");
 	
 	if (check_col(pinfo->cinfo, COL_INFO)) {
 		hello_type = "";
@@ -317,7 +315,7 @@ proto_reg_handoff_sonmp(void)
 {
 	dissector_handle_t sonmp_handle;
 	
-	sonmp_handle = create_dissector_handle(dissect_sonmp, proto_sonmp);
+	sonmp_handle = find_dissector("sonmp");
 	
 	dissector_add("llc.nortel_pid", 0x01a1, sonmp_handle); /* flatnet hello */
 	dissector_add("llc.nortel_pid", 0x01a2, sonmp_handle); /* Segment hello */ 
