@@ -2,7 +2,7 @@
  * Routines for QLLC protocol - Qualified? LLC
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
- * $Id: packet-qllc.c 23406 2007-11-08 22:49:03Z etxrab $
+ * $Id: packet-qllc.c 29344 2009-08-09 07:36:13Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -91,10 +91,8 @@ dissect_qllc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     }
 
     /* Summary information */
-    if (check_col(pinfo->cinfo, COL_PROTOCOL))
-	col_set_str(pinfo->cinfo, COL_PROTOCOL, "QLLC");
-    if (check_col(pinfo->cinfo, COL_INFO))
-	col_clear(pinfo->cinfo, COL_INFO);
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "QLLC");
+    col_clear(pinfo->cinfo, COL_INFO);
 
     if (tree) {
 	qllc_ti = proto_tree_add_item(tree, proto_qllc, tvb, 0, -1, FALSE);
@@ -140,8 +138,10 @@ dissect_qllc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
         /* Add the field for filtering purposes */
         if (tree) {
-            proto_tree_add_uint_hidden(qllc_tree, hf_qllc_control, tvb,
+            proto_item *hidden_item;
+            hidden_item = proto_tree_add_uint(qllc_tree, hf_qllc_control, tvb,
                     1, 1, ctrl);
+            PROTO_ITEM_SET_HIDDEN(hidden_item);
         }
     }
     else {
@@ -171,11 +171,11 @@ proto_register_qllc(void)
 	static hf_register_info hf[] = {
 	    { &hf_qllc_address,
 		{ "Address Field",	"qllc.address", FT_UINT8, BASE_HEX, NULL, 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_qllc_control,
 		{ "Control Field",	"qllc.control", FT_UINT8, BASE_HEX,
-		  VALS(qllc_control_vals), 0x0, "", HFILL }},
+		  VALS(qllc_control_vals), 0x0, NULL, HFILL }},
 	};
 
 	static gint *ett[] = {
