@@ -8,7 +8,7 @@
  * Copyright 2008 Richard van der Hoff, MX Telecom
  * <richardv@mxtelecom.com>
  *
- * $Id: packet-rfc2190.c 26277 2008-09-26 17:04:01Z wmeier $
+ * $Id: packet-rfc2190.c 30125 2009-09-24 20:00:21Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -91,24 +91,16 @@ dissect_rfc2190( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 
     rfc2190_version = (tvb_get_guint8( tvb, offset ) & 0xc0 ) >> 6;
 
-    if ( check_col( pinfo->cinfo, COL_PROTOCOL ) )   {
-        col_set_str( pinfo->cinfo, COL_PROTOCOL, "H.263 " );
-    }
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "H.263 ");
 
     if( rfc2190_version == 0x00) {
-        if ( check_col( pinfo->cinfo, COL_INFO) ) {
-	    col_append_str( pinfo->cinfo, COL_INFO, "MODE A ");
-        }
+        col_append_str( pinfo->cinfo, COL_INFO, "MODE A ");
     }
     else if( rfc2190_version == 0x02) {
-        if ( check_col( pinfo->cinfo, COL_INFO) ) {
-	    col_append_str( pinfo->cinfo, COL_INFO, "MODE B ");
-        }
+        col_append_str( pinfo->cinfo, COL_INFO, "MODE B ");
     }
     else if( rfc2190_version == 0x03) {
-        if ( check_col( pinfo->cinfo, COL_INFO) ) {
-	    col_append_str( pinfo->cinfo, COL_INFO, "MODE C ");
-        }
+        col_append_str( pinfo->cinfo, COL_INFO, "MODE C ");
     }
 
     if ( tree ) {
@@ -449,7 +441,7 @@ proto_register_rfc2190(void)
 				BASE_DEC,
 				NULL,
 				0x0,
-				"Horizontal motion vector predictor for the first MB in this packet ", HFILL
+				"Horizontal motion vector predictor for the first MB in this packet", HFILL
 			}
 		},
 		{
@@ -461,7 +453,7 @@ proto_register_rfc2190(void)
 				BASE_DEC,
 				NULL,
 				0x0,
-				"Vertical motion vector predictor for the first MB in this packet ", HFILL
+				"Vertical motion vector predictor for the first MB in this packet", HFILL
 			}
 		},
 		{
@@ -497,7 +489,7 @@ proto_register_rfc2190(void)
 				BASE_DEC,
 				NULL,
 				0x0,
-				"Reserved field that houls contain zeroes", HFILL
+				"Reserved field that should contain zeroes", HFILL
 			}
 		},
 		{
