@@ -17,7 +17,7 @@
  * References:
  *     RFC 3450, Asynchronous Layered Coding protocol instantiation
  *
- * $Id: packet-rmt-alc.c 24228 2008-01-30 22:34:17Z etxrab $
+ * $Id: packet-rmt-alc.c 29446 2009-08-16 12:36:22Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -61,9 +61,7 @@ static int proto = -1;
 static struct _alc_hf hf;
 static struct _alc_ett ett;
 
-static gboolean preferences_initialized = FALSE;
 static struct _alc_prefs preferences;
-static struct _alc_prefs preferences_old;
 dissector_handle_t xml_handle;
 
 
@@ -132,10 +130,8 @@ static void dissect_alc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	pinfo->current_proto = "ALC";
 	
 	/* Make entries in Protocol column and Info column on summary display */
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "ALC");
-	if (check_col(pinfo->cinfo, COL_INFO)) 
-		col_clear(pinfo->cinfo, COL_INFO);
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "ALC");
+	col_clear(pinfo->cinfo, COL_INFO);
 	
 	/* ALC header dissection */
 	/* --------------------- */
@@ -189,7 +185,7 @@ static void dissect_alc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		/* Add the Payload item */
 		if (tvb_length(tvb) > offset){
 			if(is_flute){
-				new_tvb = tvb_new_subset(tvb,offset,-1,-1);
+				new_tvb = tvb_new_subset_remaining(tvb,offset);
 				call_dissector(xml_handle, new_tvb, pinfo, alc_tree);
 			}else{
 				proto_tree_add_none_format(alc_tree, hf.payload, tvb, offset, -1, "Payload (%u bytes)", tvb_length(tvb) - offset);
@@ -223,12 +219,15 @@ static void dissect_alc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 void proto_reg_handoff_alc(void)
 {
 	static dissector_handle_t handle;
+	static gboolean preferences_initialized = FALSE;
+	static struct _alc_prefs preferences_old;
 
 	if (!preferences_initialized)
 	{
 		preferences_initialized = TRUE;		
 		handle = create_dissector_handle(dissect_alc, proto);
 		dissector_add_handle("udp.port", handle);
+		xml_handle = find_dissector("xml");
 		
 	} else {
 		
@@ -240,7 +239,6 @@ void proto_reg_handoff_alc(void)
 		dissector_add("udp.port", preferences.default_udp_port, handle);
 		
 	alc_prefs_save(&preferences, &preferences_old);
-	xml_handle = find_dissector("xml");
 
 }
 
@@ -250,13 +248,13 @@ void proto_register_alc(void)
 	static hf_register_info hf_ptr[] = {
 		
 		{ &hf.version,
-			{ "Version", "alc.version", FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL }},
+			{ "Version", "alc.version", FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 		
 		LCT_FIELD_ARRAY(hf.lct, "alc"),
 		FEC_FIELD_ARRAY(hf.fec, "alc"),
 
 		{ &hf.payload,
-			{ "Payload", "alc.payload", FT_NONE, BASE_NONE, NULL, 0x0, "", HFILL }}
+			{ "Payload", "alc.payload", FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL }}
 	};
 
 	/* Setup protocol subtree array */
@@ -282,7 +280,6 @@ void proto_register_alc(void)
 	
 	/* Reset preferences */
 	alc_prefs_set_default(&preferences);
-	alc_prefs_save(&preferences, &preferences_old);
 	
 	/* Register preferences */
 	module = prefs_register_protocol(proto, proto_reg_handoff_alc);
