@@ -15,7 +15,7 @@
  * Dinesh G Dutt (ddutt@cisco.com)
  * Ronnie sahlberg 2006
  *
- * $Id: packet-scsi-sbc.c 26091 2008-08-26 01:28:50Z wmeier $
+ * $Id: packet-scsi-sbc.c 28770 2009-06-18 21:30:42Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -146,7 +146,7 @@ static gint ett_scsi_writesame			= -1;
 
 
 static const true_false_string dpo_tfs = {
-    "Disable Page Out (dont cache this data)",
+    "Disable Page Out (don't cache this data)",
     "Disable page out is DISABLED (cache this data)"
 };
 static const true_false_string fua_tfs = {
@@ -1734,127 +1734,127 @@ proto_register_scsi_sbc(void)
 	static hf_register_info hf[] = {
         { &hf_scsi_sbc_opcode,
           {"SBC Opcode", "scsi.sbc.opcode", FT_UINT8, BASE_HEX,
-           VALS (scsi_sbc_vals), 0x0, "", HFILL}},
+           VALS (scsi_sbc_vals), 0x0, NULL, HFILL}},
         { &hf_scsi_sbc_formatunit_flags,
           {"Flags", "scsi.sbc.formatunit.flags", FT_UINT8, BASE_HEX, NULL, 0xF8,
-           "", HFILL}},
+           NULL, HFILL}},
         { &hf_scsi_sbc_defect_list_format,
           {"Defect List Format", "scsi.sbc.defect_list_format", FT_UINT8, BASE_DEC,
-           NULL, 0x7, "", HFILL}},
+           NULL, 0x7, NULL, HFILL}},
         { &hf_scsi_sbc_formatunit_vendor,
           {"Vendor Unique", "scsi.sbc.formatunit.vendor", FT_UINT8, BASE_HEX, NULL,
-           0x0, "", HFILL}},
+           0x0, NULL, HFILL}},
         { &hf_scsi_sbc_formatunit_interleave,
           {"Interleave", "scsi.sbc.formatunit.interleave", FT_UINT16, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_sbc_rdwr6_lba,
           {"Logical Block Address (LBA)", "scsi.sbc.rdwr6.lba", FT_UINT24, BASE_DEC,
-           NULL, 0x0FFFFF, "", HFILL}},
+           NULL, 0x0FFFFF, NULL, HFILL}},
         { &hf_scsi_sbc_rdwr6_xferlen,
           {"Transfer Length", "scsi.sbc.rdwr6.xferlen", FT_UINT24, BASE_DEC, NULL, 0x0,
-           "", HFILL}},
+           NULL, HFILL}},
         { &hf_scsi_sbc_rdwr10_lba,
           {"Logical Block Address (LBA)", "scsi.sbc.rdwr10.lba", FT_UINT32, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_sbc_rdwr10_xferlen,
           {"Transfer Length", "scsi.sbc.rdwr10.xferlen", FT_UINT16, BASE_DEC, NULL,
-           0x0, "", HFILL}},
+           0x0, NULL, HFILL}},
         { &hf_scsi_sbc_rdwr12_xferlen,
           {"Transfer Length", "scsi.sbc.rdwr12.xferlen", FT_UINT32, BASE_DEC, NULL,
-           0x0, "", HFILL}},
+           0x0, NULL, HFILL}},
         { &hf_scsi_sbc_rdwr16_lba,
-          {"Logical Block Address (LBA)", "scsi.sbc.rdwr16.lba", FT_BYTES, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+          {"Logical Block Address (LBA)", "scsi.sbc.rdwr16.lba", FT_BYTES, BASE_NONE,
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_sbc_ssu_immed,
           {"Immediate", "scsi.sbc.ssu.immediate", FT_BOOLEAN, 8, NULL,
-           0x01, "", HFILL}},
+           0x01, NULL, HFILL}},
         { &hf_scsi_sbc_ssu_pwr_cond,
           {"Power Conditions", "scsi.sbc.ssu.pwr", FT_UINT8, BASE_HEX,
-           VALS (scsi_ssu_pwrcnd_val), 0xF0, "", HFILL}},
+           VALS (scsi_ssu_pwrcnd_val), 0xF0, NULL, HFILL}},
         { &hf_scsi_sbc_ssu_loej,
-          {"LOEJ", "scsi.sbc.ssu.loej", FT_BOOLEAN, 8, NULL, 0x2, "",
+          {"LOEJ", "scsi.sbc.ssu.loej", FT_BOOLEAN, 8, NULL, 0x2, NULL,
            HFILL}},
         { &hf_scsi_sbc_ssu_start,
           {"Start", "scsi.sbc.ssu.start", FT_BOOLEAN, 8, NULL, 0x1,
-           "", HFILL}},
+           NULL, HFILL}},
         { &hf_scsi_sbc_bytchk,
           {"BYTCHK", "scsi.sbc.bytchk", FT_BOOLEAN, 8,
-           NULL, 0x02, "", HFILL}},
+           NULL, 0x02, NULL, HFILL}},
         { &hf_scsi_sbc_verify_reladdr,
           {"RELADDR", "scsi.sbc.verify.reladdr", FT_BOOLEAN, 8, NULL,
-           0x1, "", HFILL}},
+           0x1, NULL, HFILL}},
         { &hf_scsi_sbc_verify_lba,
-          {"LBA", "scsi.sbc.verify.lba", FT_UINT32, BASE_DEC, NULL, 0x0, "",
+          {"LBA", "scsi.sbc.verify.lba", FT_UINT32, BASE_DEC, NULL, 0x0, NULL,
            HFILL}},
         { &hf_scsi_sbc_verify_lba64,
-          {"LBA", "scsi.sbc.verify.lba64", FT_UINT64, BASE_DEC, NULL, 0x0, "",
+          {"LBA", "scsi.sbc.verify.lba64", FT_UINT64, BASE_DEC, NULL, 0x0, NULL,
            HFILL}},
         { &hf_scsi_sbc_verify_vlen,
           {"Verification Length", "scsi.sbc.verify.vlen", FT_UINT16,
-           BASE_DEC, NULL, 0x0, "", HFILL}},
+           BASE_DEC, NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_sbc_verify_vlen32,
           {"Verification Length", "scsi.sbc.verify.vlen32", FT_UINT32,
-           BASE_DEC, NULL, 0x0, "", HFILL}},
+           BASE_DEC, NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_sbc_wrverify_lba,
-          {"LBA", "scsi.sbc.wrverify.lba", FT_UINT32, BASE_DEC, NULL, 0x0, "",
+          {"LBA", "scsi.sbc.wrverify.lba", FT_UINT32, BASE_DEC, NULL, 0x0, NULL,
            HFILL}},
         { &hf_scsi_sbc_wrverify_xferlen,
           {"Transfer Length", "scsi.sbc.wrverify.xferlen", FT_UINT16, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_sbc_wrverify_lba64,
           {"LBA", "scsi.sbc.wrverify.lba64", FT_UINT64, BASE_DEC, NULL, 0x0,
-           "", HFILL}},
+           NULL, HFILL}},
         { &hf_scsi_sbc_wrverify_xferlen32,
           {"Transfer Length", "scsi.sbc.wrverify.xferlen32", FT_UINT32,
-           BASE_DEC, NULL, 0x0, "", HFILL}},
+           BASE_DEC, NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_sbc_readcapacity_flags,
           {"Flags", "scsi.sbc.readcapacity.flags", FT_UINT8, BASE_HEX, NULL, 0x0,
-           "", HFILL}},
+           NULL, HFILL}},
         { &hf_scsi_sbc_readcapacity_lba,
           {"Logical Block Address", "scsi.sbc.readcapacity.lba", FT_UINT32, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_sbc_readdefdata_flags,
-          {"Flags", "scsi.sbc.readdefdata.flags", FT_UINT8, BASE_HEX, NULL, 0x0, "",
+          {"Flags", "scsi.sbc.readdefdata.flags", FT_UINT8, BASE_HEX, NULL, 0x0, NULL,
            HFILL}},
         { &hf_scsi_sbc_reassignblks_flags,
-          {"Flags", "scsi.sbc.reassignblks.flags", FT_UINT8, BASE_HEX, NULL, 0x0, "",
+          {"Flags", "scsi.sbc.reassignblks.flags", FT_UINT8, BASE_HEX, NULL, 0x0, NULL,
            HFILL}},
         { &hf_scsi_sbc_read_flags,
-          {"Flags", "scsi.sbc.read.flags", FT_UINT8, BASE_HEX, NULL, 0x0, "",
+          {"Flags", "scsi.sbc.read.flags", FT_UINT8, BASE_HEX, NULL, 0x0, NULL,
            HFILL}},
         { &hf_scsi_sbc_alloclen32,
           {"Allocation Length", "scsi.sbc.alloclen32", FT_UINT32, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_sbc_alloclen16,
           {"Allocation Length", "scsi.sbc.alloclen16", FT_UINT16, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_sbc_fuflags_fmtpinfo,
           {"FMTPINFO", "scsi.sbc.format_unit.fmtpinfo", FT_BOOLEAN, 8,
-           NULL, 0x80, "", HFILL}},
+           NULL, 0x80, NULL, HFILL}},
         { &hf_scsi_sbc_fuflags_rto_req,
           {"RTO_REQ", "scsi.sbc.format_unit.rto_req", FT_BOOLEAN, 8,
-           NULL, 0x40, "", HFILL}},
+           NULL, 0x40, NULL, HFILL}},
         { &hf_scsi_sbc_fuflags_longlist,
           {"LONGLIST", "scsi.sbc.format_unit.longlist", FT_BOOLEAN, 8,
-           NULL, 0x20, "", HFILL}},
+           NULL, 0x20, NULL, HFILL}},
         { &hf_scsi_sbc_fuflags_fmtdata,
           {"FMTDATA", "scsi.sbc.format_unit.fmtdata", FT_BOOLEAN, 8,
-           NULL, 0x10, "", HFILL}},
+           NULL, 0x10, NULL, HFILL}},
         { &hf_scsi_sbc_fuflags_cmplist,
           {"CMPLIST", "scsi.sbc.format_unit.cmplist", FT_BOOLEAN, 8,
-           NULL, 0x08, "", HFILL}},
+           NULL, 0x08, NULL, HFILL}},
         { &hf_scsi_sbc_prefetch_flags,
-          {"Flags", "scsi.sbc.prefetch.flags", FT_UINT8, BASE_HEX, NULL, 0x0, "",
+          {"Flags", "scsi.sbc.prefetch.flags", FT_UINT8, BASE_HEX, NULL, 0x0, NULL,
            HFILL}},
         { &hf_scsi_sbc_prefetch_immed,
           {"Immediate", "scsi.sbc.prefetch.immediate", FT_BOOLEAN, 8, NULL,
-           0x2, "", HFILL}},
+           0x2, NULL, HFILL}},
         { &hf_scsi_sbc_group,
           {"Group", "scsi.sbc.group", FT_UINT8, BASE_HEX, NULL,
-           0x1f, "", HFILL}},
+           0x1f, NULL, HFILL}},
         { &hf_scsi_sbc_rdprotect,
           {"RDPROTECT", "scsi.sbc.rdprotect", FT_UINT8, BASE_HEX,
-           NULL, 0xe0, "", HFILL}},
+           NULL, 0xe0, NULL, HFILL}},
         { &hf_scsi_sbc_dpo,
           {"DPO", "scsi.sbc.dpo", FT_BOOLEAN, 8,
            TFS(&dpo_tfs), 0x10, "DisablePageOut: Whether the device should cache the data or not", HFILL}},
@@ -1869,84 +1869,84 @@ proto_register_scsi_sbc(void)
            TFS(&pmi_tfs), 0x01, "Partial Medium Indicator", HFILL}},
         { &hf_scsi_sbc_pmi_flags,
           {"PMI Flags", "scsi.sbc.pmi_flags", FT_UINT8, BASE_HEX,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_sbc_blocksize,
           {"Block size in bytes", "scsi.sbc.blocksize", FT_UINT32, BASE_DEC,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_sbc_returned_lba,
           {"Returned LBA", "scsi.sbc.returned_lba", FT_UINT32, BASE_DEC,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_sbc_req_plist,
           {"REQ_PLIST", "scsi.sbc.req_plist", FT_BOOLEAN, 8,
-           NULL, 0x10, "", HFILL}},
+           NULL, 0x10, NULL, HFILL}},
         { &hf_scsi_sbc_req_glist,
           {"REQ_GLIST", "scsi.sbc.req_glist", FT_BOOLEAN, 8,
-           NULL, 0x08, "", HFILL}},
+           NULL, 0x08, NULL, HFILL}},
         { &hf_scsi_sbc_corrct,
           {"CORRCT", "scsi.sbc.corrct", FT_BOOLEAN, 8,
-           NULL, 0x02, "", HFILL}},
+           NULL, 0x02, NULL, HFILL}},
         { &hf_scsi_sbc_corrct_flags,
           {"Flags", "scsi.sbc.corrct_flags", FT_UINT8, BASE_HEX,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_sbc_reassignblocks_longlba,
           {"LongLBA", "scsi.sbc.reassignblocks.longlba", FT_BOOLEAN, 8,
-           NULL, 0x02, "", HFILL}},
+           NULL, 0x02, NULL, HFILL}},
         { &hf_scsi_sbc_reassignblocks_longlist,
           {"LongList", "scsi.sbc.reassignblocks.longlist", FT_BOOLEAN, 8,
-           NULL, 0x01, "", HFILL}},
+           NULL, 0x01, NULL, HFILL}},
         { &hf_scsi_sbc_ssu_immed_flags,
           {"Immed flags", "scsi.sbc.ssu.immed_flags", FT_UINT8, BASE_HEX,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_sbc_ssu_pwr_flags,
           {"Pwr flags", "scsi.sbc.ssu.pwr_flags", FT_UINT8, BASE_HEX,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_sbc_synccache_flags,
-          {"Flags", "scsi.sbc.synccache.flags", FT_UINT8, BASE_HEX, NULL, 0x0, "",
+          {"Flags", "scsi.sbc.synccache.flags", FT_UINT8, BASE_HEX, NULL, 0x0, NULL,
            HFILL}},
         { &hf_scsi_sbc_synccache_immed,
           {"Immediate", "scsi.sbc.synccache.immediate", FT_BOOLEAN, 8, NULL,
-           0x02, "", HFILL}},
+           0x02, NULL, HFILL}},
         { &hf_scsi_sbc_synccache_sync_nv,
           {"SYNC_NV", "scsi.sbc.synccache.sync_nv", FT_BOOLEAN, 8, NULL,
-           0x04, "", HFILL}},
+           0x04, NULL, HFILL}},
         { &hf_scsi_sbc_vrprotect,
           {"VRPROTECT", "scsi.sbc.vrprotect", FT_UINT8, BASE_HEX,
-           NULL, 0xe0, "", HFILL}},
+           NULL, 0xe0, NULL, HFILL}},
         { &hf_scsi_sbc_verify_flags,
           {"Flags", "scsi.sbc.verify_flags", FT_UINT8, BASE_HEX,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_sbc_wrprotect,
           {"WRPROTECT", "scsi.sbc.wrprotect", FT_UINT8, BASE_HEX,
-           NULL, 0xe0, "", HFILL}},
+           NULL, 0xe0, NULL, HFILL}},
         { &hf_scsi_sbc_wrverify_flags,
           {"Flags", "scsi.sbc.wrverify_flags", FT_UINT8, BASE_HEX,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_sbc_writesame_flags,
           {"Flags", "scsi.sbc.writesame_flags", FT_UINT8, BASE_HEX,
-           NULL, 0, "", HFILL}},
+           NULL, 0, NULL, HFILL}},
         { &hf_scsi_sbc_pbdata,
           {"PBDATA", "scsi.sbc.pbdata", FT_BOOLEAN, 8, NULL,
-           0x04, "", HFILL}},
+           0x04, NULL, HFILL}},
         { &hf_scsi_sbc_lbdata,
           {"LBDATA", "scsi.sbc.lbdata", FT_BOOLEAN, 8, NULL,
-           0x02, "", HFILL}},
+           0x02, NULL, HFILL}},
         { &hf_scsi_sbc_xdread_flags,
-          {"Flags", "scsi.sbc.xdread.flags", FT_UINT8, BASE_HEX, NULL, 0x0, "",
+          {"Flags", "scsi.sbc.xdread.flags", FT_UINT8, BASE_HEX, NULL, 0x0, NULL,
            HFILL}},
         { &hf_scsi_sbc_xorpinfo,
           {"XORPINFO", "scsi.sbc.xorpinfo", FT_BOOLEAN, 8, NULL,
-           0x01, "", HFILL}},
+           0x01, NULL, HFILL}},
         { &hf_scsi_sbc_disable_write,
           {"DISABLE_WRITE", "scsi.sbc.disable_write", FT_BOOLEAN, 8, NULL,
-           0x04, "", HFILL}},
+           0x04, NULL, HFILL}},
         { &hf_scsi_sbc_xdwrite_flags,
-          {"Flags", "scsi.sbc.xdwrite.flags", FT_UINT8, BASE_HEX, NULL, 0x0, "",
+          {"Flags", "scsi.sbc.xdwrite.flags", FT_UINT8, BASE_HEX, NULL, 0x0, NULL,
            HFILL}},
         { &hf_scsi_sbc_xdwriteread_flags,
-          {"Flags", "scsi.sbc.xdwriteread.flags", FT_UINT8, BASE_HEX, NULL, 0x0, "",
+          {"Flags", "scsi.sbc.xdwriteread.flags", FT_UINT8, BASE_HEX, NULL, 0x0, NULL,
            HFILL}},
         { &hf_scsi_sbc_xpwrite_flags,
-          {"Flags", "scsi.sbc.xpwrite.flags", FT_UINT8, BASE_HEX, NULL, 0x0, "",
+          {"Flags", "scsi.sbc.xpwrite.flags", FT_UINT8, BASE_HEX, NULL, 0x0, NULL,
            HFILL}},
 	};
 
