@@ -6,7 +6,7 @@
  * Dinesh G Dutt (ddutt@cisco.com)
  * Ronnie sahlberg 2006
  *
- * $Id: packet-scsi-smc.c 21412 2007-04-13 17:16:24Z standel $
+ * $Id: packet-scsi-smc.c 28770 2009-06-18 21:30:42Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -35,8 +35,6 @@
 #include <string.h>
 #include <epan/strutil.h>
 #include <epan/packet.h>
-#include <epan/prefs.h>
-#include <epan/emem.h>
 #include <epan/conversation.h>
 #include <epan/tap.h>
 #include "packet-scsi.h"
@@ -79,7 +77,7 @@ dissect_smc_exchangemedium (tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *t
 	NULL
     };
 
-    if (!tree) 
+    if (!tree)
         return;
 
     if (isreq && iscdb) {
@@ -110,7 +108,7 @@ dissect_smc_position_to_element (tvbuff_t *tvb, packet_info *pinfo _U_, proto_tr
 	NULL
     };
 
-    if (!tree) 
+    if (!tree)
         return;
 
     if (isreq && iscdb) {
@@ -134,7 +132,7 @@ dissect_smc_initialize_element_status (tvbuff_t *tvb, packet_info *pinfo _U_, pr
 {
     guint8 flags;
 
-    if (!tree) 
+    if (!tree)
         return;
 
     if (isreq && iscdb) {
@@ -158,7 +156,7 @@ dissect_smc_initialize_element_status_with_range (tvbuff_t *tvb, packet_info *pi
 	NULL
     };
 
-    if (!tree) 
+    if (!tree)
         return;
 
     if (isreq && iscdb) {
@@ -183,7 +181,7 @@ dissect_smc_openclose_importexport_element (tvbuff_t *tvb, packet_info *pinfo _U
 {
     guint8 flags;
 
-    if (!tree) 
+    if (!tree)
         return;
 
     if (isreq && iscdb) {
@@ -290,8 +288,6 @@ dissect_scsi_smc_element (tvbuff_t *tvb, packet_info *pinfo _U_,
     guint8 flags;
     guint8 ident_len;
 
-    if (elem_bytecnt < 2)
-        return;
     proto_tree_add_text (tree, tvb, offset, 2,
                          "Element Address: %u",
                          tvb_get_ntohs (tvb, offset));
@@ -483,8 +479,13 @@ dissect_scsi_smc_elements (tvbuff_t *tvb, packet_info *pinfo,
 
     while (desc_bytecnt != 0) {
         elem_bytecnt = elem_desc_len;
+
         if (elem_bytecnt > desc_bytecnt)
             elem_bytecnt = desc_bytecnt;
+
+	if (elem_bytecnt < 2)
+	    break;
+
         dissect_scsi_smc_element (tvb, pinfo, tree, offset, elem_bytecnt,
                                    elem_type, voltag_flags);
         offset += elem_bytecnt;
@@ -913,55 +914,55 @@ proto_register_scsi_smc(void)
 	static hf_register_info hf[] = {
         { &hf_scsi_smc_opcode,
           {"SMC Opcode", "scsi.smc.opcode", FT_UINT8, BASE_HEX,
-           VALS (scsi_smc_vals), 0x0, "", HFILL}},
+           VALS (scsi_smc_vals), 0x0, NULL, HFILL}},
         { &hf_scsi_smc_mta,
           {"Medium Transport Address", "scsi.smc.mta", FT_UINT16, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_smc_sa,
           {"Source Address", "scsi.smc.sa", FT_UINT16, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_smc_da,
           {"Destination Address", "scsi.smc.da", FT_UINT16, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_smc_fda,
           {"First Destination Address", "scsi.smc.fda", FT_UINT16, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_smc_sda,
           {"Second Destination Address", "scsi.smc.sda", FT_UINT16, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
 	{ &hf_scsi_smc_medium_flags,
           {"Flags", "scsi.smc.medium_flags", FT_UINT8, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
 	{ &hf_scsi_smc_inv1,
           {"INV1", "scsi.smc.inv1", FT_BOOLEAN, 8,
-           NULL, 0x02, "", HFILL}},
+           NULL, 0x02, NULL, HFILL}},
 	{ &hf_scsi_smc_inv2,
           {"INV2", "scsi.smc.inv2", FT_BOOLEAN, 8,
-           NULL, 0x01, "", HFILL}},
+           NULL, 0x01, NULL, HFILL}},
 	{ &hf_scsi_smc_range_flags,
           {"Flags", "scsi.smc.range_flags", FT_UINT8, BASE_HEX,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
 	{ &hf_scsi_smc_fast,
           {"FAST", "scsi.smc.fast", FT_BOOLEAN, 8,
-           NULL, 0x02, "", HFILL}},
+           NULL, 0x02, NULL, HFILL}},
 	{ &hf_scsi_smc_range,
           {"RANGE", "scsi.smc.range", FT_BOOLEAN, 8,
-           NULL, 0x01, "", HFILL}},
+           NULL, 0x01, NULL, HFILL}},
         { &hf_scsi_smc_sea,
           {"Starting Element Address", "scsi.smc.sea", FT_UINT16, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_smc_num_elements,
           {"Number of Elements", "scsi.smc.num_elements", FT_UINT16, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
 	{ &hf_scsi_smc_invert,
           {"INVERT", "scsi.smc.invert", FT_BOOLEAN, 8,
-           NULL, 0x01, "", HFILL}},
+           NULL, 0x01, NULL, HFILL}},
         { &hf_scsi_smc_ea,
           {"Element Address", "scsi.smc.ea", FT_UINT16, BASE_DEC,
-           NULL, 0x0, "", HFILL}},
+           NULL, 0x0, NULL, HFILL}},
         { &hf_scsi_smc_action_code,
           {"Action Code", "scsi.smc.action_code", FT_UINT8, BASE_HEX,
-           VALS(action_code_vals), 0x1f, "", HFILL}},
+           VALS(action_code_vals), 0x1f, NULL, HFILL}},
 	};
 
 
