@@ -2,7 +2,7 @@
  * Routines for snooping SID to name mappings
  * Copyright 2003, Ronnie Sahlberg
  *
- * $Id: packet-smb-sidsnooping.c 25617 2008-06-27 16:07:21Z gerald $
+ * $Id: packet-smb-sidsnooping.c 30691 2009-10-25 11:43:30Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,9 +29,9 @@
 
 #include <stdio.h>
 #include <string.h>
-#include "epan/packet_info.h"
-#include "epan/epan_dissect.h"
-#include "epan/proto.h"
+#include <epan/packet_info.h>
+#include <epan/epan_dissect.h>
+#include <epan/proto.h>
 #include <epan/tap.h>
 #include <epan/emem.h>
 #include <epan/strutil.h>
@@ -148,8 +148,7 @@ samr_query_dispinfo(void *dummy _U_, packet_info *pinfo, epan_dissect_t *edt, co
 			g_hash_table_remove(ctx_handle_table, GINT_TO_POINTER(pinfo->fd->num));
 		}
 		if(!old_ctx){
-			old_ctx=se_alloc(20);
-			memcpy(old_ctx, fi->value.value.bytes->data, 20);
+			old_ctx=se_memdup(fi->value.value.bytes->data, 20);
 		}
 		g_hash_table_insert(ctx_handle_table, GINT_TO_POINTER(pinfo->fd->num), old_ctx);
 
@@ -292,7 +291,7 @@ sid_name_hash(gconstpointer k)
 	const sid_name *sn = (const sid_name *)k;
 	int i, sum;
 
-	for(sum=0,i=strlen(sn->sid)-1;i>=0;i--){
+	for(sum=0,i=(int)strlen(sn->sid)-1;i>=0;i--){
 		sum+=sn->sid[i];
 	}
 
@@ -404,7 +403,10 @@ sid_name_snooping=0;
 	}
 
 
-	error_string=register_tap_listener("dcerpc", &lsa_policy_information_tap_installed, "lsa.policy_information and ( lsa.info.level or lsa.domain or nt.domain_sid )", NULL, lsa_policy_information, NULL);
+	error_string=register_tap_listener("dcerpc",
+	    &lsa_policy_information_tap_installed,
+	    "lsa.policy_information and ( lsa.info.level or lsa.domain or nt.domain_sid )",
+	    TL_REQUIRES_PROTO_TREE, NULL, lsa_policy_information, NULL);
 	if(error_string){
 		/* error, we failed to attach to the tap. clean up */
 
@@ -415,7 +417,10 @@ sid_name_snooping=0;
 	}
 	lsa_policy_information_tap_installed=TRUE;
 
-	error_string=register_tap_listener("dcerpc", &samr_query_dispinfo_tap_installed, "samr and samr.opnum==40 and ( samr.handle or samr.rid or samr.acct_name or samr.level )", NULL, samr_query_dispinfo, NULL);
+	error_string=register_tap_listener("dcerpc",
+	    &samr_query_dispinfo_tap_installed,
+	    "samr and samr.opnum==40 and ( samr.handle or samr.rid or samr.acct_name or samr.level )",
+	    TL_REQUIRES_PROTO_TREE, NULL, samr_query_dispinfo, NULL);
 	if(error_string){
 		/* error, we failed to attach to the tap. clean up */
 
