@@ -2,7 +2,7 @@
  * Routines for SSCF-NNI (Q.2140) frame disassembly
  * Jeff Morriss <jeff.morriss[AT]ulticom.com>
  *
- * $Id: packet-sscf-nni.c 26277 2008-09-26 17:04:01Z wmeier $
+ * $Id: packet-sscf-nni.c 29340 2009-08-09 06:26:46Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -95,8 +95,7 @@ dissect_sscf_nni(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     sscf_status = tvb_get_guint8(tvb, SSCF_STATUS_OFFSET);
 
-    if (check_col(pinfo->cinfo, COL_PROTOCOL))
-      col_set_str(pinfo->cinfo, COL_PROTOCOL, "SSCF-NNI");
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "SSCF-NNI");
     if (check_col(pinfo->cinfo, COL_INFO))
       col_add_fstr(pinfo->cinfo, COL_INFO, "STATUS (%s) ",
 		   val_to_str(sscf_status, sscf_status_vals, "Unknown"));
@@ -115,9 +114,9 @@ proto_register_sscf(void)
 {
   static hf_register_info hf[] = 
   { { &hf_status, { "Status", "sscf-nni.status", FT_UINT8, BASE_HEX,
-		    VALS(sscf_status_vals), 0x0, "", HFILL} },
+		    VALS(sscf_status_vals), 0x0, NULL, HFILL} },
     { &hf_spare, { "Spare", "sscf-nni.spare", FT_UINT24, BASE_HEX,
-		    NULL, 0x0, "", HFILL} }
+		    NULL, 0x0, NULL, HFILL} }
   };
 
   static gint *ett[] = {
