@@ -3,7 +3,7 @@
  * Copyright 2000-2002, Brian Bruns <camber@ais.org>
  * Copyright 2002, Steve Langasek <vorlon@netexpress.net>
  *
- * $Id: packet-tds.c 24282 2008-02-07 12:14:40Z stig $
+ * $Id: packet-tds.c 30127 2009-09-24 20:21:23Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -883,7 +883,7 @@ dissect_tds7_login(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				len *= 2;
 				proto_tree_add_text(login_tree, tvb, offset2, len, "%s: %s", val_to_str(i, login_field_names, "Unknown"), val);
 			} else {
-				/* This field is the password.  We retrieve it from the packet 
+				/* This field is the password.  We retrieve it from the packet
 				 * as a non-unicode string and then perform two operations on it
 				 * to "decrypt" it.  Finally, we create a new string that consists
 				 * of ASCII characters instead of unicode by skipping every other
@@ -978,7 +978,7 @@ static char *data_to_string(void *data, guint col_type, guint col_size)
  * the length must be computed using the column information seen in the result
  * PDU. This function does just that.
  */
-static size_t
+static guint
 tds_get_row_size(tvbuff_t *tvb, struct _netlib_data *nl_data, guint offset)
 {
 	guint cur, i, csize;
@@ -1647,8 +1647,7 @@ dissect_netlib_buffer(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	if (tds_defragment &&
 	    (packet_number > 1 || status == STATUS_NOT_LAST_BUFFER)) {
 		if (status == STATUS_NOT_LAST_BUFFER) {
-			if (check_col(pinfo->cinfo, COL_INFO))
-				col_append_str(pinfo->cinfo, COL_INFO,
+			col_append_str(pinfo->cinfo, COL_INFO,
 				    " (Not last buffer)");
 		}
 		len = tvb_reported_length_remaining(tvb, offset);
@@ -1677,7 +1676,7 @@ dissect_netlib_buffer(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		if (status == STATUS_NOT_LAST_BUFFER)
 			next_tvb = NULL;
 		else {
-			next_tvb = tvb_new_subset(tvb, offset, -1, -1);
+			next_tvb = tvb_new_subset_remaining(tvb, offset);
 		}
 	}
 
@@ -1711,7 +1710,7 @@ dissect_netlib_buffer(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			break;
 		}
 	} else {
-		next_tvb = tvb_new_subset (tvb, offset, -1, -1);
+		next_tvb = tvb_new_subset_remaining (tvb, offset);
 		call_dissector(data_handle, next_tvb, pinfo, tds_tree);
 	}
 }
@@ -1725,7 +1724,7 @@ dissect_tds_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	guint8 type;
 	guint16 plen;
 	guint length;
-	tvbuff_t *next_tvb;
+	tvbuff_t *volatile next_tvb;
 	proto_item *tds_item = NULL;
 	proto_tree *tds_tree = NULL;
 
@@ -1809,8 +1808,7 @@ dissect_tds_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		}
 
 		if (first_time) {
-			if (check_col(pinfo->cinfo, COL_PROTOCOL))
-				col_set_str(pinfo->cinfo, COL_PROTOCOL, "TDS");
+			col_set_str(pinfo->cinfo, COL_PROTOCOL, "TDS");
 
 			/*
 			 * Set the packet description based on its TDS packet
@@ -1981,7 +1979,7 @@ tds_init(void)
 */
 
 void
-proto_register_netlib(void)
+proto_register_tds(void)
 {
 	static hf_register_info hf[] = {
 		{ &hf_tds_type,
@@ -2007,12 +2005,12 @@ proto_register_netlib(void)
 		{ &hf_tds_packet_number,
 			{ "Packet Number",  "tds.packet_number",
 			FT_UINT8, BASE_DEC, NULL, 0x0,
-			"Packet Number", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_tds_window,
 			{ "Window",         "tds.window",
 			FT_UINT8, BASE_DEC, NULL, 0x0,
-			"Window", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_tds_fragment_overlap,
 			{ "Segment overlap",	"tds.fragment.overlap",
@@ -2042,12 +2040,12 @@ proto_register_netlib(void)
 		{ &hf_tds_fragment,
 			{ "TDS Fragment",	"tds.fragment",
 			FT_FRAMENUM, BASE_NONE, NULL, 0x0,
-			"TDS Fragment", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_tds_fragments,
 			{ "TDS Fragments",	"tds.fragments",
 			FT_NONE, BASE_NONE, NULL, 0x0,
-			"TDS Fragments", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_tds_reassembled_in,
 			{ "Reassembled TDS in frame", "tds.reassembled_in",
@@ -2062,7 +2060,7 @@ proto_register_netlib(void)
 		{ &hf_tds7_version,
                         { "TDS version", "tds7login.version",
                         FT_UINT32, BASE_HEX, NULL, 0x0,
-                        "TDS version", HFILL }
+                        NULL, HFILL }
                 },
 		{ &hf_tds7_packet_size,
                         { "Packet Size", "tds7login.packet_size",
@@ -2072,32 +2070,32 @@ proto_register_netlib(void)
 		{ &hf_tds7_client_version,
                         { "Client version", "tds7login.client_version",
                         FT_UINT32, BASE_DEC, NULL, 0x0,
-                        "Client version", HFILL }
+                        NULL, HFILL }
                 },
 		{ &hf_tds7_client_pid,
                         { "Client PID", "tds7login.client_pid",
                         FT_UINT32, BASE_DEC, NULL, 0x0,
-                        "Client PID", HFILL }
+                        NULL, HFILL }
                 },
 		{ &hf_tds7_connection_id,
                         { "Connection ID", "tds7login.connection_id",
                         FT_UINT32, BASE_DEC, NULL, 0x0,
-                        "Connection ID", HFILL }
+                        NULL, HFILL }
                 },
 		{ &hf_tds7_option_flags1,
                         { "Option Flags 1", "tds7login.option_flags1",
                         FT_UINT8, BASE_HEX, NULL, 0x0,
-                        "Option Flags 1", HFILL }
+                        NULL, HFILL }
                 },
 		{ &hf_tds7_option_flags2,
                         { "Option Flags 2", "tds7login.option_flags2",
                         FT_UINT8, BASE_HEX, NULL, 0x0,
-                        "Option Flags 2", HFILL }
+                        NULL, HFILL }
                 },
 		{ &hf_tds7_sql_type_flags,
                         { "SQL Type Flags", "tds7login.sql_type_flags",
                         FT_UINT8, BASE_HEX, NULL, 0x0,
-                        "SQL Type Flags", HFILL }
+                        NULL, HFILL }
                 },
 		{ &hf_tds7_reserved_flags,
                         { "Reserved Flags", "tds7login.reserved_flags",
@@ -2107,17 +2105,17 @@ proto_register_netlib(void)
 		{ &hf_tds7_time_zone,
                         { "Time Zone", "tds7login.time_zone",
                         FT_UINT32, BASE_HEX, NULL, 0x0,
-                        "Time Zone", HFILL }
+                        NULL, HFILL }
                 },
 		{ &hf_tds7_collation,
                         { "Collation", "tds7login.collation",
                         FT_UINT32, BASE_HEX, NULL, 0x0,
-                        "Collation", HFILL }
+                        NULL, HFILL }
                 },
 		{ &hf_tds7_message,
 			{ "Message", "tds7.message",
 			FT_STRING, BASE_NONE, NULL, 0x0,
-			"", HFILL }
+			NULL, HFILL }
 		},
 	};
 
@@ -2139,6 +2137,9 @@ proto_register_netlib(void)
 	proto_register_field_array(proto_tds, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
 
+/* Allow dissector to be found by name. */
+	register_dissector("tds", dissect_tds_tcp, proto_tds);
+
 	tds_module = prefs_register_protocol(proto_tds, NULL);
 	prefs_register_bool_preference(tds_module, "desegment_buffers",
 	    "Reassemble TDS buffers spanning multiple TCP segments",
