@@ -7,7 +7,7 @@
  * Joerg Mayer (see AUTHORS file)
  *      RFC2348 TFTP Blocksize Option
  *
- * $Id: packet-tftp.c 27870 2009-03-27 19:45:46Z sfisher $
+ * $Id: packet-tftp.c 29884 2009-09-13 23:03:38Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -45,11 +45,14 @@
 #endif
 
 #include <glib.h>
+#include <stdlib.h>
 #include <string.h>
 #include <epan/packet.h>
 #include <epan/conversation.h>
 #include <epan/emem.h>
 #include <epan/expert.h>
+#include <epan/range.h>
+#include <epan/prefs.h>
 
 /* Things we may want to remember for a whole conversation */
 typedef struct _tftp_conv_info_t {
@@ -74,7 +77,12 @@ static gint ett_tftp_option = -1;
 
 static dissector_handle_t tftp_handle;
 
-#define UDP_PORT_TFTP    69
+#define UDP_PORT_TFTP_RANGE    "69"
+
+void proto_reg_handoff_tftp (void);
+
+/* User definable values */
+static range_t *global_tftp_port_range;
 
 #define	TFTP_RRQ	1
 #define	TFTP_WRQ	2
@@ -169,8 +177,7 @@ static void dissect_tftp_message(tftp_conv_info_t *tftp_info,
 	guint            i1;
 	guint16	         error;
 
-  	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "TFTP");
+  	col_set_str(pinfo->cinfo, COL_PROTOCOL, "TFTP");
 
 	opcode = tvb_get_ntohs(tvb, offset);
 
@@ -421,7 +428,7 @@ dissect_tftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	 * the destination address of this packet, and its port 2 being
 	 * wildcarded, and give it the TFTP dissector as a dissector.
 	 */
-	if (pinfo->destport == UDP_PORT_TFTP) {
+	if (value_is_in_range(global_tftp_port_range, pinfo->destport)) {
 	  conversation = find_conversation(pinfo->fd->num, &pinfo->src, &pinfo->dst, PT_UDP,
 					   pinfo->srcport, 0, NO_PORT_B);
 	  if( (conversation == NULL) || (conversation->dissector_handle!=tftp_handle) ){
@@ -465,17 +472,17 @@ proto_register_tftp(void)
 
     { &hf_tftp_source_file,
       { "Source File",	      "tftp.source_file",
-	FT_STRINGZ, BASE_DEC, NULL, 0x0,
+	FT_STRINGZ, BASE_NONE, NULL, 0x0,
       	"TFTP source file name", HFILL }},
 
     { &hf_tftp_destination_file,
       { "DESTINATION File",   "tftp.destination_file",
-	FT_STRINGZ, BASE_DEC, NULL, 0x0,
+	FT_STRINGZ, BASE_NONE, NULL, 0x0,
       	"TFTP source file name", HFILL }},
 
     { &hf_tftp_transfer_type,
       { "Type",	              "tftp.type",
-	FT_STRINGZ, BASE_DEC, NULL, 0x0,
+	FT_STRINGZ, BASE_NONE, NULL, 0x0,
       	"TFTP transfer type", HFILL }},
 
     { &hf_tftp_blocknum,
@@ -490,18 +497,18 @@ proto_register_tftp(void)
 
     { &hf_tftp_error_string,
       { "Error message",      "tftp.error.message",
-	FT_STRINGZ, BASE_DEC, NULL, 0x0,
+	FT_STRINGZ, BASE_NONE, NULL, 0x0,
       	"Error string in case of TFTP error message", HFILL }},
 
     { &hf_tftp_option_name,
       { "Option name",              "tftp.option.name",
-	FT_STRINGZ, BASE_DEC, NULL, 0x0,
-      	"", HFILL }},
+	FT_STRINGZ, BASE_NONE, NULL, 0x0,
+      	NULL, HFILL }},
 
     { &hf_tftp_option_value,
       { "Option value",              "tftp.option.value",
-	FT_STRINGZ, BASE_DEC, NULL, 0x0,
-      	"", HFILL }},
+	FT_STRINGZ, BASE_NONE, NULL, 0x0,
+      	NULL, HFILL }},
 
   };
   static gint *ett[] = {
@@ -509,21 +516,51 @@ proto_register_tftp(void)
     &ett_tftp_option,
   };
 
+  module_t *tftp_module;
+
   proto_tftp = proto_register_protocol("Trivial File Transfer Protocol",
 				       "TFTP", "tftp");
   proto_register_field_array(proto_tftp, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
 
   register_dissector("tftp", dissect_tftp, proto_tftp);
+
+  /* Set default UDP ports */
+  range_convert_str (&global_tftp_port_range, UDP_PORT_TFTP_RANGE, MAX_UDP_PORT);
+
+  tftp_module = prefs_register_protocol (proto_tftp, proto_reg_handoff_tftp);
+  prefs_register_range_preference (tftp_module, "udp_ports",
+				  "TFTP port numbers",
+				  "Port numbers used for TFTP traffic "
+				   "(default " UDP_PORT_TFTP_RANGE ")",
+				   &global_tftp_port_range, MAX_UDP_PORT);
+}
+
+static void range_delete_callback (guint32 port)
+{
+    dissector_delete ("udp.port", port, tftp_handle);
+}
+
+static void range_add_callback (guint32 port)
+{
+    dissector_add ("udp.port", port, tftp_handle);
 }
 
 void
 proto_reg_handoff_tftp(void)
 {
-  tftp_handle = find_dissector("tftp");
+  static range_t *tftp_port_range;
+  static gboolean tftp_initialized = FALSE;
 
-  dissector_add("udp.port", UDP_PORT_TFTP, tftp_handle);
+  if (!tftp_initialized) {
+    tftp_handle = find_dissector("tftp");
+    heur_dissector_add("stun", dissect_embeddedtftp_heur, proto_tftp);
+    tftp_initialized = TRUE;
+  } else {
+    range_foreach (tftp_port_range, range_delete_callback);
+    g_free (tftp_port_range);
+  }
 
-  heur_dissector_add("stun2", dissect_embeddedtftp_heur, 
-  		     proto_tftp);
+  tftp_port_range = range_copy (global_tftp_port_range);
+  range_foreach (tftp_port_range, range_add_callback);
 }
