@@ -7,7 +7,7 @@
  * Routine to dissect RFC 1006 TPKT packet containing OSI TP PDU
  * Copyright 2001, Martin Thomas <Martin_A_Thomas@yahoo.com>
  *
- * $Id: packet-tpkt.c 26308 2008-09-30 14:49:44Z wmeier $
+ * $Id: packet-tpkt.c 29342 2009-08-09 07:01:26Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -217,7 +217,7 @@ dissect_asciitpkt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     int mgcp_version = 0;
     int mgcp_reserved = 0;
     volatile int length;
-    tvbuff_t *next_tvb;
+    tvbuff_t *volatile next_tvb;
     const char *saved_proto;
     guint8 string[4];
     /*
@@ -245,10 +245,8 @@ dissect_asciitpkt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
              * so don't get the length and don't try to
              * do reassembly.
              */
-            if (check_col(pinfo->cinfo, COL_PROTOCOL))
-                col_set_str(pinfo->cinfo, COL_PROTOCOL, "TPKT");
-            if (check_col(pinfo->cinfo, COL_INFO))
-                col_set_str(pinfo->cinfo, COL_INFO, "Continuation");
+            col_set_str(pinfo->cinfo, COL_PROTOCOL, "TPKT");
+            col_set_str(pinfo->cinfo, COL_INFO, "Continuation");
             if (tree) {
                 ti = proto_tree_add_item(tree, proto_tpkt, tvb,
                     offset, -1, FALSE);
@@ -282,8 +280,7 @@ dissect_asciitpkt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
         saved_proto = pinfo->current_proto;
         pinfo->current_proto = "TPKT";
 
-        if (check_col(pinfo->cinfo, COL_PROTOCOL))
-            col_set_str(pinfo->cinfo, COL_PROTOCOL, "TPKT");
+        col_set_str(pinfo->cinfo, COL_PROTOCOL, "TPKT");
         /*
          * Don't add the TPKT header information if we're
          * reassembling segmented TPKT PDUs or if this
@@ -372,7 +369,7 @@ dissect_tpkt_encap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	int length_remaining;
 	int data_len;
 	volatile int length;
-	tvbuff_t *next_tvb;
+	tvbuff_t *volatile next_tvb;
 	const char *saved_proto;
 
 	/*
@@ -400,10 +397,8 @@ dissect_tpkt_encap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 			 * so don't get the length and don't try to
 			 * do reassembly.
 			 */
-			if (check_col(pinfo->cinfo, COL_PROTOCOL))
-				col_set_str(pinfo->cinfo, COL_PROTOCOL, "TPKT");
-			if (check_col(pinfo->cinfo, COL_INFO))
-				col_set_str(pinfo->cinfo, COL_INFO, "Continuation");
+			col_set_str(pinfo->cinfo, COL_PROTOCOL, "TPKT");
+			col_set_str(pinfo->cinfo, COL_INFO, "Continuation");
 			if (tree) {
 				ti = proto_tree_add_item(tree, proto_tpkt, tvb,
 				    offset, -1, FALSE);
@@ -473,8 +468,7 @@ dissect_tpkt_encap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		saved_proto = pinfo->current_proto;
 		pinfo->current_proto = "TPKT";
 
-		if (check_col(pinfo->cinfo, COL_PROTOCOL))
-			col_set_str(pinfo->cinfo, COL_PROTOCOL, "TPKT");
+		col_set_str(pinfo->cinfo, COL_PROTOCOL, "TPKT");
 		/*
 		 * Don't add the TPKT header information if we're
 		 * reassembling segmented TPKT PDUs or if this
