@@ -3,7 +3,7 @@
  * Copyright 2000, Scott Hovis scott.hovis@ums.msfc.nasa.gov
  * Enhanced 2008, Matt Dunkle Matthew.L.Dunkle@nasa.gov
  *
- * $Id: packet-vcdu.c 29446 2009-08-16 12:36:22Z krj $
+ * $Id: packet-vcdu.c 30415 2009-10-09 07:24:33Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.com>
@@ -299,7 +299,7 @@ dissect_vcdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "VCDU");
 	col_set_str(pinfo->cinfo, COL_INFO, "Virtual Channel Data Unit");
 
-	if (tree) {
+	{
                 /* build the smex header tree */
 		smex_header=proto_tree_add_text(tree, tvb, offset, SMEX_HEADER_LENGTH, "SMEX Header");
 		smex_tree=proto_item_add_subtree(smex_header, ett_smex);
