@@ -1,7 +1,7 @@
 /* packet-vlan.c
  * Routines for VLAN 802.1Q ethernet header disassembly
  *
- * $Id: packet-vlan.c 26822 2008-11-22 15:55:01Z stig $
+ * $Id: packet-vlan.c 29513 2009-08-23 09:07:54Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -79,10 +79,8 @@ dissect_vlan(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   volatile gboolean is_802_2;
   proto_tree *volatile vlan_tree;
 
-  if (check_col(pinfo->cinfo, COL_PROTOCOL))
-    col_set_str(pinfo->cinfo, COL_PROTOCOL, "VLAN");
-  if (check_col(pinfo->cinfo, COL_INFO))
-    col_clear(pinfo->cinfo, COL_INFO);
+  col_set_str(pinfo->cinfo, COL_PROTOCOL, "VLAN");
+  col_clear(pinfo->cinfo, COL_INFO);
 
   tci = tvb_get_ntohs( tvb, 0 );
 
@@ -93,9 +91,6 @@ dissect_vlan(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   if ( check_col(pinfo->cinfo, COL_8021Q_VLAN_ID)) {
       col_add_fstr(pinfo->cinfo, COL_8021Q_VLAN_ID, "%u", (tci & 0xFFF));
   }
-  if ( check_col(pinfo->cinfo, COL_COS_VALUE)) {
-      col_add_fstr(pinfo->cinfo, COL_COS_VALUE, "%u", (tci >> 13));
-    }
 
   vlan_tree = NULL;
 
@@ -181,7 +176,7 @@ proto_register_vlan(void)
         "Whether the vlan summary line should be shown in the protocol tree",
         &vlan_summary_in_tree);
   prefs_register_uint_preference(vlan_module, "qinq_ethertype",
-        "802.1QinQ (Hex) Ethertype",
+        "802.1QinQ Ethertype (in hex)",
         "The (hexadecimal) Ethertype used to indicate 802.1QinQ VLAN in VLAN tunneling.",
         16, &q_in_q_ethertype);
 
