@@ -1,7 +1,7 @@
 /* packet-vtp.c
  * Routines for the disassembly of Cisco's Virtual Trunking Protocol
  *
- * $Id: packet-vtp.c 21210 2007-03-26 11:06:26Z sahlberg $
+ * $Id: packet-vtp.c 29342 2009-08-09 07:01:26Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -97,10 +97,8 @@ dissect_vtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	const guint8 *upd_timestamp;
 	int vlan_info_len;
 
-	if (check_col(pinfo->cinfo, COL_PROTOCOL))
-		col_set_str(pinfo->cinfo, COL_PROTOCOL, "VTP");
-	if (check_col(pinfo->cinfo, COL_INFO))
-		col_set_str(pinfo->cinfo, COL_INFO, "Virtual Trunking Protocol");
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "VTP");
+	col_set_str(pinfo->cinfo, COL_INFO, "Virtual Trunking Protocol");
 
 	if (tree) {
 		ti = proto_tree_add_item(tree, proto_vtp, tvb, offset, -1,
@@ -593,11 +591,11 @@ proto_register_vtp(void)
 	static hf_register_info hf[] = {
 		{ &hf_vtp_version,
 		{ "Version",	"vtp.version", FT_UINT8, BASE_HEX, NULL, 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_vtp_code,
 		{ "Code",	"vtp.code", FT_UINT8, BASE_HEX, VALS(type_vals), 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_vtp_followers,
 		{ "Followers",	"vtp.followers", FT_UINT8, BASE_DEC, NULL, 0x0,
@@ -608,7 +606,7 @@ proto_register_vtp(void)
 			"Length of management domain string", HFILL }},
 
 		{ &hf_vtp_md,
-		{ "Management Domain", "vtp.md", FT_STRING, BASE_DEC, NULL, 0,
+		{ "Management Domain", "vtp.md", FT_STRING, BASE_NONE, NULL, 0,
 			"Management domain", HFILL }},
 
 		{ &hf_vtp_conf_rev_num,
@@ -620,12 +618,12 @@ proto_register_vtp(void)
 			"IP address of the updater", HFILL }},
 
 		{ &hf_vtp_upd_ts,
-		{ "Update Timestamp", "vtp.upd_ts", FT_STRING, BASE_DEC, NULL, 0,
+		{ "Update Timestamp", "vtp.upd_ts", FT_STRING, BASE_NONE, NULL, 0,
 			"Time stamp of the current configuration revision", HFILL }},
 
 		{ &hf_vtp_md5_digest,
-		{ "MD5 Digest",	"vtp.md5_digest", FT_BYTES, BASE_HEX, NULL, 0x0,
-			"", HFILL }},
+		{ "MD5 Digest",	"vtp.md5_digest", FT_BYTES, BASE_NONE, NULL, 0x0,
+			NULL, HFILL }},
 
 		{ &hf_vtp_seq_num,
 		{ "Sequence Number",	"vtp.seq_num", FT_UINT8, BASE_DEC, NULL, 0x0,
@@ -641,7 +639,7 @@ proto_register_vtp(void)
 
 		{ &hf_vtp_vlan_status_vlan_susp,
 		{ "VLAN suspended",	"vtp.vlan_info.status.vlan_susp", FT_BOOLEAN, 8, NULL, VLAN_SUSPENDED,
-			"VLAN suspended", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_vtp_vlan_type,
 		{ "VLAN Type",	"vtp.vlan_info.vlan_type", FT_UINT8, BASE_HEX, VALS(vlan_type_vals), 0x0,
@@ -664,16 +662,16 @@ proto_register_vtp(void)
 			"IEEE 802.10 security association identifier for this VLAN", HFILL }},
 
 		{ &hf_vtp_vlan_name,
-		{ "VLAN Name", "vtp.vlan_info.vlan_name", FT_STRING, BASE_DEC, NULL, 0,
+		{ "VLAN Name", "vtp.vlan_info.vlan_name", FT_STRING, BASE_NONE, NULL, 0,
 			"VLAN name", HFILL }},
 
 		{ &hf_vtp_vlan_tlvtype,
 		{ "Type",	"vtp.vlan_info.tlv_type", FT_UINT8, BASE_HEX, VALS(vlan_tlv_type_vals), 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
 
 		{ &hf_vtp_vlan_tlvlength,
 		{ "Length",	"vtp.vlan_info.tlv_len", FT_UINT8, BASE_DEC, NULL, 0x0,
-			"", HFILL }},
+			NULL, HFILL }},
         };
 	static gint *ett[] = {
 		&ett_vtp,
