@@ -3,7 +3,7 @@
  *
  * (C) 2005, Luis E. Garcia Ontanon.
  *
- * $Id: packet-xml.c 29137 2009-07-18 20:10:14Z stig $
+ * $Id: packet-xml.c 30216 2009-09-30 14:02:49Z wmeier $
  *
  * Refer to the AUTHORS file or the AUTHORS section in the man page
  * for contacting the author(s) of this file.
@@ -760,7 +760,7 @@ static void add_xml_field(GArray* hfs, int* p_id, gchar* name, gchar* fqn) {
 	hfri.hfinfo.blurb = NULL;
 	hfri.hfinfo.id = 0;
 	hfri.hfinfo.parent = 0;
-	hfri.hfinfo.ref_count = HF_REF_TYPE_NONE;
+	hfri.hfinfo.ref_type = HF_REF_TYPE_NONE;
 	hfri.hfinfo.bitshift = 0;
 	hfri.hfinfo.same_name_next = NULL;
 	hfri.hfinfo.same_name_prev = NULL;
