@@ -1,6 +1,6 @@
 /* epan.c
  *
- * $Id: epan.c 29806 2009-09-08 19:00:54Z krj $
+ * $Id: epan.c 30646 2009-10-20 17:43:05Z morriss $
  *
  * Wireshark Protocol Analyzer Library
  *
@@ -82,8 +82,7 @@ epan_init(void (*register_all_protocols_func)(register_cb cb, gpointer client_da
 	    report_read_failure, report_write_failure);
 
 	/* initialize memory allocation subsystem */
-	ep_init_chunk();
-	se_init_chunk();
+	emem_init();
 
 	/* initialize the GUID to name mapping table */
 	guids_init();
