@@ -3,7 +3,7 @@
  *
  * Implemented as a tap named "expert".
  *
- * $Id: expert.c 27772 2009-03-18 15:03:46Z wmeier $
+ * $Id: expert.c 30210 2009-09-30 13:04:06Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -35,15 +35,15 @@
 
 
 
-static int expert_tap = -1;
-static int proto_expert = -1;
-static int highest_severity = 0;
+static int expert_tap         = -1;
+static int proto_expert       = -1;
+static int highest_severity   =  0;
 
-static int ett_expert = -1;
-static int ett_subexpert = -1;
+static int ett_expert         = -1;
+static int ett_subexpert      = -1;
 
-static int hf_expert_msg = -1;
-static int hf_expert_group = -1;
+static int hf_expert_msg      = -1;
+static int hf_expert_group    = -1;
 static int hf_expert_severity = -1;
 
 const value_string expert_group_vals[] = {
@@ -52,8 +52,9 @@ const value_string expert_group_vals[] = {
 	{ PI_RESPONSE_CODE,	"Response" },
 	{ PI_REQUEST_CODE,	"Request" },
 	{ PI_UNDECODED,		"Undecoded" },
-	{ PI_MALFORMED,		"Malformed" },
 	{ PI_REASSEMBLE,	"Reassemble" },
+	{ PI_MALFORMED,		"Malformed" },
+	{ PI_DEBUG,		"Debug" },
 /*	{ PI_SECURITY,		"Security" },*/
 	{ 0, NULL }
 };
@@ -67,8 +68,6 @@ const value_string expert_severity_vals[] = {
 	{ 0, NULL }
 };
 
-
-
 void
 expert_init(void)
 {
@@ -76,10 +75,10 @@ expert_init(void)
 		{ &hf_expert_msg,
 			{ "Message", "expert.message", FT_STRING, BASE_NONE, NULL, 0, "Wireshark expert information", HFILL }
 		},
-		{ &hf_expert_group, 
+		{ &hf_expert_group,
 			{ "Group", "expert.group", FT_UINT32, BASE_NONE, VALS(expert_group_vals), 0, "Wireshark expert group", HFILL }
 		},
-		{ &hf_expert_severity, 
+		{ &hf_expert_severity,
 			{ "Severity level", "expert.severity", FT_UINT32, BASE_NONE, VALS(expert_severity_vals), 0, "Wireshark expert severity level", HFILL }
 		}
 	};
@@ -117,8 +116,8 @@ expert_get_highest_severity(void)
 }
 
 
-/* set's the PI_ flags to a protocol item 
- * (and it's parent items till the toplevel) */
+/* set's the PI_ flags to a protocol item
+ * (and its parent items till the toplevel) */
 static void
 expert_set_item_flags(proto_item *pi, int group, int severity)
 {
@@ -137,10 +136,10 @@ expert_create_tree(proto_item *pi, int group, int severity, const char *msg)
 	proto_item *ti;
 
 	tree = proto_item_add_subtree(pi, ett_expert);
-	ti = proto_tree_add_protocol_format(tree, proto_expert, NULL, 0, 0, "Expert Info (%s/%s): %s", 
-		val_to_str(severity, expert_severity_vals, "?%u?"),
-		val_to_str(group, expert_group_vals, "?%u?"),
-		msg);
+	ti = proto_tree_add_protocol_format(tree, proto_expert, NULL, 0, 0, "Expert Info (%s/%s): %s",
+					    val_to_str(severity, expert_severity_vals, "?%u?"),
+					    val_to_str(group, expert_group_vals, "?%u?"),
+					    msg);
 	PROTO_ITEM_SET_GENERATED(ti);
 
 	return proto_item_add_subtree(ti, ett_subexpert);
@@ -150,7 +149,8 @@ static void
 expert_set_info_vformat(
 packet_info *pinfo, proto_item *pi, int group, int severity, const char *format, va_list ap)
 {
-	char			formatted[300];
+	char		formatted[300];
+	int		tap;
 	expert_info_t	*ei;
 	proto_tree	*tree;
 	proto_item	*ti;
@@ -161,21 +161,22 @@ packet_info *pinfo, proto_item *pi, int group, int severity, const char *format,
 		return;
 	}
 
-        if(severity > highest_severity) {
-            highest_severity = severity;
-        }
+	if(severity > highest_severity) {
+		highest_severity = severity;
+	}
+
+	if(pi != NULL && pi->finfo != NULL) {	
+		expert_set_item_flags(pi, group, severity);
+	}
+
+	if (check_col(pinfo->cinfo, COL_EXPERT))
+		col_add_str(pinfo->cinfo, COL_EXPERT, val_to_str(severity, expert_severity_vals, "?%u?"));
+
+	tap = have_tap_listener(expert_tap);
 
 	/* XXX - use currently nonexistant se_vsnprintf instead */
 	g_vsnprintf(formatted, sizeof(formatted), format, ap);
 
-	ei = ep_alloc(sizeof(expert_info_t));
-	ei->packet_num	= pinfo->fd->num;
-	ei->group		= group;
-	ei->severity	= severity;
-	ei->protocol	= ep_strdup(pinfo->current_proto);
-	ei->summary		= ep_strdup(formatted);
-	ei->pitem       = NULL;
-
 	tree = expert_create_tree(pi, group, severity, formatted);
 	ti = proto_tree_add_string(tree, hf_expert_msg, NULL, 0, 0, formatted);
 	PROTO_ITEM_SET_GENERATED(ti);
@@ -184,14 +185,22 @@ packet_info *pinfo, proto_item *pi, int group, int severity, const char *format,
 	ti = proto_tree_add_uint(tree, hf_expert_group, NULL, 0, 0, group);
 	PROTO_ITEM_SET_GENERATED(ti);
 
-	/* if we have a proto_item (not a faked item), set expert attributes to it */
-	if(pi != NULL && pi->finfo != NULL) {	
-        ei->pitem       = pi;
-		expert_set_item_flags(pi, group, severity);
-	}
+	if (!tap)
+		return;
 
-	if (check_col(pinfo->cinfo, COL_EXPERT))
-	  col_add_str(pinfo->cinfo, COL_EXPERT, val_to_str(severity, expert_severity_vals, "?%u?"));
+	ei = ep_alloc(sizeof(expert_info_t));
+
+	ei->packet_num	= pinfo->fd->num;
+	ei->group	= group;
+	ei->severity	= severity;
+	ei->protocol	= pinfo->current_proto; /* ep_strdup(pinfo->current_proto); it's a const */
+	ei->summary	= ep_strdup(formatted);
+	ei->pitem       = NULL;
+
+	/* if we have a proto_item (not a faked item), set expert attributes to it */
+	if(pi != NULL && PITEM_FINFO(pi) != NULL) {
+		ei->pitem = pi;
+	}
 
 	tap_queue_packet(expert_tap, pinfo, ei);
 }
