@@ -1,7 +1,7 @@
 /* filesystem.c
  * Filesystem utility routines
  *
- * $Id: filesystem.c 27821 2009-03-22 18:06:06Z guy $
+ * $Id: filesystem.c 30675 2009-10-23 17:52:18Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -77,6 +77,8 @@
 #include <wiretap/wtap.h>	/* for WTAP_ERR_SHORT_WRITE */
 
 #define PROFILES_DIR    "profiles"
+#define PLUGINS_DIR_NAME    "plugins"
+
 #define U3_MY_CAPTURES  "\\My Captures"
 
 char *persconffile_dir = NULL;
@@ -277,7 +279,7 @@ init_progfile_dir(const char *arg0
 	 * Attempt to get the full pathname of the currently running
 	 * program.
 	 */
-	if (GetModuleFileName(NULL, prog_pathname_w, sizeof prog_pathname_w) != 0) {
+	if (GetModuleFileName(NULL, prog_pathname_w, G_N_ELEMENTS(prog_pathname_w)) != 0) {
 		/*
 		 * XXX - Should we use g_utf16_to_utf8(), as in
 		 * getenv_utf8()?
@@ -669,7 +671,103 @@ get_datafile_dir(void)
 	return datafile_dir;
 }
 
-#ifdef HAVE_PLUGINS
+#ifdef HAVE_PYTHON
+/*
+ * Find the directory where the python dissectors are stored.
+ *
+ * On Windows, we use the "py_dissector" subdirectory of the datafile directory.
+ *
+ * On UN*X, we use the PYTHON_DIR value supplied by the configure
+ * script, unless we think we're being run from the build directory,
+ * in which case we use the "py_dissector" subdirectory of the datafile directory.
+ *
+ * In both cases, we then use the subdirectory of that directory whose
+ * name is the version number.
+ *
+ * XXX - if we think we're being run from the build directory, perhaps we
+ * should have the plugin code not look in the version subdirectory
+ * of the plugin directory, but look in all of the subdirectories
+ * of the plugin directory, so it can just fetch the plugins built
+ * as part of the build process.
+ */
+static const char *wspython_dir = NULL;
+
+static void
+init_wspython_dir(void)
+{
+#ifdef _WIN32
+	/*
+	 * On Windows, the data file directory is the installation
+	 * directory; the python dissectors are stored under it.
+	 *
+	 * Assume we're running the installed version of Wireshark;
+	 * on Windows, the data file directory is the directory
+	 * in which the Wireshark binary resides.
+	 */
+        wspython_dir = g_strdup_printf("%s\\python\\%s", get_datafile_dir(),
+                                        VERSION);
+
+	/*
+	 * Make sure that pathname refers to a directory.
+	 */
+	if (test_for_directory(wspython_dir) != EISDIR) {
+		/*
+		 * Either it doesn't refer to a directory or it
+		 * refers to something that doesn't exist.
+		 *
+		 * Assume that means we're running a version of
+		 * Wireshark we've built in a build directory,
+		 * in which case {datafile dir}\python is the
+		 * top-level plugins source directory, and use
+		 * that directory and set the "we're running in
+		 * a build directory" flag, so the plugin
+		 * scanner will check all subdirectories of that
+		 * directory for python dissectors.
+		 */
+		g_free( (gpointer) wspython_dir);
+		wspython_dir = g_strdup_printf("%s\\python", get_datafile_dir());
+		running_in_build_directory_flag = TRUE;
+	}
+#else
+	if (running_in_build_directory_flag) {
+		/*
+		 * We're (probably) being run from the build directory and
+		 * weren't started with special privileges, so we'll use
+		 * the "python" subdirectory of the datafile directory
+		 * (the datafile directory is the build directory).
+		 */
+		wspython_dir = g_strdup_printf("%s/epan/wspython/", get_datafile_dir());
+	} else {
+		if (getenv("WIRESHARK_PYTHON_DIR") && !started_with_special_privs()) {
+			/*
+			 * The user specified a different directory for plugins
+			 * and we aren't running with special privileges.
+			 */
+			wspython_dir = g_strdup(getenv("WIRESHARK_PYTHON_DIR"));
+		} else {
+			wspython_dir = PYTHON_DIR;
+		}
+	}
+#endif
+}
+#endif /* HAVE_PYTHON */
+
+/*
+ * Get the directory in which the python dissectors are stored.
+ */
+const char *
+get_wspython_dir(void)
+{
+#ifdef HAVE_PYTHON
+	if (!wspython_dir) init_wspython_dir();
+	return wspython_dir;
+#else
+	return NULL;
+#endif
+}
+
+
+#if defined(HAVE_PLUGINS) || defined(HAVE_LUA_5_1)
 /*
  * Find the directory where the plugins are stored.
  *
@@ -748,7 +846,7 @@ init_plugin_dir(void)
 	}
 #endif
 }
-#endif /* HAVE_PLUGINS */
+#endif /* HAVE_PLUGINS || HAVE_LUA_5_1 */
 
 /*
  * Get the directory in which the plugins are stored.
@@ -756,7 +854,7 @@ init_plugin_dir(void)
 const char *
 get_plugin_dir(void)
 {
-#ifdef HAVE_PLUGINS
+#if defined(HAVE_PLUGINS) || defined(HAVE_LUA_5_1)
 	if (!plugin_dir) init_plugin_dir();
 	return plugin_dir;
 #else
@@ -1395,6 +1493,14 @@ get_datafile_path(const char *filename)
 		filename);
 }
 
+/* Get the personal plugin dir */
+/* Return value is malloced so the caller should g_free() it. */
+char *
+get_plugins_pers_dir(void)
+{
+    return get_persconffile_path(PLUGINS_DIR_NAME, FALSE, FALSE);
+}
+
 /* Delete a file */
 gboolean
 deletefile(const char *path)
