@@ -3,7 +3,7 @@
  *
  * (c) 2007, Luis E. Garcia Ontanon <luis@ontanon.org>
  *
- * $Id: oids.c 29014 2009-07-08 08:00:55Z stig $
+ * $Id: oids.c 30600 2009-10-18 20:13:06Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -266,7 +266,7 @@ static char* alnumerize(const char* name) {
 	return s;
 }
 
-const oid_value_type_t* get_typedata(SmiType* smiType) {
+static const oid_value_type_t* get_typedata(SmiType* smiType) {
 	/*
 	 * There has to be a better way to know if a given
 	 * OCTETSTRING type is actually human readable text,
@@ -459,7 +459,7 @@ static inline oid_kind_t smikind(SmiNode* sN, oid_key_t** key_p) {
 				kl = k;
 			}
 
-			if (implied) {
+			if (implied && kl) {
 				switch (kl->key_type) {
 					case OID_KEY_TYPE_BYTES:  kl->key_type = OID_KEY_TYPE_IMPLIED_BYTES; break;
 					case OID_KEY_TYPE_STRING: kl->key_type = OID_KEY_TYPE_IMPLIED_STRING; break;
@@ -486,7 +486,7 @@ static inline oid_kind_t smikind(SmiNode* sN, oid_key_t** key_p) {
 						   || (ft == FT_INT8) || (ft == FT_INT16) || (ft == FT_INT24) || (ft == FT_INT32) \
 						   || (ft == FT_UINT64) || (ft == FT_INT64) )
 
-void register_mibs(void) {
+static void register_mibs(void) {
 	SmiModule *smiModule;
 	SmiNode *smiNode;
 	guint i;
@@ -915,7 +915,6 @@ guint oid_subid2encoded(guint subids_len, guint32* subids, guint8** bytes_p) {
 	guint bytelen = 0;
 	guint i;
 	guint32 subid;
-	guint8* bytes;
 	guint8* b;
 
 	if ( !subids || subids_len <= 0) {
@@ -942,7 +941,7 @@ guint oid_subid2encoded(guint subids_len, guint32* subids, guint8** bytes_p) {
 			subid = subids[i];
 	} while ( i++ < subids_len );
 
-	*bytes_p = b = bytes = ep_alloc(bytelen);
+	*bytes_p = b = ep_alloc(bytelen);
 
 	subid = (subids[0] * 40) + subids[1];
 	i = 2;
