@@ -1,7 +1,7 @@
 /* packet.c
  * Routines for packet disassembly
  *
- * $Id: packet.c 33115 2010-06-06 22:13:16Z gerald $
+ * $Id: packet.c 30527 2009-10-12 01:31:01Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -83,15 +83,15 @@ packet_cleanup(void)
 void
 set_actual_length(tvbuff_t *tvb, guint specified_len)
 {
-  if (specified_len < tvb_reported_length(tvb)) {
-    /* Adjust the length of this tvbuff to include only the specified
-       payload length.
+	if (specified_len < tvb_reported_length(tvb)) {
+		/* Adjust the length of this tvbuff to include only the specified
+		   payload length.
 
-       The dissector above the one calling us (the dissector above is
-       probably us) may use that to determine how much of its packet
-       was padding. */
-    tvb_set_reported_length(tvb, specified_len);
-  }
+		   The dissector above the one calling us (the dissector above is
+		   probably us) may use that to determine how much of its packet
+		   was padding. */
+		tvb_set_reported_length(tvb, specified_len);
+	}
 }
 
 /* Allow protocols to register "init" routines, which are called before
@@ -142,7 +142,7 @@ init_dissection(void)
 	/* Initialize the common data structures for fragment reassembly.
 	   Must be done *after* calling init routines, as those routines
 	   may free up space for fragments, which they find by using the
-	   data structures that "reassemble_init()" frees. */
+	   data structures that "reassemble_cleanup()" frees. */
 	reassemble_init();
 
 	/* Initialize the stream-handling tables */
@@ -155,7 +155,30 @@ init_dissection(void)
 void
 cleanup_dissection(void)
 {
-	init_dissection();
+	/* Reclaim all memory of seasonal scope */
+	se_free_all();
+
+	/* Cleanup the table of conversations. */
+	epan_conversation_cleanup();
+
+	/* Cleanup the table of circuits. */
+	epan_circuit_cleanup();
+
+	/* TODO: Introduce cleanup_routines */
+	/* Cleanup protocol-specific variables. */
+	g_slist_foreach(init_routines, &call_init_routine, NULL);
+
+	/* Cleanup the common data structures for fragment reassembly.
+	   Must be done *after* calling init routines, as those routines
+	   may free up space for fragments, which they find by using the
+	   data structures that "reassemble_cleanup()" frees. */
+	reassemble_cleanup();
+
+	/* Cleanup the stream-handling tables */
+	stream_cleanup();
+
+	/* Initialize the expert infos */
+	expert_cleanup();
 }
 
 /* Allow protocols to register a "cleanup" routine to be
@@ -197,23 +220,46 @@ add_new_data_source(packet_info *pinfo, tvbuff_t *tvb, const char *name)
 
 	src = ep_alloc(sizeof (data_source));
 	src->tvb = tvb;
-	/*
-	 * XXX - if we require this argument to be a string constant,
-	 * we don't need to allocate a buffer for a copy and make a
-	 * copy, and wouldn't need to free the buffer, either.
-	 */
-	src->name = ep_strdup_printf("%s (%u bytes)", name, tvb_length(tvb));
+	src->name_initialized = FALSE;
+	src->name = name;
 	pinfo->data_src = g_slist_append(pinfo->data_src, src);
 }
 
+/*
+ * This should only add a data source to the list of data sources for
+ * a frame if the data sources are being used.  Note that they can
+ * be used even if the protocol tree isn't being built or isn't visible,
+ * e.g. if you run tshark with -x but without -V or anything else to
+ * cause the protocol tree to be built.
+ */
+void
+packet_add_new_data_source(packet_info *pinfo, proto_tree *tree _U_,
+			   tvbuff_t *tvb, const char *name)
+{
+	add_new_data_source(pinfo, tvb, name);
+}
+
+const char*
+get_data_source_name(data_source *src)
+{
+	if (!src->name_initialized) {
+		src->name = ep_strdup_printf("%s (%u bytes)", src->name, tvb_length(src->tvb));
+		src->name_initialized = TRUE;
+	}
+
+	return src->name;
+}
+
 /*
  * Free up a frame's list of data sources.
  */
 void
 free_data_sources(packet_info *pinfo)
 {
-	g_slist_free(pinfo->data_src);
-	pinfo->data_src = NULL;
+	if (pinfo->data_src) {
+		g_slist_free(pinfo->data_src);
+		pinfo->data_src = NULL;
+	}
 }
 
 /* Allow dissectors to register a "final_registration" routine
@@ -256,81 +302,32 @@ dissect_packet(epan_dissect_t *edt, union wtap_pseudo_header *pseudo_header,
 {
 	if (cinfo != NULL)
 		col_init(cinfo);
+	memset(&edt->pi, 0, sizeof(edt->pi));
 	edt->pi.current_proto = "<Missing Protocol Name>";
 	edt->pi.cinfo = cinfo;
 	edt->pi.fd = fd;
 	edt->pi.pseudo_header = pseudo_header;
-	edt->pi.data_src = NULL;
 	edt->pi.dl_src.type = AT_NONE;
-	edt->pi.dl_src.len = 0;
-	edt->pi.dl_src.data = NULL;
 	edt->pi.dl_dst.type = AT_NONE;
-	edt->pi.dl_dst.len = 0;
-	edt->pi.dl_dst.data = NULL;
 	edt->pi.net_src.type = AT_NONE;
-	edt->pi.net_src.len = 0;
-	edt->pi.net_src.data = NULL;
 	edt->pi.net_dst.type = AT_NONE;
-	edt->pi.net_dst.len = 0;
-	edt->pi.net_dst.data = NULL;
 	edt->pi.src.type = AT_NONE;
-	edt->pi.src.len = 0;
-	edt->pi.src.data = NULL;
 	edt->pi.dst.type = AT_NONE;
-	edt->pi.dst.len = 0;
-	edt->pi.dst.data = NULL;
-	edt->pi.ethertype = 0;
-	edt->pi.mpls_label = 0;
-	edt->pi.ipproto  = 0;
-	edt->pi.ipxptype = 0;
 	edt->pi.ctype = CT_NONE;
-	edt->pi.circuit_id = 0;
 	edt->pi.noreassembly_reason = "";
-	edt->pi.fragmented = FALSE;
-	edt->pi.in_error_pkt = FALSE;
 	edt->pi.ptype = PT_NONE;
-	edt->pi.srcport  = 0;
-	edt->pi.destport = 0;
-	edt->pi.match_port = 0;
-	edt->pi.match_string = NULL;
-	edt->pi.can_desegment = 0;
-	edt->pi.want_pdu_tracking = 0;
 	edt->pi.p2p_dir = P2P_DIR_UNKNOWN;
-	edt->pi.private_data = NULL;
-	edt->pi.oxid = 0;
-	edt->pi.rxid = 0;
-	edt->pi.r_ctl = 0;
-	edt->pi.src_idx = 0;
-	edt->pi.dst_idx = 0;
-	edt->pi.vsan = 0;
-	edt->pi.dcectxid = 0;
 	edt->pi.dcetransporttype = -1;
-	edt->pi.decrypt_gssapi_tvb = 0;
-	edt->pi.gssapi_wrap_tvb = NULL;
-	edt->pi.gssapi_encrypted_tvb = NULL;
-	edt->pi.gssapi_decrypted_tvb = NULL;
-	edt->pi.layer_names = NULL;
-	edt->pi.link_number = 0;
 	edt->pi.annex_a_used = MTP2_ANNEX_A_USED_UNKNOWN;
-	edt->pi.profinet_conv = NULL;
-	edt->pi.profinet_type = 0;
-	edt->pi.usb_conv_info = NULL;
-	edt->pi.tcp_tree = NULL;
 	edt->pi.dcerpc_procedure_name="";
-	edt->pi.sccp_info = NULL;
-	edt->pi.clnp_srcref = 0;
-	edt->pi.clnp_dstref = 0;
 	edt->pi.link_dir = LINK_DIR_UNKNOWN;
 
-	/* to enable decode as for ethertype=0x0000 (fix for bug 4721) */
-	edt->pi.ethertype = G_MAXINT;
-
 	EP_CHECK_CANARY(("before dissecting frame %d",fd->num));
-    
+
 	TRY {
 		edt->tvb = tvb_new_real_data(pd, fd->cap_len, fd->pkt_len);
 		/* Add this tvbuffer into the data_src list */
-		add_new_data_source(&edt->pi, edt->tvb, "Frame");
+		packet_add_new_data_source(&edt->pi, edt->tree, edt->tvb, "Frame");
 
 		/* Even though dissect_frame() catches all the exceptions a
 		 * sub-dissector can throw, dissect_frame() itself may throw
@@ -346,7 +343,7 @@ dissect_packet(epan_dissect_t *edt, union wtap_pseudo_header *pseudo_header,
 	CATCH(ReportedBoundsError) {
 		if(proto_malformed != -1){
 			proto_tree_add_protocol_format(edt->tree, proto_malformed, edt->tvb, 0, 0,
-			                               "[Malformed Frame: Packet Length]" );
+						       "[Malformed Frame: Packet Length]" );
 		} else {
 			g_assert_not_reached();
 		}
@@ -355,8 +352,8 @@ dissect_packet(epan_dissect_t *edt, union wtap_pseudo_header *pseudo_header,
 		RETHROW;
 	}
 	ENDTRY;
-    
-    EP_CHECK_CANARY(("after dissecting frame %d",fd->num));
+
+	EP_CHECK_CANARY(("after dissecting frame %d",fd->num));
 
 	fd->flags.visited = 1;
 }
@@ -388,7 +385,7 @@ struct dissector_handle {
  */
 static int
 call_dissector_through_handle(dissector_handle_t handle, tvbuff_t *tvb,
-    packet_info *pinfo, proto_tree *tree)
+			      packet_info *pinfo, proto_tree *tree)
 {
 	const char *saved_proto;
 	int ret;
@@ -397,17 +394,17 @@ call_dissector_through_handle(dissector_handle_t handle, tvbuff_t *tvb,
 
 	if (handle->protocol != NULL) {
 		pinfo->current_proto =
-		    proto_get_protocol_short_name(handle->protocol);
+			proto_get_protocol_short_name(handle->protocol);
 	}
 
 	if (handle->is_new) {
-        EP_CHECK_CANARY(("before calling handle->dissector.new for %s",handle->name));
+		EP_CHECK_CANARY(("before calling handle->dissector.new for %s",handle->name));
 		ret = (*handle->dissector.new)(tvb, pinfo, tree);
-        EP_CHECK_CANARY(("after calling handle->dissector.new for %s",handle->name));
+		EP_CHECK_CANARY(("after calling handle->dissector.new for %s",handle->name));
 	} else {
-        EP_CHECK_CANARY(("before calling handle->dissector.old for %s",handle->name));
+		EP_CHECK_CANARY(("before calling handle->dissector.old for %s",handle->name));
 		(*handle->dissector.old)(tvb, pinfo, tree);
-        EP_CHECK_CANARY(("after calling handle->dissector.old for %s",handle->name));
+		EP_CHECK_CANARY(("after calling handle->dissector.old for %s",handle->name));
 		ret = tvb_length(tvb);
 		if (ret == 0) {
 			/*
@@ -435,7 +432,7 @@ call_dissector_through_handle(dissector_handle_t handle, tvbuff_t *tvb,
 
 static int
 call_dissector_work_error(dissector_handle_t handle, tvbuff_t *tvb,
-    packet_info *pinfo_arg, proto_tree *tree);
+			  packet_info *pinfo_arg, proto_tree *tree);
 
 static int
 call_dissector_work(dissector_handle_t handle, tvbuff_t *tvb,
@@ -477,7 +474,7 @@ call_dissector_work(dissector_handle_t handle, tvbuff_t *tvb,
 	pinfo->can_desegment = saved_can_desegment-(saved_can_desegment>0);
 	if (handle->protocol != NULL) {
 		pinfo->current_proto =
-		    proto_get_protocol_short_name(handle->protocol);
+			proto_get_protocol_short_name(handle->protocol);
 
 		/*
 		 * Add the protocol name to the layers
@@ -486,8 +483,8 @@ call_dissector_work(dissector_handle_t handle, tvbuff_t *tvb,
 		if ((pinfo->layer_names)&&(add_proto_name)) {
 			if (pinfo->layer_names->len > 0)
 				g_string_append(pinfo->layer_names, ":");
-			g_string_append(pinfo->layer_names,
-			    proto_get_protocol_filter_name(proto_get_id(handle->protocol)));
+				g_string_append(pinfo->layer_names,
+				proto_get_protocol_filter_name(proto_get_id(handle->protocol)));
 		}
 	}
 
@@ -506,8 +503,7 @@ call_dissector_work(dissector_handle_t handle, tvbuff_t *tvb,
  		 * of protocols.
 		 */
  		if ((pinfo->layer_names != NULL)&&(add_proto_name)) {
- 			g_string_truncate(pinfo->layer_names,
- 			    saved_layer_names_len);
+ 			g_string_truncate(pinfo->layer_names, saved_layer_names_len);
 		}
  	}
  	pinfo->current_proto = saved_proto;
@@ -518,7 +514,7 @@ call_dissector_work(dissector_handle_t handle, tvbuff_t *tvb,
 
 static int
 call_dissector_work_error(dissector_handle_t handle, tvbuff_t *tvb,
-    packet_info *pinfo_arg, proto_tree *tree)
+			  packet_info *pinfo_arg, proto_tree *tree)
 {
 	packet_info *pinfo = pinfo_arg;
 	const char *saved_proto;
@@ -611,7 +607,7 @@ call_dissector_work_error(dissector_handle_t handle, tvbuff_t *tvb,
 	}
 	CATCH(OutOfMemoryError) {
 		RETHROW;
-        }
+	}
 	ENDTRY;
 
 	col_set_writable(pinfo->cinfo, save_writable);
@@ -697,9 +693,29 @@ find_uint_dtbl_entry(dissector_table_t sub_dissectors, guint32 pattern)
 	 * Find the entry.
 	 */
 	return g_hash_table_lookup(sub_dissectors->hash_table,
-	    GUINT_TO_POINTER(pattern));
+				   GUINT_TO_POINTER(pattern));
 }
 
+#if 0
+static void
+dissector_add_sanity_check(const char *name, guint32 pattern, dissector_handle_t handle, dissector_table_t sub_dissectors)
+{
+	dtbl_entry_t *dtbl_entry;
+
+	if (pattern == 0) {
+		g_warning("%s: %s registering using a pattern of 0",
+			  name, proto_get_protocol_filter_name(proto_get_id(handle->protocol)));
+	}
+
+	dtbl_entry = g_hash_table_lookup(sub_dissectors->hash_table, GUINT_TO_POINTER(pattern));
+	if (dtbl_entry != NULL) {
+		g_warning("%s: %s registering using pattern %d already registered by %s",
+			  name, proto_get_protocol_filter_name(proto_get_id(handle->protocol)),
+						  pattern, proto_get_protocol_filter_name(proto_get_id(dtbl_entry->initial->protocol)));
+	}
+}
+#endif
+
 /* Add an entry to a uint dissector table. */
 void
 dissector_add(const char *name, guint32 pattern, dissector_handle_t handle)
@@ -729,13 +745,17 @@ dissector_add(const char *name, guint32 pattern, dissector_handle_t handle)
 		g_assert_not_reached();
 	}
 
+#if 0
+	dissector_add_sanity_check(name, pattern, handle, sub_dissectors);
+#endif
+
 	dtbl_entry = g_malloc(sizeof (dtbl_entry_t));
 	dtbl_entry->current = handle;
 	dtbl_entry->initial = dtbl_entry->current;
 
 /* do the table insertion */
-    	g_hash_table_insert( sub_dissectors->hash_table,
-    	    GUINT_TO_POINTER( pattern), (gpointer)dtbl_entry);
+	g_hash_table_insert( sub_dissectors->hash_table,
+			     GUINT_TO_POINTER( pattern), (gpointer)dtbl_entry);
 
 	/*
 	 * Now add it to the list of handles that could be used with this
@@ -772,7 +792,7 @@ dissector_delete(const char *name, guint32 pattern,
 		 * Found - remove it.
 		 */
 		g_hash_table_remove(sub_dissectors->hash_table,
-		    GUINT_TO_POINTER(pattern));
+				    GUINT_TO_POINTER(pattern));
 
 		/*
 		 * Now free up the entry.
@@ -814,8 +834,8 @@ dissector_change(const char *name, guint32 pattern, dissector_handle_t handle)
 	dtbl_entry->current = handle;
 
 /* do the table insertion */
-    	g_hash_table_insert( sub_dissectors->hash_table,
-    	    GUINT_TO_POINTER( pattern), (gpointer)dtbl_entry);
+	g_hash_table_insert( sub_dissectors->hash_table,
+			     GUINT_TO_POINTER( pattern), (gpointer)dtbl_entry);
 }
 
 /* Reset an entry in a uint dissector table to its initial value. */
@@ -843,7 +863,7 @@ dissector_reset(const char *name, guint32 pattern)
 		dtbl_entry->current = dtbl_entry->initial;
 	} else {
 		g_hash_table_remove(sub_dissectors->hash_table,
-		    GUINT_TO_POINTER(pattern));
+				    GUINT_TO_POINTER(pattern));
 		g_free(dtbl_entry);
 	}
 }
@@ -854,7 +874,7 @@ dissector_reset(const char *name, guint32 pattern)
 
 gboolean
 dissector_try_port_new(dissector_table_t sub_dissectors, guint32 port,
-    tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean add_proto_name)
+		       tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean add_proto_name)
 {
 	dtbl_entry_t *dtbl_entry;
 	struct dissector_handle *handle;
@@ -906,7 +926,7 @@ dissector_try_port_new(dissector_table_t sub_dissectors, guint32 port,
 
 gboolean
 dissector_try_port(dissector_table_t sub_dissectors, guint32 port,
-    tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+		   tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 
 	return dissector_try_port_new(sub_dissectors, port, tvb, pinfo, tree, TRUE);
@@ -955,7 +975,7 @@ find_string_dtbl_entry(dissector_table_t sub_dissectors, const gchar *pattern)
 /* Add an entry to a string dissector table. */
 void
 dissector_add_string(const char *name, const gchar *pattern,
-    dissector_handle_t handle)
+		     dissector_handle_t handle)
 {
 	dissector_table_t sub_dissectors = find_dissector_table( name);
 	dtbl_entry_t *dtbl_entry;
@@ -985,8 +1005,8 @@ dissector_add_string(const char *name, const gchar *pattern,
 	dtbl_entry->initial = dtbl_entry->current;
 
 /* do the table insertion */
-    	g_hash_table_insert( sub_dissectors->hash_table, (gpointer)pattern,
-    	    (gpointer)dtbl_entry);
+	g_hash_table_insert( sub_dissectors->hash_table, (gpointer)pattern,
+			     (gpointer)dtbl_entry);
 
 	/*
 	 * Now add it to the list of handles that could be used with this
@@ -1036,7 +1056,7 @@ dissector_delete_string(const char *name, const gchar *pattern,
    with a particular pattern to use a new dissector handle. */
 void
 dissector_change_string(const char *name, gchar *pattern,
-    dissector_handle_t handle)
+			dissector_handle_t handle)
 {
 	dissector_table_t sub_dissectors = find_dissector_table( name);
 	dtbl_entry_t *dtbl_entry;
@@ -1066,8 +1086,8 @@ dissector_change_string(const char *name, gchar *pattern,
 	dtbl_entry->current = handle;
 
 /* do the table insertion */
-    	g_hash_table_insert( sub_dissectors->hash_table, pattern,
-    	    (gpointer)dtbl_entry);
+	g_hash_table_insert( sub_dissectors->hash_table, pattern,
+			     (gpointer)dtbl_entry);
 }
 
 /* Reset an entry in a string sub-dissector table to its initial value. */
@@ -1104,7 +1124,7 @@ dissector_reset_string(const char *name, const gchar *pattern)
    return FALSE. */
 gboolean
 dissector_try_string(dissector_table_t sub_dissectors, const gchar *string,
-    tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+		     tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	dtbl_entry_t *dtbl_entry;
 	struct dissector_handle *handle;
@@ -1160,7 +1180,7 @@ dissector_try_string(dissector_table_t sub_dissectors, const gchar *string,
    return the dissector handle for that value. */
 dissector_handle_t
 dissector_get_string_handle(dissector_table_t sub_dissectors,
-    const gchar *string)
+			    const gchar *string)
 {
 	dtbl_entry_t *dtbl_entry;
 
@@ -1199,7 +1219,7 @@ dissector_add_handle(const char *name, dissector_handle_t handle)
 
 	/* Add it to the list. */
 	sub_dissectors->dissector_handles =
-	    g_slist_append(sub_dissectors->dissector_handles, (gpointer)handle);
+		g_slist_append(sub_dissectors->dissector_handles, (gpointer)handle);
 }
 
 dissector_handle_t
@@ -1249,7 +1269,7 @@ dissector_table_foreach_func (gpointer key, gpointer value, gpointer user_data)
 
 	info = user_data;
 	info->caller_func(info->table_name, info->selector_type, key, value,
-	    info->caller_data);
+			  info->caller_data);
 }
 
 /*
@@ -1319,7 +1339,7 @@ dissector_table_foreach_handle(const char *name,
 	GSList *tmp;
 
 	for (tmp = sub_dissectors->dissector_handles; tmp != NULL;
-	    tmp = g_slist_next(tmp))
+	     tmp = g_slist_next(tmp))
 		func(name, tmp->data, user_data);
 }
 
@@ -1345,7 +1365,7 @@ dissector_table_foreach_changed_func (gpointer key, gpointer value, gpointer use
 
 	info = user_data;
 	info->caller_func(info->table_name, info->selector_type, key, value,
-	    info->caller_data);
+			  info->caller_data);
 }
 
 /*
@@ -1381,12 +1401,12 @@ dissector_table_foreach_changed (const char *name,
 	info.caller_func = func;
 	info.caller_data = user_data;
 	g_hash_table_foreach(sub_dissectors->hash_table,
-	    dissector_table_foreach_changed_func, &info);
+			     dissector_table_foreach_changed_func, &info);
 }
 
 typedef struct dissector_foreach_table_info {
-  gpointer      caller_data;
-  DATFunc_table caller_func;
+	gpointer      caller_data;
+	DATFunc_table caller_func;
 } dissector_foreach_table_info_t;
 
 /*
@@ -1420,7 +1440,7 @@ dissector_all_tables_foreach_table (DATFunc_table func,
 
 dissector_table_t
 register_dissector_table(const char *name, const char *ui_name, ftenum_t type,
-    int base)
+			 int base)
 {
 	dissector_table_t	sub_dissectors;
 
@@ -1449,13 +1469,13 @@ register_dissector_table(const char *name, const char *ui_name, ftenum_t type,
 		 * so we use "g_direct_hash()" and "g_direct_equal()".
 		 */
 		sub_dissectors->hash_table = g_hash_table_new( g_direct_hash,
-		    g_direct_equal );
+							       g_direct_equal );
 		break;
 
 	case FT_STRING:
 	case FT_STRINGZ:
 		sub_dissectors->hash_table = g_hash_table_new( g_str_hash,
-		    g_str_equal );
+							       g_str_equal );
 		break;
 
 	default:
@@ -1528,9 +1548,9 @@ heur_dissector_add(const char *name, heur_dissector_t dissector, int proto)
 
 
 static int find_matching_heur_dissector( gconstpointer a, gconstpointer b) {
-    const heur_dtbl_entry_t *dtbl_entry_a = (const heur_dtbl_entry_t *) a;
-    const heur_dtbl_entry_t *dtbl_entry_b = (const heur_dtbl_entry_t *) b;
-    return (dtbl_entry_a->dissector == dtbl_entry_b->dissector) &&
+	const heur_dtbl_entry_t *dtbl_entry_a = (const heur_dtbl_entry_t *) a;
+	const heur_dtbl_entry_t *dtbl_entry_b = (const heur_dtbl_entry_t *) b;
+	return (dtbl_entry_a->dissector == dtbl_entry_b->dissector) &&
 		(dtbl_entry_a->protocol == dtbl_entry_b->protocol) ? 0 : 1;
 }
 
@@ -1558,7 +1578,7 @@ void heur_dissector_delete(const char *name, heur_dissector_t dissector, int pro
 
 gboolean
 dissector_try_heuristic(heur_dissector_list_t sub_dissectors,
-    tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+			tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	gboolean status;
 	const char *saved_proto;
@@ -1601,7 +1621,7 @@ dissector_try_heuristic(heur_dissector_list_t sub_dissectors,
 
 		if (dtbl_entry->protocol != NULL) {
 			pinfo->current_proto =
-			    proto_get_protocol_short_name(dtbl_entry->protocol);
+				proto_get_protocol_short_name(dtbl_entry->protocol);
 
 			/*
 			 * Add the protocol name to the layers; we'll remove it
@@ -1610,20 +1630,20 @@ dissector_try_heuristic(heur_dissector_list_t sub_dissectors,
 			if (pinfo->layer_names) {
 				if (pinfo->layer_names->len > 0)
 					g_string_append(pinfo->layer_names, ":");
-				g_string_append(pinfo->layer_names,
+					g_string_append(pinfo->layer_names,
 					proto_get_protocol_filter_name(proto_get_id(dtbl_entry->protocol)));
 			}
 		}
-        EP_CHECK_CANARY(("before calling heuristic dissector for protocol: %s",
-                         proto_get_protocol_filter_name(proto_get_id(dtbl_entry->protocol))));
+		EP_CHECK_CANARY(("before calling heuristic dissector for protocol: %s",
+				 proto_get_protocol_filter_name(proto_get_id(dtbl_entry->protocol))));
 		if ((*dtbl_entry->dissector)(tvb, pinfo, tree)) {
-            EP_CHECK_CANARY(("after heuristic dissector for protocol: %s has accepted and dissected packet",
-                             proto_get_protocol_filter_name(proto_get_id(dtbl_entry->protocol))));
+			EP_CHECK_CANARY(("after heuristic dissector for protocol: %s has accepted and dissected packet",
+					 proto_get_protocol_filter_name(proto_get_id(dtbl_entry->protocol))));
 			status = TRUE;
 			break;
 		} else {
-            EP_CHECK_CANARY(("after heuristic dissector for protocol: %s has returned true",
-                             proto_get_protocol_filter_name(proto_get_id(dtbl_entry->protocol))));
+			EP_CHECK_CANARY(("after heuristic dissector for protocol: %s has returned true",
+					 proto_get_protocol_filter_name(proto_get_id(dtbl_entry->protocol))));
 
 			/*
 			 * That dissector didn't accept the packet, so
@@ -1631,9 +1651,8 @@ dissector_try_heuristic(heur_dissector_list_t sub_dissectors,
 			 * of protocols.
 			 */
 			if (pinfo->layer_names != NULL) {
-				g_string_truncate(pinfo->layer_names,
-				    saved_layer_names_len);
-            }
+				g_string_truncate(pinfo->layer_names, saved_layer_names_len);
+			}
 		}
 	}
 	pinfo->current_proto = saved_proto;
@@ -1655,7 +1674,7 @@ register_heur_dissector_list(const char *name, heur_dissector_list_t *sub_dissec
 
 	*sub_dissectors = NULL;	/* initially empty */
 	g_hash_table_insert(heur_dissector_lists, (gpointer)name,
-	    (gpointer) sub_dissectors);
+			    (gpointer) sub_dissectors);
 }
 
 /*
@@ -1763,7 +1782,7 @@ register_dissector(const char *name, dissector_t dissector, int proto)
 	handle->protocol = find_protocol_by_id(proto);
 
 	g_hash_table_insert(registered_dissectors, (gpointer)name,
-	    (gpointer) handle);
+			    (gpointer) handle);
 }
 
 void
@@ -1787,7 +1806,7 @@ new_register_dissector(const char *name, new_dissector_t dissector, int proto)
 	handle->protocol = find_protocol_by_id(proto);
 
 	g_hash_table_insert(registered_dissectors, (gpointer)name,
-	    (gpointer) handle);
+			    (gpointer) handle);
 }
 
 /* Call a dissector through a handle but if the dissector rejected it
@@ -1795,7 +1814,7 @@ new_register_dissector(const char *name, new_dissector_t dissector, int proto)
  */
 int
 call_dissector_only(dissector_handle_t handle, tvbuff_t *tvb,
-    packet_info *pinfo, proto_tree *tree)
+		    packet_info *pinfo, proto_tree *tree)
 {
 	int ret;
 
@@ -1809,7 +1828,7 @@ call_dissector_only(dissector_handle_t handle, tvbuff_t *tvb,
  */
 int
 call_dissector(dissector_handle_t handle, tvbuff_t *tvb,
-    packet_info *pinfo, proto_tree *tree)
+	       packet_info *pinfo, proto_tree *tree)
 {
 	int ret;
 
@@ -1819,7 +1838,7 @@ call_dissector(dissector_handle_t handle, tvbuff_t *tvb,
 		 * The protocol was disabled, or the dissector rejected
 		 * it.  Just dissect this packet as data.
 		 */
-	        g_assert(data_handle != NULL);
+		g_assert(data_handle != NULL);
 		g_assert(data_handle->protocol != NULL);
 		call_dissector_work(data_handle, tvb, pinfo, tree, TRUE);
 		return tvb_length(tvb);
@@ -1841,8 +1860,8 @@ call_dissector(dissector_handle_t handle, tvbuff_t *tvb,
 
 static void
 dissector_dump_decodes_display(const gchar *table_name,
-    ftenum_t selector_type _U_, gpointer key, gpointer value,
-    gpointer user_data _U_)
+			       ftenum_t selector_type _U_, gpointer key, gpointer value,
+			       gpointer user_data _U_)
 {
 	guint32 selector = (guint32)(unsigned long) key;
 	dissector_table_t sub_dissectors = find_dissector_table(table_name);
@@ -1890,38 +1909,38 @@ static guint num_of_postdissectors = 0;
 void
 register_postdissector(dissector_handle_t handle)
 {
-    if (!post_dissectors)
-        post_dissectors = g_ptr_array_new();
+	if (!post_dissectors)
+		post_dissectors = g_ptr_array_new();
 
-    g_ptr_array_add(post_dissectors, handle);
-    num_of_postdissectors++;
+	g_ptr_array_add(post_dissectors, handle);
+	num_of_postdissectors++;
 }
 
 gboolean
 have_postdissector()
 {
-    guint i;
-    dissector_handle_t handle;
+	guint i;
+	dissector_handle_t handle;
 
-    for(i = 0; i < num_of_postdissectors; i++) {
-	handle = (dissector_handle_t) g_ptr_array_index(post_dissectors,i);
+	for(i = 0; i < num_of_postdissectors; i++) {
+		handle = (dissector_handle_t) g_ptr_array_index(post_dissectors,i);
 
-	if (handle->protocol != NULL
-	    && proto_is_protocol_enabled(handle->protocol)) {
-	    /* We have at least one enabled postdissector */
-	    return TRUE;
+		if (handle->protocol != NULL
+		    && proto_is_protocol_enabled(handle->protocol)) {
+			/* We have at least one enabled postdissector */
+			return TRUE;
+		}
 	}
-    }
-    return FALSE;
+	return FALSE;
 }
 
 void
 call_all_postdissectors(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-    guint i;
+	guint i;
 
-    for(i = 0; i < num_of_postdissectors; i++) {
-        call_dissector_only((dissector_handle_t) g_ptr_array_index(post_dissectors,i),
-			    tvb,pinfo,tree);
-    }
+	for(i = 0; i < num_of_postdissectors; i++) {
+		call_dissector_only((dissector_handle_t) g_ptr_array_index(post_dissectors,i),
+				    tvb,pinfo,tree);
+	}
 }
