@@ -1,11 +1,11 @@
 /* plugins.h
  * definitions for plugins structures
  *
- * $Id: plugins.h 20261 2007-01-02 06:49:40Z guy $
+ * $Id: plugins.h 30675 2009-10-23 17:52:18Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
- * Copyright 1999 Gerald Combs
+ * Copyright 1998 Gerald Combs
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -37,17 +37,18 @@ typedef struct _plugin {
     void (*register_protoinfo)(void); /* routine to call to register protocol information */
     void (*reg_handoff)(void);    /* routine to call to register dissector handoff */
     void (*register_tap_listener)(void);   /* routine to call to register tap listener */
+    void (*register_wtap_module)(void);  /* routine to call to register a wiretap module */
+    void (*register_codec_module)(void);  /* routine to call to register a codec */
     struct _plugin *next;         /* forward link */
 } plugin;
 
 WS_VAR_IMPORT plugin *plugin_list;
 
 extern void init_plugins(void);
+extern void register_all_plugin_registrations(void);
 extern void register_all_plugin_handoffs(void);
 extern void register_all_plugin_tap_listeners(void);
-
-/* get the personal plugin dir */
-/* Return value is g_malloced so the caller should g_free() it. */
-extern char *get_plugins_pers_dir(void);
+extern void register_all_wiretap_modules(void);
+extern void register_all_codecs(void);
 
 #endif /* __PLUGINS_H__ */
