@@ -1,7 +1,7 @@
 /* prefs.h
  * Definitions for preference handling routines
  *
- * $Id: prefs.h 27166 2009-01-06 14:34:18Z rbalint $
+ * $Id: prefs.h 30136 2009-09-25 05:19:18Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -115,6 +115,7 @@ typedef struct _e_prefs {
   gint     gui_ptree_expander_style;
   gboolean gui_hex_dump_highlight_style;
   gint     gui_toolbar_main_style;
+  gint     gui_toolbar_filter_style;
   gchar   *gui_font_name;
   color_t  gui_marked_fg;
   color_t  gui_marked_bg;
@@ -149,6 +150,7 @@ typedef struct _e_prefs {
   gchar   *capture_devices_descr;
   gchar   *capture_devices_hide;
   gboolean capture_prom_mode;
+  gboolean capture_pcap_ng;
   gboolean capture_real_time;
   gboolean capture_auto_scroll;
   gboolean capture_show_info;
