@@ -9,7 +9,7 @@
  * 		the data of a backing tvbuff, or can be a composite of
  * 		other tvbuffs.
  *
- * $Id: tvbuff.h 35159 2010-12-08 22:48:31Z etxrab $
+ * $Id: tvbuff.h 29844 2009-09-10 16:54:02Z krj $
  *
  * Copyright (c) 2000 by Gilbert Ramirez <gram@alumni.rice.edu>
  *
@@ -44,9 +44,9 @@
  * "testy, virtual(-izable) buffer".  They are testy in that they get mad when
  * an attempt is made to access data beyond the bounds of their array. In that
  * case, they throw an exception.
- * 
- * They are virtualizable in that new tvbuff's can be made from other tvbuffs, 
- * while only the original tvbuff may have data. That is, the new tvbuff has 
+ *
+ * They are virtualizable in that new tvbuff's can be made from other tvbuffs,
+ * while only the original tvbuff may have data. That is, the new tvbuff has
  * virtual data.
  */
 
@@ -349,20 +349,6 @@ extern guint16 tvb_get_bits16(tvbuff_t *tvb, gint bit_offset, gint no_of_bits, g
 extern guint32 tvb_get_bits32(tvbuff_t *tvb, gint bit_offset, gint no_of_bits, gboolean little_endian);
 extern guint64 tvb_get_bits64(tvbuff_t *tvb, gint bit_offset, gint no_of_bits, gboolean little_endian);
 
-/* Fetch a specified number of bits from bit offset in a tvb, but allow number
- * of bits to range between 1 and 32. If the requested number of bits is known
- * beforehand, or its range can be handled by a single function of the group
- * above, use one of them instead.
- */
-extern guint32 tvb_get_bits(tvbuff_t *tvb, gint bit_offset, gint no_of_bits, gboolean little_endian);
-
-/* Fetch a specified number of bits from bit offset in a tvb, but allow number
- * of bits to range between 1 and 32. If the requested number of bits is known
- * beforehand, or its range can be handled by a single function of the group
- * above, use one of them instead.
- */
-extern guint32 tvb_get_bits(tvbuff_t *tvb, gint bit_offset, gint no_of_bits, gboolean little_endian);
-
 /** Returns target for convenience. Does not suffer from possible
  * expense of tvb_get_ptr(), since this routine is smart enough
  * to copy data in chunks if the request range actually exists in
@@ -386,6 +372,13 @@ extern void* ep_tvb_memdup(tvbuff_t *tvb, gint offset, size_t length);
  * this pointer is given to the user, there's no guarantee that the user will
  * honor the 'length' and not overstep the boundaries of the buffer.
  *
+ * If you're thinking of using tvb_get_ptr, STOP WHAT YOU ARE DOING
+ * IMMEDIATELY. Go take a break. Consider that tvb_get_ptr hands you
+ * a raw, unprotected pointer that you can easily use to create a
+ * security vulnerability or otherwise crash Wireshark. Then consider
+ * that you can probably find a function elsewhere in this file that
+ * does exactly what you want in a much more safe and robust manner.
+ *
  * The returned pointer is data that is internal to the tvbuff, so do not
  * attempt to free it. Don't modify the data, either, because another tvbuff
  * that might be using this tvbuff may have already copied that portion of
@@ -413,12 +406,11 @@ extern gint tvb_find_guint8(tvbuff_t*, gint offset, gint maxlength,
 
 /** Find first occurence of any of the needles in tvbuff, starting at offset.
  * Searches at most maxlength number of bytes. Returns the offset of the
- * found needle, or -1 if not found and the found needle.
- * Will not throw an exception, even if
+ * found needle, or -1 if not found. Will not throw an exception, even if
  * maxlength exceeds boundary of tvbuff; in that case, -1 will be returned if
  * the boundary is reached before finding needle. */
 extern gint tvb_pbrk_guint8(tvbuff_t *, gint offset, gint maxlength,
-    const guint8 *needles, guchar *found_needle);
+    const guint8 *needles);
 
 /** Find size of stringz (NUL-terminated string) by looking for terminating
  * NUL.  The size of the string includes the terminating NUL.
@@ -434,8 +426,8 @@ extern guint tvb_strsize(tvbuff_t *tvb, gint offset);
 extern gint tvb_strnlen(tvbuff_t*, gint offset, guint maxlength);
 
 /** Convert a string from Unicode to ASCII.  At the moment we fake it by
- * assuming all characters are ASCII  )-:  The len parameter is the number 
- * of guint16's to convert from Unicode. 
+ * assuming all characters are ASCII  )-:  The len parameter is the number
+ * of guint16's to convert from Unicode.
  *
  * tvb_fake_unicode() returns a buffer allocated by g_malloc() and must
  *                    be g_free() by the caller.
