@@ -1,7 +1,7 @@
 /* value_string.h
  * Definitions for value_string structures and routines
  *
- * $Id: value_string.h 20061 2006-12-07 20:29:40Z sfisher $
+ * $Id: value_string.h 29726 2009-09-06 04:26:50Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,6 +34,13 @@ typedef struct _value_string {
   const gchar   *strptr;
 } value_string;
 
+/* Struct for the str_to_str, match_strstr_idx, and match_strstr functions */
+
+typedef struct _string_string {
+  const gchar   *value;
+  const gchar   *strptr;
+} string_string;
+
 /* Struct for the rval_to_str, match_strrval_idx, and match_strrval functions */
 typedef struct _range_string {
   guint32        value_min;
@@ -58,6 +65,25 @@ extern const gchar* match_strval(guint32 val, const value_string *vs);
    Formats val with fmt, and returns the resulting string, on failure. */
 extern const gchar* val_to_str(guint32 val, const value_string *vs, const char *fmt);
 
+/* Tries to match val against each element in the value_string array vs.
+   Returns the associated string ptr on a match.
+   Returns 'unknown_str', on failure. */
+extern const gchar* val_to_str_const(guint32 val, const value_string *vs, const char *unknown_str);
+
+/* Tries to match val against each element in the value_string array vs.
+   Returns the associated string ptr, and sets "*idx" to the index in
+   that table, on a match, and returns NULL, and sets "*idx" to -1,
+   on failure. */
+extern const gchar* match_strstr_idx(const gchar *val, const string_string *vs, gint *idx);
+
+/* Like match_strval_idx(), but doesn't return the index. */
+extern const gchar* match_strstr(const gchar *val, const string_string *vs);
+
+/* Tries to match val against each element in the value_string array vs.
+   Returns the associated string ptr on a match.
+   Formats val with fmt, and returns the resulting string, on failure. */
+extern const gchar* str_to_str(const gchar *val, const string_string *vs, const char *fmt);
+
 /* Generate a string describing an enumerated bitfield (an N-bit field
    with various specific values having particular names). */
 extern const char *decode_enumerated_bitfield(guint32 val, guint32 mask,
