@@ -6,7 +6,7 @@
  * (c) 2006, Luis E. Garcia Ontanon <luis@ontanon.org>
  * (c) 2008, Balint Reczey <balint.reczey@ericsson.com>
  *
- * $Id: wslua_pinfo.c 25937 2008-08-05 21:03:46Z lego $
+ * $Id: wslua_pinfo.c 30517 2009-10-11 16:27:37Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -67,7 +67,7 @@ WSLUA_CLASS_DEFINE(Address,NOP,NOP); /* Represents an address */
 
 WSLUA_CONSTRUCTOR Address_ip(lua_State* L) {
 	/* Creates an Address Object representing an IP address. */
-	
+
 #define WSLUA_ARG_Address_ip_HOSTNAME 1 /* The address or name of the IP host. */
     Address addr = g_malloc(sizeof(address));
     guint32* ip_addr = g_malloc(sizeof(guint32));
@@ -79,7 +79,7 @@ WSLUA_CONSTRUCTOR Address_ip(lua_State* L) {
 
     SET_ADDRESS(addr, AT_IPv4, 4, ip_addr);
     pushAddress(L,addr);
-    WSLUA_RETURN(1); /* the Address object */
+    WSLUA_RETURN(1); /* The Address object */
 }
 
 #if 0
@@ -223,14 +223,14 @@ static int Address__gc(lua_State* L) {
     Address addr = checkAddress(L,1);
 
     if (addr) {
-        if (addr->data) g_free((void*)addr->data);
+        g_free((void*)addr->data);
         g_free((void*)addr);
     }
 
     return 0;
 }
 
-WSLUA_METAMETHOD Address__eq(lua_State* L) { /* compares two Addresses */
+WSLUA_METAMETHOD Address__eq(lua_State* L) { /* Compares two Addresses */
     Address addr1 = checkAddress(L,1);
     Address addr2 = checkAddress(L,2);
     gboolean result = FALSE;
@@ -243,7 +243,7 @@ WSLUA_METAMETHOD Address__eq(lua_State* L) { /* compares two Addresses */
     return 1;
 }
 
-WSLUA_METAMETHOD Address__le(lua_State* L) { /* compares two Addresses */
+WSLUA_METAMETHOD Address__le(lua_State* L) { /* Compares two Addresses */
     Address addr1 = checkAddress(L,1);
     Address addr2 = checkAddress(L,2);
     gboolean result = FALSE;
@@ -256,7 +256,7 @@ WSLUA_METAMETHOD Address__le(lua_State* L) { /* compares two Addresses */
     return 1;
 }
 
-WSLUA_METAMETHOD Address__lt(lua_State* L) { /* compares two Addresses */
+WSLUA_METAMETHOD Address__lt(lua_State* L) { /* Compares two Addresses */
     Address addr1 = checkAddress(L,1);
     Address addr2 = checkAddress(L,2);
     gboolean result = FALSE;
@@ -280,7 +280,7 @@ WSLUA_META Address_meta[] = {
 
 
 int Address_register(lua_State *L) {
-	WSLUA_REGISTER_CLASS(Address);
+    WSLUA_REGISTER_CLASS(Address);
     return 1;
 }
 
@@ -328,17 +328,10 @@ static const struct col_names_t colnames[] = {
     {"info",COL_INFO},
     {"packet_len",COL_PACKET_LENGTH},
     {"cumulative_bytes",COL_CUMULATIVE_BYTES},
-    {"oxid",COL_OXID},
-    {"rxid",COL_RXID},
     {"direction",COL_IF_DIR},
-    {"circuit_id",COL_CIRCUIT_ID},
-    {"src_idx",COL_SRCIDX},
-    {"dst_idx",COL_DSTIDX},
     {"vsan",COL_VSAN},
     {"tx_rate",COL_TX_RATE},
     {"rssi",COL_RSSI},
-    {"hpux_subsys",COL_HPUX_SUBSYS},
-    {"hpux_devid",COL_HPUX_DEVID},
     {"dce_call",COL_DCE_CALL},
     {NULL,0}
 };
@@ -384,7 +377,7 @@ static int Column__gc(lua_State* L) {
     Column col = checkColumn(L,1);
 
     if (!col) return 0;
-    
+
     if (!col->expired)
         col->expired = TRUE;
     else
@@ -409,13 +402,13 @@ WSLUA_METHOD Column_clear(lua_State *L) {
 WSLUA_METHOD Column_set(lua_State *L) {
 	/* Sets the text of a Column */
 #define WSLUA_ARG_Column_set_TEXT 2 /* The text to which to set the Column */
-	Column c = checkColumn(L,1);
+    Column c = checkColumn(L,1);
     const gchar* s = luaL_checkstring(L,WSLUA_ARG_Column_set_TEXT);
 
     if (!(c && c->cinfo))
-		return 0;
+        return 0;
 
-	if (!s) WSLUA_ARG_ERROR(Column_set,TEXT,"must be a string");
+    if (!s) WSLUA_ARG_ERROR(Column_set,TEXT,"must be a string");
 
     if (check_col(c->cinfo, c->col))
         col_set_str(c->cinfo, c->col, s);
@@ -429,11 +422,10 @@ WSLUA_METHOD Column_append(lua_State *L) {
     Column c = checkColumn(L,1);
     const gchar* s = luaL_checkstring(L,WSLUA_ARG_Column_append_TEXT);
 
-	if (!(c && c->cinfo))
-		return 0;
-
-	if (!s) WSLUA_ARG_ERROR(Column_append,TEXT,"must be a string");
+    if (!(c && c->cinfo))
+        return 0;
 
+    if (!s) WSLUA_ARG_ERROR(Column_append,TEXT,"must be a string");
 
     if (check_col(c->cinfo, c->col))
         col_append_str(c->cinfo, c->col, s);
@@ -447,10 +439,10 @@ WSLUA_METHOD Column_preppend(lua_State *L) {
     Column c = checkColumn(L,1);
     const gchar* s = luaL_checkstring(L,WSLUA_ARG_Column_prepend_TEXT);
 
-	if (!(c && c->cinfo))
-		return 0;
+    if (!(c && c->cinfo))
+        return 0;
 
-	if (!s) WSLUA_ARG_ERROR(Column_prepend,TEXT,"must be a string");
+    if (!s) WSLUA_ARG_ERROR(Column_prepend,TEXT,"must be a string");
 
     if (check_col(c->cinfo, c->col))
         col_prepend_fstr(c->cinfo, c->col, "%s",s);
@@ -475,7 +467,7 @@ WSLUA_META Column_meta[] = {
 
 
 int Column_register(lua_State *L) {
-	WSLUA_REGISTER_CLASS(Column);
+    WSLUA_REGISTER_CLASS(Column);
     return 1;
 }
 
@@ -490,13 +482,13 @@ WSLUA_CLASS_DEFINE(Columns,NOP,NOP);
 WSLUA_METAMETHOD Columns__tostring(lua_State *L) {
     lua_pushstring(L,"Columns");
     WSLUA_RETURN(1);
-	/* The string "Columns", no real use, just for debugging purposes. */
+    /* The string "Columns", no real use, just for debugging purposes. */
 }
 
 WSLUA_METAMETHOD Columns__newindex(lua_State *L) {
 	/* Sets the text of a specific column */
-#define WSLUA_ARG_Columns__newindex_COLUMN 2 /* the name of the column to set */
-#define WSLUA_ARG_Columns__newindex_TEXT 3 /* the text for the column */
+#define WSLUA_ARG_Columns__newindex_COLUMN 2 /* The name of the column to set */
+#define WSLUA_ARG_Columns__newindex_TEXT 3 /* The text for the column */
     Columns cols = checkColumns(L,1);
     const struct col_names_t* cn;
     const char* colname;
@@ -566,7 +558,7 @@ static int Columns_gc(lua_State* L) {
     Columns cols = checkColumns(L,1);
 
     if (!cols) return 0;
-    
+
     if (!cols->expired)
         cols->expired = TRUE;
     else
@@ -587,7 +579,7 @@ static const luaL_reg Columns_meta[] = {
 
 
 int Columns_register(lua_State *L) {
-	WSLUA_REGISTER_META(Columns);
+    WSLUA_REGISTER_META(Columns);
     return 1;
 }
 
@@ -634,6 +626,17 @@ static int Pinfo_tostring(lua_State *L) { lua_pushstring(L,"a Pinfo"); return 1;
     return 1; \
 }
 
+#define PINFO_GET_LIGHTUSERDATA(name, val) static int name(lua_State *L) { \
+    Pinfo pinfo = checkPinfo(L, 1); \
+    if (!pinfo) return 0; \
+    if (pinfo->expired) { \
+        luaL_error(L, "expired_pinfo"); \
+        return 0; \
+    } \
+    lua_pushlightuserdata(L, (void *) (val)); \
+    return 1; \
+}
+
 PINFO_GET_NUMBER(Pinfo_number,pinfo->ws_pinfo->fd->num)
 PINFO_GET_NUMBER(Pinfo_len,pinfo->ws_pinfo->fd->pkt_len)
 PINFO_GET_NUMBER(Pinfo_caplen,pinfo->ws_pinfo->fd->cap_len)
@@ -643,6 +646,8 @@ PINFO_GET_NUMBER(Pinfo_delta_ts,(((double)pinfo->ws_pinfo->fd->del_cap_ts.secs)
 PINFO_GET_NUMBER(Pinfo_delta_dis_ts,(((double)pinfo->ws_pinfo->fd->del_dis_ts.secs) + (((double)pinfo->ws_pinfo->fd->del_dis_ts.nsecs) / 1000000000.0) ))
 PINFO_GET_NUMBER(Pinfo_ipproto,pinfo->ws_pinfo->ipproto)
 PINFO_GET_NUMBER(Pinfo_circuit_id,pinfo->ws_pinfo->circuit_id)
+PINFO_GET_NUMBER(Pinfo_desegment_len,pinfo->ws_pinfo->desegment_len)
+PINFO_GET_NUMBER(Pinfo_desegment_offset,pinfo->ws_pinfo->desegment_offset)
 PINFO_GET_NUMBER(Pinfo_ptype,pinfo->ws_pinfo->ptype)
 PINFO_GET_NUMBER(Pinfo_src_port,pinfo->ws_pinfo->srcport)
 PINFO_GET_NUMBER(Pinfo_dst_port,pinfo->ws_pinfo->destport)
@@ -656,6 +661,8 @@ PINFO_GET_ADDRESS(Pinfo_dl_dst,dl_dst)
 PINFO_GET_ADDRESS(Pinfo_src,src)
 PINFO_GET_ADDRESS(Pinfo_dst,dst)
 
+PINFO_GET_LIGHTUSERDATA(Pinfo_private_data, pinfo->ws_pinfo->private_data)
+
 static int Pinfo_visited(lua_State *L) {
     Pinfo pinfo = checkPinfo(L,1);
     if (!pinfo) return 0;
@@ -695,7 +702,7 @@ static int Pinfo_columns(lua_State *L) {
         luaL_error(L,"expired_pinfo");
         return 0;
     }
-    
+
     cols = g_malloc(sizeof(struct _wslua_cols));
     cols->cinfo = pinfo->ws_pinfo->cinfo;
     cols->expired = FALSE;
@@ -723,6 +730,8 @@ typedef enum {
     PARAM_PORT_SRC,
     PARAM_PORT_DST,
     PARAM_CIRCUIT_ID,
+    PARAM_DESEGMENT_LEN,
+    PARAM_DESEGMENT_OFFSET,
     PARAM_PORT_TYPE
 } pinfo_param_type_t;
 
@@ -731,7 +740,7 @@ static int pushnil_param(lua_State* L, packet_info* pinfo _U_, pinfo_param_type_
     return 1;
 }
 
-int Pinfo_set_addr(lua_State* L, packet_info* pinfo, pinfo_param_type_t pt) {
+static int Pinfo_set_addr(lua_State* L, packet_info* pinfo, pinfo_param_type_t pt) {
     const address* from = checkAddress(L,1);
     address* to;
 
@@ -739,7 +748,7 @@ int Pinfo_set_addr(lua_State* L, packet_info* pinfo, pinfo_param_type_t pt) {
         luaL_error(L,"Not an OK address");
         return 0;
     }
-    
+
     if (!pinfo) {
         luaL_error(L,"expired_pinfo");
         return 0;
@@ -773,23 +782,29 @@ int Pinfo_set_addr(lua_State* L, packet_info* pinfo, pinfo_param_type_t pt) {
     return 0;
 }
 
-int Pinfo_set_int(lua_State* L, packet_info* pinfo, pinfo_param_type_t pt) {
-    guint v = luaL_checkint(L,1);
+static int Pinfo_set_int(lua_State* L, packet_info* pinfo, pinfo_param_type_t pt) {
+    gint64 v = luaL_checkint(L,1);
 
     if (!pinfo) {
         luaL_error(L,"expired_pinfo");
         return 0;
     }
-    
+
     switch(pt) {
         case PARAM_PORT_SRC:
-            pinfo->srcport = v;
+            pinfo->srcport = (guint32)v;
             return 0;
         case PARAM_PORT_DST:
-            pinfo->destport = v;
+            pinfo->destport = (guint32)v;
             return 0;
         case PARAM_CIRCUIT_ID:
-            pinfo->circuit_id = v;
+            pinfo->circuit_id = (guint32)v;
+            return 0;
+        case PARAM_DESEGMENT_LEN:
+            pinfo->desegment_len = (guint32)v;
+            return 0;
+        case PARAM_DESEGMENT_OFFSET:
+            pinfo->desegment_offset = (int)v;
             return 0;
         default:
             g_assert(!"BUG: A bad parameter");
@@ -807,42 +822,42 @@ typedef struct _pinfo_method_t {
 
 static int Pinfo_hi(lua_State *L) {
     Pinfo pinfo = checkPinfo(L,1);
-	Address addr = g_malloc(sizeof(address));
+    Address addr = g_malloc(sizeof(address));
 
-	if (!pinfo) return 0;
-        if (pinfo->expired) {
+    if (!pinfo) return 0;
+    if (pinfo->expired) {
         luaL_error(L,"expired_pinfo");
         return 0;
     }
 
-	if (CMP_ADDRESS(&(pinfo->ws_pinfo->src), &(pinfo->ws_pinfo->dst) ) >= 0) {
-		COPY_ADDRESS(addr, &(pinfo->ws_pinfo->src));
-	} else {
-		COPY_ADDRESS(addr, &(pinfo->ws_pinfo->dst));
-	}
+    if (CMP_ADDRESS(&(pinfo->ws_pinfo->src), &(pinfo->ws_pinfo->dst) ) >= 0) {
+        COPY_ADDRESS(addr, &(pinfo->ws_pinfo->src));
+    } else {
+        COPY_ADDRESS(addr, &(pinfo->ws_pinfo->dst));
+    }
 
-	pushAddress(L,addr);
-	return 1;
+    pushAddress(L,addr);
+    return 1;
 }
 
 static int Pinfo_lo(lua_State *L) {
     Pinfo pinfo = checkPinfo(L,1);
-	Address addr = g_malloc(sizeof(address));
+    Address addr = g_malloc(sizeof(address));
 
-	if (!pinfo) return 0;
-        if (pinfo->expired) {
+    if (!pinfo) return 0;
+    if (pinfo->expired) {
         luaL_error(L,"expired_pinfo");
         return 0;
     }
 
-	if (CMP_ADDRESS(&(pinfo->ws_pinfo->src), &(pinfo->ws_pinfo->dst) ) < 0) {
-		COPY_ADDRESS(addr, &(pinfo->ws_pinfo->src));
-	} else {
-		COPY_ADDRESS(addr, &(pinfo->ws_pinfo->dst));
-	}
+    if (CMP_ADDRESS(&(pinfo->ws_pinfo->src), &(pinfo->ws_pinfo->dst) ) < 0) {
+        COPY_ADDRESS(addr, &(pinfo->ws_pinfo->src));
+    } else {
+        COPY_ADDRESS(addr, &(pinfo->ws_pinfo->dst));
+    }
 
-	pushAddress(L,addr);
-	return 1;
+    pushAddress(L,addr);
+    return 1;
 }
 
 
@@ -920,10 +935,19 @@ static const pinfo_method_t Pinfo_methods[] = {
 	/* WSLUA_ATTRIBUTE Pinfo_columns RO Accesss to the packet list columns */
     {"columns", Pinfo_columns, pushnil_param, PARAM_NONE },
 
-	/* WSLUA_ATTRIBUTE Pinfo_cols RO Accesss to the packet list columns (equivalent to pinfo.cols) */
+	/* WSLUA_ATTRIBUTE Pinfo_cols RO Accesss to the packet list columns (equivalent to pinfo.columns) */
     {"cols", Pinfo_columns, pushnil_param, PARAM_NONE },
-	
-	{NULL,NULL,NULL,PARAM_NONE}
+
+	/* WSLUA_ATTRIBUTE Pinfo_desegment_len RW Estimated number of additional bytes required for completing the PDU */
+    {"desegment_len", Pinfo_desegment_len, Pinfo_set_int,  PARAM_DESEGMENT_LEN },
+
+	/* WSLUA_ATTRIBUTE Pinfo_desegment_offset RW Offset in the tvbuff at which the dissector will continue processing when next called*/
+    {"desegment_offset", Pinfo_desegment_offset, Pinfo_set_int,  PARAM_DESEGMENT_OFFSET },
+
+	/* WSLUA_ATTRIBUTE Pinfo_private_data RO Access to private data */
+    {"private_data", Pinfo_private_data, pushnil_param, PARAM_NONE},
+
+    {NULL,NULL,NULL,PARAM_NONE}
 };
 
 
@@ -990,7 +1014,7 @@ static int Pinfo_gc(lua_State* L) {
     Pinfo pinfo = checkPinfo(L,1);
 
     if (!pinfo) return 0;
-    
+
     if (!pinfo->expired)
         pinfo->expired = TRUE;
     else
@@ -1009,7 +1033,7 @@ static const luaL_reg Pinfo_meta[] = {
 };
 
 int Pinfo_register(lua_State* L) {
-	WSLUA_REGISTER_META(Pinfo);
+    WSLUA_REGISTER_META(Pinfo);
     outstanding_Pinfo = g_ptr_array_new();
     outstanding_Column = g_ptr_array_new();
     outstanding_Columns = g_ptr_array_new();
