@@ -1,9 +1,9 @@
 /*
  *  wslua_util.c
  *  
- * (c) 2006, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
+ * (c) 2006, Luis E. Garcia Ontanon <luis@ontanon.org>
  * 
- * $Id: wslua_util.c 24501 2008-02-29 02:09:22Z wmeier $
+ * $Id: wslua_util.c 30517 2009-10-11 16:27:37Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -67,11 +67,11 @@ WSLUA_FUNCTION wslua_format_date(lua_State* LS) { /* Formats an absolute timesta
 	str = abs_time_to_str(&then);    
 	lua_pushstring(LS,str);
 
-	WSLUA_RETURN(1); /* a string with the formated date */
+	WSLUA_RETURN(1); /* A string with the formated date */
 }
 
 WSLUA_FUNCTION wslua_format_time(lua_State* LS) { /* Formats a relative timestamp in a human readable form */
-#define WSLUA_ARG_format_time_TIMESTAMP 1 /* a timestamp value to convert */
+#define WSLUA_ARG_format_time_TIMESTAMP 1 /* A timestamp value to convert */
 	lua_Number time = luaL_checknumber(LS,WSLUA_ARG_format_time_TIMESTAMP);
 	nstime_t then;
 	gchar* str;
@@ -81,11 +81,11 @@ WSLUA_FUNCTION wslua_format_time(lua_State* LS) { /* Formats a relative timestam
 	str = rel_time_to_str(&then);    
 	lua_pushstring(LS,str);
 
-	WSLUA_RETURN(1); /* a string with the formated time */
+	WSLUA_RETURN(1); /* A string with the formated time */
 }
 
-WSLUA_FUNCTION wslua_report_failure(lua_State* LS) { /* reports a failure to the user */
-#define WSLUA_ARG_report_failure_TEXT 1 /* message */
+WSLUA_FUNCTION wslua_report_failure(lua_State* LS) { /* Reports a failure to the user */
+#define WSLUA_ARG_report_failure_TEXT 1 /* Message */
 	const gchar* s = luaL_checkstring(LS,WSLUA_ARG_report_failure_TEXT);
 	report_failure("%s",s);
 	return 0;
@@ -93,7 +93,7 @@ WSLUA_FUNCTION wslua_report_failure(lua_State* LS) { /* reports a failure to the
 
 static int wslua_log(lua_State* L, GLogLevelFlags log_level) {
     GString* str = g_string_new("");
-    int n = lua_gettop(L);  /* number of arguments */
+    int n = lua_gettop(L);  /* Number of arguments */
     int i;
     
     lua_getglobal(L, "tostring");
@@ -186,7 +186,7 @@ static char* wslua_get_actual_filename(const char* fname) {
 WSLUA_FUNCTION wslua_loadfile(lua_State* L) {
 	/* Lua's loadfile() has been modified so that if a file does not exist
 	in the current directory it will look for it in wireshark's user and system directories */
-#define WSLUA_ARG_loadfile_FILENAME 1 /* name of the file to be loaded */
+#define WSLUA_ARG_loadfile_FILENAME 1 /* Name of the file to be loaded */
 	const char *given_fname = luaL_checkstring(L, WSLUA_ARG_loadfile_FILENAME);
 	char* filename;
 	
@@ -208,7 +208,7 @@ WSLUA_FUNCTION wslua_loadfile(lua_State* L) {
 WSLUA_FUNCTION wslua_dofile(lua_State* L) {
 	/* Lua's dofile() has been modified so that if a file does not exist
 	in the current directory it will look for it in wireshark's user and system directories */
-#define WSLUA_ARG_dofile_FILENAME 1 /* name of the file to be run */
+#define WSLUA_ARG_dofile_FILENAME 1 /* Name of the file to be run */
 	const char *given_fname = luaL_checkstring(L, WSLUA_ARG_dofile_FILENAME);
 	char* filename;
 	int n;
@@ -228,30 +228,30 @@ WSLUA_FUNCTION wslua_dofile(lua_State* L) {
 
 
 WSLUA_FUNCTION wslua_persconffile_path(lua_State* L) {
-#define WSLUA_OPTARG_persconffile_path_FILENAME 1 /* a filename */
+#define WSLUA_OPTARG_persconffile_path_FILENAME 1 /* A filename */
 	const char *fname = luaL_optstring(L, WSLUA_OPTARG_persconffile_path_FILENAME,"");
 	const char* filename = get_persconffile_path(fname,FALSE,FALSE);
 	
 	lua_pushstring(L,filename);
-	WSLUA_RETURN(1); /* the full pathname for a file in the personal configuration directory */
+	WSLUA_RETURN(1); /* The full pathname for a file in the personal configuration directory */
 }
 
 WSLUA_FUNCTION wslua_datafile_path(lua_State* L) {
-#define WSLUA_OPTARG_datafile_path_FILENAME 1 /* a filename */
+#define WSLUA_OPTARG_datafile_path_FILENAME 1 /* A filename */
 	const char *fname = luaL_optstring(L, WSLUA_OPTARG_datafile_path_FILENAME,"");
 	const char* filename = get_datafile_path(fname);
 
 	lua_pushstring(L,filename);
-	WSLUA_RETURN(1); /* the full pathname for a file in wireshark's configuration directory */
+	WSLUA_RETURN(1); /* The full pathname for a file in wireshark's configuration directory */
 }
 
 
 WSLUA_CLASS_DEFINE(Dir,NOP,NOP); /* A Directory */
 
 WSLUA_CONSTRUCTOR Dir_open(lua_State* L) {
-	/* usage: for filename in Dir.open(path) do ... end */
-#define WSLUA_ARG_Dir_open_PATHNAME 1 /* the pathname of the directory */
-#define WSLUA_OPTARG_Dir_open_EXTENSION 2 /* if given, only file with this extension will be returned */
+	/* Usage: for filename in Dir.open(path) do ... end */
+#define WSLUA_ARG_Dir_open_PATHNAME 1 /* The pathname of the directory */
+#define WSLUA_OPTARG_Dir_open_EXTENSION 2 /* If given, only file with this extension will be returned */
 	
 	const char* dirname = luaL_checkstring(L,WSLUA_ARG_Dir_open_PATHNAME);
 	const char* extension = luaL_optstring(L,WSLUA_OPTARG_Dir_open_EXTENSION,NULL);
@@ -272,15 +272,11 @@ WSLUA_CONSTRUCTOR Dir_open(lua_State* L) {
 	dir->dir = OPENDIR_OP(dirname_clean);
 	g_free(dirname_clean);
 	dir->ext = extension ? g_strdup(extension) : NULL;
-#if GLIB_MAJOR_VERSION >= 2
 	dir->dummy = g_malloc(sizeof(GError *));
 	*(dir->dummy) = NULL;
-#endif
 	
 	if (dir->dir == NULL) {
-#if GLIB_MAJOR_VERSION >= 2
 		g_free(dir->dummy);
-#endif
 		g_free(dir);
 
 		WSLUA_ARG_ERROR(Dir_open,PATHNAME,"could not open directory");
@@ -292,15 +288,17 @@ WSLUA_CONSTRUCTOR Dir_open(lua_State* L) {
 }
 
 WSLUA_METAMETHOD Dir__call(lua_State* L) {
-/* at every invocation will return one file (nil when done) */
+	/* At every invocation will return one file (nil when done) */
 
 	Dir dir = checkDir(L,1);
 	const FILE_T* file;
 	const gchar* filename;
 	const char* ext;
 	
-	if (!dir) 
+	if (!dir) {
 		luaL_argerror(L,1,"must be a Dir");
+		return 0;
+	}
 
 	if (!dir->dir) {
 		return 0;
@@ -336,7 +334,7 @@ WSLUA_METAMETHOD Dir__call(lua_State* L) {
 }
 
 WSLUA_METHOD Dir_close(lua_State* L) {
-/* closes the directory */
+	/* Closes the directory */
 	Dir dir = checkDir(L,1);
 
 	if (dir->dir) {
@@ -347,16 +345,14 @@ WSLUA_METHOD Dir_close(lua_State* L) {
 	return 0;
 }
 
-WSLUA_METAMETHOD wslua_Dir__gc(lua_State* L) {
+static int wslua_Dir__gc(lua_State* L) {
 	Dir dir = checkDir(L,1);
 	
 	if (dir->dir) {
 		CLOSEDIR_OP(dir->dir);
 	}
 	
-#if GLIB_MAJOR_VERSION >= 2
 	g_free(dir->dummy);
-#endif
 	
 	if (dir->ext) g_free(dir->ext);
 
@@ -368,13 +364,13 @@ WSLUA_METAMETHOD wslua_Dir__gc(lua_State* L) {
 static const luaL_reg Dir_methods[] = {
     {"open", Dir_open},
     {"close", Dir_close},
-    {0, 0}
+    { NULL, NULL }
 };
 
 static const luaL_reg Dir_meta[] = {
     {"__call", Dir__call},
     {"__gc", wslua_Dir__gc},
-    {0, 0}
+    { NULL, NULL }
 };
 
 int Dir_register(lua_State* L) {
@@ -390,12 +386,12 @@ typedef struct _statcmd_t {
 	int func_ref;
 } statcmd_t;
 
-int statcmd_init_cb_error_handler(lua_State* L) {
+static int statcmd_init_cb_error_handler(lua_State* L) {
 	(void)L;
 	return 0;
 }
 
-void statcmd_init(const char *optarg, void* userdata) {
+static void statcmd_init(const char *optarg, void* userdata) {
 	statcmd_t* sc = userdata;
     lua_State* L = sc->L;
     
@@ -423,8 +419,8 @@ void statcmd_init(const char *optarg, void* userdata) {
 
 WSLUA_FUNCTION wslua_register_stat_cmd_arg(lua_State* L) {
 	/*  Register a function to handle a -z option */
-#define WSLUA_ARG_register_stat_cmd_arg_ARGUMENT 1 /*  */
-#define WSLUA_OPTARG_register_stat_cmd_arg_ACTION 2 /*  */
+#define WSLUA_ARG_register_stat_cmd_arg_ARGUMENT 1 /* Argument */
+#define WSLUA_OPTARG_register_stat_cmd_arg_ACTION 2 /* Action */
 	const char* arg = luaL_checkstring(L,WSLUA_ARG_register_stat_cmd_arg_ARGUMENT);
 	statcmd_t* sc = g_malloc0(sizeof(statcmd_t)); /* XXX leaked */
 	
