@@ -1,7 +1,7 @@
 /* file.h
  * Definitions for file structures and routines
  *
- * $Id: file.h 32655 2010-05-04 00:20:39Z gerald $
+ * $Id: file.h 29625 2009-08-30 10:35:48Z sake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -169,24 +169,6 @@ cf_status_t cf_save(capture_file * cf, const char *fname, packet_range_t *range,
  */
 const gchar *cf_get_display_name(capture_file *cf);
 
-/**
- * Set the source of the capture data for temporary files, e.g.
- * "Interface eth0" or "Pipe from Pong"
- *
- * @param cf the capture file
- * @param source the source description. this will be copied internally.
- */
-void cf_set_tempfile_source(capture_file *cf, gchar *source);
-
-/**
- * Get the source of the capture data for temporary files. Guaranteed to
- * return a non-null value. The returned value should not be freed.
- *
- * @param cf the capture file
- * @param source the source description. this will be copied internally.
- */
-const gchar *cf_get_tempfile_source(capture_file *cf);
-
 /**
  * Get the number of packets in the capture file.
  * 
@@ -275,7 +257,12 @@ cf_status_t cf_filter_packets(capture_file *cf, gchar *dfilter, gboolean force);
 void cf_reftime_packets(capture_file *cf);
 
 /**
- * At least one "Refence Time" flag has changed, rescan all packets.
+ * Return the time it took to load the file
+ */
+gulong cf_get_computed_elapsed(void);
+
+/**
+ * The coloring rules have changed, redo coloring
  * 
  * @param cf the capture file
  */
@@ -292,10 +279,9 @@ void cf_redissect_packets(capture_file *cf);
  * Rescan all packets and just run taps - don't reconstruct the display.
  * 
  * @param cf the capture file
- * @param do_columns TRUE if columns are to be generated, FALSE otherwise
  * @return one of cf_read_status_t
  */
-cf_read_status_t cf_retap_packets(capture_file *cf, gboolean do_columns);
+cf_read_status_t cf_retap_packets(capture_file *cf);
 
 /**
  * The time format has changed, rescan all packets.
@@ -304,6 +290,13 @@ cf_read_status_t cf_retap_packets(capture_file *cf, gboolean do_columns);
  */
 void cf_change_time_formats(capture_file *cf);
 
+/**
+ * Adjust timestamp precision if auto is selected.
+ * 
+ * @param cf the capture file
+ */
+void cf_timestamp_auto_precision(capture_file *cf);
+
 /**
  * Print the capture file.
  * 
