@@ -1,7 +1,7 @@
 /* capture_file_dlg.c
  * Dialog boxes for handling capture files
  *
- * $Id: capture_file_dlg.c 33115 2010-06-06 22:13:16Z gerald $
+ * $Id: capture_file_dlg.c 30181 2009-09-28 17:44:06Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -58,9 +58,12 @@
 #include "gtk/capture_file_dlg.h"
 #include "gtk/drag_and_drop.h"
 #include "gtk/main.h"
-#include "gtk/main_menu.h"
+#include "gtk/menus.h"
 #include "gtk/recent.h"
 #include "gtk/color_dlg.h"
+#ifdef NEW_PACKET_LIST
+#include "gtk/new_packet_list.h"
+#endif
 #ifdef HAVE_LIBPCAP
 #include "gtk/capture_dlg.h"
 #endif
@@ -118,7 +121,6 @@ static GtkWidget *file_save_as_w;
 static packet_range_t range;
 static gboolean color_selected;
 static int filetype;
-static GtkWidget *cfselect_cb;
 static GtkWidget *ft_om;
 static GtkWidget *range_tb;
 
@@ -323,7 +325,7 @@ static void
 file_open_entry_changed(GtkWidget *w _U_, gpointer file_sel)
 {
     GtkWidget *prev = g_object_get_data(G_OBJECT(file_sel), PREVIEW_TABLE_KEY);
-    const gchar* cf_name;
+    gchar *cf_name;
     gboolean have_preview;
     wtap       *wth;
 
@@ -334,35 +336,14 @@ file_open_entry_changed(GtkWidget *w _U_, gpointer file_sel)
     wth = preview_set_filename(prev, cf_name);
     have_preview = (wth != NULL);
 
+    g_free(cf_name);
+
     /* make the preview widget sensitive */
     gtk_widget_set_sensitive(prev, have_preview);
 
-    /*
-     * XXX - if the Open button isn't sensitive, you can't type into
-     * the location bar and select the file or directory you've typed.
-     * See
-     *
-     *	https://bugs.wireshark.org/bugzilla/show_bug.cgi?id=1791
-     *
-     * It's not as if allowing users to click Open when they've
-     * selected a file that's not a valid capture file will cause
-     * anything worse than an error dialog, so we'll leave the Open
-     * button sensitive for now.  Perhaps making it sensitive if
-     * cf_name is NULL would also work, although I don't know whether
-     * there are any cases where it would be non-null when you've
-     * typed in the location bar.
-     *
-     * XXX - Bug 1791 also notes that, with the line removed, Bill
-     * Meier "somehow managed to get the file chooser window somewhat
-     * wedged in that neither the cancel or open buttons were responsive".
-     * That seems a bit odd, given that, without this line, we're not
-     * monkeying with the Open button's sensitivity, but...
-     */
-#if 0
     /* make the open/save/... dialog button sensitive */
 
     gtk_dialog_set_response_sensitive(file_sel, GTK_RESPONSE_ACCEPT, have_preview);
-#endif
 
     /* do the actual preview */
     if(have_preview)
@@ -623,7 +604,7 @@ file_open_ok_cb(GtkWidget *w, gpointer fs) {
   dfilter_t   *rfcode = NULL;
   int          err;
 
-  cf_name = g_strdup(gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fs)));
+  cf_name = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fs));
   filter_te = g_object_get_data(G_OBJECT(w), E_RFILTER_TE_KEY);
   rfilter = gtk_entry_get_text(GTK_ENTRY(filter_te));
   if (!dfilter_compile(rfilter, &rfcode)) {
@@ -711,7 +692,9 @@ file_open_ok_cb(GtkWidget *w, gpointer fs) {
      "get_dirname()" does write over its argument. */
   s = get_dirname(cf_name);
   set_last_open_dir(s);
+#ifndef NEW_PACKET_LIST
   gtk_widget_grab_focus(packet_list);
+#endif
 
   g_free(cf_name);
 }
@@ -737,8 +720,13 @@ file_merge_cmd(GtkWidget *w)
 {
 #if _WIN32
   win32_merge_file(GDK_WINDOW_HWND(top_level->window));
+#ifdef NEW_PACKET_LIST
+  new_packet_list_freeze();
+  new_packet_list_thaw();
+#else
   packet_list_freeze();
   packet_list_thaw();
+#endif /* NEW_PACKET_LIST */
 #else /* _WIN32 */
   GtkWidget	*main_hb, *main_vb, *ft_hb, *ft_lb, *filter_hbox,
 		*filter_bt, *filter_te, *prepend_rb, *chrono_rb,
@@ -937,7 +925,7 @@ file_merge_ok_cb(GtkWidget *w, gpointer fs) {
   char        *in_filenames[2];
   char        *tmpname;
 
-  cf_name = g_strdup(gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fs)));
+  cf_name = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fs));
   filter_te = g_object_get_data(G_OBJECT(w), E_RFILTER_TE_KEY);
   rfilter = gtk_entry_get_text(GTK_ENTRY(filter_te));
   if (!dfilter_compile(rfilter, &rfcode)) {
@@ -1041,7 +1029,9 @@ file_merge_ok_cb(GtkWidget *w, gpointer fs) {
      "get_dirname()" does write over its argument. */
   s = get_dirname(tmpname);
   set_last_open_dir(s);
+#ifndef NEW_PACKET_LIST
   gtk_widget_grab_focus(packet_list);
+#endif
 }
 
 static void
@@ -1302,7 +1292,7 @@ file_save_as_cb(GtkWidget *w _U_, gpointer fs) {
   GtkWidget *compressed_cb;
 
 
-  cf_name = g_strdup(gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fs)));
+  cf_name = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fs));
 
   compressed_cb = g_object_get_data(G_OBJECT(file_save_as_w), "compressed");
 
@@ -1375,7 +1365,7 @@ static void file_save_as_exists_answered_cb(gpointer dialog _U_, gint btn, gpoin
 {
     gchar	*cf_name;
 
-    cf_name = g_strdup(gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(data)));
+    cf_name = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(data));
 
     switch(btn) {
     case(ESD_BTN_OK):
@@ -1393,6 +1383,7 @@ static void file_save_as_exists_answered_cb(gpointer dialog _U_, gint btn, gpoin
     default:
         g_assert_not_reached();
     }
+    g_free(cf_name);
 }
 
 
@@ -1402,7 +1393,7 @@ file_save_as_ok_cb(GtkWidget *w _U_, gpointer fs) {
   gchar	*cf_name;
   gpointer  dialog;
 
-  cf_name = g_strdup(gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fs)));
+  cf_name = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fs));
 
   /* Perhaps the user specified a directory instead of a file.
      Check whether they did. */
@@ -1569,7 +1560,7 @@ file_color_import_ok_cb(GtkWidget *w, gpointer color_filters) {
   gchar     *cf_name, *s;
   GtkWidget *fs = gtk_widget_get_toplevel(w);
 
-  cf_name = g_strdup(gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fs)));
+  cf_name = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fs));
 
   /* Perhaps the user specified a directory instead of a file.
      Check whether they did. */
@@ -1593,8 +1584,7 @@ file_color_import_ok_cb(GtkWidget *w, gpointer color_filters) {
     /* XXX - as we cannot start a new event loop (using gtk_dialog_run()),
      * as this will prevent the user from closing the now existing error
      * message, simply close the dialog (this is the best we can do here). */
-    if (file_save_as_w)
-      window_destroy(GTK_WIDGET (fs));
+    window_destroy(GTK_WIDGET (fs));
 
     return;
   }
@@ -1607,7 +1597,9 @@ file_color_import_ok_cb(GtkWidget *w, gpointer color_filters) {
      "get_dirname()" does write over its argument. */
   s = get_dirname(cf_name);
   set_last_open_dir(s);
+#ifndef NEW_PACKET_LIST
   gtk_widget_grab_focus(packet_list);
+#endif
 
   g_free(cf_name);
 }
@@ -1661,6 +1653,7 @@ file_color_export_cmd_cb(GtkWidget *w _U_, gpointer filter_list)
   win32_export_color_file(GDK_WINDOW_HWND(top_level->window), filter_list);
 #else /* _WIN32 */
   GtkWidget *main_vb, *cfglobal_but;
+  GtkWidget *cfselect_cb;
 
   if (file_color_export_w != NULL) {
     /* There's already an "Color Filter Export" dialog box; reactivate it. */
@@ -1668,9 +1661,7 @@ file_color_export_cmd_cb(GtkWidget *w _U_, gpointer filter_list)
     return;
   }
 
-  /* Default to saving all packets, in the file's current format. */
   color_selected   = FALSE;
-  filetype = cfile.cd_t;
 
   file_color_export_w = file_selection_new("Wireshark: Export Color Filters",
                                            FILE_SELECTION_SAVE);
@@ -1712,7 +1703,7 @@ file_color_export_ok_cb(GtkWidget *w, gpointer filter_list) {
   gchar	*dirname;
   GtkWidget *fs = gtk_widget_get_toplevel(w);
 
-  cf_name = g_strdup(gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fs)));
+  cf_name = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fs));
 
   /* Perhaps the user specified a directory instead of a file.
      Check whether they did. */
@@ -1738,8 +1729,7 @@ file_color_export_ok_cb(GtkWidget *w, gpointer filter_list) {
       /* XXX - as we cannot start a new event loop (using gtk_dialog_run()),
        * as this will prevent the user from closing the now existing error
        * message, simply close the dialog (this is the best we can do here). */
-      if (file_save_as_w)
-        window_destroy(GTK_WIDGET (fs));
+       window_destroy(GTK_WIDGET (fs));
 
        return;
    }
