@@ -1,7 +1,7 @@
 /* color_dlg.c
  * Definitions for dialog boxes for color filters
  *
- * $Id: color_dlg.c 28108 2009-04-21 16:57:52Z guy $
+ * $Id: color_dlg.c 30102 2009-09-23 18:36:50Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -51,6 +51,9 @@
 #include "gtk/gtkglobals.h"
 #include "gtk/help_dlg.h"
 #include "gtk/color_edit_dlg.h"
+#ifdef NEW_PACKET_LIST 
+#include "gtk/new_packet_list.h" 
+#endif /* NEW_PACKET_LIST */ 
 
 
 #define BUTTON_SIZE_X -1
@@ -307,7 +310,7 @@ colorize_dialog_new (char *filter)
   store = gtk_list_store_new(6, 
                                  G_TYPE_STRING, 
                                  G_TYPE_STRING,
-                             G_TYPE_STRING, 
+                                 G_TYPE_STRING, 
                                  G_TYPE_STRING, 
                                  G_TYPE_BOOLEAN, 
                                  G_TYPE_POINTER);
@@ -715,7 +718,6 @@ select_row(GtkWidget *color_filters, int row)
 }
 
 
-
 /* add a single color filter to the list */
 static void
 add_filter_to_list(gpointer filter_arg, gpointer list_arg)
@@ -778,7 +780,11 @@ create_new_color_filter(GtkButton *button, const char *filter)
   gtk_tree_selection_unselect_all (sel);
 
   /* Use the default background and foreground colors as the colors. */
-  style = gtk_widget_get_style(packet_list);
+#ifdef NEW_PACKET_LIST 
+  style = gtk_widget_get_style(new_packet_list_get_widget()); 
+#else 
+   style = gtk_widget_get_style(packet_list); 
+#endif /* NEW_PACKET_LIST */ 
   gdkcolor_to_color_t(&bg_color, &style->base[GTK_STATE_NORMAL]);
   gdkcolor_to_color_t(&fg_color, &style->text[GTK_STATE_NORMAL]);
 
@@ -1023,7 +1029,11 @@ color_apply_cb(GtkButton *button _U_, gpointer user_data _U_)
   color_filters_apply(color_filter_tmp_list, color_filter_edit_list);
 
   /* colorize list */
+#ifdef NEW_PACKET_LIST
+  new_packet_list_colorize_packets();
+#else
   cf_colorize_packets(&cfile);
+#endif /* NEW_PACKET_LIST */
 }
 
 /* User pressed the "Save" button: save the color filters to the
