@@ -1,7 +1,7 @@
 /* dnd.c
  * Drag and Drop
  *
- * $Id: drag_and_drop.c 26641 2008-10-31 09:53:56Z stig $
+ * $Id: drag_and_drop.c 28892 2009-06-30 18:05:04Z sfisher $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -48,7 +48,7 @@
 #include "gtk/capture_file_dlg.h"
 #include "gtk/drag_and_drop.h"
 #include "gtk/main.h"
-#include "gtk/main_menu.h"
+#include "gtk/menus.h"
 #ifdef HAVE_LIBPCAP
 #include "gtk/capture_globals.h"
 #endif
@@ -194,7 +194,9 @@ dnd_merge_files(int in_file_count, char **in_filenames)
 	return;
     }
 
+#ifndef NEW_PACKET_LIST
     gtk_widget_grab_focus(packet_list);
+#endif
 }
 
 /* open/merge the dnd file */
