@@ -1,7 +1,7 @@
 /* follow_udp.c
  * UDP specific routines for following traffic streams
  *
- * $Id: follow_udp.c 28062 2009-04-16 00:45:26Z gerald $
+ * $Id: follow_udp.c 28645 2009-06-05 22:42:47Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -151,7 +151,7 @@ follow_udp_stream_cb(GtkWidget *w, gpointer data _U_)
 
 	/* data will be passed via tap callback*/
 	msg = register_tap_listener("udp_follow", follow_info, follow_filter,
-				    NULL, udp_queue_packet_data, NULL);
+				    0, NULL, udp_queue_packet_data, NULL);
 	if (msg) {
 		simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
 			      "Can't register udp_follow tap: %s\n",
