@@ -1,6 +1,6 @@
 /* help_dlg.c
  *
- * $Id: help_dlg.c 27776 2009-03-18 16:21:45Z martinm $
+ * $Id: help_dlg.c 29948 2009-09-16 19:23:15Z gerald $
  *
  * Laurent Deniel <laurent.deniel@free.fr>
  *
@@ -170,6 +170,9 @@ topic_online_url(topic_action_e action)
     case(ONLINEPAGE_SECURITY):
         return "http://wiki.wireshark.org/Security";
         break;
+    case(ONLINEPAGE_CHIMNEY):
+        return "http://wiki.wireshark.org/CaptureSetup/Offloading#chimney";
+        break;
     default:
         return NULL;
     }
@@ -283,6 +286,9 @@ topic_action(topic_action_e action)
     case(HELP_STATS_IO_GRAPH_DIALOG):
         help_topic_html("ChStatIOGraphs.html");
         break;
+    case(HELP_STATS_COMPARE_FILES_DIALOG):
+        help_topic_html("ChStatCompareCaptureFiles.html");
+        break;
     case(HELP_STATS_LTE_MAC_TRAFFIC_DIALOG):
         help_topic_html("ChStatLTEMACTraffic.html");
         break;
