@@ -1,6 +1,6 @@
 /* help_dlg.h
  *
- * $Id: help_dlg.h 27776 2009-03-18 16:21:45Z martinm $
+ * $Id: help_dlg.h 29948 2009-09-16 19:23:15Z gerald $
  *
  * Laurent Deniel <laurent.deniel@free.fr>
  *
@@ -44,6 +44,7 @@ typedef enum {
     ONLINEPAGE_NETWORK_MEDIA,
     ONLINEPAGE_SAMPLE_CAPTURES,
     ONLINEPAGE_SECURITY,
+    ONLINEPAGE_CHIMNEY,
 
     /* local manual pages */
     LOCALPAGE_MAN_WIRESHARK = 100,
@@ -79,6 +80,7 @@ typedef enum {
     HELP_STATS_ENDPOINTS_DIALOG,
     HELP_STATS_CONVERSATIONS_DIALOG,
     HELP_STATS_IO_GRAPH_DIALOG,
+    HELP_STATS_COMPARE_FILES_DIALOG,
     HELP_STATS_LTE_MAC_TRAFFIC_DIALOG,
     HELP_STATS_WLAN_TRAFFIC_DIALOG,
     HELP_CAPTURE_INTERFACE_OPTIONS_DIALOG,
