@@ -1,7 +1,7 @@
 /* main.h
  * Global defines, etc.
  *
- * $Id: main.h 25574 2008-06-24 03:38:15Z guy $
+ * $Id: main.h 30322 2009-10-05 07:02:38Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -25,10 +25,6 @@
 #ifndef __MAIN_H__
 #define __MAIN_H__
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "globals.h"
 
 /** @defgroup main_window_group Main window
@@ -37,7 +33,7 @@
   digraph main_dependencies {
       node [shape=record, fontname=Helvetica, fontsize=10];
       main [ label="main window" URL="\ref main.h"];
-      menu [ label="menubar" URL="\ref main_menu.h"];
+      menu [ label="menubar" URL="\ref menus.h"];
       toolbar [ label="toolbar" URL="\ref toolbar.h"];
       packet_list [ label="packet list pane" URL="\ref main_packet_list.h"];
       proto_draw [ label="packet details & bytes panes" URL="\ref main_proto_draw.h"];
@@ -124,13 +120,6 @@ typedef enum {
 /** "bitwise or" this with MATCH_SELECTED_E value for copy to clipboard instead of prepare only */
 #define MATCH_SELECTED_COPY_ONLY    0x200
 
-/** User highlited item in details window and then right clicked and selected the copy option
- *
- * @param widget parent widget
- * @param data parent widget
- */
-extern void copy_selected_plist_cb(GtkWidget *w _U_, gpointer data);
-
 /** User requested one of "Apply as Filter" or "Prepare a Filter" functions
  *  by menu or context menu of protocol tree.
  *
@@ -140,6 +129,21 @@ extern void copy_selected_plist_cb(GtkWidget *w _U_, gpointer data);
  */
 extern void match_selected_ptree_cb(GtkWidget *widget, gpointer data, MATCH_SELECTED_E action);
 
+/** "Copy ..." action type. */
+typedef enum {
+    COPY_SELECTED_DESCRIPTION,  /**< "Copy Description" */
+    COPY_SELECTED_FIELDNAME,    /**< "Copy Fieldname" */
+    COPY_SELECTED_VALUE         /**< "Copy Value" */
+} COPY_SELECTED_E;
+
+/** User highlited item in details window and then right clicked and selected the copy option
+ *
+ * @param widget parent widget
+ * @param data parent widget
+ * @param action the function to use
+ */
+extern void copy_selected_plist_cb(GtkWidget *w _U_, gpointer data, COPY_SELECTED_E action);
+
 /** User requested the colorize function
  *  by menu or context menu of protocol tree.
  *
@@ -326,12 +330,20 @@ extern gboolean main_filter_packets(capture_file *cf, const gchar *dftext,
 extern void create_console(void);
 #endif
 
+#if defined(_WIN32) || ! defined USE_THREADS
+/** Restart the tap update display timer with new configured interval */
+extern void reset_tap_update_timer(void);
+#endif
+
 /** Fill in capture options with values from the preferences */
 extern void prefs_to_capture_opts(void);
 
 /** Change configuration profile */
 extern void change_configuration_profile(const gchar *profile_name);
 
+/** redissect packets and update UI */
+extern void redissect_packets(void);
+
 extern GtkWidget *pkt_scrollw;
 
 #endif /* __MAIN_H__ */
