@@ -1,6 +1,6 @@
 /* main_welcome.c
  *
- * $Id: main_welcome.c 26899 2008-12-02 08:11:23Z jmayer $
+ * $Id: main_welcome.c 29949 2009-09-16 20:29:00Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -47,9 +47,10 @@
 #include "gtk/recent.h"
 #include "gtk/gtkglobals.h"
 #include "gtk/main.h"
-#include "gtk/main_menu.h"
+#include "gtk/menus.h"
 #include "gtk/main_welcome.h"
 #include "gtk/capture_dlg.h"
+#include "gtk/capture_if_dlg.h"
 #include "gtk/capture_file_dlg.h"
 #include "gtk/help_dlg.h"
 #include "gtk/stock_icons.h"
@@ -57,6 +58,11 @@
 #include "../image/wssplash-dev.xpm"
 #include "../version_info.h"
 
+#ifdef _WIN32
+#include <tchar.h>
+#include <windows.h>
+#endif
+
 #ifdef HAVE_AIRPCAP
 #include "airpcap.h"
 #include "airpcap_loader.h"
@@ -66,7 +72,8 @@
 /* XXX */
 extern gint if_list_comparator_alph (const void *first_arg, const void *second_arg);
 
-
+static GtkWidget *welcome_hb = NULL;
+static GtkWidget *header_lb = NULL;
 static GdkColor header_bar_bg;
 static GdkColor topic_header_bg;
 static GdkColor topic_content_bg;
@@ -78,6 +85,7 @@ static GtkWidget *welcome_file_panel_vb = NULL;
 static GtkWidget *welcome_if_panel_vb = NULL;
 #endif
 
+static GSList *status_messages = NULL;
 
 /* The "scroll box dynamic" is a (complicated) pseudo widget to */
 /* place a vertically list of widgets in (currently the interfaces and recent files). */
@@ -132,13 +140,13 @@ scroll_box_dynamic_add(GtkWidget *parent_box)
         /* XXX - there's no way to get rid of the shadow frame - except for creating an own widget :-( */
         scrollw = scrolled_window_new(NULL, NULL);
         scrollw_y_size = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(parent_box), SCROLL_BOX_SCROLLW_Y_SIZE));
-	    gtk_widget_set_usize(scrollw, -1, scrollw_y_size);
+	    gtk_widget_set_size_request(scrollw, -1, scrollw_y_size);
 
         g_object_set_data(G_OBJECT(parent_box), SCROLL_BOX_SCROLLW, scrollw);
         gtk_box_pack_start(GTK_BOX(parent_box), scrollw, TRUE, TRUE, 0);
 
         /* move child_box from parent_box into scrolled window */
-        gtk_widget_ref(child_box);
+        g_object_ref(child_box);
         gtk_container_remove(GTK_CONTAINER(parent_box), child_box);
         gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrollw),
                                               child_box);
@@ -159,7 +167,7 @@ scroll_box_dynamic_reset(GtkWidget *parent_box)
 
     if(scrollw != NULL) {
         /* move the child_box back from scrolled window into the parent_box */
-        gtk_widget_ref(child_box);
+        g_object_ref(child_box);
         gtk_container_remove(GTK_CONTAINER(parent_box), scrollw);
         g_object_set_data(G_OBJECT(parent_box), SCROLL_BOX_SCROLLW, NULL);
         gtk_box_pack_start(GTK_BOX(parent_box), child_box, TRUE, TRUE, 0);
@@ -225,7 +233,7 @@ welcome_button(const gchar *stock_item,
 
     /* title */
     w = gtk_label_new(title);
-    gtk_misc_set_alignment (GTK_MISC(w), 0.0, 0.5);
+    gtk_misc_set_alignment (GTK_MISC(w), 0.0f, 0.5f);
     formatted_text = g_strdup_printf("<span weight=\"bold\" size=\"x-large\" foreground=\"black\">%s</span>", title);
     gtk_label_set_markup(GTK_LABEL(w), formatted_text);
     g_free(formatted_text);
@@ -233,7 +241,7 @@ welcome_button(const gchar *stock_item,
 
     /* subtitle */
     w = gtk_label_new(subtitle);
-    gtk_misc_set_alignment (GTK_MISC(w), 0.0, 0.5);
+    gtk_misc_set_alignment (GTK_MISC(w), 0.0f, 0.5f);
     formatted_text = g_strdup_printf("<span size=\"small\" foreground=\"black\">%s</span>", subtitle);
     gtk_label_set_markup(GTK_LABEL(w), formatted_text);
     g_free(formatted_text);
@@ -244,6 +252,34 @@ welcome_button(const gchar *stock_item,
     return eb;
 }
 
+static void
+welcome_header_set_message(gchar *msg) {
+    GString *message;
+    time_t secs = time(NULL);
+    struct tm *now = localtime(&secs);
+    
+    message = g_string_new("<span weight=\"bold\" size=\"x-large\" foreground=\"black\">");
+    
+    if (msg) {
+	g_string_append(message, msg);
+    } else { /* Use our default header */
+	if ((now->tm_mon == 3 && now->tm_mday == 1) || (now->tm_mon == 6 && now->tm_mday == 14)) {
+	    g_string_append(message, "Sniffing the glue that holds the Internet together");
+	} else {
+	    g_string_append(message, prefs.gui_start_title);
+	}
+    
+	if (prefs.gui_version_in_start_page) {
+	    g_string_append_printf(message, "</span>\n<span size=\"large\" foreground=\"black\">Version " VERSION "%s",
+				   wireshark_svnversion);
+	}
+    }
+
+    g_string_append(message, "</span>");
+
+    gtk_label_set_markup(GTK_LABEL(header_lb), message->str);
+    g_string_free(message, TRUE);
+}
 
 /* create the banner "above our heads" */
 static GtkWidget *
@@ -253,10 +289,6 @@ welcome_header_new(void)
     GtkWidget *item_hb;
     GtkWidget *eb;
     GtkWidget *icon;
-    GString *message;
-    GtkWidget *w;
-    time_t secs = time(NULL);
-    struct tm *now = localtime(&secs);
 
     item_vb = gtk_vbox_new(FALSE, 0);
 
@@ -271,30 +303,46 @@ welcome_header_new(void)
     icon = xpm_to_widget_from_parent(top_level, wssplash_xpm);
     gtk_box_pack_start(GTK_BOX(item_hb), icon, FALSE, FALSE, 10);
 
-    message = g_string_new("<span weight=\"bold\" size=\"x-large\" foreground=\"black\">");
-    if ((now->tm_mon == 3 && now->tm_mday == 1) || (now->tm_mon == 6 && now->tm_mday == 14)) {
-        g_string_append(message, "Sniffing the glue that holds the Internet together");
-    } else {
-        g_string_append(message, prefs.gui_start_title);
-    }
-    g_string_append(message, "</span>");
-
-    if (prefs.gui_version_in_start_page) {
-        g_string_append_printf(message, "\n<span size=\"large\" foreground=\"black\">Version " VERSION "%s</span>",
-                               wireshark_svnversion);
-    }
-
-    w = gtk_label_new(message->str);
-    gtk_label_set_markup(GTK_LABEL(w), message->str);
-    g_string_free(message, TRUE);
-    gtk_misc_set_alignment (GTK_MISC(w), 0.0, 0.5);
-    gtk_box_pack_start(GTK_BOX(item_hb), w, TRUE, TRUE, 5);
+    header_lb = gtk_label_new(NULL);
+    welcome_header_set_message(NULL);
+    gtk_misc_set_alignment (GTK_MISC(header_lb), 0.0f, 0.5f);
+    gtk_box_pack_start(GTK_BOX(item_hb), header_lb, TRUE, TRUE, 5);
 
     gtk_widget_show_all(eb);
 
     return eb;
 }
 
+void
+welcome_header_push_msg(gchar *msg) {
+    gchar *msg_copy = g_strdup(msg);
+    
+    status_messages = g_slist_append(status_messages, msg_copy);
+    
+    welcome_header_set_message(msg_copy);
+    
+    gtk_widget_hide(welcome_hb);
+}
+
+void
+welcome_header_pop_msg(void) {
+    gchar *msg = NULL;    
+
+    if (status_messages) {
+	g_free(status_messages->data);
+        status_messages = g_slist_delete_link(status_messages, status_messages);
+    }
+    
+    if (status_messages) {
+	msg = status_messages->data;
+    }
+
+    welcome_header_set_message(msg);
+    
+    if (!status_messages) {
+        gtk_widget_show(welcome_hb);
+    }
+}
 
 /* create a "topic header widget" */
 static GtkWidget *
@@ -362,11 +410,12 @@ welcome_filename_link_press_cb(GtkWidget *widget _U_, GdkEvent *event _U_, gpoin
 static GtkWidget *
 welcome_filename_link_new(const gchar *filename, GtkWidget **label)
 {
-    GtkWidget *w;
-    GtkWidget *eb;
-    GString		*str;
+    GtkWidget	*w;
+    GtkWidget	*eb;
+    GString	*str;
+    gchar	*str_escaped;
     const unsigned int max = 60;
-    int err;
+    int		err;
     struct stat stat_buf;
     GtkTooltips *tooltips;
 
@@ -382,15 +431,26 @@ welcome_filename_link_new(const gchar *filename, GtkWidget **label)
         g_string_insert(str, 20, " ... ");
     }
 
-    /* add file size */
+    /* escape the possibly shortened filename before adding pango language */
+    str_escaped=g_markup_escape_text(str->str, -1);
+    g_string_free(str, TRUE);
+    str=g_string_new(str_escaped);
+    g_free(str_escaped);
+
+    /*
+     * Add file size. We use binary prefixes instead of IEC because that's what
+     * most OSes use.
+     */
     err = ws_stat(filename, &stat_buf);
     if(err == 0) {
-        if (stat_buf.st_size/1024/1024 > 10) {
-            g_string_append_printf(str, " %" G_GINT64_MODIFIER "dMB", (gint64) (stat_buf.st_size/1024/1024));
+        if (stat_buf.st_size/1024/1024/1024 > 10) {
+            g_string_append_printf(str, " (%" G_GINT64_MODIFIER "d GB)", (gint64) (stat_buf.st_size/1024/1024/1024));
+	} else if (stat_buf.st_size/1024/1024 > 10) {
+            g_string_append_printf(str, " (%" G_GINT64_MODIFIER "d MB)", (gint64) (stat_buf.st_size/1024/1024));
         } else if (stat_buf.st_size/1024 > 10) {
-            g_string_append_printf(str, " %" G_GINT64_MODIFIER "dKB", (gint64) (stat_buf.st_size/1024));
+            g_string_append_printf(str, " (%" G_GINT64_MODIFIER "d KB)", (gint64) (stat_buf.st_size/1024));
         } else {
-            g_string_append_printf(str, " %" G_GINT64_MODIFIER "d Bytes", (gint64) (stat_buf.st_size));
+            g_string_append_printf(str, " (%" G_GINT64_MODIFIER "d Bytes)", (gint64) (stat_buf.st_size));
         }
     } else {
         g_string_append(str, " [not found]");
@@ -408,7 +468,7 @@ welcome_filename_link_new(const gchar *filename, GtkWidget **label)
     gtk_label_set_markup(GTK_LABEL(w), str->str);
     gtk_misc_set_padding(GTK_MISC(w), 5, 2);
 
-	/* event box */
+    /* event box */
     eb = gtk_event_box_new();
     gtk_container_add(GTK_CONTAINER(eb), w);
     gtk_tooltips_set_tip(tooltips, eb, filename, "");
@@ -461,7 +521,7 @@ main_welcome_add_recent_capture_files(const char *widget_cf_name)
 
     w = welcome_filename_link_new(widget_cf_name, &label);
     gtk_widget_modify_bg(w, GTK_STATE_NORMAL, &topic_item_idle_bg);
-    gtk_misc_set_alignment (GTK_MISC(label), 0.0, 0.0);
+    gtk_misc_set_alignment (GTK_MISC(label), 0.0f, 0.0f);
     child_box = scroll_box_dynamic_add(welcome_file_panel_vb);
     gtk_box_pack_start(GTK_BOX(child_box), w, FALSE, FALSE, 0);
     gtk_widget_show_all(w);
@@ -474,10 +534,8 @@ main_welcome_add_recent_capture_files(const char *widget_cf_name)
 static gboolean
 welcome_if_press_cb(GtkWidget *widget _U_, GdkEvent *event _U_, gpointer data)
 {
-    if (global_capture_opts.iface)
-        g_free(global_capture_opts.iface);
-    if (global_capture_opts.iface_descr)
-        g_free(global_capture_opts.iface_descr);
+    g_free(global_capture_opts.iface);
+    g_free(global_capture_opts.iface_descr);
 
     global_capture_opts.iface = g_strdup(data);
     global_capture_opts.iface_descr = NULL;
@@ -504,7 +562,7 @@ welcome_if_press_cb(GtkWidget *widget _U_, GdkEvent *event _U_, gpointer data)
 
 /* create a single interface entry */
 static GtkWidget *
-welcome_if_new(const char *if_name, GdkColor *topic_bg _U_, gpointer interf)
+welcome_if_new(const if_info_t *if_info, const gchar *user_descr, GdkColor *topic_bg _U_, gpointer interf)
 {
     GtkWidget *interface_hb;
     GtkWidget *w;
@@ -524,10 +582,15 @@ welcome_if_new(const char *if_name, GdkColor *topic_bg _U_, gpointer interf)
     gtk_container_add(GTK_CONTAINER(eb), interface_hb);
 
     /* icon */
-    w = gtk_image_new_from_stock(WIRESHARK_STOCK_CAPTURE_START, GTK_ICON_SIZE_SMALL_TOOLBAR);
+    w = capture_get_if_icon(if_info);
     gtk_box_pack_start(GTK_BOX(interface_hb), w, FALSE, FALSE, 5);
 
-    message = g_string_new(if_name);
+    if (user_descr != NULL)
+        message = g_string_new(user_descr);
+    else if (if_info->description != NULL)
+        message = g_string_new(if_info->description);
+    else
+        message = g_string_new(if_info->name);
 
     /* truncate string if it's too long */
     /* (the number of chars is a bit arbitrary, though) */
@@ -541,7 +604,7 @@ welcome_if_new(const char *if_name, GdkColor *topic_bg _U_, gpointer interf)
     gtk_label_set_markup(GTK_LABEL(w), message->str);
     g_string_free(message, TRUE);
 
-    gtk_misc_set_alignment (GTK_MISC(w), 0.0, 0.0);
+    gtk_misc_set_alignment (GTK_MISC(w), 0.0f, 0.0f);
     gtk_box_pack_start(GTK_BOX(interface_hb), w, FALSE, FALSE, 0);
 
     return eb;
@@ -561,7 +624,7 @@ welcome_if_panel_load(void)
   gchar         *err_str;
   int           ifs;
   GList         *curr;
-  gchar         *descr;
+  gchar         *user_descr;
 
 
   /* LOAD THE INTERFACES */
@@ -583,19 +646,17 @@ welcome_if_panel_load(void)
           continue;
       }
 
-      descr = capture_dev_user_descr_find(if_info->name);
-      if (descr) {
+      user_descr = capture_dev_user_descr_find(if_info->name);
+      if (user_descr) {
 #ifndef _WIN32
-        gchar *comment = descr;
-        descr = g_strdup_printf("%s (%s)", comment, if_info->name);
+        gchar *comment = user_descr;
+        user_descr = g_strdup_printf("%s (%s)", comment, if_info->name);
         g_free (comment);
 #endif
-        interface_hb = welcome_if_new(descr, &topic_content_bg, g_strdup(if_info->name));
-        g_free (descr);
-      } else if (if_info->description != NULL) {
-        interface_hb = welcome_if_new(if_info->description, &topic_content_bg, g_strdup(if_info->name));
+        interface_hb = welcome_if_new(if_info, user_descr, &topic_content_bg, g_strdup(if_info->name));
+        g_free (user_descr);
       } else {
-        interface_hb = welcome_if_new(if_info->name, &topic_content_bg, g_strdup(if_info->name));
+        interface_hb = welcome_if_new(if_info, NULL, &topic_content_bg, g_strdup(if_info->name));
       }
 
       child_box = scroll_box_dynamic_add(welcome_if_panel_vb);
@@ -641,7 +702,6 @@ welcome_new(void)
 {
     GtkWidget *welcome_scrollw;
     GtkWidget *welcome_vb;
-    GtkWidget *welcome_hb;
     GtkWidget *column_vb;
     GtkWidget *item_hb;
     GtkWidget *w;
@@ -653,7 +713,11 @@ welcome_new(void)
 #endif  /* HAVE_LIBPCAP */
     GtkWidget *file_child_box;
     gchar *label_text;
-
+#ifdef _WIN32
+    LONG reg_ret;
+    DWORD chimney_enabled = 0;
+    DWORD ce_size = sizeof(chimney_enabled);
+#endif
 
     /* prepare colors */
     /* header bar background color */
@@ -733,14 +797,14 @@ welcome_new(void)
         "Interface List",
 		"Live list of the capture interfaces (counts incoming packets)",
         "Same as Capture/Interfaces menu or toolbar item",
-        GTK_SIGNAL_FUNC(capture_if_cb), NULL);
+        G_CALLBACK(capture_if_cb), NULL);
     gtk_box_pack_start(GTK_BOX(topic_to_fill), item_hb, FALSE, FALSE, 5);
 
-    label_text =  g_strdup_printf("<span foreground=\"black\">Start capture on interface:</span>");
+    label_text =  g_strdup("<span foreground=\"black\">Start capture on interface:</span>");
     w = gtk_label_new(label_text);
     gtk_label_set_markup(GTK_LABEL(w), label_text);
     g_free (label_text);
-    gtk_misc_set_alignment (GTK_MISC(w), 0.0, 0.0);
+    gtk_misc_set_alignment (GTK_MISC(w), 0.0f, 0.0f);
     gtk_box_pack_start(GTK_BOX(topic_to_fill), w, FALSE, FALSE, 5);
 
     if_child_box = gtk_vbox_new(FALSE, 0);
@@ -754,9 +818,24 @@ welcome_new(void)
         "Capture Options",
 		"Start a capture with detailed options",
         "Same as Capture/Options menu or toolbar item",
-        GTK_SIGNAL_FUNC(capture_prep_cb), NULL);
+        G_CALLBACK(capture_prep_cb), NULL);
     gtk_box_pack_start(GTK_BOX(topic_to_fill), item_hb, FALSE, FALSE, 5);
 
+#ifdef _WIN32
+    /* Check for chimney offloading */
+    reg_ret = RegQueryValueEx(HKEY_LOCAL_MACHINE,
+			      _T("SYSTEM\\CurrentControlSet\\Services\\Tcpip\\Parameters\\EnableTCPChimney"),
+			      NULL, NULL, (LPBYTE) &chimney_enabled, &ce_size);
+    if (reg_ret == ERROR_SUCCESS && chimney_enabled) {	
+	item_hb = welcome_button(WIRESHARK_STOCK_WIKI,
+		    "Offloading Detected",
+	    "TCP Chimney offloading is enabled. You \nmight not capture much data.",
+	    topic_online_url(ONLINEPAGE_CHIMNEY),
+	    G_CALLBACK(topic_menu_cb), GINT_TO_POINTER(ONLINEPAGE_CHIMNEY));
+	gtk_box_pack_start(GTK_BOX(topic_to_fill), item_hb, FALSE, FALSE, 5);
+    }
+#endif /* _WIN32 */
+
     /* capture help topic */
     topic_vb = welcome_topic_new("Capture Help", &topic_to_fill);
     gtk_box_pack_start(GTK_BOX(column_vb), topic_vb, TRUE, TRUE, 0);
@@ -765,21 +844,21 @@ welcome_new(void)
 		"How to Capture",
 		"Step by step to a successful capture setup",
         topic_online_url(ONLINEPAGE_CAPTURE_SETUP),
-        GTK_SIGNAL_FUNC(topic_menu_cb), GINT_TO_POINTER(ONLINEPAGE_CAPTURE_SETUP));
+        G_CALLBACK(topic_menu_cb), GINT_TO_POINTER(ONLINEPAGE_CAPTURE_SETUP));
     gtk_box_pack_start(GTK_BOX(topic_to_fill), item_hb, FALSE, FALSE, 5);
 
     item_hb = welcome_button(WIRESHARK_STOCK_WIKI,
 		"Network Media",
         "Specific information for capturing on: Ethernet, WLAN, ...",
         topic_online_url(ONLINEPAGE_NETWORK_MEDIA),
-        GTK_SIGNAL_FUNC(topic_menu_cb), GINT_TO_POINTER(ONLINEPAGE_NETWORK_MEDIA));
+        G_CALLBACK(topic_menu_cb), GINT_TO_POINTER(ONLINEPAGE_NETWORK_MEDIA));
     gtk_box_pack_start(GTK_BOX(topic_to_fill), item_hb, FALSE, FALSE, 5);
 #else
-    label_text =  g_strdup_printf("<span foreground=\"black\">Capturing is not compiled into this version of Wireshark!</span>");
+    label_text =  g_strdup("<span foreground=\"black\">Capturing is not compiled into this version of Wireshark!</span>");
     w = gtk_label_new(label_text);
     gtk_label_set_markup(GTK_LABEL(w), label_text);
     g_free (label_text);
-    gtk_misc_set_alignment (GTK_MISC(w), 0.0, 0.0);
+    gtk_misc_set_alignment (GTK_MISC(w), 0.0f, 0.0f);
     gtk_box_pack_start(GTK_BOX(topic_to_fill), w, FALSE, FALSE, 5);
 #endif  /* HAVE_LIBPCAP */
 
@@ -796,15 +875,15 @@ welcome_new(void)
         "Open",
 		"Open a previously captured file",
         "Same as File/Open menu or toolbar item",
-        GTK_SIGNAL_FUNC(file_open_cmd_cb), NULL);
+        G_CALLBACK(file_open_cmd_cb), NULL);
     gtk_box_pack_start(GTK_BOX(topic_to_fill), item_hb, FALSE, FALSE, 5);
 
     /* prepare list of recent files (will be filled in later) */
-    label_text =  g_strdup_printf("<span foreground=\"black\">Open Recent:</span>");
+    label_text =  g_strdup("<span foreground=\"black\">Open Recent:</span>");
     w = gtk_label_new(label_text);
     gtk_label_set_markup(GTK_LABEL(w), label_text);
     g_free (label_text);
-    gtk_misc_set_alignment (GTK_MISC(w), 0.0, 0.0);
+    gtk_misc_set_alignment (GTK_MISC(w), 0.0f, 0.0f);
     gtk_box_pack_start(GTK_BOX(topic_to_fill), w, FALSE, FALSE, 5);
 
     file_child_box = gtk_vbox_new(FALSE, 1);
@@ -817,7 +896,7 @@ welcome_new(void)
         "Sample Captures",
 		"A rich assortment of example capture files on the wiki",
         topic_online_url(ONLINEPAGE_SAMPLE_CAPTURES),
-        GTK_SIGNAL_FUNC(topic_menu_cb), GINT_TO_POINTER(ONLINEPAGE_SAMPLE_CAPTURES));
+        G_CALLBACK(topic_menu_cb), GINT_TO_POINTER(ONLINEPAGE_SAMPLE_CAPTURES));
     gtk_box_pack_start(GTK_BOX(topic_to_fill), item_hb, FALSE, FALSE, 5);
 
     /* fill bottom space */
@@ -837,21 +916,21 @@ welcome_new(void)
         "Website",
 		"Visit the project's website",
         topic_online_url(ONLINEPAGE_HOME),
-        GTK_SIGNAL_FUNC(topic_menu_cb), GINT_TO_POINTER(ONLINEPAGE_HOME));
+        G_CALLBACK(topic_menu_cb), GINT_TO_POINTER(ONLINEPAGE_HOME));
     gtk_box_pack_start(GTK_BOX(topic_to_fill), item_hb, FALSE, FALSE, 5);
 
     item_hb = welcome_button(GTK_STOCK_HELP,
         "User's Guide",
 		"The User's Guide (local version, if installed)",
         "Locally installed (if installed) otherwise online version",
-        GTK_SIGNAL_FUNC(topic_menu_cb), GINT_TO_POINTER(HELP_CONTENT));
+        G_CALLBACK(topic_menu_cb), GINT_TO_POINTER(HELP_CONTENT));
     gtk_box_pack_start(GTK_BOX(topic_to_fill), item_hb, FALSE, FALSE, 5);
 
     item_hb = welcome_button(WIRESHARK_STOCK_WIKI,
         "Security",
 		"Work with Wireshark as securely as possible",
         topic_online_url(ONLINEPAGE_SECURITY),
-        GTK_SIGNAL_FUNC(topic_menu_cb), GINT_TO_POINTER(ONLINEPAGE_SECURITY));
+        G_CALLBACK(topic_menu_cb), GINT_TO_POINTER(ONLINEPAGE_SECURITY));
     gtk_box_pack_start(GTK_BOX(topic_to_fill), item_hb, FALSE, FALSE, 5);
 
 #if 0
@@ -860,7 +939,7 @@ welcome_new(void)
     topic_vb = welcome_topic_new("Updates", &topic_to_fill);
     gtk_box_pack_start(GTK_BOX(column_vb), topic_vb, TRUE, TRUE, 0);
 
-    label_text =  g_strdup_printf("<span foreground=\"black\">No updates available!</span>");
+    label_text =  g_strdup("<span foreground=\"black\">No updates available!</span>");
     w = gtk_label_new(label_text);
     gtk_label_set_markup(GTK_LABEL(w), label_text);
     g_free (label_text);
