@@ -1,8 +1,9 @@
 /* new_packet_list.c
  * Routines to implement a new GTK2 packet list using our custom model
  * Copyright 2008-2009, Stephen Fisher (see AUTHORS file)
+ * Co-authors Anders Broman and Kovarththanan Rajaratnam.
  *
- * $Id: new_packet_list.c 29868 2009-09-11 20:36:01Z gerald $
+ * $Id: new_packet_list.c 30529 2009-10-12 07:55:24Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,9 +31,7 @@
 
 #ifdef NEW_PACKET_LIST
 
-#ifdef HAVE_STRING_H
 #include "string.h"
-#endif
 
 #include <stdio.h>
 #include <gtk/gtk.h>
@@ -62,19 +61,27 @@
 #include "gtk/color_utils.h"
 #include "gtk/capture_file_dlg.h"
 #include "gtk/main_statusbar.h"
+#include "gtk/packet_win.h"
 
 static PacketList *packetlist;
 static gboolean last_at_end = FALSE;
 static gboolean enable_color;
 
 static GtkWidget *create_view_and_model(void);
-static void scroll_to_and_select_iter(GtkTreeIter *iter);
+static void scroll_to_and_select_iter(GtkTreeModel *model, GtkTreeSelection *selection, GtkTreeIter *iter);
 static void new_packet_list_select_cb(GtkTreeView *tree_view, gpointer data _U_);
+static void new_packet_list_double_click_cb(GtkTreeView *treeview,
+					    GtkTreePath *path,
+					    GtkTreeViewColumn *col _U_,
+					    gpointer userdata _U_);
 static void show_cell_data_func(GtkTreeViewColumn *col,
 				GtkCellRenderer *renderer,
 				GtkTreeModel *model,
 				GtkTreeIter *iter,
 				gpointer data);
+static guint row_number_from_iter(GtkTreeIter *iter);
+
+void new_packet_list_set_sel_browse(gboolean val, gboolean force_set);
 
 GtkWidget *
 new_packet_list_create(void)
@@ -85,16 +92,9 @@ new_packet_list_create(void)
 
 	view = create_view_and_model();
 
-	gtk_container_add(GTK_CONTAINER(scrollwin), view);
+	new_packet_list_set_sel_browse(prefs.gui_plist_sel_browse, FALSE);
 
-	/* XXX - Implement me
-	g_signal_connect(view, "row-activated",
-			 G_CALLBACK(popup_menu_handler),
-			 g_object_get_data(G_OBJECT(popup_menu_object),
-					   PM_PACKET_LIST_KEY));
-	g_signal_connect(view, "button_press_event",
-			 G_CALLBACK(new_packet_list_button_pressed_cb), NULL);
-	*/
+	gtk_container_add(GTK_CONTAINER(scrollwin), view);
 
 	g_object_set_data(G_OBJECT(popup_menu_object), E_MPACKET_LIST_KEY, view);
 
@@ -164,6 +164,10 @@ create_view_and_model(void)
 #endif
 	g_signal_connect(packetlist->view, "cursor-changed",
 			 G_CALLBACK(new_packet_list_select_cb), NULL);
+	g_signal_connect(packetlist->view, "row-activated",
+			 G_CALLBACK(new_packet_list_double_click_cb),
+			 g_object_get_data(G_OBJECT(popup_menu_object),
+					   PM_PACKET_LIST_KEY));
 	g_signal_connect(packetlist->view, "button_press_event", G_CALLBACK(popup_menu_handler),
 				   g_object_get_data(G_OBJECT(popup_menu_object), PM_PACKET_LIST_KEY));
 	g_object_set_data(G_OBJECT(popup_menu_object), E_MPACKET_LIST_KEY, packetlist);
@@ -204,9 +208,21 @@ create_view_and_model(void)
 
 		/* Set the size the column will be displayed with */
 		col_width = recent_get_column_width(i);
-		if(col_width == -1) {
-			layout = gtk_widget_create_pango_layout(packetlist->view, get_column_width_string(get_column_format(i), i));
-			pango_layout_get_pixel_size(layout, &col_width, NULL);
+		if(col_width < 1) {
+			gint fmt;
+			const gchar *long_str;
+
+			fmt = get_column_format(i);
+			long_str = get_column_width_string(fmt, i);
+			layout = gtk_widget_create_pango_layout(packetlist->view, long_str);
+			/*  the logical width and height of a PangoLayout in device units */
+			pango_layout_get_pixel_size(layout,
+				&col_width, /* width */
+				NULL); /* height */
+			if (col_width < 1){
+				g_warning("*** Error: A column width of %u passed to gtk_tree_view_column_set_fixed_width()\n"
+					"column %u Long string  %s format %u",col_width,i,long_str, fmt );
+			}
 			gtk_tree_view_column_set_fixed_width(col, col_width);
 			g_object_unref(G_OBJECT(layout));
 		}else{
@@ -227,7 +243,7 @@ new_packet_list_get_record(GtkTreeModel *model, GtkTreeIter *iter)
 
 	gtk_tree_model_get(model, iter,
 			   record_column,
-			   (PacketListRecord*) &record,
+			   &record,
 			   -1);
 
 	return record;
@@ -240,6 +256,12 @@ new_packet_list_clear(void)
 
 	new_packet_list_store_clear(packetlist);
 	gtk_widget_queue_draw(packetlist->view);
+	/* XXX is this correct in all cases?
+	 * Reset the sort column, use packetlist as model in case the list is frozen.
+	 */
+	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(packetlist),
+			0, GTK_SORT_ASCENDING);
+
 }
 
 void
@@ -267,7 +289,9 @@ new_packet_list_thaw(void)
 void
 new_packet_list_recreate_visible_rows(void)
 {
+
 	packet_list_recreate_visible_rows(packetlist);
+
 }
 
 void new_packet_list_resize_column(gint col)
@@ -275,10 +299,14 @@ void new_packet_list_resize_column(gint col)
 	PangoLayout *layout;
 	GtkTreeViewColumn *column;
 	gint col_width;
+	const gchar *long_str;
 
+	long_str = packet_list_get_widest_column_string(packetlist, col);
+	if(strcmp("",long_str)==0)
+		/* If we get an empty string levae the width unchanged */
+		return;
 	column = gtk_tree_view_get_column (GTK_TREE_VIEW(packetlist->view), col);
-	layout = gtk_widget_create_pango_layout(packetlist->view,
-										  packet_list_get_widest_column_string(packetlist, col));
+	layout = gtk_widget_create_pango_layout(packetlist->view, long_str );
 	pango_layout_get_pixel_size(layout, &col_width, NULL);
 	gtk_tree_view_column_set_fixed_width(column, col_width);
 	g_object_unref(G_OBJECT(layout));
@@ -308,16 +336,21 @@ new_packet_list_next(void)
 	GtkTreeSelection *selection;
 	GtkTreeIter iter;
 	GtkTreeModel *model;
+	GtkWidget *focus = gtk_window_get_focus(GTK_WINDOW(top_level));
 
 	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(packetlist->view));
-	if (!gtk_tree_selection_get_selected(selection, NULL, &iter))
+	/* model is filled with the current model as a convenience. */
+	if (!gtk_tree_selection_get_selected(selection, &model, &iter))
 		return;
 
-	model = gtk_tree_view_get_model(GTK_TREE_VIEW(packetlist->view));
 	if (!gtk_tree_model_iter_next(model, &iter))
 		return;
 
-	scroll_to_and_select_iter(&iter);
+	scroll_to_and_select_iter(model, selection, &iter);
+
+	/* Set the focus back where it was */
+	if (focus)
+		gtk_window_set_focus(GTK_WINDOW(top_level), focus);
 }
 
 void
@@ -327,12 +360,13 @@ new_packet_list_prev(void)
 	GtkTreeIter iter;
 	GtkTreeModel *model;
 	GtkTreePath *path;
+	GtkWidget *focus = gtk_window_get_focus(GTK_WINDOW(top_level));
 
 	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(packetlist->view));
-	if (!gtk_tree_selection_get_selected(selection, NULL, &iter))
+	/* model is filled with the current model as a convenience. */
+	if (!gtk_tree_selection_get_selected(selection, &model, &iter))
 		return;
 
-	model = gtk_tree_view_get_model(GTK_TREE_VIEW(packetlist->view));
 	path = gtk_tree_model_get_path(model, &iter);
 
 	if (!gtk_tree_path_prev(path))
@@ -341,22 +375,25 @@ new_packet_list_prev(void)
 	if (!gtk_tree_model_get_iter(model, &iter, path))
 		return;
 
-	scroll_to_and_select_iter(&iter);
+	scroll_to_and_select_iter(model, selection, &iter);
 
 	gtk_tree_path_free(path);
+
+	/* Set the focus back where it was */
+	if (focus)
+		gtk_window_set_focus(GTK_WINDOW(top_level), focus);
 }
 
 static void
-scroll_to_and_select_iter(GtkTreeIter *iter)
+scroll_to_and_select_iter(GtkTreeModel *model, GtkTreeSelection *selection, GtkTreeIter *iter)
 {
-	GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(packetlist->view));
-	GtkTreeSelection *selection;
 	GtkTreePath *path;
 
 	g_assert(model);
 
 	/* Select the row */
-	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(packetlist->view));
+	if(!selection)
+		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(packetlist->view));
 	gtk_tree_selection_select_iter (selection, iter);
 	path = gtk_tree_model_get_path(model, iter);
 	gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(packetlist->view),
@@ -385,7 +422,7 @@ new_packet_list_select_first_row(void)
 	if(!gtk_tree_model_get_iter_first(model, &iter))
 		return;
 
-	scroll_to_and_select_iter(&iter);
+	scroll_to_and_select_iter(model, NULL, &iter);
 }
 
 void
@@ -403,7 +440,7 @@ new_packet_list_select_last_row(void)
 	if(!gtk_tree_model_iter_nth_child(model, &iter, NULL, last_row))
 		return;
 
-	scroll_to_and_select_iter(&iter);
+	scroll_to_and_select_iter(model, NULL, &iter);
 }
 
 void
@@ -411,7 +448,6 @@ new_packet_list_moveto_end(void)
 {
 	GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(packetlist->view));
 	GtkTreeIter iter;
-	GtkTreeSelection *selection;
 	GtkTreePath *path;
 	gint children;
 	guint last_row;
@@ -424,20 +460,16 @@ new_packet_list_moveto_end(void)
 		return;
 
 	path = gtk_tree_model_get_path(model, &iter);
-	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(packetlist->view));
 
-	if (!gtk_tree_selection_path_is_selected(selection, path)) {
-		/* XXX - this doesn't seem to work, i.e. gtk_tree_selection_path_is_selected() is always false? */
-		gtk_tree_selection_select_path(selection, path);
-		gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(packetlist->view),
-				path,
-				NULL,
-				TRUE,	/* use_align */
-				0.5,	/* row_align determines where the row is placed, 0.5 means center */
-				0); 	/* The horizontal alignment of the column */
-	}
+	gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(packetlist->view),
+			path,
+			NULL,
+			TRUE,	/* use_align */
+			0.5,	/* row_align determines where the row is placed, 0.5 means center */
+			0); 	/* The horizontal alignment of the column */
 
 	gtk_tree_path_free(path);
+	gtk_widget_grab_focus(packetlist->view);
 }
 
 gboolean
@@ -483,7 +515,7 @@ new_packet_list_find_row_from_data(gpointer data, gboolean select)
 
 		if(fdata == fdata_needle) {
 			if(select)
-				scroll_to_and_select_iter(&iter);
+				scroll_to_and_select_iter(model, NULL, &iter);
 
 			return fdata->num;
 		}
@@ -557,11 +589,19 @@ new_packet_list_select_cb(GtkTreeView *tree_view, gpointer data _U_)
 	row = row_number_from_iter(&iter);
 
 	cf_select_packet(&cfile, row);
+	gtk_widget_grab_focus(packetlist->view);
 
 	/* Add newly selected frame to packet history (breadcrumbs) */
 	packet_history_add(row);
 }
 
+static void
+new_packet_list_double_click_cb(GtkTreeView *treeview, GtkTreePath *path _U_,
+    GtkTreeViewColumn *col _U_, gpointer userdata _U_)
+{
+        new_window_cb(GTK_WIDGET(treeview));
+}
+
 gboolean
 new_packet_list_get_event_row_column(GdkEventButton *event_button,
 								 gint *physical_row, gint *row, gint *column)
@@ -646,6 +686,8 @@ show_cell_data_func(GtkTreeViewColumn *col _U_, GtkCellRenderer *renderer,
 	}else
 		cell_text = fdata->col_text[col_num];
 
+	g_assert(cell_text);
+
 	if((fdata->color_filter)||(fdata->flags.marked)){
 		gboolean color_on = enable_color;
 		GdkColor fg_gdk;
@@ -657,7 +699,7 @@ show_cell_data_func(GtkTreeViewColumn *col _U_, GtkCellRenderer *renderer,
 		}else{
 			color_t fg_color_t;
 			color_t bg_color_t;
-			color_filter_t *color_filter = fdata->color_filter;
+			const color_filter_t *color_filter = fdata->color_filter;
 
 			fg_color_t = color_filter->fg_color;
 			bg_color_t = color_filter->bg_color;
@@ -714,7 +756,7 @@ static void mark_all_frames(gboolean set)
 	frame_data *fdata;
 
 	/* XXX: we might need a progressbar here */
-	for (fdata = cfile.plist; fdata != NULL; fdata = fdata->next) {
+	for (fdata = cfile.plist_start; fdata != NULL; fdata = fdata->next) {
 		set_frame_mark(set, fdata);
 	}
 	mark_frames_ready();
@@ -731,6 +773,46 @@ void new_packet_list_unmark_all_frames_cb(GtkWidget *w _U_, gpointer data _U_)
 	mark_all_frames(FALSE);
 }
 
+/* Set the selection mode of the packet list window. */
+void
+new_packet_list_set_sel_browse(gboolean val, gboolean force_set)
+{
+    GtkSelectionMode new_mode;
+    /* initialize with a mode we don't use, so that the mode == new_mode
+     * test will fail the first time */
+    static GtkSelectionMode mode = GTK_SELECTION_MULTIPLE;
+
+    /* Yeah, GTK uses "browse" in the case where we do not, but oh well. I
+     * think "browse" in Wireshark makes more sense than "SINGLE" in GTK+ */
+    new_mode = val ? GTK_SELECTION_SINGLE : GTK_SELECTION_BROWSE;
+
+    if ((mode == new_mode) && !force_set) {
+        /*
+         * The mode isn't changing, so don't do anything.
+         * In particular, don't gratuitiously unselect the
+         * current packet.
+         *
+		 * XXX - Copied code from "old" packet list 
+		 *  - I don't know if the comment below is still true...
+         * XXX - why do we have to unselect the current packet
+         * ourselves?  The documentation for the GtkCList at
+         *
+         *      http://developer.gnome.org/doc/API/gtk/gtkclist.html
+         *
+         * says "Note that setting the widget's selection mode to
+         * one of GTK_SELECTION_BROWSE or GTK_SELECTION_SINGLE will
+         * cause all the items in the GtkCList to become deselected."
+         */
+      return;
+    }
+
+    if (cfile.finfo_selected)
+        cf_unselect_field(&cfile);
+
+    mode = new_mode;
+    gtk_tree_selection_set_mode (gtk_tree_view_get_selection(GTK_TREE_VIEW(packetlist->view)), mode);
+}
+
 void
 new_packet_list_set_font(PangoFontDescription *font)
 {
@@ -739,13 +821,14 @@ new_packet_list_set_font(PangoFontDescription *font)
 
 void new_packet_list_mark_frame_cb(GtkWidget *w _U_, gpointer data _U_)
 {
-	GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(packetlist->view));
+	GtkTreeModel *model;
 	GtkTreeSelection *selection;
 	GtkTreeIter iter;
 	PacketListRecord *record;
 
 	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(packetlist->view));
-	gtk_tree_selection_get_selected(selection, NULL, &iter);
+	/* model is filled with the current model as a convenience. */
+	gtk_tree_selection_get_selected(selection, &model, &iter);
 	record = new_packet_list_get_record(model, &iter);
 
 	set_frame_mark(!record->fdata->flags.marked, record->fdata);
@@ -776,7 +859,7 @@ new_packet_list_copy_summary_cb(GtkWidget * w _U_, gpointer data _U_, gint copy_
 	gint col;
 	gchar *celltext;
 	GString* text;
-	GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(packetlist->view));
+	GtkTreeModel *model;
 	GtkTreeSelection *selection;
 	GtkTreeIter iter;
 	PacketListRecord *record;
@@ -789,7 +872,8 @@ new_packet_list_copy_summary_cb(GtkWidget * w _U_, gpointer data _U_, gint copy_
 
 	if (cfile.current_frame) {
 		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(packetlist->view));
-		gtk_tree_selection_get_selected(selection, NULL, &iter);
+		/* model is filled with the current model as a convenience.  */
+		gtk_tree_selection_get_selected(selection, &model, &iter);
 		record = new_packet_list_get_record(model, &iter);
 		for(col = 0; col < cfile.cinfo.num_cols; ++col) {
 			if(col != 0) {
@@ -818,15 +902,17 @@ new_packet_list_copy_summary_cb(GtkWidget * w _U_, gpointer data _U_, gint copy_
 void
 new_packet_list_recent_write_all(FILE *rf)
 {
-	gint col, width;
+	gint col, width, num_cols, col_fmt;
 	GtkTreeViewColumn *tree_column;
 
 	fprintf (rf, "%s:", RECENT_KEY_COL_WIDTH);
-	for (col = 0; col < cfile.cinfo.num_cols; col++) {
-		if (cfile.cinfo.col_fmt[col] == COL_CUSTOM) {
+	num_cols = g_list_length(prefs.col_list);
+	for (col = 0; col < num_cols; col++) {
+		col_fmt = get_column_format(col);
+		if (col_fmt == COL_CUSTOM) {
 			fprintf (rf, " %%Cus:%s,", get_column_custom_field(col));
 		} else {
-			fprintf (rf, " %s,", col_format_to_string(cfile.cinfo.col_fmt[col]));
+			fprintf (rf, " %s,", col_format_to_string(col_fmt));
 		}
 		tree_column = gtk_tree_view_get_column(GTK_TREE_VIEW(GTK_TREE_VIEW(packetlist->view)), col);
 		width = gtk_tree_view_column_get_width(tree_column);
@@ -835,7 +921,7 @@ new_packet_list_recent_write_all(FILE *rf)
 			width = recent_get_column_width (col);
 		}
 		fprintf (rf, " %d", width);
-		if (col != cfile.cinfo.num_cols-1) {
+		if (col != num_cols-1) {
 			fprintf (rf, ",");
 		}
 	}
