@@ -1,8 +1,9 @@
 /* packet_list_store.c
  * Routines to implement a custom GTK+ list model for Wireshark's packet list
  * Copyright 2008-2009, Stephen Fisher (see AUTHORS file)
+ * * Co-authors Anders Broman and Kovarththanan Rajaratnam.
  *
- * $Id: packet_list_store.c 29868 2009-09-11 20:36:01Z gerald $
+ * $Id: packet_list_store.c 30685 2009-10-24 15:51:10Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -387,7 +388,7 @@ packet_list_get_value(GtkTreeModel *tree_model, GtkTreeIter *iter, gint column,
 			g_value_set_string(value, record->fdata->col_text[column]);
 			break;
 		default:
-			g_warning ("%s: Unsupported type (%s) retrieved.", G_STRLOC, g_type_name (value->g_type));
+			g_warning (G_STRLOC ": Unsupported type (%s) retrieved.", g_type_name (value->g_type));
 			break;
 	}
 }
@@ -664,6 +665,7 @@ void
 packet_list_change_record(PacketList *packet_list, guint row, gint col, column_info *cinfo)
 {
 	PacketListRecord *record;
+	gchar *str;
 
 	g_return_if_fail(packet_list);
 	g_return_if_fail(PACKETLIST_IS_LIST(packet_list));
@@ -726,9 +728,12 @@ packet_list_change_record(PacketList *packet_list, guint row, gint col, column_i
 		/* !! FALL-THROUGH!! */
 
 		default:
+			if(!packet_list->string_pool)
+				packet_list->string_pool = g_string_chunk_new(32);
+
 			record->fdata->col_text_len[col] = (guint) strlen(cinfo->col_data[col]);
-			record->fdata->col_text[col] = se_memdup(cinfo->col_data[col],
-													 record->fdata->col_text_len[col] + 1);
+			str = g_string_chunk_insert_const (packet_list->string_pool,  (const gchar *)cinfo->col_data[col]);
+			record->fdata->col_text[col] = str;
 			break;
 	}
 }
@@ -881,8 +886,7 @@ packet_list_sortable_set_sort_func(GtkTreeSortable *sortable _U_,
 				   gpointer user_data _U_,
 				   GtkDestroyNotify destroy_func _U_)
 {
-	g_warning("%s is not supported by the PacketList model.\n",
-		  __FUNCTION__);
+	g_warning(G_STRLOC ": is not supported by the PacketList model.\n");
 }
 
 static void
@@ -891,8 +895,7 @@ packet_list_sortable_set_default_sort_func(GtkTreeSortable *sortable _U_,
 					   gpointer user_data _U_,
 					   GtkDestroyNotify destroy_func _U_)
 {
-	g_warning("%s is not supported by the PacketList model.\n",
-		  __FUNCTION__);
+	g_warning(G_STRLOC ": is not supported by the PacketList model.\n");
 }
 
 static gboolean
@@ -914,11 +917,11 @@ packet_list_compare_records(gint sort_id, PacketListRecord *a,
 	g_assert(a->fdata->col_text[sort_id]);
 	g_assert(b->fdata->col_text[sort_id]);
 
+	if(a->fdata->col_text[sort_id] == b->fdata->col_text[sort_id])
+		return 0; /* not always NULL, but anyway no need to call strcmp() */
+
 	if((a->fdata->col_text[sort_id]) && (b->fdata->col_text[sort_id]))
 		return strcmp(a->fdata->col_text[sort_id], b->fdata->col_text[sort_id]);
-
-	if(a->fdata->col_text[sort_id] == b->fdata->col_text[sort_id])
-		return 0; /* both are NULL */
 	else
 		return (a->fdata->col_text[sort_id] == NULL) ? -1 : 1;
 
