@@ -2,7 +2,7 @@
  * Recent "preference" handling routines
  * Copyright 2004, Ulf Lamping <ulf.lamping@web.de>
  *
- * $Id: recent.c 27718 2009-03-13 22:06:48Z stig $
+ * $Id: recent.c 29684 2009-09-03 11:37:12Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -44,9 +44,13 @@
 
 #include "gtk/recent.h"
 #include "gtk/main.h"
-#include "gtk/main_menu.h"
+#include "gtk/menus.h"
 #include "gtk/gui_utils.h"
+#ifdef NEW_PACKET_LIST
+#include "gtk/new_packet_list.h"
+#else
 #include "gtk/main_packet_list.h"
+#endif /*NEW_PACKET_LIST */
 #include "gtk/file_dlg.h"
 #include "gtk/cfilter_combo_utils.h"
 #include "gtk/u3.h"
@@ -128,7 +132,7 @@ free_col_width_info(recent_settings_t *rs)
   rs->col_width_list = NULL;
 }
 
-/* Attempt to Write out "recent" to the user's recent file.
+/* Attempt to Write out "recent common" to the user's recent common file.
    If we got an error report it with a dialog box and return FALSE,
    otherwise return TRUE. */
 gboolean
@@ -251,7 +255,7 @@ write_recent(void)
 }
 
 
-/* Attempt to Write out profile "recent" to the user's recent file.
+/* Attempt to Write out profile "recent" to the user's profile recent file.
    If we got an error report it with a dialog box and return FALSE,
    otherwise return TRUE. */
 gboolean
@@ -373,7 +377,11 @@ write_profile_recent(void)
 
   fprintf(rf, "\n# Packet list column pixel widths.\n");
   fprintf(rf, "# Each pair of strings consists of a column format and its pixel width.\n");
+#ifdef NEW_PACKET_LIST
+  new_packet_list_recent_write_all(rf);
+#else
   packet_list_recent_write_all(rf);
+#endif
 
   if (get_last_open_dir() != NULL) {
     fprintf(rf, "\n# Last directory navigated to in File Open dialog.\n");
@@ -518,7 +526,7 @@ read_set_recent_pair_static(gchar *key, gchar *value, void *private_data _U_)
   GList *col_l, *col_l_elt;
   col_width_data *cfmt;
   const gchar *cust_format = col_format_to_string(COL_CUSTOM);
-  int cust_format_len = strlen(cust_format);
+  int cust_format_len = (int) strlen(cust_format);
 
   if (strcmp(key, RECENT_KEY_MAIN_TOOLBAR_SHOW) == 0) {
     if (g_ascii_strcasecmp(value, "true") == 0) {
@@ -618,7 +626,8 @@ read_set_recent_pair_static(gchar *key, gchar *value, void *private_data _U_)
       return PREFS_SET_SYNTAX_ERR;	/* number must be positive */
     recent.gui_geometry_main_lower_pane = num;
     recent.has_gui_geometry_main_lower_pane = TRUE;
-  } else if (strcmp(key, RECENT_KEY_COL_WIDTH) == 0) {
+  }
+  else if (strcmp(key, RECENT_KEY_COL_WIDTH) == 0) {
     col_l = prefs_get_string_list(value);
     if (col_l == NULL)
       return PREFS_SET_SYNTAX_ERR;
@@ -749,7 +758,7 @@ recent_set_arg(char *prefarg)
 }
 
 
-/* opens the user's recent file and read the first part */
+/* opens the user's recent common file and read the first part */
 void
 recent_read_static(char **rf_path_return, int *rf_errno_return)
 {
@@ -772,10 +781,10 @@ recent_read_static(char **rf_path_return, int *rf_errno_return)
 
   recent.col_width_list = NULL;
 
-  /* Construct the pathname of the user's recent file. */
+  /* Construct the pathname of the user's recent common file. */
   rf_path = get_persconffile_path(RECENT_COMMON_FILE_NAME, FALSE, FALSE);
 
-  /* Read the user's recent file, if it exists. */
+  /* Read the user's recent common file, if it exists. */
   *rf_path_return = NULL;
   if ((rf = ws_fopen(rf_path, "r")) != NULL) {
     /* We succeeded in opening it; read it. */
@@ -830,7 +839,7 @@ recent_read_profile_static(char **rf_path_return, int *rf_errno_return)
     free_col_width_info(&recent);
   }
 
-  /* Construct the pathname of the user's recent file. */
+  /* Construct the pathname of the user's profile recent file. */
   rf_path = get_persconffile_path(RECENT_FILE_NAME, TRUE, FALSE);
 
   /* Read the user's recent file, if it exists. */
@@ -839,6 +848,15 @@ recent_read_profile_static(char **rf_path_return, int *rf_errno_return)
     /* We succeeded in opening it; read it. */
     read_prefs_file(rf_path, rf, read_set_recent_pair_static, NULL);
     fclose(rf);
+
+    /* XXX: The following code doesn't actually do anything since
+     *  the "recent common file" always exists. Presumably the 
+     *  "if (!file_exists())" should actually be "if (file_exists())".
+     *  However, I've left the code as is because this 
+     *  behaviour has existed for quite some time and I don't
+     *  know what's supposed to happen at this point.
+     *  ToDo: Determine if the "recent common file" should be read at this point
+     */
     rf_common_path = get_persconffile_path(RECENT_COMMON_FILE_NAME, FALSE, FALSE);
     if (!file_exists(rf_common_path)) {
       /* Read older common settings from recent file */
@@ -868,10 +886,10 @@ recent_read_dynamic(char **rf_path_return, int *rf_errno_return)
   FILE       *rf;
 
 
-  /* Construct the pathname of the user's recent file. */
+  /* Construct the pathname of the user's recent common file. */
   rf_path = get_persconffile_path(RECENT_COMMON_FILE_NAME, FALSE, FALSE);
   if (!file_exists (rf_path)) {
-    /* Recent common file does not exist, read from recent */
+    /* Recent common file does not exist, read from default recent */
     g_free (rf_path);
     rf_path = get_persconffile_path(RECENT_FILE_NAME, FALSE, FALSE);
   }
