@@ -1,7 +1,7 @@
 /* rtp_stream_dlg.c
  * RTP streams summary addition for Wireshark
  *
- * $Id: rtp_stream_dlg.c 27800 2009-03-19 17:49:11Z wmeier $
+ * $Id: rtp_stream_dlg.c 29747 2009-09-06 14:25:47Z krj $
  *
  * Copyright 2003, Alcatel Business Systems
  * By Lars Ruoff <lars.ruoff@gmx.net>
@@ -28,6 +28,8 @@
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
+
+#include <stdio.h>
 #include <string.h>
 #include <locale.h>
 
@@ -39,6 +41,7 @@
 
 #include "../globals.h"
 #include "../stat_menu.h"
+#include "../simple_dialog.h"
 
 #include "gtk/rtp_stream_dlg.h"
 #include "gtk/gui_stat_menu.h"
@@ -122,9 +125,9 @@ static void add_to_clist(rtp_stream_info_t* strinfo)
 		perc = 0;
 	}
 	data[7] = g_strdup_printf("%d (%.1f%%)", lost, perc);
-	data[8] = g_strdup_printf("%.2f", strinfo->rtp_stats.max_delta*1000);
-	data[9] = g_strdup_printf("%.2f", strinfo->rtp_stats.max_jitter*1000);
-	data[10] = g_strdup_printf("%.2f", strinfo->rtp_stats.mean_jitter*1000);
+	data[8] = g_strdup_printf("%.2f", strinfo->rtp_stats.max_delta);
+	data[9] = g_strdup_printf("%.2f", strinfo->rtp_stats.max_jitter);
+	data[10] = g_strdup_printf("%.2f", strinfo->rtp_stats.mean_jitter);
 	if (strinfo->problem)
 		data[11] = g_strdup("X");
 	else
@@ -156,32 +159,48 @@ static void save_stream_destroy_cb(GtkWidget *win _U_, gpointer user_data _U_)
 
 /****************************************************************************/
 /* save in a file */
-static void save_stream_ok_cb(GtkWidget *ok_bt _U_, gpointer fs _U_)
+static gboolean save_stream_ok_cb(GtkWidget *ok_bt _U_, gpointer fs)
 {
 	gchar *g_dest;
 
-	if (!selected_stream_fwd)
-		return;
+	if (!selected_stream_fwd) {
+		return TRUE;
+	}
 
-	g_dest = g_strdup(gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fs)));
+	g_dest = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fs));
 
 	/* Perhaps the user specified a directory instead of a file.
-	Check whether they did. */
+	   Check whether they did. */
 	if (test_for_directory(g_dest) == EISDIR) {
 		/* It's a directory - set the file selection box to display it. */
 		set_last_open_dir(g_dest);
 		g_free(g_dest);
-		file_selection_set_current_folder(rtpstream_save_dlg, get_last_open_dir());
-		return;
+		file_selection_set_current_folder(fs, get_last_open_dir());
+		gtk_file_chooser_set_current_name(fs, "");
+		return FALSE;
 	}
 
+#if 0 /* GtkFileChooser/gtk_dialog_run currently being used.         */
+      /*  So: Leaving the dialog box displayed after popping-up an   */
+      /*  alert box won't work.                                      */
 	/*
 	 * Don't dismiss the dialog box if the save operation fails.
 	 */
-	if (!rtpstream_save(selected_stream_fwd, g_dest))
+	if (!rtpstream_save(selected_stream_fwd, g_dest)) {
+		g_free(g_dest);
 		return;
-
+	}
+	g_free(g_dest);
 	window_destroy(GTK_WIDGET(rtpstream_save_dlg));
+	return;
+#else
+	/*  Dialog box needs to be always destroyed. Return TRUE      */
+	/*  so that caller will destroy the dialog box.               */
+	/*  See comment under rtpstream_on_save.                      */
+	rtpstream_save(selected_stream_fwd, g_dest);
+	g_free(g_dest);
+	return TRUE;
+#endif
 }
 
 
@@ -263,7 +282,7 @@ rtpstream_on_findrev		       (GtkButton	*button _U_,
 		row++) {
 		if (rtp_stream_info_cmp_reverse(selected_stream_fwd, pstream) == 0) {
 			gtk_clist_select_row(GTK_CLIST(clist), row, 0);
-			gtk_clist_moveto(GTK_CLIST(clist), row, 0, 0.5, 0);
+			gtk_clist_moveto(GTK_CLIST(clist), row, 0, 0.5f, 0);
 			return;
 		}
 	}
@@ -274,7 +293,7 @@ rtpstream_on_findrev		       (GtkButton	*button _U_,
 		row++) {
 		if (rtp_stream_info_cmp_reverse(selected_stream_fwd, pstream) == 0) {
 			gtk_clist_select_row(GTK_CLIST(clist), row, 0);
-			gtk_clist_moveto(GTK_CLIST(clist), row, 0, 0.5, 0);
+			gtk_clist_moveto(GTK_CLIST(clist), row, 0, 0.5f, 0);
 			return;
 		}
 	}
@@ -282,7 +301,7 @@ rtpstream_on_findrev		       (GtkButton	*button _U_,
 	/* if we didnt find another stream, highlight the current reverse stream */
 	if (selected_stream_rev!=NULL) {
 		gtk_clist_select_row(GTK_CLIST(clist), row, 0);
-		gtk_clist_moveto(GTK_CLIST(clist), row, 0, 0.5, 0);
+		gtk_clist_moveto(GTK_CLIST(clist), row, 0, 0.5f, 0);
 	}
 }
 
@@ -306,37 +325,65 @@ static void
 rtpstream_on_save                      (GtkButton       *button _U_,
                                         gpointer         data _U_)
 {
-/* XX - not neded?
+/* XX - not needed?
 	rtpstream_tapinfo_t* tapinfo = data;
 */
 
-	if (!selected_stream_fwd)
+    if (!selected_stream_fwd) {
+		simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
+			      "Please select a forward stream");
 		return;
+    }
 
+#if 0  /* XXX: GtkFileChooserDialog/gtk_dialog_run currently being used is effectively modal so this is not req'd */
 	if (rtpstream_save_dlg != NULL) {
 		/* There's already a Save dialog box; reactivate it. */
 		reactivate_window(rtpstream_save_dlg);
 		return;
 	}
+#endif
 
-	rtpstream_save_dlg = gtk_file_chooser_dialog_new("Wireshark: Save selected stream in rtpdump ('-F dump') format", GTK_WINDOW(rtp_stream_dlg), GTK_FILE_CHOOSER_ACTION_SAVE,
+	rtpstream_save_dlg = gtk_file_chooser_dialog_new(
+		"Wireshark: Save selected stream in rtpdump ('-F dump') format",
+		GTK_WINDOW(rtp_stream_dlg), GTK_FILE_CHOOSER_ACTION_SAVE,
 		GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 		NULL);
+#if GTK_CHECK_VERSION(2,8,0)
+	gtk_file_chooser_set_do_overwrite_confirmation(GTK_FILE_CHOOSER(rtpstream_save_dlg), TRUE);
+#endif
 
 	g_signal_connect(rtpstream_save_dlg, "delete_event", G_CALLBACK(window_delete_event_cb), NULL);
-	g_signal_connect(rtpstream_save_dlg, "destroy", G_CALLBACK(save_stream_destroy_cb),
-	               NULL);
+	g_signal_connect(rtpstream_save_dlg, "destroy", G_CALLBACK(save_stream_destroy_cb), NULL);
 
 	gtk_widget_show(rtpstream_save_dlg);
 	window_present(rtpstream_save_dlg);
-
+#if 0
 	if (gtk_dialog_run(GTK_DIALOG(rtpstream_save_dlg)) == GTK_RESPONSE_ACCEPT){
 		save_stream_ok_cb(rtpstream_save_dlg, rtpstream_save_dlg);
 	}else{
 		window_destroy(rtpstream_save_dlg);
 	}
-
+#endif
+	/* "Run" the GtkFileChooserDialog.                                              */
+        /* Upon exit: If "Accept" run the OK callback.                                  */
+        /*            If the OK callback returns with a FALSE status, re-run the dialog.*/
+        /*            If not accept (ie: cancel) destroy the window.                    */
+        /* XXX: If the OK callback pops up an alert box (eg: for an error) it *must*    */
+        /*      return with a TRUE status so that the dialog window will be destroyed.  */
+	/*      Trying to re-run the dialog after popping up an alert box will not work */
+        /*       since the user will not be able to dismiss the alert box.              */
+	/*      The (somewhat unfriendly) effect: the user must re-invoke the           */
+	/*      GtkFileChooserDialog whenever the OK callback pops up an alert box.     */
+	/*                                                                              */
+        /*      ToDo: use GtkFileChooserWidget in a dialog window instead of            */
+	/*            GtkFileChooserDialog.                                             */
+	while (gtk_dialog_run(GTK_DIALOG(rtpstream_save_dlg)) == GTK_RESPONSE_ACCEPT) {
+		if (save_stream_ok_cb(NULL, rtpstream_save_dlg)) {
+                    break; /* we're done */
+		}
+	}
+	window_destroy(rtpstream_save_dlg);
 }
 
 
@@ -368,17 +415,17 @@ rtpstream_on_filter                    (GtkButton       *button _U_,
 	{
 		if (selected_stream_fwd->src_addr.type==AT_IPv6){
 			g_strlcpy(ip_version,"v6",sizeof(ip_version));
-		}		
+		}
 		else{
 			ip_version[0] = '\0';
 		}
 		filter_string_fwd = g_strdup_printf(
 			"(ip%s.src==%s && udp.srcport==%u && ip%s.dst==%s && udp.dstport==%u && rtp.ssrc==0x%X)",
 			ip_version,
-			address_to_str(&(selected_stream_fwd->src_addr)),
+			ep_address_to_str(&(selected_stream_fwd->src_addr)),
 			selected_stream_fwd->src_port,
 			ip_version,
-			address_to_str(&(selected_stream_fwd->dest_addr)),
+			ep_address_to_str(&(selected_stream_fwd->dest_addr)),
 			selected_stream_fwd->dest_port,
 			selected_stream_fwd->ssrc);
         filter_string = filter_string_fwd;
@@ -386,34 +433,34 @@ rtpstream_on_filter                    (GtkButton       *button _U_,
 
 	if (selected_stream_rev)
 	{
-		if (selected_stream_fwd->src_addr.type==AT_IPv6){
+		if (selected_stream_rev->src_addr.type==AT_IPv6){
 			g_strlcpy(ip_version,"v6",sizeof(ip_version));
-		}		
+		}
 		else{
 			ip_version[0] = '\0';
 		}
 		filter_string_rev = g_strdup_printf(
 			"(ip%s.src==%s && udp.srcport==%u && ip%s.dst==%s && udp.dstport==%u && rtp.ssrc==0x%X)",
 			ip_version,
-			address_to_str(&(selected_stream_rev->src_addr)),
+			ep_address_to_str(&(selected_stream_rev->src_addr)),
 			selected_stream_rev->src_port,
 			ip_version,
-			address_to_str(&(selected_stream_rev->dest_addr)),
+			ep_address_to_str(&(selected_stream_rev->dest_addr)),
 			selected_stream_rev->dest_port,
 			selected_stream_rev->ssrc);
 
 		filter_string = filter_string_rev;
 
-	    if (selected_stream_fwd)
-	    {
-            filter_string = g_strdup_printf("%s || %s", filter_string, filter_string_rev);
-            g_free(filter_string_fwd);
-            g_free(filter_string_rev);
-        }
-    }
+		if (selected_stream_fwd)
+		{
+			filter_string = g_strdup_printf("%s || %s", filter_string, filter_string_rev);
+			g_free(filter_string_fwd);
+			g_free(filter_string_rev);
+		}
+	}
 
-    gtk_entry_set_text(GTK_ENTRY(main_display_filter_widget), filter_string);
-    g_free(filter_string);
+	gtk_entry_set_text(GTK_ENTRY(main_display_filter_widget), filter_string);
+	g_free(filter_string);
 
 /*
 	main_filter_packets(&cfile, filter_string, FALSE);
@@ -445,13 +492,13 @@ rtpstream_on_copy_as_csv(GtkWindow *win _U_, gpointer data _U_)
 			gtk_clist_get_text(GTK_CLIST(clist),i,j,&table_entry);
 			g_string_append(CSV_str,table_entry);
 			g_string_append(CSV_str,",");
-		} 
+		}
 		g_string_append(CSV_str,"\n");
 	}
 
 	/* Now that we have the CSV data, copy it into the default clipboard */
 	cb = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
-	gtk_clipboard_set_text(cb, CSV_str->str, CSV_str->len);
+	gtk_clipboard_set_text(cb, CSV_str->str, (gint) CSV_str->len);
 	g_string_free(CSV_str, TRUE);
 }
 
@@ -459,7 +506,7 @@ rtpstream_on_copy_as_csv(GtkWindow *win _U_, gpointer data _U_)
 static void
 rtpstream_on_analyse                   (GtkButton       *button _U_,
                                         gpointer         user_data _U_)
-{ 
+{
 	address ip_src_fwd;
 	guint16 port_src_fwd = 0;
 	address ip_dst_fwd;
@@ -475,12 +522,12 @@ rtpstream_on_analyse                   (GtkButton       *button _U_,
 	{
 		return;
 	}
-	
+
 	SET_ADDRESS(&ip_src_fwd,AT_NONE,0,NULL);
 	SET_ADDRESS(&ip_dst_fwd,AT_NONE,0,NULL);
 	SET_ADDRESS(&ip_src_rev,AT_NONE,0,NULL);
 	SET_ADDRESS(&ip_dst_rev,AT_NONE,0,NULL);
-	
+
 	if (selected_stream_fwd) {
 		COPY_ADDRESS(&(ip_src_fwd), &(selected_stream_fwd->src_addr));
 		port_src_fwd = selected_stream_fwd->src_port;
@@ -773,7 +820,7 @@ static void rtpstream_dlg_create (void)
     /*bt_copy = gtk_button_new_with_label ("Copy content to clipboard as CSV");*/
     bt_copy = gtk_button_new_from_stock(GTK_STOCK_COPY);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), bt_copy);
-    gtk_tooltips_set_tip(tooltips, bt_copy, 
+    gtk_tooltips_set_tip(tooltips, bt_copy,
         "Copy all statistical values of this page to the clipboard in CSV (Comma Separated Values) format.", NULL);
 
     bt_analyze = gtk_button_new_with_label ("Analyze");
@@ -879,6 +926,6 @@ static void rtpstream_launch(GtkWidget *w _U_, gpointer data _U_)
 void
 register_tap_listener_rtp_stream_dlg(void)
 {
-	register_stat_menu_item("RTP/Show All Streams", REGISTER_STAT_GROUP_TELEPHONY,
+	register_stat_menu_item("_RTP/Show All Streams", REGISTER_STAT_GROUP_TELEPHONY,
 	    rtpstream_launch, NULL, NULL, NULL);
 }
