@@ -1,7 +1,7 @@
 /* summary_dlg.c
  * Routines for capture file summary window
  *
- * $Id: summary_dlg.c 25634 2008-06-29 15:51:43Z wmeier $
+ * $Id: summary_dlg.c 28108 2009-04-21 16:57:52Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -69,13 +69,18 @@ add_string_to_table_sensitive(GtkWidget *list, guint *row, const gchar *title, c
         indent = g_strdup(title);
     }
     label = gtk_label_new(indent);
+    if (strlen(value) == 0) {
+      gchar *message = g_strdup_printf("<span weight=\"bold\">%s</span>", title);
+      gtk_label_set_markup(GTK_LABEL(label), message);
+      g_free (message);
+    }
     g_free(indent);
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+    gtk_misc_set_alignment(GTK_MISC(label), 0.0f, 0.5f);
     gtk_widget_set_sensitive(label, sensitive);
     gtk_table_attach_defaults(GTK_TABLE(list), label, 0, 1, *row, *row+1);
 
     label = gtk_label_new(value);
-    gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+    gtk_misc_set_alignment(GTK_MISC(label), 0.0f, 0.5f);
     gtk_widget_set_sensitive(label, sensitive);
     gtk_table_attach_defaults(GTK_TABLE(list), label, 1, 2, *row, *row+1);
 
@@ -158,9 +163,13 @@ summary_open_cb(GtkWidget *w _U_, gpointer d _U_)
   add_string_to_table(table, &row, "Length:", string_buff);
 
   /* format */
-  g_snprintf(string_buff, SUM_STR_MAX, "%s", wtap_file_type_string(summary.encap_type));
+  g_snprintf(string_buff, SUM_STR_MAX, "%s", wtap_file_type_string(summary.file_type));
   add_string_to_table(table, &row, "Format:", string_buff);
 
+  /* encapsulation */
+  g_snprintf(string_buff, SUM_STR_MAX, "%s", wtap_encap_string(summary.encap_type));
+  add_string_to_table(table, &row, "Encapsulation:", string_buff);
+
   if (summary.has_snap) {
     /* snapshot length */
     g_snprintf(string_buff, SUM_STR_MAX, "%u bytes", summary.snap);
@@ -384,7 +393,7 @@ summary_open_cb(GtkWidget *w _U_, gpointer d _U_)
 
   /* MBit per second */
   if (seconds > 0) {
-    g_snprintf(string_buff, SUM_STR_MAX, "%.3f", 
+    g_snprintf(string_buff, SUM_STR_MAX, "%.3f",
 	       /* MSVC cannot convert from unsigned __int64 to float, so first convert to signed __int64 */
 	       ((gint64) summary.bytes) * 8.0 / (seconds * 1000.0 * 1000.0));
   } else {
