@@ -1,7 +1,7 @@
 /* wsp_stat.c
  * wsp_stat   2003 Jean-Michel FAYARD
  *
- * $Id: wsp_stat.c 25933 2008-08-05 17:33:14Z morriss $
+ * $Id: wsp_stat.c 29028 2009-07-08 18:36:31Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -101,13 +101,13 @@ wsp_draw_statuscode(gchar *key _U_, wsp_status_code_t *data, gchar * unused _U_
 
 
 		/* Maybe we should display the hexadecimal value ? */
-		/* g_snprintf(string_buff, 256, "%s  (0X%x)", data->name, *key); */
+		/* g_snprintf(string_buff, sizeof(string_buff), "%s  (0X%x)", data->name, *key); */
 		tmp = gtk_label_new( data->name  /* string_buff */ );
 		gtk_table_attach_defaults(GTK_TABLE(data->sp->table_status_code), tmp, x, x+1, y, y+1);
 		gtk_label_set_justify(GTK_LABEL(tmp), GTK_JUSTIFY_LEFT);
 		gtk_widget_show(tmp);
 
-		g_snprintf( string_buff, 256, "%9d", data->packets );
+		g_snprintf( string_buff, sizeof(string_buff), "%9d", data->packets );
 		data->widget = gtk_label_new( string_buff );
 		gtk_table_attach_defaults(GTK_TABLE(data->sp->table_status_code), data->widget, x+1, x+2, y, y+1);
 		gtk_label_set_justify(GTK_LABEL(data->widget), GTK_JUSTIFY_LEFT);
@@ -116,8 +116,8 @@ wsp_draw_statuscode(gchar *key _U_, wsp_status_code_t *data, gchar * unused _U_
 		data->sp->index++;
 	} else {
 		/* Just update the label string */
-		g_snprintf( string_buff, 256, "%9d", data->packets );
-		gtk_label_set( GTK_LABEL(data->widget), string_buff);
+            g_snprintf( string_buff, sizeof(string_buff), "%9d", data->packets );
+		 gtk_label_set_text( GTK_LABEL(data->widget), string_buff);
 	}
 }
 static void
@@ -211,8 +211,8 @@ wspstat_draw(void *psp)
 
 	for(i=1;i<=sp->num_pdus ; i++)
 	{
-		g_snprintf(str, 256, "%9d",  sp->pdu_stats[i ].packets);
-		gtk_label_set( GTK_LABEL(sp->pdu_stats[i].widget), str);
+            g_snprintf(str, sizeof(str), "%9d",  sp->pdu_stats[i ].packets);
+		 gtk_label_set_text( GTK_LABEL(sp->pdu_stats[i].widget), str);
 	}
 
 	index=sp->index;
@@ -283,7 +283,7 @@ wsp_init_table(wspstat_t *sp)
 			x=2;
 		}
 		/* Maybe we should display the hexadecimal value ? */
-		/* g_snprintf(buffer, 50, "%s  (0X%x)", match_strval( index2pdut( i ), vals_pdu_type), index2pdut(i) );*/
+		/* g_snprintf(buffer, sizeof(buffer), "%s  (0X%x)", match_strval( index2pdut( i ), vals_pdu_type), index2pdut(i) );*/
 		add_table_entry( sp,
 				match_strval(index2pdut(i), vals_pdu_type), /* or buffer, */
 				x,
@@ -323,7 +323,9 @@ gtk_wspstat_init(const char *optarg, void *userdata _U_)
 	}
 
 	sp = g_malloc( sizeof(wspstat_t) );
-	sp->win = window_new(GTK_WINDOW_TOPLEVEL, "wsp-stat");
+	sp->win = dlg_window_new("wsp-stat");  /* transient_for top_level */
+	gtk_window_set_destroy_with_parent (GTK_WINDOW(sp->win), TRUE);
+
 	sp->hash = g_hash_table_new( g_int_hash, g_int_equal);
 	for (i=0 ; vals_status[i].strptr ; i++ )
 	{
@@ -385,12 +387,13 @@ gtk_wspstat_init(const char *optarg, void *userdata _U_)
 			"wsp",
 			sp,
 			filter,
+			0,
 			wspstat_reset,
 			wspstat_packet,
 			wspstat_draw);
 	if (error_string){
 		/* error, we failed to attach to the tap. clean up */
-		simple_dialog( ESD_TYPE_ERROR, ESD_BTN_OK, error_string->str );
+		simple_dialog( ESD_TYPE_ERROR, ESD_BTN_OK, "%s", error_string->str );
 		g_free(sp->pdu_stats);
 		g_free(sp->filter);
 		g_free(sp);
@@ -411,7 +414,8 @@ gtk_wspstat_init(const char *optarg, void *userdata _U_)
         gtk_widget_show_all(sp->win);
         window_present(sp->win);
 
-        cf_retap_packets(&cfile, FALSE);
+        cf_retap_packets(&cfile);
+	gdk_window_raise(sp->win->window);
 }
 
 static tap_dfilter_dlg wsp_stat_dlg = {
@@ -424,6 +428,6 @@ static tap_dfilter_dlg wsp_stat_dlg = {
 void
 register_tap_listener_gtkwspstat(void)
 {
-	register_dfilter_stat(&wsp_stat_dlg, "WAP-WSP",
+	register_dfilter_stat(&wsp_stat_dlg, "_WAP-WSP",
 	    REGISTER_STAT_GROUP_TELEPHONY);
 }
