@@ -2,7 +2,7 @@
  * Routines for Registration Acknowledge Message dissection
  * Copyright 2002, Anand V. Narwani <anand[AT]narwani.org>
  *
- * $Id: packet-regack.c 32662 2010-05-04 21:44:03Z gerald $
+ * $Id: packet-regack.c 30415 2009-10-09 07:24:33Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,14 +27,6 @@
 # include "config.h"
 #endif
 
-#include "moduleinfo.h"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-
-#include <gmodule.h>
-
 #include <epan/packet.h>
 
 /* Initialize the protocol and registered fields */
@@ -56,7 +48,7 @@ dissect_regack (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 {
 
   proto_item *it;
-  proto_tree *regack_tree;
+  proto_tree *regack_tree = NULL;
   guint16 sid;
   guint8 response;
   tvbuff_t *next_tvb;
@@ -69,7 +61,7 @@ dissect_regack (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
       col_clear (pinfo->cinfo, COL_INFO);
       col_add_fstr (pinfo->cinfo, COL_INFO,
 		    "Registration Acknowledge SID = %u (%s)", sid,
-		    val_to_str (response, docsis_conf_code, "%d"));
+		    val_to_str (response, docsis_conf_code, "%s"));
     }
   if (tree)
     {
@@ -82,10 +74,10 @@ dissect_regack (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
       proto_tree_add_item (regack_tree, hf_docsis_regack_response, tvb, 2, 1,
 			   FALSE);
 
-      /* Call Dissector for Appendix C TLV's */
-      next_tvb = tvb_new_subset (tvb, 3, -1, -1);
-      call_dissector (docsis_tlv_handle, next_tvb, pinfo, regack_tree);
     }
+    /* Call Dissector for Appendix C TLV's */
+    next_tvb = tvb_new_subset_remaining (tvb, 3);
+    call_dissector (docsis_tlv_handle, next_tvb, pinfo, regack_tree);
 
 }
 
@@ -107,18 +99,18 @@ proto_register_docsis_regack (void)
   static hf_register_info hf[] = {
     {&hf_docsis_regack,
      {"Registration Request", "docsis_regack",
-      FT_BYTES, BASE_HEX, NULL, 0x0,
-      "Registration Request", HFILL}
+      FT_BYTES, BASE_NONE, NULL, 0x0,
+      NULL, HFILL}
      },
     {&hf_docsis_regack_sid,
      {"Service Identifier", "docsis_regack.sid",
       FT_UINT16, BASE_DEC, NULL, 0x0,
-      "Service Identifier", HFILL}
+      NULL, HFILL}
      },
     {&hf_docsis_regack_response,
      {"Response Code", "docsis_regack.respnse",
       FT_UINT8, BASE_DEC, VALS (docsis_conf_code), 0x0,
-      "Response Code", HFILL}
+      NULL, HFILL}
      },
   };
 
