@@ -1,7 +1,7 @@
 /* packet-ethercat-frame.c
  * Routines for ethercat packet disassembly
  *
- * $Id: packet-ethercat-frame.c 26103 2008-08-29 01:40:32Z wmeier $
+ * $Id: packet-ethercat-frame.c 29492 2009-08-21 14:36:27Z wmeier $
  *
  * Copyright (c) 2007 by Beckhoff Automation GmbH
  *
@@ -30,23 +30,13 @@
 #include "config.h"
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <ctype.h>
-#include <time.h>
-#include <string.h>
-
 #include <glib.h>
 
 #include <epan/packet.h>
-#include <epan/addr_resolv.h>
-#include <epan/strutil.h>
 #include <epan/etypes.h>
 
 #include "packet-ethercat-frame.h"
 
-void proto_reg_handoff_ethercat_frame(void);
-
 /* Define the Ethercat frame proto */
 static int proto_ethercat_frame = -1;
 
@@ -84,15 +74,9 @@ static void dissect_ethercat_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree
    gint offset = 0;
    EtherCATFrameParserHDR hdr;
 
-   if (check_col(pinfo->cinfo, COL_PROTOCOL))
-   {
-      col_set_str(pinfo->cinfo, COL_PROTOCOL, "ECATF");
-   }
+   col_set_str(pinfo->cinfo, COL_PROTOCOL, "ECATF");
 
-   if (check_col(pinfo->cinfo, COL_INFO))
-   {
-      col_clear(pinfo->cinfo, COL_INFO);
-   }
+   col_clear(pinfo->cinfo, COL_INFO);
 
    if (tree)
    {
@@ -108,7 +92,7 @@ static void dissect_ethercat_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree
 
    /* The EtherCAT frame header has now been processed, allow sub dissectors to
       handle the rest of the PDU. */
-   next_tvb = tvb_new_subset (tvb, offset, -1, -1);
+   next_tvb = tvb_new_subset_remaining (tvb, offset);
 
    if (!dissector_try_port(ethercat_frame_dissector_table, hdr.v.protocol,
        next_tvb, pinfo, tree))
@@ -130,13 +114,13 @@ void proto_register_ethercat_frame(void)
       { &hf_ethercat_frame_length,
       { "Length", "ecatf.length",
       FT_UINT16, BASE_HEX, NULL, 0x07FF,
-      "", HFILL }
+      NULL, HFILL }
       },
 
       { &hf_ethercat_frame_reserved,
       { "Reserved", "ecatf.reserved",
       FT_UINT16, BASE_HEX, VALS(&ethercat_frame_reserved_vals), 0x0800,
-      "", HFILL}
+      NULL, HFILL}
       },
 
       { &hf_ethercat_frame_type,
@@ -166,9 +150,9 @@ void proto_register_ethercat_frame(void)
 
 void proto_reg_handoff_ethercat_frame(void)
 {
-   static dissector_handle_t ethercat_frame_handle;
+   dissector_handle_t ethercat_frame_handle;
 
-   ethercat_frame_handle = create_dissector_handle(dissect_ethercat_frame, proto_ethercat_frame);
+   ethercat_frame_handle = find_dissector("ecatf");
    dissector_add("ethertype", ETHERTYPE_ECATF, ethercat_frame_handle);
    dissector_add("udp.port", ETHERTYPE_ECATF, ethercat_frame_handle);
    dissector_add("tcp.port", ETHERTYPE_ECATF, ethercat_frame_handle);
