@@ -1,7 +1,7 @@
 /* packet-dcom-cba.c
  * Routines for DCOM CBA
  *
- * $Id: packet-dcom-cba.c 21158 2007-03-23 22:49:23Z sfisher $
+ * $Id: packet-dcom-cba.c 28771 2009-06-18 23:22:10Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1428,89 +1428,89 @@ proto_register_dcom_cba (void)
 {
 	static hf_register_info hf_cba_browse_array[] = {
 		{ &hf_cba_browse_count,
-		{ "Count",   "cba.browse.count", FT_UINT32, BASE_DEC, NULL, 0x0, "", HFILL }},
+		{ "Count",   "cba.browse.count", FT_UINT32, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_browse_offset,
-		{ "Offset",   "cba.browse.offset", FT_UINT32, BASE_DEC, NULL, 0x0, "", HFILL }},
+		{ "Offset",   "cba.browse.offset", FT_UINT32, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_browse_max_return,
-		{ "MaxReturn",   "cba.browse.max_return", FT_UINT32, BASE_DEC, NULL, 0x0, "", HFILL }},
+		{ "MaxReturn",   "cba.browse.max_return", FT_UINT32, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_browse_item,
-		{ "ItemNames", "cba.browse.item", FT_NONE, BASE_NONE, NULL, 0x0, "", HFILL }},
+		{ "ItemNames", "cba.browse.item", FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_browse_data_type,
-		{ "DataTypes", "cba.browse.data_type", FT_NONE, BASE_NONE, NULL, 0x0, "", HFILL }},
+		{ "DataTypes", "cba.browse.data_type", FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_browse_access_right,
-		{ "AccessRights", "cba.browse.access_right", FT_NONE, BASE_NONE, NULL, 0x0, "", HFILL }},
+		{ "AccessRights", "cba.browse.access_right", FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_browse_selector,
-		{ "Selector",   "cba.browse.selector", FT_UINT32, BASE_DEC, NULL, 0x0, "", HFILL }},
+		{ "Selector",   "cba.browse.selector", FT_UINT32, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_browse_info1,
-		{ "Info1", "cba.browse.info1", FT_NONE, BASE_NONE, NULL, 0x0, "", HFILL }},
+		{ "Info1", "cba.browse.info1", FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_browse_info2,
-		{ "Info2", "cba.browse.info2", FT_NONE, BASE_NONE, NULL, 0x0, "", HFILL }},
+		{ "Info2", "cba.browse.info2", FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL }},
 	};
 
 
 	static hf_register_info hf_cba_pdev_array[] = {
 		{ &hf_cba_revision_major,
-		{ "Major", "cba.revision_major", FT_UINT16, BASE_DEC, NULL, 0x0, "", HFILL }},
+		{ "Major", "cba.revision_major", FT_UINT16, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_revision_minor,
-		{ "Minor", "cba.revision_minor", FT_UINT16, BASE_DEC, NULL, 0x0, "", HFILL }},
+		{ "Minor", "cba.revision_minor", FT_UINT16, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_revision_service_pack,
-		{ "ServicePack", "cba.revision_service_pack", FT_UINT16, BASE_DEC, NULL, 0x0, "", HFILL }},
+		{ "ServicePack", "cba.revision_service_pack", FT_UINT16, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_revision_build,
-		{ "Build", "cba_revision_build", FT_UINT16, BASE_DEC, NULL, 0x0, "", HFILL }},
+		{ "Build", "cba_revision_build", FT_UINT16, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_producer,
-		{ "Producer", "cba.producer", FT_STRING, BASE_NONE, NULL, 0x0, "", HFILL }},
+		{ "Producer", "cba.producer", FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_product,
-		{ "Product", "cba.product", FT_STRING, BASE_NONE, NULL, 0x0, "", HFILL }},
+		{ "Product", "cba.product", FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_multi_app,
-		{ "MultiApp", "cba.multi_app", FT_UINT16, BASE_HEX, VALS(dcom_boolean_vals), 0x0, "", HFILL }},
+		{ "MultiApp", "cba.multi_app", FT_UINT16, BASE_HEX, VALS(dcom_boolean_vals), 0x0, NULL, HFILL }},
 		{ &hf_cba_profinet_dcom_stack,
-		{ "PROFInetDCOMStack", "cba.profinet_dcom_stack", FT_UINT16, BASE_HEX, VALS(dcom_boolean_vals), 0x0, "", HFILL }},
+		{ "PROFInetDCOMStack", "cba.profinet_dcom_stack", FT_UINT16, BASE_HEX, VALS(dcom_boolean_vals), 0x0, NULL, HFILL }},
 		{ &hf_cba_pdev_stamp,
-		{ "PDevStamp", "cba.pdev_stamp", FT_UINT32, BASE_HEX, NULL, 0x0, "", HFILL }},
+		{ "PDevStamp", "cba.pdev_stamp", FT_UINT32, BASE_HEX, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_save_ldev_name,
-		{ "LDevName", "cba.save_ldev_name", FT_NONE, BASE_NONE, NULL, 0x0, "", HFILL }},
+		{ "LDevName", "cba.save_ldev_name", FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_save_result,
-		{ "PatialResult", "cba.save_result", FT_NONE, BASE_NONE, NULL, 0x0, "", HFILL }},
+		{ "PartialResult", "cba.save_result", FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL }},
 	};
 
 	static hf_register_info hf_cba_ldev_array[] = {
 		{ &hf_cba_name,
-		{ "Name", "cba.name", FT_STRING, BASE_NONE, NULL, 0x0, "", HFILL }},
+		{ "Name", "cba.name", FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_component_id,
-		{ "ComponentID", "cba.component_id", FT_STRING, BASE_NONE, NULL, 0x0, "", HFILL }},
+		{ "ComponentID", "cba.component_id", FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_component_version,
-		{ "Version", "cba.component_version", FT_STRING, BASE_NONE, NULL, 0x0, "", HFILL }},
+		{ "Version", "cba.component_version", FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_pbaddress,
-		{ "PROFIBUS Address", "cba.pbaddress", FT_NONE, BASE_NONE, NULL, 0x0, "", HFILL }},
+		{ "PROFIBUS Address", "cba.pbaddress", FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_pbaddress_system_id,
-		{ "SystemID", "cba.pbaddress.system_id", FT_UINT8, BASE_HEX, NULL, 0x0, "", HFILL }},
+		{ "SystemID", "cba.pbaddress.system_id", FT_UINT8, BASE_HEX, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_pbaddress_address,
-		{ "Address", "cba.pbaddress.address", FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL }},
+		{ "Address", "cba.pbaddress.address", FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 	};
 
 	static hf_register_info hf_cba_array[] = {
         { &hf_cba_opnum,
-	    { "Operation", "cba.opnum", FT_UINT16, BASE_DEC, NULL, 0x0, "Operation", HFILL }},
+	    { "Operation", "cba.opnum", FT_UINT16, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_production_date,
-		{ "ProductionDate", "cba.production_date", FT_DOUBLE, BASE_NONE, NULL, 0x0, "", HFILL }},
+		{ "ProductionDate", "cba.production_date", FT_DOUBLE, BASE_NONE, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_time,
-		{ "Time", "cba.time", FT_DOUBLE, BASE_NONE, NULL, 0x0, "", HFILL }},
+		{ "Time", "cba.time", FT_DOUBLE, BASE_NONE, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_serial_no,
-		{ "SerialNo", "cba.serial_no", FT_NONE, BASE_NONE, NULL, 0x0, "", HFILL }},
+		{ "SerialNo", "cba.serial_no", FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_state,
-		{ "State",  "cba.state", FT_UINT16, BASE_HEX, VALS(cba_state_vals), 0x0, "", HFILL }},
+		{ "State",  "cba.state", FT_UINT16, BASE_HEX, VALS(cba_state_vals), 0x0, NULL, HFILL }},
 		{ &hf_cba_new_state,
-		{ "NewState",  "cba.state_new", FT_UINT16, BASE_HEX, VALS(cba_state_vals), 0x0, "", HFILL }},
+		{ "NewState",  "cba.state_new", FT_UINT16, BASE_HEX, VALS(cba_state_vals), 0x0, NULL, HFILL }},
 		{ &hf_cba_old_state,
-		{ "OldState",  "cba.state_old", FT_UINT16, BASE_HEX, VALS(cba_state_vals), 0x0, "", HFILL }},
+		{ "OldState",  "cba.state_old", FT_UINT16, BASE_HEX, VALS(cba_state_vals), 0x0, NULL, HFILL }},
 		{ &hf_cba_cookie,
-		{ "Cookie", "cba.cookie", FT_UINT32, BASE_HEX, NULL, 0x0, "", HFILL }},
+		{ "Cookie", "cba.cookie", FT_UINT32, BASE_HEX, NULL, 0x0, NULL, HFILL }},
 		{ &hf_cba_grouperror,
-		{ "GroupError", "cba.grouperror", FT_UINT16, BASE_HEX, VALS(cba_grouperror_vals), 0x0, "", HFILL }},
+		{ "GroupError", "cba.grouperror", FT_UINT16, BASE_HEX, VALS(cba_grouperror_vals), 0x0, NULL, HFILL }},
 		{ &hf_cba_new_grouperror,
-		{ "NewGroupError", "cba.grouperror_new", FT_UINT16, BASE_HEX, VALS(cba_grouperror_vals), 0x0, "", HFILL }},
+		{ "NewGroupError", "cba.grouperror_new", FT_UINT16, BASE_HEX, VALS(cba_grouperror_vals), 0x0, NULL, HFILL }},
 		{ &hf_cba_old_grouperror,
-		{ "OldGroupError", "cba.grouperror_old", FT_UINT16, BASE_HEX, VALS(cba_grouperror_vals), 0x0, "", HFILL }},
+		{ "OldGroupError", "cba.grouperror_old", FT_UINT16, BASE_HEX, VALS(cba_grouperror_vals), 0x0, NULL, HFILL }},
 	};
 
         static gint *ett_cba[] = {
