@@ -3,7 +3,7 @@
  * This is the base for other PROFINET protocols like IO, CBA, DCP, ...
  * (the "content subdissectors" will register themselves using a heuristic)
  *
- * $Id: packet-pn-rt.c 28934 2009-07-03 10:29:45Z tuexen $
+ * $Id: packet-pn-rt.c 30089 2009-09-23 14:52:01Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -356,9 +356,9 @@ dissect_pn_rt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
    * an exception.  We can set them (or append things) later again ....
    */
   if (check_col(pinfo->cinfo, COL_PROTOCOL))
-    col_add_str(pinfo->cinfo, COL_PROTOCOL, "PN-RT");
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "PN-RT");
   if (check_col(pinfo->cinfo, COL_INFO))
-    col_add_str(pinfo->cinfo, COL_INFO, "PROFINET Real-Time");
+    col_set_str(pinfo->cinfo, COL_INFO, "PROFINET Real-Time");
 
   if (tvb_len < 6) {
     dissect_pn_malformed(tvb, 0, pinfo, tree, tvb_len);
@@ -676,7 +676,7 @@ dissect_pn_rt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     /* ask heuristics, if some sub-dissector is interested in this packet payload */
     if(!dissector_try_heuristic(heur_subdissector_list, next_tvb, pinfo, tree)) {
         /*if (check_col(pinfo->cinfo, COL_INFO))
-              col_add_fstr(pinfo->cinfo, COL_INFO, "Unknown");*/
+              col_set_str(pinfo->cinfo, COL_INFO, "Unknown");*/
 
         /* Oh, well, we don't know this; dissect it as data. */
         dissect_pn_undecoded(next_tvb, 0, pinfo, tree, tvb_length(next_tvb));
