@@ -1,7 +1,7 @@
 /* packet-sercosiii_1v1_at.c
  * Routines for SERCOS III dissection
  *
- * $Id: packet-sercosiii_1v1_at.c 27082 2008-12-22 13:34:51Z wmeier $
+ * $Id: packet-sercosiii_1v1_at.c 29934 2009-09-15 18:20:56Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,10 +26,6 @@
 # include "config.h"
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-
 #include <glib.h>
 
 #include <epan/packet.h>
@@ -43,7 +39,7 @@ static gint ett_siii_at_devstats = -1;
 static gint ett_siii_at_svc_channel[MAX_SERCOS_DEVICES];
 static gint ett_siii_at_dev_status[MAX_SERCOS_DEVICES];
 
-void dissect_siii_at_cp0(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
+static void dissect_siii_at_cp0(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 {
   guint16 seqcnt; /* sequence counter */
   guint16 tfield; /* topology field for sercos addresses */
@@ -79,7 +75,7 @@ void dissect_siii_at_cp0(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree
   }
 }
 
-void dissect_siii_at_cp1_2(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint telno)
+static void dissect_siii_at_cp1_2(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint telno)
 {
   guint devstart = telno * 128; /* AT0: slaves 0-127; AT1: slaves 128-255; ... */
   tvbuff_t* tvb_n;
@@ -113,7 +109,7 @@ void dissect_siii_at_cp1_2(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
   }
 }
 
-void dissect_siii_at_cp3_4(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint telno)
+static void dissect_siii_at_cp3_4(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint telno)
 {
   proto_item* ti;
   proto_tree* subtree_svc;
@@ -145,8 +141,7 @@ void dissect_siii_at(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   phase = (tvb_get_guint8(tvb, 1)&0x8F); /* read communication phase out of SERCOS III header*/
   telno = (tvb_get_guint8(tvb, 0) & 0xF); /* read number of AT out of SERCOS III header */
 
-  if(check_col(pinfo->cinfo, COL_PROTOCOL))
-    col_set_str(pinfo->cinfo, COL_PROTOCOL, "SIII AT");
+  col_set_str(pinfo->cinfo, COL_PROTOCOL, "SIII AT");
 
   if(check_col(pinfo->cinfo, COL_INFO))
   {
@@ -182,7 +177,7 @@ void dissect_siii_at(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
     case COMMUNICATION_PHASE_3: /* CP3 */
     case COMMUNICATION_PHASE_4: /* CP4 */
-      tvb_n = tvb_new_subset(tvb, 6, -1, -1);
+      tvb_n = tvb_new_subset_remaining(tvb, 6);
       dissect_siii_at_cp3_4(tvb_n, pinfo, subtree, telno);
     break;
 
@@ -203,7 +198,7 @@ void dissect_siii_at_init(gint proto_siii _U_)
     &ett_siii_at_devstats
   };
 
-  static gint* etts[MAX_SERCOS_DEVICES];
+  gint* etts[MAX_SERCOS_DEVICES];
 
   for(idx = 0; idx < MAX_SERCOS_DEVICES; ++idx)
   {
