@@ -1,7 +1,7 @@
 /* print.c
  * Routines for printing packet analysis trees.
  *
- * $Id: print.c 29703 2009-09-04 21:35:02Z gerald $
+ * $Id: print.c 30361 2009-10-06 13:23:07Z stig $
  *
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
@@ -82,7 +82,6 @@ struct _output_fields {
 };
 
 static const gchar* get_field_hex_value(GSList* src_list, field_info *fi);
-const gchar* get_node_field_value(field_info* fi, epan_dissect_t* edt);
 static void proto_tree_print_node(proto_node *node, gpointer data);
 static void proto_tree_write_node_pdml(proto_node *node, gpointer data);
 static const guint8 *get_field_data(GSList *src_list, field_info *fi);
@@ -151,12 +150,14 @@ proto_tree_print(print_args_t *print_args, epan_dissect_t *edt,
 static
 void proto_tree_print_node(proto_node *node, gpointer data)
 {
-	field_info	*fi = PITEM_FINFO(node);
+	field_info	*fi = PNODE_FINFO(node);
 	print_data	*pdata = (print_data*) data;
 	const guint8	*pd;
 	gchar		label_str[ITEM_LABEL_LENGTH];
 	gchar		*label_ptr;
 
+	g_assert(fi && "dissection with an invisible proto tree?");
+
 	/* Don't print invisible entries. */
 	if (PROTO_ITEM_IS_HIDDEN(node))
 		return;
@@ -240,6 +241,10 @@ proto_tree_write_pdml(epan_dissect_t *edt, FILE *fh)
 	data.src_list = edt->pi.data_src;
 	data.edt = edt;
 
+	/* We shouldn't be called with a NULL pointer here because we've
+	 * created a visible protocol tree */
+	g_assert(data.src_list);
+
 	fprintf(fh, "<packet>\n");
 
 	/* Print a "geninfo" protocol as required by PDML */
@@ -255,17 +260,20 @@ proto_tree_write_pdml(epan_dissect_t *edt, FILE *fh)
 static void
 proto_tree_write_node_pdml(proto_node *node, gpointer data)
 {
-	field_info	*fi = PITEM_FINFO(node);
+	field_info	*fi = PNODE_FINFO(node);
 	write_pdml_data	*pdata = (write_pdml_data*) data;
 	const gchar	*label_ptr;
 	gchar		label_str[ITEM_LABEL_LENGTH];
 	char		*dfilter_string;
 	size_t		chop_len;
 	int		i;
+	gboolean wrap_in_fake_protocol;
+
+	g_assert(fi && "dissection with an invisible proto tree?");
 
 	/* Will wrap up top-level field items inside a fake protocol wrapper to
 	   preserve the PDML schema */
-	gboolean wrap_in_fake_protocol =
+	wrap_in_fake_protocol =
 	    (((fi->hfinfo->type != FT_PROTOCOL) ||
 	     (fi->hfinfo->id == proto_data)) &&
 	    (pdata->level == 0));
@@ -771,11 +779,15 @@ print_hex_data(print_stream_t *stream, epan_dissect_t *edt)
 	GSList *src_le;
 	data_source *src;
 	tvbuff_t *tvb;
-	char *name;
+	const char *name;
 	char *line;
 	const guchar *cp;
 	guint length;
 
+	/* We shouldn't be called with a NULL pointer here because we've
+	 * created a visible protocol tree */
+	g_assert(edt->pi.data_src);
+
 	/*
 	 * Set "multiple_sources" iff this frame has more than one
 	 * data source; if it does, we need to print the name of
@@ -789,7 +801,7 @@ print_hex_data(print_stream_t *stream, epan_dissect_t *edt)
 		src = src_le->data;
 		tvb = src->tvb;
 		if (multiple_sources) {
-			name = src->name;
+			name = get_data_source_name(src);
 			print_line(stream, 0, "");
 			line = g_strdup_printf("%s:", name);
 			print_line(stream, 0, line);
@@ -869,7 +881,6 @@ print_hex_data_buffer(print_stream_t *stream, const guchar *cp,
 			 * Start of a new line.
 			 */
 			j = 0;
-			k = 0;
 			l = use_digits;
 			do {
 				l--;
@@ -1059,17 +1070,12 @@ static const print_stream_ops_t print_text_ops = {
 	destroy_text
 };
 
-print_stream_t *
-print_stream_text_new(int to_file, const char *dest)
+static print_stream_t *
+print_stream_text_alloc(int to_file, FILE *fh)
 {
-	FILE *fh;
 	print_stream_t *stream;
 	output_text *output;
 
-	fh = open_print_dest(to_file, dest);
-	if (fh == NULL)
-		return NULL;
-
 	output = g_malloc(sizeof *output);
 	output->to_file = to_file;
 	output->fh = fh;
@@ -1080,20 +1086,22 @@ print_stream_text_new(int to_file, const char *dest)
 	return stream;
 }
 
+print_stream_t *
+print_stream_text_new(int to_file, const char *dest)
+{
+	FILE *fh;
+
+	fh = open_print_dest(to_file, dest);
+	if (fh == NULL)
+		return NULL;
+
+	return print_stream_text_alloc(to_file, fh);
+}
+
 print_stream_t *
 print_stream_text_stdio_new(FILE *fh)
 {
-	print_stream_t *stream;
-	output_text *output;
-
-	output = g_malloc(sizeof *output);
-	output->to_file = TRUE;
-	output->fh = fh;
-	stream = g_malloc(sizeof (print_stream_t));
-	stream->ops = &print_text_ops;
-	stream->data = output;
-
-	return stream;
+	return print_stream_text_alloc(TRUE, fh);
 }
 
 typedef struct {
@@ -1199,17 +1207,12 @@ static const print_stream_ops_t print_ps_ops = {
 	destroy_ps
 };
 
-print_stream_t *
-print_stream_ps_new(int to_file, const char *dest)
+static print_stream_t *
+print_stream_ps_alloc(int to_file, FILE *fh)
 {
-	FILE *fh;
 	print_stream_t *stream;
 	output_ps *output;
 
-	fh = open_print_dest(to_file, dest);
-	if (fh == NULL)
-		return NULL;
-
 	output = g_malloc(sizeof *output);
 	output->to_file = to_file;
 	output->fh = fh;
@@ -1220,20 +1223,22 @@ print_stream_ps_new(int to_file, const char *dest)
 	return stream;
 }
 
+print_stream_t *
+print_stream_ps_new(int to_file, const char *dest)
+{
+	FILE *fh;
+
+	fh = open_print_dest(to_file, dest);
+	if (fh == NULL)
+		return NULL;
+
+	return print_stream_ps_alloc(to_file, fh);
+}
+
 print_stream_t *
 print_stream_ps_stdio_new(FILE *fh)
 {
-	print_stream_t *stream;
-	output_ps *output;
-
-	output = g_malloc(sizeof *output);
-	output->to_file = TRUE;
-	output->fh = fh;
-	stream = g_malloc(sizeof (print_stream_t));
-	stream->ops = &print_ps_ops;
-	stream->data = output;
-
-	return stream;
+	return print_stream_ps_alloc(TRUE, fh);
 }
 
 output_fields_t* output_fields_new()
@@ -1407,7 +1412,9 @@ static void proto_tree_get_node_field_values(proto_node *node, gpointer data)
     gpointer field_index;
 
     call_data = data;
-    fi = PITEM_FINFO(node);
+    fi = PNODE_FINFO(node);
+
+    g_assert(fi && "dissection with an invisible proto tree?");
 
     field_index = g_hash_table_lookup(call_data->fields->field_indicies, fi->hfinfo->abbrev);
     if(NULL != field_index) {
