@@ -1,7 +1,7 @@
 /* proto_hier_stats.c
  * Routines for calculating statistics based on protocol.
  *
- * $Id: proto_hier_stats.c 23786 2007-12-06 18:10:35Z stig $
+ * $Id: proto_hier_stats.c 30047 2009-09-21 18:09:19Z krj $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,6 +26,8 @@
 # include "config.h"
 #endif
 
+#include <stdio.h>
+
 #include "globals.h"
 #include "proto_hier_stats.h"
 #include "progress_dlg.h"
@@ -85,8 +87,9 @@ process_node(proto_node *ptree_node, GNode *parent_stat_node, ph_stats_t *ps, gu
 	proto_node		*proto_sibling_node;
 	GNode			*stat_node;
 
-	finfo = PITEM_FINFO(ptree_node);
-	g_assert(finfo);
+	finfo = PNODE_FINFO(ptree_node);
+	/* We don't fake protocol nodes we expect them to have a field_info */
+	g_assert(finfo && "dissection with faked proto tree?");
 
 	/* If the field info isn't related to a protocol but to a field,
 	 * don't count them, as they don't belong to any protocol.
@@ -110,7 +113,7 @@ process_node(proto_node *ptree_node, GNode *parent_stat_node, ph_stats_t *ps, gu
 		 * not a normal protocol in the top-level tree.  It was instead
 		 * added as a normal tree such as IPv6's Hop-by-hop Option Header and
 		 * should be skipped when creating the protocol hierarchy display. */
-		if(strlen(proto_sibling_node->finfo->hfinfo->name) == 0 && ptree_node->next)
+		if(strlen(PNODE_FINFO(proto_sibling_node)->hfinfo->name) == 0 && ptree_node->next)
 			proto_sibling_node = proto_sibling_node->next;
 
 		process_node(proto_sibling_node, stat_node, ps, pkt_len);
@@ -138,7 +141,7 @@ process_tree(proto_tree *protocol_tree, ph_stats_t* ps, guint pkt_len)
 static gboolean
 process_frame(frame_data *frame, column_info *cinfo, ph_stats_t* ps)
 {
-	epan_dissect_t			*edt;
+	epan_dissect_t			edt;
 	union wtap_pseudo_header	phdr;
 	guint8				pd[WTAP_MAX_PACKET_SIZE];
 	int				err;
@@ -154,11 +157,13 @@ process_frame(frame_data *frame, column_info *cinfo, ph_stats_t* ps)
 	}
 
 	/* Dissect the frame   tree  not visible */
-	edt = epan_dissect_new(TRUE, FALSE);
-	epan_dissect_run(edt, &phdr, pd, frame, cinfo);
+	epan_dissect_init(&edt, TRUE, FALSE);
+	/* Don't fake protocols. We need them for the protocol hierarchy */
+	epan_dissect_fake_protocols(&edt, FALSE);
+	epan_dissect_run(&edt, &phdr, pd, frame, cinfo);
 
 	/* Get stats from this protocol tree */
-	process_tree(edt->tree, ps, frame->pkt_len);
+	process_tree(edt.tree, ps, frame->pkt_len);
 
 	/* Update times */
 	cur_time = nstime_to_sec(&frame->abs_ts);
@@ -170,7 +175,7 @@ process_frame(frame_data *frame, column_info *cinfo, ph_stats_t* ps)
 	}
 
 	/* Free our memory. */
-	epan_dissect_free(edt);
+	epan_dissect_cleanup(&edt);
 
 	return TRUE;	/* success */
 }
@@ -206,7 +211,7 @@ ph_stats_new(void)
 	/* Count of packets at which we've looked. */
 	count = 0;
 	/* Progress so far. */
-	progbar_val = 0.0;
+	progbar_val = 0.0f;
 
 	stop_flag = FALSE;
 	g_get_current_time(&start_time);
@@ -214,7 +219,7 @@ ph_stats_new(void)
 	tot_packets = 0;
 	tot_bytes = 0;
 
-	for (frame = cfile.plist; frame != NULL; frame = frame->next) {
+	for (frame = cfile.plist_start; frame != NULL; frame = frame->next) {
 		/* Create the progress bar if necessary.
 		   We check on every iteration of the loop, so that
 		   it takes no longer than the standard time to create
@@ -223,7 +228,7 @@ ph_stats_new(void)
 		   to get to the next progress bar step). */
 		if (progbar == NULL)
 			progbar = delayed_create_progress_dlg(
-			    "Computing", "protocol hierarchy statistics", 
+			    "Computing", "protocol hierarchy statistics",
 			    TRUE, &stop_flag, &start_time, progbar_val);
 
 		/* Update the progress bar, but do it only N_PROGBAR_UPDATES
@@ -267,7 +272,7 @@ ph_stats_new(void)
 				ps->first_time = cur_time;
 				ps->last_time = cur_time;
 			}
-			
+
 			/* we don't care about colinfo */
 			if (!process_frame(frame, NULL, ps)) {
 				/*
