@@ -4,7 +4,7 @@
  * Creates random packet traces. Useful for debugging sniffers by testing
  * assumptions about the veracity of the data found in the packet.
  *
- * $Id: randpkt.c 28388 2009-05-17 21:41:23Z gerald $
+ * $Id: randpkt.c 30370 2009-10-06 16:01:18Z stig $
  *
  * Copyright (C) 1999 by Gilbert Ramirez <gram@alumni.rice.edu>
  *
@@ -27,8 +27,10 @@
 #include "config.h"
 #endif
 
-#ifdef NEED_GETOPT_H
-#include "getopt.h"
+#ifdef HAVE_GETOPT_H
+#include <getopt.h>
+#else
+#include "wsgetopt.h"
 #endif
 
 #ifdef HAVE_UNISTD_H
@@ -500,9 +502,6 @@ main(int argc, char **argv)
 	guint8			buffer[65536];
 
 	int			opt;
-	extern char		*optarg;
-	extern int		optind;
-
 	int			produce_count = 1000; /* number of pkts to produce */
 	int			produce_type = PKT_ETHERNET;
 	char			*produce_filename = NULL;
